import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

import 'icon_forest.dart';

/// App crypto icons (30 icons)
///
/// - build svg for app_crypto_icons icon libraries
/// - constants link to svg icon resources
class GrommetIcons extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  const GrommetIcons(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return IconForest.svgAsset(
      'grommet_icons',
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  static const String accessibility = 'accessibility.svg';
  static const String achievement = 'achievement.svg';
  static const String action = 'action.svg';
  static const String actions = 'actions.svg';
  static const String ad = 'ad.svg';
  static const String add_circle = 'add_circle.svg';
  static const String add = 'add.svg';
  static const String aed = 'aed.svg';
  static const String aggregate = 'aggregate.svg';
  static const String aid_option = 'aid_option.svg';
  static const String aid = 'aid.svg';
  static const String alarm = 'alarm.svg';
  static const String alert = 'alert.svg';
  static const String amazon = 'amazon.svg';
  static const String amex = 'amex.svg';
  static const String analytics = 'analytics.svg';
  static const String anchor = 'anchor.svg';
  static const String android = 'android.svg';
  static const String announce = 'announce.svg';
  static const String apple_app_store = 'apple_app_store.svg';
  static const String apple = 'apple.svg';
  static const String apps_rounded = 'apps_rounded.svg';
  static const String apps = 'apps.svg';
  static const String archive = 'archive.svg';
  static const String archlinux = 'archlinux.svg';
  static const String article = 'article.svg';
  static const String aruba = 'aruba.svg';
  static const String ascend = 'ascend.svg';
  static const String ascending = 'ascending.svg';
  static const String assist_listening = 'assist_listening.svg';
  static const String atm = 'atm.svg';
  static const String attachment = 'attachment.svg';
  static const String attraction = 'attraction.svg';
  static const String baby = 'baby.svg';
  static const String back_ten = 'back_ten.svg';
  static const String bar_chart = 'bar_chart.svg';
  static const String bar = 'bar.svg';
  static const String basket = 'basket.svg';
  static const String beacon = 'beacon.svg';
  static const String bike = 'bike.svg';
  static const String bitcoin = 'bitcoin.svg';
  static const String blades_horizontal = 'blades_horizontal.svg';
  static const String blades_vertical = 'blades_vertical.svg';
  static const String block_quote = 'block_quote.svg';
  static const String blog = 'blog.svg';
  static const String bluetooth = 'bluetooth.svg';
  static const String bold = 'bold.svg';
  static const String book = 'book.svg';
  static const String bookmark = 'bookmark.svg';
  static const String bottom_corner = 'bottom_corner.svg';
  static const String braille = 'braille.svg';
  static const String briefcase = 'briefcase.svg';
  static const String brush = 'brush.svg';
  static const String bug = 'bug.svg';
  static const String bundle_ = 'bundle.svg';
  static const String bus = 'bus.svg';
  static const String business_service = 'business_service.svg';
  static const String cafeteria = 'cafeteria.svg';
  static const String calculator = 'calculator.svg';
  static const String calendar = 'calendar.svg';
  static const String camera = 'camera.svg';
  static const String capacity = 'capacity.svg';
  static const String car = 'car.svg';
  static const String caret_down_fill = 'caret_down_fill.svg';
  static const String caret_down = 'caret_down.svg';
  static const String caret_left_fill = 'caret_left_fill.svg';
  static const String caret_next = 'caret_next.svg';
  static const String caret_previous = 'caret_previous.svg';
  static const String caret_right_fill = 'caret_right_fill.svg';
  static const String caret_up_fill = 'caret_up_fill.svg';
  static const String caret_up = 'caret_up.svg';
  static const String cart = 'cart.svg';
  static const String catalog_option = 'catalog_option.svg';
  static const String catalog = 'catalog.svg';
  static const String centos = 'centos.svg';
  static const String certificate = 'certificate.svg';
  static const String channel = 'channel.svg';
  static const String chapter_add = 'chapter_add.svg';
  static const String chapter_next = 'chapter_next.svg';
  static const String chapter_previous = 'chapter_previous.svg';
  static const String chat_option = 'chat_option.svg';
  static const String chat = 'chat.svg';
  static const String checkbox_selected = 'checkbox_selected.svg';
  static const String checkbox = 'checkbox.svg';
  static const String checkmark = 'checkmark.svg';
  static const String chrome = 'chrome.svg';
  static const String circle_alert = 'circle_alert.svg';
  static const String circle_information = 'circle_information.svg';
  static const String circle_play = 'circle_play.svg';
  static const String circle_question = 'circle_question.svg';
  static const String clear_option = 'clear_option.svg';
  static const String clear = 'clear.svg';
  static const String cli = 'cli.svg';
  static const String clipboard = 'clipboard.svg';
  static const String clock = 'clock.svg';
  static const String clone = 'clone.svg';
  static const String close = 'close.svg';
  static const String closed_caption = 'closed_caption.svg';
  static const String cloud_computer = 'cloud_computer.svg';
  static const String cloud_download = 'cloud_download.svg';
  static const String cloud_software = 'cloud_software.svg';
  static const String cloud_upload = 'cloud_upload.svg';
  static const String cloud = 'cloud.svg';
  static const String cloudlinux = 'cloudlinux.svg';
  static const String cluster = 'cluster.svg';
  static const String coat_check = 'coat_check.svg';
  static const String code_sandbox = 'code_sandbox.svg';
  static const String code = 'code.svg';
  static const String codepen = 'codepen.svg';
  static const String coffee = 'coffee.svg';
  static const String columns = 'columns.svg';
  static const String command = 'command.svg';
  static const String compare = 'compare.svg';
  static const String compass = 'compass.svg';
  static const String compliance = 'compliance.svg';
  static const String configure = 'configure.svg';
  static const String connect = 'connect.svg';
  static const String connectivity = 'connectivity.svg';
  static const String console = 'console.svg';
  static const String contact_info = 'contact_info.svg';
  static const String contact = 'contact.svg';
  static const String contract = 'contract.svg';
  static const String copy = 'copy.svg';
  static const String cpu = 'cpu.svg';
  static const String creative_commons = 'creative_commons.svg';
  static const String credit_card = 'credit_card.svg';
  static const String css3 = 'css3.svg';
  static const String cube = 'cube.svg';
  static const String cubes = 'cubes.svg';
  static const String currency = 'currency.svg';
  static const String cursor = 'cursor.svg';
  static const String cut = 'cut.svg';
  static const String cycle = 'cycle.svg';
  static const String dashboard = 'dashboard.svg';
  static const String database = 'database.svg';
  static const String debian = 'debian.svg';
  static const String deliver = 'deliver.svg';
  static const String deploy = 'deploy.svg';
  static const String descend = 'descend.svg';
  static const String descending = 'descending.svg';
  static const String desktop = 'desktop.svg';
  static const String detach = 'detach.svg';
  static const String device = 'device.svg';
  static const String diamond = 'diamond.svg';
  static const String directions = 'directions.svg';
  static const String disabled_outline = 'disabled_outline.svg';
  static const String disc = 'disc.svg';
  static const String dislike = 'dislike.svg';
  static const String docker = 'docker.svg';
  static const String document_cloud = 'document_cloud.svg';
  static const String document_config = 'document_config.svg';
  static const String document_csv = 'document_csv.svg';
  static const String document_download = 'document_download.svg';
  static const String document_excel = 'document_excel.svg';
  static const String document_image = 'document_image.svg';
  static const String document_locked = 'document_locked.svg';
  static const String document_missing = 'document_missing.svg';
  static const String document_notes = 'document_notes.svg';
  static const String document_outlook = 'document_outlook.svg';
  static const String document_pdf = 'document_pdf.svg';
  static const String document_performance = 'document_performance.svg';
  static const String document_ppt = 'document_ppt.svg';
  static const String document_rtf = 'document_rtf.svg';
  static const String document_sound = 'document_sound.svg';
  static const String document_store = 'document_store.svg';
  static const String document_test = 'document_test.svg';
  static const String document_text = 'document_text.svg';
  static const String document_threat = 'document_threat.svg';
  static const String document_time = 'document_time.svg';
  static const String document_transfer = 'document_transfer.svg';
  static const String document_txt = 'document_txt.svg';
  static const String document_update = 'document_update.svg';
  static const String document_upload = 'document_upload.svg';
  static const String document_user = 'document_user.svg';
  static const String document_verified = 'document_verified.svg';
  static const String document_video = 'document_video.svg';
  static const String document_windows = 'document_windows.svg';
  static const String document_word = 'document_word.svg';
  static const String document_zip = 'document_zip.svg';
  static const String document = 'document.svg';
  static const String domain = 'domain.svg';
  static const String dos = 'dos.svg';
  static const String down = 'down.svg';
  static const String download_option = 'download_option.svg';
  static const String download = 'download.svg';
  static const String drag = 'drag.svg';
  static const String drawer = 'drawer.svg';
  static const String dribbble = 'dribbble.svg';
  static const String drive_cage = 'drive_cage.svg';
  static const String dropbox = 'dropbox.svg';
  static const String duplicate = 'duplicate.svg';
  static const String dxc = 'dxc.svg';
  static const String ebay = 'ebay.svg';
  static const String edge = 'edge.svg';
  static const String edit = 'edit.svg';
  static const String eject = 'eject.svg';
  static const String elevator = 'elevator.svg';
  static const String emergency = 'emergency.svg';
  static const String emoji = 'emoji.svg';
  static const String empty_circle = 'empty_circle.svg';
  static const String erase = 'erase.svg';
  static const String escalator = 'escalator.svg';
  static const String expand = 'expand.svg';
  static const String ezmeral = 'ezmeral.svg';
  static const String facebook_option = 'facebook_option.svg';
  static const String facebook = 'facebook.svg';
  static const String fan_option = 'fan_option.svg';
  static const String fan = 'fan.svg';
  static const String fast_forward = 'fast_forward.svg';
  static const String favorite = 'favorite.svg';
  static const String fedora = 'fedora.svg';
  static const String figma = 'figma.svg';
  static const String filter = 'filter.svg';
  static const String finger_print = 'finger_print.svg';
  static const String fireball = 'fireball.svg';
  static const String firefox = 'firefox.svg';
  static const String firewall = 'firewall.svg';
  static const String flag_fill = 'flag_fill.svg';
  static const String flag = 'flag.svg';
  static const String flows = 'flows.svg';
  static const String folder_cycle = 'folder_cycle.svg';
  static const String folder_open = 'folder_open.svg';
  static const String folder = 'folder.svg';
  static const String form_add = 'form_add.svg';
  static const String form_attachment = 'form_attachment.svg';
  static const String form_calendar = 'form_calendar.svg';
  static const String form_checkmark = 'form_checkmark.svg';
  static const String form_clock = 'form_clock.svg';
  static const String form_close = 'form_close.svg';
  static const String form_cut = 'form_cut.svg';
  static const String form_down = 'form_down.svg';
  static const String form_edit = 'form_edit.svg';
  static const String form_filter = 'form_filter.svg';
  static const String form_folder = 'form_folder.svg';
  static const String form_location = 'form_location.svg';
  static const String form_lock = 'form_lock.svg';
  static const String form_next_link = 'form_next_link.svg';
  static const String form_next = 'form_next.svg';
  static const String form_previous_link = 'form_previous_link.svg';
  static const String form_previous = 'form_previous.svg';
  static const String form_refresh = 'form_refresh.svg';
  static const String form_schedule = 'form_schedule.svg';
  static const String form_search = 'form_search.svg';
  static const String form_subtract = 'form_subtract.svg';
  static const String form_trash = 'form_trash.svg';
  static const String form_up = 'form_up.svg';
  static const String form_upload = 'form_upload.svg';
  static const String form_view_hide = 'form_view_hide.svg';
  static const String form_view = 'form_view.svg';
  static const String forward_ten = 'forward_ten.svg';
  static const String freebsd = 'freebsd.svg';
  static const String gallery = 'gallery.svg';
  static const String gamepad = 'gamepad.svg';
  static const String gateway = 'gateway.svg';
  static const String gatsbyjs = 'gatsbyjs.svg';
  static const String gem = 'gem.svg';
  static const String gift = 'gift.svg';
  static const String github = 'github.svg';
  static const String globe = 'globe.svg';
  static const String golang = 'golang.svg';
  static const String google_play = 'google_play.svg';
  static const String google_plus = 'google_plus.svg';
  static const String google_wallet = 'google_wallet.svg';
  static const String google = 'google.svg';
  static const String graph_ql = 'graph_ql.svg';
  static const String gremlin = 'gremlin.svg';
  static const String grid = 'grid.svg';
  static const String grommet = 'grommet.svg';
  static const String group = 'group.svg';
  static const String grow = 'grow.svg';
  static const String hadoop = 'hadoop.svg';
  static const String halt = 'halt.svg';
  static const String help_option = 'help_option.svg';
  static const String help = 'help.svg';
  static const String heroku = 'heroku.svg';
  static const String hide = 'hide.svg';
  static const String history = 'history.svg';
  static const String home_option = 'home_option.svg';
  static const String home_rounded = 'home_rounded.svg';
  static const String home = 'home.svg';
  static const String horton = 'horton.svg';
  static const String host_maintenance = 'host_maintenance.svg';
  static const String host = 'host.svg';
  static const String hp = 'hp.svg';
  static const String hpe_labs = 'hpe_labs.svg';
  static const String hpe = 'hpe.svg';
  static const String hpi = 'hpi.svg';
  static const String html5 = 'html5.svg';
  static const String ice_cream = 'ice_cream.svg';
  static const String image = 'image.svg';
  static const String impact = 'impact.svg';
  static const String in_progress = 'in_progress.svg';
  static const String inbox = 'inbox.svg';
  static const String indicator = 'indicator.svg';
  static const String info = 'info.svg';
  static const String inherit = 'inherit.svg';
  static const String insecure = 'insecure.svg';
  static const String inspect = 'inspect.svg';
  static const String instagram = 'instagram.svg';
  static const String install_option = 'install_option.svg';
  static const String install = 'install.svg';
  static const String integration = 'integration.svg';
  static const String internet_explorer = 'internet_explorer.svg';
  static const String italic = 'italic.svg';
  static const String iteration = 'iteration.svg';
  static const String java = 'java.svg';
  static const String js = 'js.svg';
  static const String key_ = 'key.svg';
  static const String keyboard = 'keyboard.svg';
  static const String language = 'language.svg';
  static const String lastfm = 'lastfm.svg';
  static const String launch = 'launch.svg';
  static const String layer = 'layer.svg';
  static const String license = 'license.svg';
  static const String like = 'like.svg';
  static const String line_chart = 'line_chart.svg';
  static const String link_bottom = 'link_bottom.svg';
  static const String link_down = 'link_down.svg';
  static const String link_next = 'link_next.svg';
  static const String link_previous = 'link_previous.svg';
  static const String link_top = 'link_top.svg';
  static const String link_up = 'link_up.svg';
  static const String link = 'link.svg';
  static const String linkedin_option = 'linkedin_option.svg';
  static const String linkedin = 'linkedin.svg';
  static const String list = 'list.svg';
  static const String local = 'local.svg';
  static const String location_pin = 'location_pin.svg';
  static const String location = 'location.svg';
  static const String lock = 'lock.svg';
  static const String login = 'login.svg';
  static const String logout = 'logout.svg';
  static const String lounge = 'lounge.svg';
  static const String magic = 'magic.svg';
  static const String mail_option = 'mail_option.svg';
  static const String mail = 'mail.svg';
  static const String mandriva = 'mandriva.svg';
  static const String manual = 'manual.svg';
  static const String map_location = 'map_location.svg';
  static const String map = 'map.svg';
  static const String mastercard = 'mastercard.svg';
  static const String medium = 'medium.svg';
  static const String memory = 'memory.svg';
  static const String menu = 'menu.svg';
  static const String microfocus = 'microfocus.svg';
  static const String microphone = 'microphone.svg';
  static const String money = 'money.svg';
  static const String monitor = 'monitor.svg';
  static const String monospace = 'monospace.svg';
  static const String moon = 'moon.svg';
  static const String more_vertical = 'more_vertical.svg';
  static const String more = 'more.svg';
  static const String mouse = 'mouse.svg';
  static const String multimedia = 'multimedia.svg';
  static const String multiple = 'multiple.svg';
  static const String music = 'music.svg';
  static const String mysql = 'mysql.svg';
  static const String navigate = 'navigate.svg';
  static const String network_drive = 'network_drive.svg';
  static const String network = 'network.svg';
  static const String new_window = 'new_window.svg';
  static const String new_ = 'new.svg';
  static const String next = 'next.svg';
  static const String node = 'node.svg';
  static const String nodes = 'nodes.svg';
  static const String norton = 'norton.svg';
  static const String note = 'note.svg';
  static const String notes = 'notes.svg';
  static const String notification = 'notification.svg';
  static const String npm = 'npm.svg';
  static const String object_group = 'object_group.svg';
  static const String object_ungroup = 'object_ungroup.svg';
  static const String offline_storage = 'offline_storage.svg';
  static const String onedrive = 'onedrive.svg';
  static const String opera = 'opera.svg';
  static const String optimize = 'optimize.svg';
  static const String oracle = 'oracle.svg';
  static const String ordered_list = 'ordered_list.svg';
  static const String organization = 'organization.svg';
  static const String overview = 'overview.svg';
  static const String package_ = 'package.svg';
  static const String paint = 'paint.svg';
  static const String pan = 'pan.svg';
  static const String pause_fill = 'pause_fill.svg';
  static const String pause = 'pause.svg';
  static const String paypal = 'paypal.svg';
  static const String performance = 'performance.svg';
  static const String personal_computer = 'personal_computer.svg';
  static const String phone_flip = 'phone_flip.svg';
  static const String phone_horizontal = 'phone_horizontal.svg';
  static const String phone_vertical = 'phone_vertical.svg';
  static const String phone = 'phone.svg';
  static const String pie_chart = 'pie_chart.svg';
  static const String pied_piper = 'pied_piper.svg';
  static const String pin = 'pin.svg';
  static const String pinterest = 'pinterest.svg';
  static const String plan = 'plan.svg';
  static const String play_fill = 'play_fill.svg';
  static const String play = 'play.svg';
  static const String plug = 'plug.svg';
  static const String pocket = 'pocket.svg';
  static const String power_cycle = 'power_cycle.svg';
  static const String power_force_shutdown = 'power_force_shutdown.svg';
  static const String power_reset = 'power_reset.svg';
  static const String power_shutdown = 'power_shutdown.svg';
  static const String power = 'power.svg';
  static const String previous = 'previous.svg';
  static const String print = 'print.svg';
  static const String product_hunt = 'product_hunt.svg';
  static const String projects = 'projects.svg';
  static const String qr = 'qr.svg';
  static const String radial_selected = 'radial_selected.svg';
  static const String radial = 'radial.svg';
  static const String raspberry = 'raspberry.svg';
  static const String reactjs = 'reactjs.svg';
  static const String reddit = 'reddit.svg';
  static const String redhat = 'redhat.svg';
  static const String redo = 'redo.svg';
  static const String refresh = 'refresh.svg';
  static const String resources = 'resources.svg';
  static const String restaurant = 'restaurant.svg';
  static const String restroom_men = 'restroom_men.svg';
  static const String restroom_women = 'restroom_women.svg';
  static const String restroom = 'restroom.svg';
  static const String resume = 'resume.svg';
  static const String return_ = 'return_.svg';
  static const String revert = 'revert.svg';
  static const String rewind = 'rewind.svg';
  static const String risk = 'risk.svg';
  static const String robot = 'robot.svg';
  static const String rotate_left = 'rotate_left.svg';
  static const String rotate_right = 'rotate_right.svg';
  static const String rss = 'rss.svg';
  static const String run = 'run.svg';
  static const String safari_option = 'safari_option.svg';
  static const String sans = 'sans.svg';
  static const String satellite = 'satellite.svg';
  static const String save = 'save.svg';
  static const String scan = 'scan.svg';
  static const String schedule_new = 'schedule_new.svg';
  static const String schedule_play = 'schedule_play.svg';
  static const String schedule = 'schedule.svg';
  static const String schedules = 'schedules.svg';
  static const String sco = 'sco.svg';
  static const String scorecard = 'scorecard.svg';
  static const String script = 'script.svg';
  static const String sd = 'sd.svg';
  static const String search_advanced = 'search_advanced.svg';
  static const String search = 'search.svg';
  static const String secure = 'secure.svg';
  static const String select = 'select.svg';
  static const String selection = 'selection.svg';
  static const String semantics = 'semantics.svg';
  static const String send = 'send.svg';
  static const String server_cluster = 'server_cluster.svg';
  static const String server = 'server.svg';
  static const String servers = 'servers.svg';
  static const String service_play = 'service_play.svg';
  static const String services = 'services.svg';
  static const String settings_option = 'settings_option.svg';
  static const String share_option = 'share_option.svg';
  static const String share_rounded = 'share_rounded.svg';
  static const String share = 'share.svg';
  static const String shield_security = 'shield_security.svg';
  static const String shield = 'shield.svg';
  static const String shift = 'shift.svg';
  static const String shop = 'shop.svg';
  static const String sidebar = 'sidebar.svg';
  static const String sign = 'sign.svg';
  static const String skype = 'skype.svg';
  static const String slack = 'slack.svg';
  static const String snapchat = 'snapchat.svg';
  static const String solaris = 'solaris.svg';
  static const String sort = 'sort.svg';
  static const String soundcloud = 'soundcloud.svg';
  static const String spa = 'spa.svg';
  static const String spectrum = 'spectrum.svg';
  static const String split = 'split.svg';
  static const String splits = 'splits.svg';
  static const String spotify = 'spotify.svg';
  static const String square = 'square.svg';
  static const String stack_overflow = 'stack_overflow.svg';
  static const String stakeholder = 'stakeholder.svg';
  static const String star_half = 'star_half.svg';
  static const String star = 'star.svg';
  static const String status_critical_small = 'status_critical_small.svg';
  static const String status_critical = 'status_critical.svg';
  static const String status_disabled_small = 'status_disabled_small.svg';
  static const String status_disabled = 'status_disabled.svg';
  static const String status_good_small = 'status_good_small.svg';
  static const String status_good = 'status_good.svg';
  static const String status_info_small = 'status_info_small.svg';
  static const String status_info = 'status_info.svg';
  static const String status_placeholder_small = 'status_placeholder_small.svg';
  static const String status_placeholder = 'status_placeholder.svg';
  static const String status_unknown_small = 'status_unknown_small.svg';
  static const String status_unknown = 'status_unknown.svg';
  static const String status_warning_small = 'status_warning_small.svg';
  static const String status_warning = 'status_warning.svg';
  static const String steps_option = 'steps_option.svg';
  static const String steps = 'steps.svg';
  static const String stop_fill = 'stop_fill.svg';
  static const String stop = 'stop.svg';
  static const String storage = 'storage.svg';
  static const String street_view = 'street_view.svg';
  static const String strike_through = 'strike_through.svg';
  static const String stripe = 'stripe.svg';
  static const String subscript = 'subscript.svg';
  static const String subtract_circle = 'subtract_circle.svg';
  static const String subtract = 'subtract.svg';
  static const String sun = 'sun.svg';
  static const String superscript = 'superscript.svg';
  static const String support = 'support.svg';
  static const String suse = 'suse.svg';
  static const String swift = 'swift.svg';
  static const String swim = 'swim.svg';
  static const String switch_ = 'switch.svg';
  static const String sync = 'sync.svg';
  static const String system = 'system.svg';
  static const String table_add = 'table_add.svg';
  static const String table = 'table.svg';
  static const String tag = 'tag.svg';
  static const String tape_option = 'tape_option.svg';
  static const String tape = 'tape.svg';
  static const String target = 'target.svg';
  static const String task = 'task.svg';
  static const String tasks = 'tasks.svg';
  static const String technology = 'technology.svg';
  static const String template = 'template.svg';
  static const String terminal = 'terminal.svg';
  static const String test_desktop = 'test_desktop.svg';
  static const String test = 'test.svg';
  static const String text_align_center = 'text_align_center.svg';
  static const String text_align_full = 'text_align_full.svg';
  static const String text_align_left = 'text_align_left.svg';
  static const String text_align_right = 'text_align_right.svg';
  static const String text_wrap = 'text_wrap.svg';
  static const String threats = 'threats.svg';
  static const String three_d_effects = 'three_d_effects.svg';
  static const String three_d = 'three_d.svg';
  static const String ticket = 'ticket.svg';
  static const String tictok = 'tictok.svg';
  static const String time = 'time.svg';
  static const String tip = 'tip.svg';
  static const String toast = 'toast.svg';
  static const String tools = 'tools.svg';
  static const String tooltip = 'tooltip.svg';
  static const String top_corner = 'top_corner.svg';
  static const String train = 'train.svg';
  static const String transaction = 'transaction.svg';
  static const String trash = 'trash.svg';
  static const String tree_option = 'tree_option.svg';
  static const String tree = 'tree.svg';
  static const String trigger = 'trigger.svg';
  static const String trophy = 'trophy.svg';
  static const String troubleshoot = 'troubleshoot.svg';
  static const String tty = 'tty.svg';
  static const String tumblr = 'tumblr.svg';
  static const String turbolinux = 'turbolinux.svg';
  static const String twitter = 'twitter.svg';
  static const String ubuntu = 'ubuntu.svg';
  static const String underline = 'underline.svg';
  static const String undo = 'undo.svg';
  static const String unlink = 'unlink.svg';
  static const String unlock = 'unlock.svg';
  static const String unordered_list = 'unordered_list.svg';
  static const String unsorted = 'unsorted.svg';
  static const String up = 'up.svg';
  static const String update = 'update.svg';
  static const String upgrade = 'upgrade.svg';
  static const String upload_option = 'upload_option.svg';
  static const String upload = 'upload.svg';
  static const String usb_key = 'usb_key.svg';
  static const String user_add = 'user_add.svg';
  static const String user_admin = 'user_admin.svg';
  static const String user_expert = 'user_expert.svg';
  static const String user_female = 'user_female.svg';
  static const String user_manager = 'user_manager.svg';
  static const String user_new = 'user_new.svg';
  static const String user_police = 'user_police.svg';
  static const String user_settings = 'user_settings.svg';
  static const String user_worker = 'user_worker.svg';
  static const String user = 'user.svg';
  static const String validate = 'validate.svg';
  static const String vend = 'vend.svg';
  static const String video = 'video.svg';
  static const String view = 'view.svg';
  static const String vimeo = 'vimeo.svg';
  static const String virtual_machine = 'virtual_machine.svg';
  static const String virtual_storage = 'virtual_storage.svg';
  static const String visa = 'visa.svg';
  static const String vm_maintenance = 'vm_maintenance.svg';
  static const String vmware = 'vmware.svg';
  static const String volume_control = 'volume_control.svg';
  static const String volume_low = 'volume_low.svg';
  static const String volume_mute = 'volume_mute.svg';
  static const String volume = 'volume.svg';
  static const String vulnerability = 'vulnerability.svg';
  static const String waypoint = 'waypoint.svg';
  static const String webcam = 'webcam.svg';
  static const String wheelchair_active = 'wheelchair_active.svg';
  static const String wheelchair = 'wheelchair.svg';
  static const String wifi_low = 'wifi_low.svg';
  static const String wifi_medium = 'wifi_medium.svg';
  static const String wifi_none = 'wifi_none.svg';
  static const String wifi = 'wifi.svg';
  static const String windows_legacy = 'windows_legacy.svg';
  static const String windows = 'windows.svg';
  static const String wordpress = 'wordpress.svg';
  static const String workshop = 'workshop.svg';
  static const String yoga = 'yoga.svg';
  static const String youtube = 'youtube.svg';
  static const String zoom_in = 'zoom_in.svg';
  static const String zoom_out = 'zoom_out.svg';
  static const String zoom = 'zoom.svg';
}
