import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

import 'icon_forest.dart';

/// App crypto icons (30 icons)
///
/// - build svg for app_crypto_icons icon libraries
/// - constants link to svg icon resources
class IconPark extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  const IconPark(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return IconForest.svgAsset(
      'icon_park',
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  static const String a_cane = 'a_cane.svg';
  static const String abdominal = 'abdominal.svg';
  static const String abnormal = 'abnormal.svg';
  static const String acceleration = 'acceleration.svg';
  static const String accept_email = 'accept_email.svg';
  static const String acoustic = 'acoustic.svg';
  static const String activity_source = 'activity_source.svg';
  static const String ad = 'ad.svg';
  static const String ad_product = 'ad_product.svg';
  static const String add = 'add.svg';
  static const String add_four = 'add_four.svg';
  static const String add_item = 'add_item.svg';
  static const String add_mode = 'add_mode.svg';
  static const String add_music = 'add_music.svg';
  static const String add_one = 'add_one.svg';
  static const String add_pic = 'add_pic.svg';
  static const String add_print = 'add_print.svg';
  static const String add_subset = 'add_subset.svg';
  static const String add_subtract = 'add_subtract.svg';
  static const String add_text = 'add_text.svg';
  static const String add_text_two = 'add_text_two.svg';
  static const String add_three = 'add_three.svg';
  static const String add_user = 'add_user.svg';
  static const String address_book = 'address_book.svg';
  static const String adjacent_item = 'adjacent_item.svg';
  static const String adjustment = 'adjustment.svg';
  static const String adobe_illustrate = 'adobe_illustrate.svg';
  static const String adobe_indesign = 'adobe_indesign.svg';
  static const String adobe_lightroom = 'adobe_lightroom.svg';
  static const String adobe_photoshop = 'adobe_photoshop.svg';
  static const String afferent = 'afferent.svg';
  static const String afferent_two = 'afferent_two.svg';
  static const String afro_pick = 'afro_pick.svg';
  static const String agreement = 'agreement.svg';
  static const String aiming = 'aiming.svg';
  static const String air_conditioning = 'air_conditioning.svg';
  static const String airplane_window = 'airplane_window.svg';
  static const String airplane_window_one = 'airplane_window_one.svg';
  static const String airplay = 'airplay.svg';
  static const String airpods = 'airpods.svg';
  static const String alarm = 'alarm.svg';
  static const String alarm_clock = 'alarm_clock.svg';
  static const String align_bottom = 'align_bottom.svg';
  static const String align_bottom_two = 'align_bottom_two.svg';
  static const String align_horizontal_center_two = 'align_horizontal_center_two.svg';
  static const String align_horizontally = 'align_horizontally.svg';
  static const String align_left = 'align_left.svg';
  static const String align_left_one = 'align_left_one.svg';
  static const String align_left_two = 'align_left_two.svg';
  static const String align_right = 'align_right.svg';
  static const String align_right_one = 'align_right_one.svg';
  static const String align_right_two = 'align_right_two.svg';
  static const String align_text_both = 'align_text_both.svg';
  static const String align_text_both_one = 'align_text_both_one.svg';
  static const String align_text_bottom = 'align_text_bottom.svg';
  static const String align_text_bottom_one = 'align_text_bottom_one.svg';
  static const String align_text_center = 'align_text_center.svg';
  static const String align_text_center_one = 'align_text_center_one.svg';
  static const String align_text_left = 'align_text_left.svg';
  static const String align_text_left_one = 'align_text_left_one.svg';
  static const String align_text_middle = 'align_text_middle.svg';
  static const String align_text_middle_one = 'align_text_middle_one.svg';
  static const String align_text_right = 'align_text_right.svg';
  static const String align_text_right_one = 'align_text_right_one.svg';
  static const String align_text_top = 'align_text_top.svg';
  static const String align_text_top_one = 'align_text_top_one.svg';
  static const String align_top = 'align_top.svg';
  static const String align_top_two = 'align_top_two.svg';
  static const String align_vertical_center_two = 'align_vertical_center_two.svg';
  static const String align_vertically = 'align_vertically.svg';
  static const String alignment_bottom_center = 'alignment_bottom_center.svg';
  static const String alignment_bottom_left = 'alignment_bottom_left.svg';
  static const String alignment_bottom_right = 'alignment_bottom_right.svg';
  static const String alignment_horizontal_bottom = 'alignment_horizontal_bottom.svg';
  static const String alignment_horizontal_center = 'alignment_horizontal_center.svg';
  static const String alignment_horizontal_top = 'alignment_horizontal_top.svg';
  static const String alignment_left_bottom = 'alignment_left_bottom.svg';
  static const String alignment_left_center = 'alignment_left_center.svg';
  static const String alignment_left_top = 'alignment_left_top.svg';
  static const String alignment_right_bottom = 'alignment_right_bottom.svg';
  static const String alignment_right_center = 'alignment_right_center.svg';
  static const String alignment_right_top = 'alignment_right_top.svg';
  static const String alignment_top_center = 'alignment_top_center.svg';
  static const String alignment_top_left = 'alignment_top_left.svg';
  static const String alignment_top_right = 'alignment_top_right.svg';
  static const String alignment_vertical_center = 'alignment_vertical_center.svg';
  static const String alignment_vertical_left = 'alignment_vertical_left.svg';
  static const String alignment_vertical_right = 'alignment_vertical_right.svg';
  static const String alipay = 'alipay.svg';
  static const String all_application = 'all_application.svg';
  static const String alphabetical_sorting = 'alphabetical_sorting.svg';
  static const String alphabetical_sorting_two = 'alphabetical_sorting_two.svg';
  static const String analysis = 'analysis.svg';
  static const String anchor = 'anchor.svg';
  static const String anchor_one = 'anchor_one.svg';
  static const String anchor_round = 'anchor_round.svg';
  static const String anchor_squre = 'anchor_squre.svg';
  static const String anchor_two = 'anchor_two.svg';
  static const String android = 'android.svg';
  static const String angry_face = 'angry_face.svg';
  static const String anguished_face = 'anguished_face.svg';
  static const String anti_corrosion = 'anti_corrosion.svg';
  static const String aperture_priority = 'aperture_priority.svg';
  static const String api = 'api.svg';
  static const String api_app = 'api_app.svg';
  static const String app_store = 'app_store.svg';
  static const String app_switch = 'app_switch.svg';
  static const String apple = 'apple.svg';
  static const String apple_one = 'apple_one.svg';
  static const String applet_closed = 'applet_closed.svg';
  static const String application = 'application.svg';
  static const String application_effect = 'application_effect.svg';
  static const String application_menu = 'application_menu.svg';
  static const String application_one = 'application_one.svg';
  static const String application_two = 'application_two.svg';
  static const String appointment = 'appointment.svg';
  static const String arc_de_triomphe = 'arc_de_triomphe.svg';
  static const String archers_bow = 'archers_bow.svg';
  static const String area_map = 'area_map.svg';
  static const String arena = 'arena.svg';
  static const String arithmetic = 'arithmetic.svg';
  static const String arithmetic_buttons = 'arithmetic_buttons.svg';
  static const String arithmetic_one = 'arithmetic_one.svg';
  static const String arrow_circle_down = 'arrow_circle_down.svg';
  static const String arrow_circle_left = 'arrow_circle_left.svg';
  static const String arrow_circle_right = 'arrow_circle_right.svg';
  static const String arrow_circle_up = 'arrow_circle_up.svg';
  static const String arrow_down = 'arrow_down.svg';
  static const String arrow_keys = 'arrow_keys.svg';
  static const String arrow_left = 'arrow_left.svg';
  static const String arrow_left_down = 'arrow_left_down.svg';
  static const String arrow_left_up = 'arrow_left_up.svg';
  static const String arrow_right = 'arrow_right.svg';
  static const String arrow_right_down = 'arrow_right_down.svg';
  static const String arrow_right_up = 'arrow_right_up.svg';
  static const String arrow_up = 'arrow_up.svg';
  static const String assembly_line = 'assembly_line.svg';
  static const String association = 'association.svg';
  static const String asterisk = 'asterisk.svg';
  static const String asterisk_key = 'asterisk_key.svg';
  static const String astonished_face = 'astonished_face.svg';
  static const String at_sign = 'at_sign.svg';
  static const String attention = 'attention.svg';
  static const String audio_file = 'audio_file.svg';
  static const String audit = 'audit.svg';
  static const String auto_focus = 'auto_focus.svg';
  static const String auto_height_one = 'auto_height_one.svg';
  static const String auto_line_height = 'auto_line_height.svg';
  static const String auto_line_width = 'auto_line_width.svg';
  static const String auto_width = 'auto_width.svg';
  static const String auto_width_one = 'auto_width_one.svg';
  static const String avatar = 'avatar.svg';
  static const String average = 'average.svg';
  static const String aviation = 'aviation.svg';
  static const String avocado = 'avocado.svg';
  static const String avocado_one = 'avocado_one.svg';
  static const String baby = 'baby.svg';
  static const String baby_app = 'baby_app.svg';
  static const String baby_bottle = 'baby_bottle.svg';
  static const String baby_car_seat = 'baby_car_seat.svg';
  static const String baby_feet = 'baby_feet.svg';
  static const String baby_meal = 'baby_meal.svg';
  static const String baby_mobile = 'baby_mobile.svg';
  static const String baby_one = 'baby_one.svg';
  static const String baby_pants = 'baby_pants.svg';
  static const String baby_sling = 'baby_sling.svg';
  static const String baby_taste = 'baby_taste.svg';
  static const String bachelor_cap = 'bachelor_cap.svg';
  static const String back = 'back.svg';
  static const String background_color = 'background_color.svg';
  static const String backpack = 'backpack.svg';
  static const String bad = 'bad.svg';
  static const String bad_one = 'bad_one.svg';
  static const String bad_two = 'bad_two.svg';
  static const String badge = 'badge.svg';
  static const String badge_two = 'badge_two.svg';
  static const String badminton = 'badminton.svg';
  static const String baggage_delay = 'baggage_delay.svg';
  static const String balance = 'balance.svg';
  static const String balance_one = 'balance_one.svg';
  static const String balance_two = 'balance_two.svg';
  static const String banana = 'banana.svg';
  static const String bank = 'bank.svg';
  static const String bank_card = 'bank_card.svg';
  static const String bank_card_one = 'bank_card_one.svg';
  static const String bank_card_two = 'bank_card_two.svg';
  static const String bank_transfer = 'bank_transfer.svg';
  static const String baokemeng = 'baokemeng.svg';
  static const String bar_code = 'bar_code.svg';
  static const String barbecue = 'barbecue.svg';
  static const String barber_brush = 'barber_brush.svg';
  static const String barber_clippers = 'barber_clippers.svg';
  static const String baseball = 'baseball.svg';
  static const String baseball_cap = 'baseball_cap.svg';
  static const String basketball = 'basketball.svg';
  static const String basketball_clothes = 'basketball_clothes.svg';
  static const String basketball_one = 'basketball_one.svg';
  static const String basketball_stand = 'basketball_stand.svg';
  static const String battery_charge = 'battery_charge.svg';
  static const String battery_empty = 'battery_empty.svg';
  static const String battery_full = 'battery_full.svg';
  static const String battery_working = 'battery_working.svg';
  static const String battery_working_one = 'battery_working_one.svg';
  static const String beach_umbrella = 'beach_umbrella.svg';
  static const String beauty = 'beauty.svg';
  static const String beauty_instrument = 'beauty_instrument.svg';
  static const String bedside = 'bedside.svg';
  static const String bedside_two = 'bedside_two.svg';
  static const String beer = 'beer.svg';
  static const String beer_mug = 'beer_mug.svg';
  static const String behance = 'behance.svg';
  static const String bell_ring = 'bell_ring.svg';
  static const String belt = 'belt.svg';
  static const String benz = 'benz.svg';
  static const String bezier_curve = 'bezier_curve.svg';
  static const String bib = 'bib.svg';
  static const String big_clock = 'big_clock.svg';
  static const String big_x = 'big_x.svg';
  static const String bike = 'bike.svg';
  static const String bill = 'bill.svg';
  static const String birthday_cake = 'birthday_cake.svg';
  static const String bitcoin = 'bitcoin.svg';
  static const String black_eight = 'black_eight.svg';
  static const String blade = 'blade.svg';
  static const String bless = 'bless.svg';
  static const String block = 'block.svg';
  static const String block_eight = 'block_eight.svg';
  static const String block_five = 'block_five.svg';
  static const String block_four = 'block_four.svg';
  static const String block_nine = 'block_nine.svg';
  static const String block_one = 'block_one.svg';
  static const String block_seven = 'block_seven.svg';
  static const String block_six = 'block_six.svg';
  static const String block_ten = 'block_ten.svg';
  static const String block_three = 'block_three.svg';
  static const String block_two = 'block_two.svg';
  static const String blockchain = 'blockchain.svg';
  static const String blocks_and_arrows = 'blocks_and_arrows.svg';
  static const String bluetooth = 'bluetooth.svg';
  static const String bolt_one = 'bolt_one.svg';
  static const String bone = 'bone.svg';
  static const String book = 'book.svg';
  static const String book_one = 'book_one.svg';
  static const String book_open = 'book_open.svg';
  static const String bookmark = 'bookmark.svg';
  static const String bookmark_one = 'bookmark_one.svg';
  static const String bookshelf = 'bookshelf.svg';
  static const String booster_car_seat = 'booster_car_seat.svg';
  static const String booth = 'booth.svg';
  static const String boots = 'boots.svg';
  static const String bottle = 'bottle.svg';
  static const String bottle_one = 'bottle_one.svg';
  static const String bottle_three = 'bottle_three.svg';
  static const String bottle_two = 'bottle_two.svg';
  static const String bottom_bar = 'bottom_bar.svg';
  static const String bottom_bar_one = 'bottom_bar_one.svg';
  static const String bow = 'bow.svg';
  static const String bowl = 'bowl.svg';
  static const String bowl_one = 'bowl_one.svg';
  static const String bowling = 'bowling.svg';
  static const String box = 'box.svg';
  static const String boxing = 'boxing.svg';
  static const String boxing_one = 'boxing_one.svg';
  static const String boy = 'boy.svg';
  static const String boy_one = 'boy_one.svg';
  static const String boy_stroller = 'boy_stroller.svg';
  static const String boy_two = 'boy_two.svg';
  static const String brain = 'brain.svg';
  static const String brake_pads = 'brake_pads.svg';
  static const String branch = 'branch.svg';
  static const String branch_one = 'branch_one.svg';
  static const String branch_two = 'branch_two.svg';
  static const String brdige_three = 'brdige_three.svg';
  static const String bread = 'bread.svg';
  static const String bread_machine = 'bread_machine.svg';
  static const String bread_one = 'bread_one.svg';
  static const String breast_pump = 'breast_pump.svg';
  static const String bridge_one = 'bridge_one.svg';
  static const String bridge_two = 'bridge_two.svg';
  static const String briefcase = 'briefcase.svg';
  static const String brightness = 'brightness.svg';
  static const String bring_forward = 'bring_forward.svg';
  static const String bring_to_front = 'bring_to_front.svg';
  static const String bring_to_front_one = 'bring_to_front_one.svg';
  static const String broadcast = 'broadcast.svg';
  static const String broadcast_one = 'broadcast_one.svg';
  static const String broadcast_radio = 'broadcast_radio.svg';
  static const String browser = 'browser.svg';
  static const String browser_chrome = 'browser_chrome.svg';
  static const String browser_safari = 'browser_safari.svg';
  static const String bubble_chart = 'bubble_chart.svg';
  static const String bug = 'bug.svg';
  static const String building_four = 'building_four.svg';
  static const String building_one = 'building_one.svg';
  static const String building_three = 'building_three.svg';
  static const String building_two = 'building_two.svg';
  static const String bullet_map = 'bullet_map.svg';
  static const String bus = 'bus.svg';
  static const String bus_two = 'bus_two.svg';
  static const String buy = 'buy.svg';
  static const String bydesign = 'bydesign.svg';
  static const String bye = 'bye.svg';
  static const String bytedance = 'bytedance.svg';
  static const String bytedance_mini_app = 'bytedance_mini_app.svg';
  static const String cable_car = 'cable_car.svg';
  static const String cake = 'cake.svg';
  static const String cake_five = 'cake_five.svg';
  static const String cake_four = 'cake_four.svg';
  static const String cake_one = 'cake_one.svg';
  static const String cake_three = 'cake_three.svg';
  static const String cake_two = 'cake_two.svg';
  static const String calculator = 'calculator.svg';
  static const String calculator_one = 'calculator_one.svg';
  static const String calendar = 'calendar.svg';
  static const String calendar_dot = 'calendar_dot.svg';
  static const String calendar_thirty = 'calendar_thirty.svg';
  static const String calendar_thirty_two = 'calendar_thirty_two.svg';
  static const String calendar_three = 'calendar_three.svg';
  static const String camera = 'camera.svg';
  static const String camera_five = 'camera_five.svg';
  static const String camera_four = 'camera_four.svg';
  static const String camera_one = 'camera_one.svg';
  static const String camera_three = 'camera_three.svg';
  static const String camera_two = 'camera_two.svg';
  static const String camp = 'camp.svg';
  static const String candy = 'candy.svg';
  static const String canned_fruit = 'canned_fruit.svg';
  static const String car = 'car.svg';
  static const String car_battery = 'car_battery.svg';
  static const String card_two = 'card_two.svg';
  static const String cardioelectric = 'cardioelectric.svg';
  static const String carousel = 'carousel.svg';
  static const String carousel_video = 'carousel_video.svg';
  static const String carrot = 'carrot.svg';
  static const String cast_screen = 'cast_screen.svg';
  static const String castle = 'castle.svg';
  static const String category_management = 'category_management.svg';
  static const String caution = 'caution.svg';
  static const String cc = 'cc.svg';
  static const String cd = 'cd.svg';
  static const String ce_marking = 'ce_marking.svg';
  static const String cell = 'cell.svg';
  static const String center_alignment = 'center_alignment.svg';
  static const String certificate = 'certificate.svg';
  static const String chafing_dish = 'chafing_dish.svg';
  static const String chafing_dish_one = 'chafing_dish_one.svg';
  static const String chair = 'chair.svg';
  static const String chair_one = 'chair_one.svg';
  static const String change = 'change.svg';
  static const String change_date_sort = 'change_date_sort.svg';
  static const String charging_treasure = 'charging_treasure.svg';
  static const String chart_graph = 'chart_graph.svg';
  static const String chart_histogram = 'chart_histogram.svg';
  static const String chart_histogram_one = 'chart_histogram_one.svg';
  static const String chart_histogram_two = 'chart_histogram_two.svg';
  static const String chart_line = 'chart_line.svg';
  static const String chart_line_area = 'chart_line_area.svg';
  static const String chart_pie = 'chart_pie.svg';
  static const String chart_pie_one = 'chart_pie_one.svg';
  static const String chart_proportion = 'chart_proportion.svg';
  static const String chart_ring = 'chart_ring.svg';
  static const String chart_scatter = 'chart_scatter.svg';
  static const String chart_stock = 'chart_stock.svg';
  static const String check = 'check.svg';
  static const String check_correct = 'check_correct.svg';
  static const String check_in = 'check_in.svg';
  static const String check_one = 'check_one.svg';
  static const String check_small = 'check_small.svg';
  static const String checkbox = 'checkbox.svg';
  static const String checkerboard = 'checkerboard.svg';
  static const String checklist = 'checklist.svg';
  static const String cheese = 'cheese.svg';
  static const String chef_hat = 'chef_hat.svg';
  static const String chef_hat_one = 'chef_hat_one.svg';
  static const String cherry = 'cherry.svg';
  static const String chess = 'chess.svg';
  static const String chess_one = 'chess_one.svg';
  static const String chest = 'chest.svg';
  static const String chicken = 'chicken.svg';
  static const String chicken_leg = 'chicken_leg.svg';
  static const String child_with_pacifier = 'child_with_pacifier.svg';
  static const String children_cap = 'children_cap.svg';
  static const String children_pyramid = 'children_pyramid.svg';
  static const String chili = 'chili.svg';
  static const String chimney = 'chimney.svg';
  static const String chinese = 'chinese.svg';
  static const String chinese_one = 'chinese_one.svg';
  static const String chinese_pavilion = 'chinese_pavilion.svg';
  static const String chip = 'chip.svg';
  static const String chopping_board = 'chopping_board.svg';
  static const String chopsticks_fork = 'chopsticks_fork.svg';
  static const String christmas_tree = 'christmas_tree.svg';
  static const String church_one = 'church_one.svg';
  static const String church_two = 'church_two.svg';
  static const String circle_double_down = 'circle_double_down.svg';
  static const String circle_double_left = 'circle_double_left.svg';
  static const String circle_double_right = 'circle_double_right.svg';
  static const String circle_double_up = 'circle_double_up.svg';
  static const String circle_five_line = 'circle_five_line.svg';
  static const String circle_four = 'circle_four.svg';
  static const String circle_four_line = 'circle_four_line.svg';
  static const String circle_house = 'circle_house.svg';
  static const String circle_left_down = 'circle_left_down.svg';
  static const String circle_left_up = 'circle_left_up.svg';
  static const String circle_right_down = 'circle_right_down.svg';
  static const String circle_right_up = 'circle_right_up.svg';
  static const String circle_three = 'circle_three.svg';
  static const String circle_two_line = 'circle_two_line.svg';
  static const String circles_and_triangles = 'circles_and_triangles.svg';
  static const String circles_seven = 'circles_seven.svg';
  static const String circular_connection = 'circular_connection.svg';
  static const String circus = 'circus.svg';
  static const String city = 'city.svg';
  static const String city_gate = 'city_gate.svg';
  static const String city_one = 'city_one.svg';
  static const String clap = 'clap.svg';
  static const String classroom = 'classroom.svg';
  static const String clear = 'clear.svg';
  static const String clear_format = 'clear_format.svg';
  static const String click = 'click.svg';
  static const String click_tap = 'click_tap.svg';
  static const String click_tap_two = 'click_tap_two.svg';
  static const String click_to_fold = 'click_to_fold.svg';
  static const String clipboard = 'clipboard.svg';
  static const String clock_tower = 'clock_tower.svg';
  static const String close = 'close.svg';
  static const String close_one = 'close_one.svg';
  static const String close_remind = 'close_remind.svg';
  static const String close_small = 'close_small.svg';
  static const String close_wifi = 'close_wifi.svg';
  static const String clothes_briefs = 'clothes_briefs.svg';
  static const String clothes_cardigan = 'clothes_cardigan.svg';
  static const String clothes_crew_neck = 'clothes_crew_neck.svg';
  static const String clothes_diapers = 'clothes_diapers.svg';
  static const String clothes_gloves = 'clothes_gloves.svg';
  static const String clothes_gloves_two = 'clothes_gloves_two.svg';
  static const String clothes_hoodie = 'clothes_hoodie.svg';
  static const String clothes_pants = 'clothes_pants.svg';
  static const String clothes_pants_short = 'clothes_pants_short.svg';
  static const String clothes_pants_sweat = 'clothes_pants_sweat.svg';
  static const String clothes_short_sleeve = 'clothes_short_sleeve.svg';
  static const String clothes_skates = 'clothes_skates.svg';
  static const String clothes_suit = 'clothes_suit.svg';
  static const String clothes_sweater = 'clothes_sweater.svg';
  static const String clothes_turtleneck = 'clothes_turtleneck.svg';
  static const String clothes_windbreaker = 'clothes_windbreaker.svg';
  static const String cloud_storage = 'cloud_storage.svg';
  static const String cloudy = 'cloudy.svg';
  static const String cloudy_night = 'cloudy_night.svg';
  static const String clue = 'clue.svg';
  static const String coat_hanger = 'coat_hanger.svg';
  static const String cocktail = 'cocktail.svg';
  static const String coconut_tree = 'coconut_tree.svg';
  static const String code = 'code.svg';
  static const String code_brackets = 'code_brackets.svg';
  static const String code_download = 'code_download.svg';
  static const String cola = 'cola.svg';
  static const String collapse_text_input = 'collapse_text_input.svg';
  static const String collection_files = 'collection_files.svg';
  static const String collection_records = 'collection_records.svg';
  static const String color_card = 'color_card.svg';
  static const String color_filter = 'color_filter.svg';
  static const String column = 'column.svg';
  static const String comb = 'comb.svg';
  static const String come = 'come.svg';
  static const String command = 'command.svg';
  static const String comment = 'comment.svg';
  static const String comment_one = 'comment_one.svg';
  static const String comments = 'comments.svg';
  static const String commodity = 'commodity.svg';
  static const String communication = 'communication.svg';
  static const String commuter_bag = 'commuter_bag.svg';
  static const String compass = 'compass.svg';
  static const String compass_one = 'compass_one.svg';
  static const String components = 'components.svg';
  static const String composition = 'composition.svg';
  static const String compression = 'compression.svg';
  static const String computer = 'computer.svg';
  static const String computer_one = 'computer_one.svg';
  static const String concept_sharing = 'concept_sharing.svg';
  static const String concern = 'concern.svg';
  static const String conditioner = 'conditioner.svg';
  static const String cone = 'cone.svg';
  static const String cones = 'cones.svg';
  static const String config = 'config.svg';
  static const String confounded_face = 'confounded_face.svg';
  static const String confused_face = 'confused_face.svg';
  static const String connect = 'connect.svg';
  static const String connect_address_one = 'connect_address_one.svg';
  static const String connect_address_two = 'connect_address_two.svg';
  static const String connection = 'connection.svg';
  static const String connection_arrow = 'connection_arrow.svg';
  static const String connection_box = 'connection_box.svg';
  static const String connection_point = 'connection_point.svg';
  static const String connection_point_two = 'connection_point_two.svg';
  static const String consignment = 'consignment.svg';
  static const String consume = 'consume.svg';
  static const String contrast = 'contrast.svg';
  static const String contrast_view = 'contrast_view.svg';
  static const String contrast_view_circle = 'contrast_view_circle.svg';
  static const String control = 'control.svg';
  static const String converging_gateway = 'converging_gateway.svg';
  static const String cook = 'cook.svg';
  static const String cooking = 'cooking.svg';
  static const String cooking_pot = 'cooking_pot.svg';
  static const String cool = 'cool.svg';
  static const String cooperative_handshake = 'cooperative_handshake.svg';
  static const String coordinate_system = 'coordinate_system.svg';
  static const String copy = 'copy.svg';
  static const String copy_link = 'copy_link.svg';
  static const String copy_one = 'copy_one.svg';
  static const String copyright = 'copyright.svg';
  static const String corner_down_left = 'corner_down_left.svg';
  static const String corner_down_right = 'corner_down_right.svg';
  static const String corner_left_down = 'corner_left_down.svg';
  static const String corner_left_up = 'corner_left_up.svg';
  static const String corner_right_down = 'corner_right_down.svg';
  static const String corner_right_up = 'corner_right_up.svg';
  static const String corner_up_left = 'corner_up_left.svg';
  static const String corner_up_right = 'corner_up_right.svg';
  static const String coronavirus = 'coronavirus.svg';
  static const String correct = 'correct.svg';
  static const String cosmetic_brush = 'cosmetic_brush.svg';
  static const String coupon = 'coupon.svg';
  static const String court = 'court.svg';
  static const String cpu = 'cpu.svg';
  static const String crab = 'crab.svg';
  static const String creation_date_sort = 'creation_date_sort.svg';
  static const String creative = 'creative.svg';
  static const String credit = 'credit.svg';
  static const String crib = 'crib.svg';
  static const String croissant = 'croissant.svg';
  static const String cross_ring = 'cross_ring.svg';
  static const String cross_ring_two = 'cross_ring_two.svg';
  static const String crown = 'crown.svg';
  static const String crown_three = 'crown_three.svg';
  static const String crown_two = 'crown_two.svg';
  static const String cruise = 'cruise.svg';
  static const String crying_baby = 'crying_baby.svg';
  static const String cube = 'cube.svg';
  static const String cube_five = 'cube_five.svg';
  static const String cube_four = 'cube_four.svg';
  static const String cube_three = 'cube_three.svg';
  static const String cube_two = 'cube_two.svg';
  static const String cup = 'cup.svg';
  static const String cup_four = 'cup_four.svg';
  static const String cup_one = 'cup_one.svg';
  static const String curling = 'curling.svg';
  static const String currency = 'currency.svg';
  static const String curve_adjustment = 'curve_adjustment.svg';
  static const String customer = 'customer.svg';
  static const String cutting = 'cutting.svg';
  static const String cutting_one = 'cutting_one.svg';
  static const String cuvette = 'cuvette.svg';
  static const String cycle = 'cycle.svg';
  static const String cycle_arrow = 'cycle_arrow.svg';
  static const String cycle_movement = 'cycle_movement.svg';
  static const String cycle_one = 'cycle_one.svg';
  static const String cylinder = 'cylinder.svg';
  static const String damage_map = 'damage_map.svg';
  static const String dark_mode = 'dark_mode.svg';
  static const String dashboard = 'dashboard.svg';
  static const String dashboard_car = 'dashboard_car.svg';
  static const String dashboard_one = 'dashboard_one.svg';
  static const String dashboard_two = 'dashboard_two.svg';
  static const String data = 'data.svg';
  static const String data_all = 'data_all.svg';
  static const String data_arrival = 'data_arrival.svg';
  static const String data_display = 'data_display.svg';
  static const String data_file = 'data_file.svg';
  static const String data_four = 'data_four.svg';
  static const String data_lock = 'data_lock.svg';
  static const String data_null = 'data_null.svg';
  static const String data_one = 'data_one.svg';
  static const String data_screen = 'data_screen.svg';
  static const String data_server = 'data_server.svg';
  static const String data_sheet = 'data_sheet.svg';
  static const String data_switching = 'data_switching.svg';
  static const String data_three = 'data_three.svg';
  static const String data_two = 'data_two.svg';
  static const String data_user = 'data_user.svg';
  static const String database_alert = 'database_alert.svg';
  static const String database_code = 'database_code.svg';
  static const String database_config = 'database_config.svg';
  static const String database_download = 'database_download.svg';
  static const String database_enter = 'database_enter.svg';
  static const String database_fail = 'database_fail.svg';
  static const String database_first = 'database_first.svg';
  static const String database_forbid = 'database_forbid.svg';
  static const String database_lock = 'database_lock.svg';
  static const String database_network = 'database_network.svg';
  static const String database_network_point = 'database_network_point.svg';
  static const String database_point = 'database_point.svg';
  static const String database_position = 'database_position.svg';
  static const String database_power = 'database_power.svg';
  static const String database_proportion = 'database_proportion.svg';
  static const String database_search = 'database_search.svg';
  static const String database_setting = 'database_setting.svg';
  static const String database_success = 'database_success.svg';
  static const String database_sync = 'database_sync.svg';
  static const String database_time = 'database_time.svg';
  static const String date_comes_back = 'date_comes_back.svg';
  static const String deadline_sort = 'deadline_sort.svg';
  static const String death_star = 'death_star.svg';
  static const String deeplink = 'deeplink.svg';
  static const String degree_hat = 'degree_hat.svg';
  static const String delete = 'delete.svg';
  static const String delete_key = 'delete_key.svg';
  static const String delete_mode = 'delete_mode.svg';
  static const String delete_one = 'delete_one.svg';
  static const String delete_themes = 'delete_themes.svg';
  static const String delete_three = 'delete_three.svg';
  static const String delete_two = 'delete_two.svg';
  static const String delivery = 'delivery.svg';
  static const String deposit = 'deposit.svg';
  static const String descend = 'descend.svg';
  static const String desk_lamp = 'desk_lamp.svg';
  static const String detection = 'detection.svg';
  static const String devices = 'devices.svg';
  static const String diamond = 'diamond.svg';
  static const String diamond_necklace = 'diamond_necklace.svg';
  static const String diamond_one = 'diamond_one.svg';
  static const String diamond_ring = 'diamond_ring.svg';
  static const String diamond_three = 'diamond_three.svg';
  static const String diamond_two = 'diamond_two.svg';
  static const String diamonds = 'diamonds.svg';
  static const String dianziqian = 'dianziqian.svg';
  static const String diapers_one = 'diapers_one.svg';
  static const String difference_set = 'difference_set.svg';
  static const String digital_watches = 'digital_watches.svg';
  static const String direction = 'direction.svg';
  static const String direction_adjustment = 'direction_adjustment.svg';
  static const String direction_adjustment_three = 'direction_adjustment_three.svg';
  static const String direction_adjustment_two = 'direction_adjustment_two.svg';
  static const String disappointed_face = 'disappointed_face.svg';
  static const String discovery_index = 'discovery_index.svg';
  static const String disk = 'disk.svg';
  static const String disk_one = 'disk_one.svg';
  static const String disk_two = 'disk_two.svg';
  static const String dislike = 'dislike.svg';
  static const String dislike_two = 'dislike_two.svg';
  static const String display = 'display.svg';
  static const String distortion = 'distortion.svg';
  static const String distraught_face = 'distraught_face.svg';
  static const String distribute_horizontal_spacing = 'distribute_horizontal_spacing.svg';
  static const String distribute_horizontally = 'distribute_horizontally.svg';
  static const String distribute_vertical_spacing = 'distribute_vertical_spacing.svg';
  static const String distribute_vertically = 'distribute_vertically.svg';
  static const String dividing_line = 'dividing_line.svg';
  static const String diving = 'diving.svg';
  static const String diving_bottle = 'diving_bottle.svg';
  static const String diving_suit = 'diving_suit.svg';
  static const String division = 'division.svg';
  static const String dizzy_face = 'dizzy_face.svg';
  static const String doc_add = 'doc_add.svg';
  static const String doc_detail = 'doc_detail.svg';
  static const String doc_fail = 'doc_fail.svg';
  static const String doc_search = 'doc_search.svg';
  static const String doc_search_two = 'doc_search_two.svg';
  static const String doc_success = 'doc_success.svg';
  static const String document_folder = 'document_folder.svg';
  static const String dollar = 'dollar.svg';
  static const String dome = 'dome.svg';
  static const String dome_light = 'dome_light.svg';
  static const String done_all = 'done_all.svg';
  static const String dongchedi = 'dongchedi.svg';
  static const String door_handle = 'door_handle.svg';
  static const String dot = 'dot.svg';
  static const String double_bed = 'double_bed.svg';
  static const String double_down = 'double_down.svg';
  static const String double_left = 'double_left.svg';
  static const String double_right = 'double_right.svg';
  static const String double_up = 'double_up.svg';
  static const String doughnut = 'doughnut.svg';
  static const String down = 'down.svg';
  static const String down_c = 'down_c.svg';
  static const String down_one = 'down_one.svg';
  static const String down_small = 'down_small.svg';
  static const String down_square = 'down_square.svg';
  static const String down_two = 'down_two.svg';
  static const String download = 'download.svg';
  static const String download_four = 'download_four.svg';
  static const String download_one = 'download_one.svg';
  static const String download_three = 'download_three.svg';
  static const String download_two = 'download_two.svg';
  static const String drag = 'drag.svg';
  static const String dribble = 'dribble.svg';
  static const String drink = 'drink.svg';
  static const String drone = 'drone.svg';
  static const String drone_one = 'drone_one.svg';
  static const String drop_down_list = 'drop_down_list.svg';
  static const String drop_shadow_down = 'drop_shadow_down.svg';
  static const String drop_shadow_left = 'drop_shadow_left.svg';
  static const String drop_shadow_right = 'drop_shadow_right.svg';
  static const String drop_shadow_up = 'drop_shadow_up.svg';
  static const String dropbox = 'dropbox.svg';
  static const String drumstick = 'drumstick.svg';
  static const String dubai = 'dubai.svg';
  static const String dumbbell = 'dumbbell.svg';
  static const String dvi = 'dvi.svg';
  static const String earth = 'earth.svg';
  static const String easy = 'easy.svg';
  static const String edit = 'edit.svg';
  static const String edit_movie = 'edit_movie.svg';
  static const String edit_name = 'edit_name.svg';
  static const String edit_one = 'edit_one.svg';
  static const String edit_two = 'edit_two.svg';
  static const String editor = 'editor.svg';
  static const String effects = 'effects.svg';
  static const String egg = 'egg.svg';
  static const String egg_one = 'egg_one.svg';
  static const String eggplant = 'eggplant.svg';
  static const String eiffel_tower = 'eiffel_tower.svg';
  static const String eight_key = 'eight_key.svg';
  static const String electric_iron = 'electric_iron.svg';
  static const String electric_wave = 'electric_wave.svg';
  static const String electrocardiogram = 'electrocardiogram.svg';
  static const String electronic_door_lock = 'electronic_door_lock.svg';
  static const String electronic_locks_close = 'electronic_locks_close.svg';
  static const String electronic_locks_open = 'electronic_locks_open.svg';
  static const String electronic_pen = 'electronic_pen.svg';
  static const String elevator = 'elevator.svg';
  static const String email_block = 'email_block.svg';
  static const String email_delect = 'email_delect.svg';
  static const String email_down = 'email_down.svg';
  static const String email_fail = 'email_fail.svg';
  static const String email_lock = 'email_lock.svg';
  static const String email_push = 'email_push.svg';
  static const String email_search = 'email_search.svg';
  static const String email_security = 'email_security.svg';
  static const String email_successfully = 'email_successfully.svg';
  static const String emotion_happy = 'emotion_happy.svg';
  static const String emotion_unhappy = 'emotion_unhappy.svg';
  static const String empty = 'empty.svg';
  static const String end_time_sort = 'end_time_sort.svg';
  static const String endless = 'endless.svg';
  static const String endocrine = 'endocrine.svg';
  static const String endpoint_displacement = 'endpoint_displacement.svg';
  static const String endpoint_flat = 'endpoint_flat.svg';
  static const String endpoint_round = 'endpoint_round.svg';
  static const String endpoint_square = 'endpoint_square.svg';
  static const String energy_socket = 'energy_socket.svg';
  static const String english = 'english.svg';
  static const String english_mustache = 'english_mustache.svg';
  static const String enquire = 'enquire.svg';
  static const String enter_key = 'enter_key.svg';
  static const String enter_key_one = 'enter_key_one.svg';
  static const String enter_the_keyboard = 'enter_the_keyboard.svg';
  static const String entertainment = 'entertainment.svg';
  static const String envelope = 'envelope.svg';
  static const String envelope_one = 'envelope_one.svg';
  static const String equal_ratio = 'equal_ratio.svg';
  static const String equalizer = 'equalizer.svg';
  static const String erase = 'erase.svg';
  static const String error = 'error.svg';
  static const String error_prompt = 'error_prompt.svg';
  static const String escalators = 'escalators.svg';
  static const String ethernet_off = 'ethernet_off.svg';
  static const String ethernet_on = 'ethernet_on.svg';
  static const String every_user = 'every_user.svg';
  static const String excel = 'excel.svg';
  static const String excel_one = 'excel_one.svg';
  static const String exchange = 'exchange.svg';
  static const String exchange_four = 'exchange_four.svg';
  static const String exchange_one = 'exchange_one.svg';
  static const String exchange_three = 'exchange_three.svg';
  static const String exchange_two = 'exchange_two.svg';
  static const String exclude_selection = 'exclude_selection.svg';
  static const String exclusive_gateway = 'exclusive_gateway.svg';
  static const String expand_down = 'expand_down.svg';
  static const String expand_down_one = 'expand_down_one.svg';
  static const String expand_left = 'expand_left.svg';
  static const String expand_left_and_right = 'expand_left_and_right.svg';
  static const String expand_right = 'expand_right.svg';
  static const String expand_text_input = 'expand_text_input.svg';
  static const String expand_up = 'expand_up.svg';
  static const String expenses = 'expenses.svg';
  static const String expenses_one = 'expenses_one.svg';
  static const String experiment = 'experiment.svg';
  static const String experiment_one = 'experiment_one.svg';
  static const String i_export = 'i_export.svg';
  static const String express_delivery = 'express_delivery.svg';
  static const String expressionless_face = 'expressionless_face.svg';
  static const String extend = 'extend.svg';
  static const String external_transmission = 'external_transmission.svg';
  static const String eyebrow = 'eyebrow.svg';
  static const String eyes = 'eyes.svg';
  static const String f_eight_key = 'f_eight_key.svg';
  static const String f_five_key = 'f_five_key.svg';
  static const String f_four_key = 'f_four_key.svg';
  static const String f_n_key = 'f_n_key.svg';
  static const String f_nine_key = 'f_nine_key.svg';
  static const String f_one_key = 'f_one_key.svg';
  static const String f_seven_key = 'f_seven_key.svg';
  static const String f_six_key = 'f_six_key.svg';
  static const String f_three_key = 'f_three_key.svg';
  static const String f_two_key = 'f_two_key.svg';
  static const String f_zero_key = 'f_zero_key.svg';
  static const String face_powder = 'face_powder.svg';
  static const String face_recognition = 'face_recognition.svg';
  static const String face_with_smiling_open_eyes = 'face_with_smiling_open_eyes.svg';
  static const String face_without_mouth = 'face_without_mouth.svg';
  static const String facebook = 'facebook.svg';
  static const String facebook_one = 'facebook_one.svg';
  static const String facetime = 'facetime.svg';
  static const String faceu = 'faceu.svg';
  static const String facial_cleanser = 'facial_cleanser.svg';
  static const String factory_building = 'factory_building.svg';
  static const String family = 'family.svg';
  static const String fan = 'fan.svg';
  static const String fanqiexiaoshuo = 'fanqiexiaoshuo.svg';
  static const String feelgood = 'feelgood.svg';
  static const String feelgood_one = 'feelgood_one.svg';
  static const String feiyu = 'feiyu.svg';
  static const String female = 'female.svg';
  static const String fence_one = 'fence_one.svg';
  static const String fence_two = 'fence_two.svg';
  static const String ferris_wheel = 'ferris_wheel.svg';
  static const String figma = 'figma.svg';
  static const String figma_component = 'figma_component.svg';
  static const String figma_flatten_selection = 'figma_flatten_selection.svg';
  static const String figma_mask = 'figma_mask.svg';
  static const String figma_reset_instance = 'figma_reset_instance.svg';
  static const String file_addition = 'file_addition.svg';
  static const String file_addition_one = 'file_addition_one.svg';
  static const String file_cabinet = 'file_cabinet.svg';
  static const String file_code = 'file_code.svg';
  static const String file_code_one = 'file_code_one.svg';
  static const String file_collection = 'file_collection.svg';
  static const String file_collection_one = 'file_collection_one.svg';
  static const String file_conversion = 'file_conversion.svg';
  static const String file_conversion_one = 'file_conversion_one.svg';
  static const String file_date = 'file_date.svg';
  static const String file_date_one = 'file_date_one.svg';
  static const String file_display = 'file_display.svg';
  static const String file_display_one = 'file_display_one.svg';
  static const String file_doc = 'file_doc.svg';
  static const String file_editing = 'file_editing.svg';
  static const String file_editing_one = 'file_editing_one.svg';
  static const String file_excel = 'file_excel.svg';
  static const String file_failed = 'file_failed.svg';
  static const String file_failed_one = 'file_failed_one.svg';
  static const String file_focus = 'file_focus.svg';
  static const String file_focus_one = 'file_focus_one.svg';
  static const String file_gif = 'file_gif.svg';
  static const String file_hash = 'file_hash.svg';
  static const String file_hash_one = 'file_hash_one.svg';
  static const String file_hiding = 'file_hiding.svg';
  static const String file_hiding_one = 'file_hiding_one.svg';
  static const String file_jpg = 'file_jpg.svg';
  static const String file_lock = 'file_lock.svg';
  static const String file_lock_one = 'file_lock_one.svg';
  static const String file_music = 'file_music.svg';
  static const String file_music_one = 'file_music_one.svg';
  static const String file_pdf = 'file_pdf.svg';
  static const String file_pdf_one = 'file_pdf_one.svg';
  static const String file_ppt = 'file_ppt.svg';
  static const String file_protection = 'file_protection.svg';
  static const String file_protection_one = 'file_protection_one.svg';
  static const String file_quality = 'file_quality.svg';
  static const String file_quality_one = 'file_quality_one.svg';
  static const String file_question = 'file_question.svg';
  static const String file_removal = 'file_removal.svg';
  static const String file_removal_one = 'file_removal_one.svg';
  static const String file_search = 'file_search.svg';
  static const String file_search_one = 'file_search_one.svg';
  static const String file_search_two = 'file_search_two.svg';
  static const String file_settings = 'file_settings.svg';
  static const String file_settings_one = 'file_settings_one.svg';
  static const String file_staff = 'file_staff.svg';
  static const String file_staff_one = 'file_staff_one.svg';
  static const String file_success = 'file_success.svg';
  static const String file_success_one = 'file_success_one.svg';
  static const String file_text = 'file_text.svg';
  static const String file_text_one = 'file_text_one.svg';
  static const String file_tips = 'file_tips.svg';
  static const String file_tips_one = 'file_tips_one.svg';
  static const String file_txt = 'file_txt.svg';
  static const String file_txt_one = 'file_txt_one.svg';
  static const String file_withdrawal = 'file_withdrawal.svg';
  static const String file_withdrawal_one = 'file_withdrawal_one.svg';
  static const String file_word = 'file_word.svg';
  static const String file_zip = 'file_zip.svg';
  static const String fill = 'fill.svg';
  static const String filter = 'filter.svg';
  static const String filter_one = 'filter_one.svg';
  static const String finance = 'finance.svg';
  static const String financing = 'financing.svg';
  static const String financing_one = 'financing_one.svg';
  static const String financing_two = 'financing_two.svg';
  static const String find = 'find.svg';
  static const String find_one = 'find_one.svg';
  static const String fingernail = 'fingernail.svg';
  static const String fingerprint = 'fingerprint.svg';
  static const String fingerprint_three = 'fingerprint_three.svg';
  static const String fingerprint_two = 'fingerprint_two.svg';
  static const String fire = 'fire.svg';
  static const String fire_extinguisher = 'fire_extinguisher.svg';
  static const String fire_extinguisher_one = 'fire_extinguisher_one.svg';
  static const String fire_two = 'fire_two.svg';
  static const String fireworks = 'fireworks.svg';
  static const String first = 'first.svg';
  static const String fish = 'fish.svg';
  static const String fishing = 'fishing.svg';
  static const String fist = 'fist.svg';
  static const String five = 'five.svg';
  static const String five_ellipses = 'five_ellipses.svg';
  static const String five_five = 'five_five.svg';
  static const String five_key = 'five_key.svg';
  static const String five_star_badge = 'five_star_badge.svg';
  static const String flag = 'flag.svg';
  static const String flash_payment = 'flash_payment.svg';
  static const String flashlamp = 'flashlamp.svg';
  static const String flashlight = 'flashlight.svg';
  static const String flask = 'flask.svg';
  static const String flight_airflow = 'flight_airflow.svg';
  static const String flight_safety = 'flight_safety.svg';
  static const String flip_camera = 'flip_camera.svg';
  static const String flip_horizontally = 'flip_horizontally.svg';
  static const String flip_vertically = 'flip_vertically.svg';
  static const String flirt = 'flirt.svg';
  static const String float = 'float.svg';
  static const String fm = 'fm.svg';
  static const String focus = 'focus.svg';
  static const String focus_one = 'focus_one.svg';
  static const String fog = 'fog.svg';
  static const String fold_up_one = 'fold_up_one.svg';
  static const String folder = 'folder.svg';
  static const String folder_block = 'folder_block.svg';
  static const String folder_block_one = 'folder_block_one.svg';
  static const String folder_close = 'folder_close.svg';
  static const String folder_code = 'folder_code.svg';
  static const String folder_code_one = 'folder_code_one.svg';
  static const String folder_conversion = 'folder_conversion.svg';
  static const String folder_conversion_one = 'folder_conversion_one.svg';
  static const String folder_download = 'folder_download.svg';
  static const String folder_failed = 'folder_failed.svg';
  static const String folder_failed_one = 'folder_failed_one.svg';
  static const String folder_focus = 'folder_focus.svg';
  static const String folder_focus_one = 'folder_focus_one.svg';
  static const String folder_lock = 'folder_lock.svg';
  static const String folder_lock_one = 'folder_lock_one.svg';
  static const String folder_minus = 'folder_minus.svg';
  static const String folder_music = 'folder_music.svg';
  static const String folder_music_one = 'folder_music_one.svg';
  static const String folder_open = 'folder_open.svg';
  static const String folder_plus = 'folder_plus.svg';
  static const String folder_protection = 'folder_protection.svg';
  static const String folder_protection_one = 'folder_protection_one.svg';
  static const String folder_quality = 'folder_quality.svg';
  static const String folder_quality_one = 'folder_quality_one.svg';
  static const String folder_search = 'folder_search.svg';
  static const String folder_search_one = 'folder_search_one.svg';
  static const String folder_settings = 'folder_settings.svg';
  static const String folder_settings_one = 'folder_settings_one.svg';
  static const String folder_success = 'folder_success.svg';
  static const String folder_success_one = 'folder_success_one.svg';
  static const String folder_upload = 'folder_upload.svg';
  static const String folder_withdrawal = 'folder_withdrawal.svg';
  static const String folder_withdrawal_one = 'folder_withdrawal_one.svg';
  static const String follow_up_date_sort = 'follow_up_date_sort.svg';
  static const String font_search = 'font_search.svg';
  static const String font_size = 'font_size.svg';
  static const String font_size_two = 'font_size_two.svg';
  static const String football = 'football.svg';
  static const String forbid = 'forbid.svg';
  static const String fork = 'fork.svg';
  static const String fork_spoon = 'fork_spoon.svg';
  static const String form = 'form.svg';
  static const String form_one = 'form_one.svg';
  static const String format = 'format.svg';
  static const String format_brush = 'format_brush.svg';
  static const String formula = 'formula.svg';
  static const String foundation_makeup = 'foundation_makeup.svg';
  static const String four = 'four.svg';
  static const String four_arrows = 'four_arrows.svg';
  static const String four_four = 'four_four.svg';
  static const String four_key = 'four_key.svg';
  static const String four_leaves = 'four_leaves.svg';
  static const String four_point_connection = 'four_point_connection.svg';
  static const String four_round_point_connection = 'four_round_point_connection.svg';
  static const String foursquare = 'foursquare.svg';
  static const String freeze_column = 'freeze_column.svg';
  static const String freeze_line = 'freeze_line.svg';
  static const String freezing_line_column = 'freezing_line_column.svg';
  static const String french_fries = 'french_fries.svg';
  static const String friends_circle = 'friends_circle.svg';
  static const String frowning_face_whit_open_mouth = 'frowning_face_whit_open_mouth.svg';
  static const String full_dress_longuette = 'full_dress_longuette.svg';
  static const String full_screen = 'full_screen.svg';
  static const String full_screen_one = 'full_screen_one.svg';
  static const String full_screen_play = 'full_screen_play.svg';
  static const String full_screen_two = 'full_screen_two.svg';
  static const String full_selection = 'full_selection.svg';
  static const String fullwidth = 'fullwidth.svg';
  static const String funds = 'funds.svg';
  static const String future_build_one = 'future_build_one.svg';
  static const String future_build_three = 'future_build_three.svg';
  static const String future_build_two = 'future_build_two.svg';
  static const String game = 'game.svg';
  static const String game_console = 'game_console.svg';
  static const String game_console_one = 'game_console_one.svg';
  static const String game_emoji = 'game_emoji.svg';
  static const String game_handle = 'game_handle.svg';
  static const String game_ps = 'game_ps.svg';
  static const String game_three = 'game_three.svg';
  static const String game_two = 'game_two.svg';
  static const String garage = 'garage.svg';
  static const String garlic = 'garlic.svg';
  static const String gastrointestinal = 'gastrointestinal.svg';
  static const String gate = 'gate.svg';
  static const String gate_machine = 'gate_machine.svg';
  static const String general_branch = 'general_branch.svg';
  static const String geometric_flowers = 'geometric_flowers.svg';
  static const String germs = 'germs.svg';
  static const String ghost = 'ghost.svg';
  static const String gift = 'gift.svg';
  static const String gift_box = 'gift_box.svg';
  static const String girl = 'girl.svg';
  static const String girl_one = 'girl_one.svg';
  static const String girl_two = 'girl_two.svg';
  static const String github = 'github.svg';
  static const String github_one = 'github_one.svg';
  static const String gitlab = 'gitlab.svg';
  static const String glasses = 'glasses.svg';
  static const String glasses_one = 'glasses_one.svg';
  static const String globe = 'globe.svg';
  static const String glove = 'glove.svg';
  static const String go_end = 'go_end.svg';
  static const String go_on = 'go_on.svg';
  static const String go_start = 'go_start.svg';
  static const String goblet = 'goblet.svg';
  static const String goblet_cracking = 'goblet_cracking.svg';
  static const String goblet_full = 'goblet_full.svg';
  static const String goblet_one = 'goblet_one.svg';
  static const String gold_medal = 'gold_medal.svg';
  static const String gold_medal_two = 'gold_medal_two.svg';
  static const String golf_course = 'golf_course.svg';
  static const String good = 'good.svg';
  static const String good_one = 'good_one.svg';
  static const String good_two = 'good_two.svg';
  static const String google = 'google.svg';
  static const String google_ads = 'google_ads.svg';
  static const String gopro = 'gopro.svg';
  static const String gps = 'gps.svg';
  static const String graphic_design = 'graphic_design.svg';
  static const String graphic_design_two = 'graphic_design_two.svg';
  static const String graphic_stitching = 'graphic_stitching.svg';
  static const String graphic_stitching_four = 'graphic_stitching_four.svg';
  static const String graphic_stitching_three = 'graphic_stitching_three.svg';
  static const String great_wall = 'great_wall.svg';
  static const String green_house = 'green_house.svg';
  static const String green_new_energy = 'green_new_energy.svg';
  static const String grid_four = 'grid_four.svg';
  static const String grid_nine = 'grid_nine.svg';
  static const String grid_sixteen = 'grid_sixteen.svg';
  static const String grid_three = 'grid_three.svg';
  static const String grid_two = 'grid_two.svg';
  static const String grimacing_face = 'grimacing_face.svg';
  static const String grinning_face = 'grinning_face.svg';
  static const String grinning_face_with_open_mouth = 'grinning_face_with_open_mouth.svg';
  static const String grinning_face_with_squinting_eyes = 'grinning_face_with_squinting_eyes.svg';
  static const String grinning_face_with_tightly_closed_eyes = 'grinning_face_with_tightly_closed_eyes.svg';
  static const String grinning_face_with_tightly_closed_eyes_open_mouth = 'grinning_face_with_tightly_closed_eyes_open_mouth.svg';
  static const String group = 'group.svg';
  static const String guide_board = 'guide_board.svg';
  static const String gymnastics = 'gymnastics.svg';
  static const String gymnastics_one = 'gymnastics_one.svg';
  static const String h = 'h.svg';
  static const String h1 = 'h1.svg';
  static const String h2 = 'h2.svg';
  static const String h3 = 'h3.svg';
  static const String hair_brush = 'hair_brush.svg';
  static const String hair_clip = 'hair_clip.svg';
  static const String hair_dryer = 'hair_dryer.svg';
  static const String hair_dryer_one = 'hair_dryer_one.svg';
  static const String halo = 'halo.svg';
  static const String hamburger = 'hamburger.svg';
  static const String hamburger_button = 'hamburger_button.svg';
  static const String hamburger_one = 'hamburger_one.svg';
  static const String hammer_and_anvil = 'hammer_and_anvil.svg';
  static const String hand_cream = 'hand_cream.svg';
  static const String hand_down = 'hand_down.svg';
  static const String hand_drag = 'hand_drag.svg';
  static const String hand_left = 'hand_left.svg';
  static const String hand_painted_plate = 'hand_painted_plate.svg';
  static const String hand_right = 'hand_right.svg';
  static const String hand_up = 'hand_up.svg';
  static const String handbag = 'handbag.svg';
  static const String handheld = 'handheld.svg';
  static const String handle_a = 'handle_a.svg';
  static const String handle_b = 'handle_b.svg';
  static const String handle_c = 'handle_c.svg';
  static const String handle_down = 'handle_down.svg';
  static const String handle_left = 'handle_left.svg';
  static const String handle_right = 'handle_right.svg';
  static const String handle_round = 'handle_round.svg';
  static const String handle_square = 'handle_square.svg';
  static const String handle_triangle = 'handle_triangle.svg';
  static const String handle_up = 'handle_up.svg';
  static const String handle_x = 'handle_x.svg';
  static const String handle_y = 'handle_y.svg';
  static const String handle_z = 'handle_z.svg';
  static const String hands = 'hands.svg';
  static const String handwashing = 'handwashing.svg';
  static const String handwashing_fluid = 'handwashing_fluid.svg';
  static const String hanfu_chinese_style = 'hanfu_chinese_style.svg';
  static const String hanger = 'hanger.svg';
  static const String hanger_one = 'hanger_one.svg';
  static const String hanger_two = 'hanger_two.svg';
  static const String hard_disk = 'hard_disk.svg';
  static const String hard_disk_one = 'hard_disk_one.svg';
  static const String harm = 'harm.svg';
  static const String hashtag_key = 'hashtag_key.svg';
  static const String hat = 'hat.svg';
  static const String hdd = 'hdd.svg';
  static const String hdmi_cable = 'hdmi_cable.svg';
  static const String hdmi_connector = 'hdmi_connector.svg';
  static const String headphone_sound = 'headphone_sound.svg';
  static const String headset = 'headset.svg';
  static const String headset_one = 'headset_one.svg';
  static const String headset_two = 'headset_two.svg';
  static const String headwear = 'headwear.svg';
  static const String health = 'health.svg';
  static const String health_products = 'health_products.svg';
  static const String healthy_recognition = 'healthy_recognition.svg';
  static const String heart = 'heart.svg';
  static const String heart_ballon = 'heart_ballon.svg';
  static const String heartbeat = 'heartbeat.svg';
  static const String heater_resistor = 'heater_resistor.svg';
  static const String heavy_metal = 'heavy_metal.svg';
  static const String heavy_rain = 'heavy_rain.svg';
  static const String heavy_wind = 'heavy_wind.svg';
  static const String helmet = 'helmet.svg';
  static const String helmet_one = 'helmet_one.svg';
  static const String help = 'help.svg';
  static const String helpcenter = 'helpcenter.svg';
  static const String hexagon_one = 'hexagon_one.svg';
  static const String hexagon_strip = 'hexagon_strip.svg';
  static const String hexagonal = 'hexagonal.svg';
  static const String hi = 'hi.svg';
  static const String high_heeled_shoes = 'high_heeled_shoes.svg';
  static const String high_light = 'high_light.svg';
  static const String histogram = 'histogram.svg';
  static const String history = 'history.svg';
  static const String history_query = 'history_query.svg';
  static const String hockey = 'hockey.svg';
  static const String hold = 'hold.svg';
  static const String hold_interface = 'hold_interface.svg';
  static const String hold_seeds = 'hold_seeds.svg';
  static const String holding_hands = 'holding_hands.svg';
  static const String holy_sword = 'holy_sword.svg';
  static const String home = 'home.svg';
  static const String home_two = 'home_two.svg';
  static const String homestay = 'homestay.svg';
  static const String honey = 'honey.svg';
  static const String honey_one = 'honey_one.svg';
  static const String horizontal_spacing_between_items = 'horizontal_spacing_between_items.svg';
  static const String horizontal_tidy_up = 'horizontal_tidy_up.svg';
  static const String horizontally_centered = 'horizontally_centered.svg';
  static const String hospital = 'hospital.svg';
  static const String hospital_two = 'hospital_two.svg';
  static const String hot_air_balloon = 'hot_air_balloon.svg';
  static const String hot_pot = 'hot_pot.svg';
  static const String hot_pot_one = 'hot_pot_one.svg';
  static const String hotel = 'hotel.svg';
  static const String hotel_do_not_clean = 'hotel_do_not_clean.svg';
  static const String hotel_please_clean = 'hotel_please_clean.svg';
  static const String hourglass = 'hourglass.svg';
  static const String hourglass_full = 'hourglass_full.svg';
  static const String hourglass_null = 'hourglass_null.svg';
  static const String html_five = 'html_five.svg';
  static const String hunting_gear = 'hunting_gear.svg';
  static const String huoshanzhibo = 'huoshanzhibo.svg';
  static const String i_mac = 'i_mac.svg';
  static const String icecream = 'icecream.svg';
  static const String icecream_five = 'icecream_five.svg';
  static const String icecream_four = 'icecream_four.svg';
  static const String icecream_one = 'icecream_one.svg';
  static const String icecream_three = 'icecream_three.svg';
  static const String icecream_two = 'icecream_two.svg';
  static const String id_card = 'id_card.svg';
  static const String id_card_h = 'id_card_h.svg';
  static const String id_card_v = 'id_card_v.svg';
  static const String image_files = 'image_files.svg';
  static const String imbalance = 'imbalance.svg';
  static const String import_and_export = 'import_and_export.svg';
  static const String in_flight = 'in_flight.svg';
  static const String inbox = 'inbox.svg';
  static const String inbox_download_r = 'inbox_download_r.svg';
  static const String inbox_in = 'inbox_in.svg';
  static const String inbox_out = 'inbox_out.svg';
  static const String inbox_r = 'inbox_r.svg';
  static const String inbox_success = 'inbox_success.svg';
  static const String inbox_success_r = 'inbox_success_r.svg';
  static const String inbox_upload_r = 'inbox_upload_r.svg';
  static const String inclusive_gateway = 'inclusive_gateway.svg';
  static const String income = 'income.svg';
  static const String income_one = 'income_one.svg';
  static const String incoming = 'incoming.svg';
  static const String increase = 'increase.svg';
  static const String increase_the_scale = 'increase_the_scale.svg';
  static const String indent_left = 'indent_left.svg';
  static const String indent_right = 'indent_right.svg';
  static const String index_finger = 'index_finger.svg';
  static const String induction_lock = 'induction_lock.svg';
  static const String industrial_scales = 'industrial_scales.svg';
  static const String info = 'info.svg';
  static const String injection = 'injection.svg';
  static const String inline = 'inline.svg';
  static const String inner_shadow_bottom_left = 'inner_shadow_bottom_left.svg';
  static const String inner_shadow_bottom_right = 'inner_shadow_bottom_right.svg';
  static const String inner_shadow_down = 'inner_shadow_down.svg';
  static const String inner_shadow_left = 'inner_shadow_left.svg';
  static const String inner_shadow_right = 'inner_shadow_right.svg';
  static const String inner_shadow_top_left = 'inner_shadow_top_left.svg';
  static const String inner_shadow_top_right = 'inner_shadow_top_right.svg';
  static const String inner_shadow_up = 'inner_shadow_up.svg';
  static const String insert_card = 'insert_card.svg';
  static const String insert_table = 'insert_table.svg';
  static const String inspection = 'inspection.svg';
  static const String instagram = 'instagram.svg';
  static const String instagram_one = 'instagram_one.svg';
  static const String install = 'install.svg';
  static const String instruction = 'instruction.svg';
  static const String intercom = 'intercom.svg';
  static const String intermediate_mode = 'intermediate_mode.svg';
  static const String internal_data = 'internal_data.svg';
  static const String internal_expansion = 'internal_expansion.svg';
  static const String internal_reduction = 'internal_reduction.svg';
  static const String internal_transmission = 'internal_transmission.svg';
  static const String international = 'international.svg';
  static const String intersect_selection = 'intersect_selection.svg';
  static const String intersection = 'intersection.svg';
  static const String invalid_files = 'invalid_files.svg';
  static const String invert_camera = 'invert_camera.svg';
  static const String ios_face_recognition = 'ios_face_recognition.svg';
  static const String ipad = 'ipad.svg';
  static const String ipad_one = 'ipad_one.svg';
  static const String iphone = 'iphone.svg';
  static const String ipo = 'ipo.svg';
  static const String iron = 'iron.svg';
  static const String iron_disable = 'iron_disable.svg';
  static const String iron_three = 'iron_three.svg';
  static const String iron_two = 'iron_two.svg';
  static const String iwatch = 'iwatch.svg';
  static const String iwatch_one = 'iwatch_one.svg';
  static const String iwatch_two = 'iwatch_two.svg';
  static const String jewelry = 'jewelry.svg';
  static const String jinritoutiao = 'jinritoutiao.svg';
  static const String journey = 'journey.svg';
  static const String joystick = 'joystick.svg';
  static const String juice = 'juice.svg';
  static const String kagi_map = 'kagi_map.svg';
  static const String kettle = 'kettle.svg';
  static const String kettle_one = 'kettle_one.svg';
  static const String key_ = 'key.svg';
  static const String keyboard = 'keyboard.svg';
  static const String keyboard_one = 'keyboard_one.svg';
  static const String keyhole = 'keyhole.svg';
  static const String keyline = 'keyline.svg';
  static const String kitchen_knife = 'kitchen_knife.svg';
  static const String knife_fork = 'knife_fork.svg';
  static const String kungfu = 'kungfu.svg';
  static const String label = 'label.svg';
  static const String ladder = 'ladder.svg';
  static const String lamp = 'lamp.svg';
  static const String land_surveying = 'land_surveying.svg';
  static const String landscape = 'landscape.svg';
  static const String laptop = 'laptop.svg';
  static const String laptop_computer = 'laptop_computer.svg';
  static const String lark = 'lark.svg';
  static const String lark_one = 'lark_one.svg';
  static const String lattice_pattern = 'lattice_pattern.svg';
  static const String layers = 'layers.svg';
  static const String layout_five = 'layout_five.svg';
  static const String layout_four = 'layout_four.svg';
  static const String layout_one = 'layout_one.svg';
  static const String layout_three = 'layout_three.svg';
  static const String layout_two = 'layout_two.svg';
  static const String leaf = 'leaf.svg';
  static const String leaves = 'leaves.svg';
  static const String led_diode = 'led_diode.svg';
  static const String left = 'left.svg';
  static const String left_alignment = 'left_alignment.svg';
  static const String left_bar = 'left_bar.svg';
  static const String left_c = 'left_c.svg';
  static const String left_expand = 'left_expand.svg';
  static const String left_one = 'left_one.svg';
  static const String left_small = 'left_small.svg';
  static const String left_small_down = 'left_small_down.svg';
  static const String left_small_up = 'left_small_up.svg';
  static const String left_square = 'left_square.svg';
  static const String left_two = 'left_two.svg';
  static const String lemon = 'lemon.svg';
  static const String lens_alignment = 'lens_alignment.svg';
  static const String level = 'level.svg';
  static const String level_adjustment = 'level_adjustment.svg';
  static const String level_eight_title = 'level_eight_title.svg';
  static const String level_five_title = 'level_five_title.svg';
  static const String level_four_title = 'level_four_title.svg';
  static const String level_nine_title = 'level_nine_title.svg';
  static const String level_seven_title = 'level_seven_title.svg';
  static const String level_six_title = 'level_six_title.svg';
  static const String lifebuoy = 'lifebuoy.svg';
  static const String light = 'light.svg';
  static const String light_house = 'light_house.svg';
  static const String light_member = 'light_member.svg';
  static const String light_rain = 'light_rain.svg';
  static const String lightning = 'lightning.svg';
  static const String like = 'like.svg';
  static const String lincoln = 'lincoln.svg';
  static const String link = 'link.svg';
  static const String link_break = 'link_break.svg';
  static const String link_cloud = 'link_cloud.svg';
  static const String link_cloud_faild = 'link_cloud_faild.svg';
  static const String link_cloud_sucess = 'link_cloud_sucess.svg';
  static const String link_four = 'link_four.svg';
  static const String link_in = 'link_in.svg';
  static const String link_interrupt = 'link_interrupt.svg';
  static const String link_left = 'link_left.svg';
  static const String link_one = 'link_one.svg';
  static const String link_out = 'link_out.svg';
  static const String link_right = 'link_right.svg';
  static const String link_three = 'link_three.svg';
  static const String link_two = 'link_two.svg';
  static const String lip_gloss = 'lip_gloss.svg';
  static const String lip_tattoo = 'lip_tattoo.svg';
  static const String lipstick = 'lipstick.svg';
  static const String lipstick_one = 'lipstick_one.svg';
  static const String liqueur = 'liqueur.svg';
  static const String list = 'list.svg';
  static const String list_add = 'list_add.svg';
  static const String list_alphabet = 'list_alphabet.svg';
  static const String list_bottom = 'list_bottom.svg';
  static const String list_checkbox = 'list_checkbox.svg';
  static const String list_fail = 'list_fail.svg';
  static const String list_middle = 'list_middle.svg';
  static const String list_numbers = 'list_numbers.svg';
  static const String list_one = 'list_one.svg';
  static const String list_success = 'list_success.svg';
  static const String list_top = 'list_top.svg';
  static const String list_two = 'list_two.svg';
  static const String list_view = 'list_view.svg';
  static const String loading = 'loading.svg';
  static const String loading_four = 'loading_four.svg';
  static const String loading_one = 'loading_one.svg';
  static const String loading_three = 'loading_three.svg';
  static const String loading_two = 'loading_two.svg';
  static const String local = 'local.svg';
  static const String local_pin = 'local_pin.svg';
  static const String local_two = 'local_two.svg';
  static const String lock = 'lock.svg';
  static const String log = 'log.svg';
  static const String login = 'login.svg';
  static const String logout = 'logout.svg';
  static const String lollipop = 'lollipop.svg';
  static const String loop_once = 'loop_once.svg';
  static const String lotion = 'lotion.svg';
  static const String loudly_crying_face = 'loudly_crying_face.svg';
  static const String loudly_crying_face_whit_open_mouth = 'loudly_crying_face_whit_open_mouth.svg';
  static const String luggage = 'luggage.svg';
  static const String luminous = 'luminous.svg';
  static const String lung = 'lung.svg';
  static const String mac_finder = 'mac_finder.svg';
  static const String macadamia_nut = 'macadamia_nut.svg';
  static const String magic = 'magic.svg';
  static const String magic_hat = 'magic_hat.svg';
  static const String magic_wand = 'magic_wand.svg';
  static const String magnet = 'magnet.svg';
  static const String mail = 'mail.svg';
  static const String mail_download = 'mail_download.svg';
  static const String mail_edit = 'mail_edit.svg';
  static const String mail_open = 'mail_open.svg';
  static const String mail_package = 'mail_package.svg';
  static const String mail_review = 'mail_review.svg';
  static const String mail_unpacking = 'mail_unpacking.svg';
  static const String maill_one = 'maill_one.svg';
  static const String makeups = 'makeups.svg';
  static const String male = 'male.svg';
  static const String mall_bag = 'mall_bag.svg';
  static const String manual_gear = 'manual_gear.svg';
  static const String many_to_many = 'many_to_many.svg';
  static const String map_distance = 'map_distance.svg';
  static const String map_draw = 'map_draw.svg';
  static const String map_road = 'map_road.svg';
  static const String map_road_two = 'map_road_two.svg';
  static const String map_two = 'map_two.svg';
  static const String margin = 'margin.svg';
  static const String margin_one = 'margin_one.svg';
  static const String mark = 'mark.svg';
  static const String market = 'market.svg';
  static const String market_analysis = 'market_analysis.svg';
  static const String mascara = 'mascara.svg';
  static const String mask = 'mask.svg';
  static const String mask_one = 'mask_one.svg';
  static const String mask_two = 'mask_two.svg';
  static const String maslow_pyramids = 'maslow_pyramids.svg';
  static const String massage_chair = 'massage_chair.svg';
  static const String massage_chair_one = 'massage_chair_one.svg';
  static const String massage_table = 'massage_table.svg';
  static const String master = 'master.svg';
  static const String material = 'material.svg';
  static const String material_three = 'material_three.svg';
  static const String material_two = 'material_two.svg';
  static const String maximum = 'maximum.svg';
  static const String maya = 'maya.svg';
  static const String mayura_gesture = 'mayura_gesture.svg';
  static const String me = 'me.svg';
  static const String measuring_cup = 'measuring_cup.svg';
  static const String mediaeditor = 'mediaeditor.svg';
  static const String medical_box = 'medical_box.svg';
  static const String medical_files = 'medical_files.svg';
  static const String medication_time = 'medication_time.svg';
  static const String medicine_bottle = 'medicine_bottle.svg';
  static const String memory = 'memory.svg';
  static const String memory_card = 'memory_card.svg';
  static const String memory_one = 'memory_one.svg';
  static const String men_jacket = 'men_jacket.svg';
  static const String menu_fold = 'menu_fold.svg';
  static const String menu_fold_one = 'menu_fold_one.svg';
  static const String menu_unfold = 'menu_unfold.svg';
  static const String menu_unfold_one = 'menu_unfold_one.svg';
  static const String merge = 'merge.svg';
  static const String merge_cells = 'merge_cells.svg';
  static const String message = 'message.svg';
  static const String message_emoji = 'message_emoji.svg';
  static const String message_failed = 'message_failed.svg';
  static const String message_one = 'message_one.svg';
  static const String message_privacy = 'message_privacy.svg';
  static const String message_search = 'message_search.svg';
  static const String message_security = 'message_security.svg';
  static const String message_sent = 'message_sent.svg';
  static const String message_success = 'message_success.svg';
  static const String message_unread = 'message_unread.svg';
  static const String messages = 'messages.svg';
  static const String messages_one = 'messages_one.svg';
  static const String micro_sd = 'micro_sd.svg';
  static const String micro_slr_camera = 'micro_slr_camera.svg';
  static const String microphone = 'microphone.svg';
  static const String microphone_one = 'microphone_one.svg';
  static const String microscope = 'microscope.svg';
  static const String microscope_one = 'microscope_one.svg';
  static const String microwave_oven = 'microwave_oven.svg';
  static const String microwaves = 'microwaves.svg';
  static const String middle_finger = 'middle_finger.svg';
  static const String milk = 'milk.svg';
  static const String milk_one = 'milk_one.svg';
  static const String min = 'min.svg';
  static const String mind_mapping = 'mind_mapping.svg';
  static const String mindmap_list = 'mindmap_list.svg';
  static const String mindmap_map = 'mindmap_map.svg';
  static const String mini_sd_card = 'mini_sd_card.svg';
  static const String minus = 'minus.svg';
  static const String minus_the_bottom = 'minus_the_bottom.svg';
  static const String minus_the_top = 'minus_the_top.svg';
  static const String mirror = 'mirror.svg';
  static const String mirror_one = 'mirror_one.svg';
  static const String mirror_two = 'mirror_two.svg';
  static const String misaligned_semicircle = 'misaligned_semicircle.svg';
  static const String mitsubishi = 'mitsubishi.svg';
  static const String modify = 'modify.svg';
  static const String modify_two = 'modify_two.svg';
  static const String monitor = 'monitor.svg';
  static const String monitor_camera = 'monitor_camera.svg';
  static const String monitor_off = 'monitor_off.svg';
  static const String monitor_one = 'monitor_one.svg';
  static const String monitor_two = 'monitor_two.svg';
  static const String monument_one = 'monument_one.svg';
  static const String monument_two = 'monument_two.svg';
  static const String moon = 'moon.svg';
  static const String more = 'more.svg';
  static const String more_app = 'more_app.svg';
  static const String more_four = 'more_four.svg';
  static const String more_one = 'more_one.svg';
  static const String more_three = 'more_three.svg';
  static const String more_two = 'more_two.svg';
  static const String mosaic = 'mosaic.svg';
  static const String mouse = 'mouse.svg';
  static const String mouse_one = 'mouse_one.svg';
  static const String mouth = 'mouth.svg';
  static const String move = 'move.svg';
  static const String move_in = 'move_in.svg';
  static const String move_in_one = 'move_in_one.svg';
  static const String move_one = 'move_one.svg';
  static const String movie = 'movie.svg';
  static const String movie_board = 'movie_board.svg';
  static const String multi_circular = 'multi_circular.svg';
  static const String multi_function_knife = 'multi_function_knife.svg';
  static const String multi_picture_carousel = 'multi_picture_carousel.svg';
  static const String multi_rectangle = 'multi_rectangle.svg';
  static const String multi_ring = 'multi_ring.svg';
  static const String multi_triangular = 'multi_triangular.svg';
  static const String multi_triangular_four = 'multi_triangular_four.svg';
  static const String multi_triangular_three = 'multi_triangular_three.svg';
  static const String multi_triangular_two = 'multi_triangular_two.svg';
  static const String multicast = 'multicast.svg';
  static const String multilayer_sphere = 'multilayer_sphere.svg';
  static const String muscle = 'muscle.svg';
  static const String museum_one = 'museum_one.svg';
  static const String museum_two = 'museum_two.svg';
  static const String music = 'music.svg';
  static const String music_cd = 'music_cd.svg';
  static const String music_list = 'music_list.svg';
  static const String music_menu = 'music_menu.svg';
  static const String music_one = 'music_one.svg';
  static const String music_rhythm = 'music_rhythm.svg';
  static const String mute = 'mute.svg';
  static const String nail_polish = 'nail_polish.svg';
  static const String nail_polish_one = 'nail_polish_one.svg';
  static const String nasal = 'nasal.svg';
  static const String natural_mode = 'natural_mode.svg';
  static const String navigation = 'navigation.svg';
  static const String necktie = 'necktie.svg';
  static const String negative_dynamics = 'negative_dynamics.svg';
  static const String nested_arrows = 'nested_arrows.svg';
  static const String nests = 'nests.svg';
  static const String network_drive = 'network_drive.svg';
  static const String network_tree = 'network_tree.svg';
  static const String neural = 'neural.svg';
  static const String neutral_face = 'neutral_face.svg';
  static const String newlybuild = 'newlybuild.svg';
  static const String newspaper_folding = 'newspaper_folding.svg';
  static const String next = 'next.svg';
  static const String nine_key = 'nine_key.svg';
  static const String nine_points_connected = 'nine_points_connected.svg';
  static const String nintendo_switch = 'nintendo_switch.svg';
  static const String nmr = 'nmr.svg';
  static const String no_shooting = 'no_shooting.svg';
  static const String node_flat = 'node_flat.svg';
  static const String node_round = 'node_round.svg';
  static const String node_square = 'node_square.svg';
  static const String noodles = 'noodles.svg';
  static const String notebook = 'notebook.svg';
  static const String notebook_and_pen = 'notebook_and_pen.svg';
  static const String notebook_one = 'notebook_one.svg';
  static const String notepad = 'notepad.svg';
  static const String notes = 'notes.svg';
  static const String nuclear_plant = 'nuclear_plant.svg';
  static const String nut = 'nut.svg';
  static const String nutrition = 'nutrition.svg';
  static const String oceanengine = 'oceanengine.svg';
  static const String octagon = 'octagon.svg';
  static const String off_screen = 'off_screen.svg';
  static const String off_screen_one = 'off_screen_one.svg';
  static const String off_screen_two = 'off_screen_two.svg';
  static const String oil_industry = 'oil_industry.svg';
  static const String okay = 'okay.svg';
  static const String one = 'one.svg';
  static const String one_key = 'one_key.svg';
  static const String one_one = 'one_one.svg';
  static const String one_third_rotation = 'one_third_rotation.svg';
  static const String one_to_many = 'one_to_many.svg';
  static const String one_to_one = 'one_to_one.svg';
  static const String onesies = 'onesies.svg';
  static const String online_meeting = 'online_meeting.svg';
  static const String open = 'open.svg';
  static const String open_an_account = 'open_an_account.svg';
  static const String open_door = 'open_door.svg';
  static const String open_one = 'open_one.svg';
  static const String optimize = 'optimize.svg';
  static const String optional = 'optional.svg';
  static const String orange = 'orange.svg';
  static const String orange_one = 'orange_one.svg';
  static const String orange_station = 'orange_station.svg';
  static const String order = 'order.svg';
  static const String ordered_list = 'ordered_list.svg';
  static const String orthopedic = 'orthopedic.svg';
  static const String oscillator = 'oscillator.svg';
  static const String other = 'other.svg';
  static const String outbound = 'outbound.svg';
  static const String outdoor = 'outdoor.svg';
  static const String outgoing = 'outgoing.svg';
  static const String oval_love = 'oval_love.svg';
  static const String oval_love_two = 'oval_love_two.svg';
  static const String oval_one = 'oval_one.svg';
  static const String oven = 'oven.svg';
  static const String oven_tray = 'oven_tray.svg';
  static const String overall_reduction = 'overall_reduction.svg';
  static const String pacifier = 'pacifier.svg';
  static const String pad = 'pad.svg';
  static const String page = 'page.svg';
  static const String page_template = 'page_template.svg';
  static const String pagoda = 'pagoda.svg';
  static const String paint = 'paint.svg';
  static const String painted_eggshell = 'painted_eggshell.svg';
  static const String painted_screen = 'painted_screen.svg';
  static const String palace = 'palace.svg';
  static const String palm = 'palm.svg';
  static const String pangle = 'pangle.svg';
  static const String panorama_horizontal = 'panorama_horizontal.svg';
  static const String panties = 'panties.svg';
  static const String paper_money = 'paper_money.svg';
  static const String paper_money_two = 'paper_money_two.svg';
  static const String paper_ship = 'paper_ship.svg';
  static const String paperclip = 'paperclip.svg';
  static const String parabola = 'parabola.svg';
  static const String parachute = 'parachute.svg';
  static const String paragraph_alphabet = 'paragraph_alphabet.svg';
  static const String paragraph_break = 'paragraph_break.svg';
  static const String paragraph_break_two = 'paragraph_break_two.svg';
  static const String paragraph_cut = 'paragraph_cut.svg';
  static const String paragraph_rectangle = 'paragraph_rectangle.svg';
  static const String paragraph_round = 'paragraph_round.svg';
  static const String paragraph_triangle = 'paragraph_triangle.svg';
  static const String paragraph_unfold = 'paragraph_unfold.svg';
  static const String parallel_gateway = 'parallel_gateway.svg';
  static const String parallelogram = 'parallelogram.svg';
  static const String parenting_book = 'parenting_book.svg';
  static const String parking = 'parking.svg';
  static const String party_balloon = 'party_balloon.svg';
  static const String passport = 'passport.svg';
  static const String passport_one = 'passport_one.svg';
  static const String pause = 'pause.svg';
  static const String pause_one = 'pause_one.svg';
  static const String pay_code = 'pay_code.svg';
  static const String pay_code_one = 'pay_code_one.svg';
  static const String pay_code_two = 'pay_code_two.svg';
  static const String payment_method = 'payment_method.svg';
  static const String paypal = 'paypal.svg';
  static const String peach = 'peach.svg';
  static const String pear = 'pear.svg';
  static const String pearl_of_the_orient = 'pearl_of_the_orient.svg';
  static const String peas = 'peas.svg';
  static const String pennant = 'pennant.svg';
  static const String pentagon_one = 'pentagon_one.svg';
  static const String people = 'people.svg';
  static const String people_bottom = 'people_bottom.svg';
  static const String people_bottom_card = 'people_bottom_card.svg';
  static const String people_delete = 'people_delete.svg';
  static const String people_delete_one = 'people_delete_one.svg';
  static const String people_download = 'people_download.svg';
  static const String people_left = 'people_left.svg';
  static const String people_minus = 'people_minus.svg';
  static const String people_minus_one = 'people_minus_one.svg';
  static const String people_plus = 'people_plus.svg';
  static const String people_plus_one = 'people_plus_one.svg';
  static const String people_right = 'people_right.svg';
  static const String people_safe = 'people_safe.svg';
  static const String people_safe_one = 'people_safe_one.svg';
  static const String people_search = 'people_search.svg';
  static const String people_search_one = 'people_search_one.svg';
  static const String people_speak = 'people_speak.svg';
  static const String people_top = 'people_top.svg';
  static const String people_top_card = 'people_top_card.svg';
  static const String people_unknown = 'people_unknown.svg';
  static const String people_upload = 'people_upload.svg';
  static const String peoples = 'peoples.svg';
  static const String peoples_two = 'peoples_two.svg';
  static const String percentage = 'percentage.svg';
  static const String performance = 'performance.svg';
  static const String perfume = 'perfume.svg';
  static const String perfumer_bottle = 'perfumer_bottle.svg';
  static const String period = 'period.svg';
  static const String permissions = 'permissions.svg';
  static const String personal_collection = 'personal_collection.svg';
  static const String personal_privacy = 'personal_privacy.svg';
  static const String perspective = 'perspective.svg';
  static const String pesticide = 'pesticide.svg';
  static const String petrol = 'petrol.svg';
  static const String phone = 'phone.svg';
  static const String phone_booth = 'phone_booth.svg';
  static const String phone_call = 'phone_call.svg';
  static const String phone_incoming = 'phone_incoming.svg';
  static const String phone_incoming_one = 'phone_incoming_one.svg';
  static const String phone_missed = 'phone_missed.svg';
  static const String phone_off = 'phone_off.svg';
  static const String phone_one = 'phone_one.svg';
  static const String phone_outgoing = 'phone_outgoing.svg';
  static const String phone_outgoing_one = 'phone_outgoing_one.svg';
  static const String phone_telephone = 'phone_telephone.svg';
  static const String phone_two = 'phone_two.svg';
  static const String phone_video_call = 'phone_video_call.svg';
  static const String phonograph = 'phonograph.svg';
  static const String photograph = 'photograph.svg';
  static const String piano = 'piano.svg';
  static const String pic = 'pic.svg';
  static const String pic_one = 'pic_one.svg';
  static const String picture = 'picture.svg';
  static const String picture_one = 'picture_one.svg';
  static const String pie = 'pie.svg';
  static const String pie_five = 'pie_five.svg';
  static const String pie_four = 'pie_four.svg';
  static const String pie_one = 'pie_one.svg';
  static const String pie_seven = 'pie_seven.svg';
  static const String pie_six = 'pie_six.svg';
  static const String pie_three = 'pie_three.svg';
  static const String pie_two = 'pie_two.svg';
  static const String pills = 'pills.svg';
  static const String pin = 'pin.svg';
  static const String pineapple = 'pineapple.svg';
  static const String pinwheel = 'pinwheel.svg';
  static const String pivot_table = 'pivot_table.svg';
  static const String plan = 'plan.svg';
  static const String planet = 'planet.svg';
  static const String plastic_surgery = 'plastic_surgery.svg';
  static const String platte = 'platte.svg';
  static const String play = 'play.svg';
  static const String play_basketball = 'play_basketball.svg';
  static const String play_cycle = 'play_cycle.svg';
  static const String play_once = 'play_once.svg';
  static const String play_one = 'play_one.svg';
  static const String play_two = 'play_two.svg';
  static const String play_volleyball = 'play_volleyball.svg';
  static const String play_wrong = 'play_wrong.svg';
  static const String playback_progress = 'playback_progress.svg';
  static const String plug = 'plug.svg';
  static const String plug_one = 'plug_one.svg';
  static const String plus = 'plus.svg';
  static const String plus_cross = 'plus_cross.svg';
  static const String point = 'point.svg';
  static const String point_out = 'point_out.svg';
  static const String pokeball_one = 'pokeball_one.svg';
  static const String poker = 'poker.svg';
  static const String popcorn = 'popcorn.svg';
  static const String popcorn_one = 'popcorn_one.svg';
  static const String positive_dynamics = 'positive_dynamics.svg';
  static const String pot = 'pot.svg';
  static const String potentiometer = 'potentiometer.svg';
  static const String pound = 'pound.svg';
  static const String pound_sign = 'pound_sign.svg';
  static const String pouting_face = 'pouting_face.svg';
  static const String powder = 'powder.svg';
  static const String power = 'power.svg';
  static const String power_supply = 'power_supply.svg';
  static const String power_supply_one = 'power_supply_one.svg';
  static const String powerpoint = 'powerpoint.svg';
  static const String ppt = 'ppt.svg';
  static const String pregnant_women = 'pregnant_women.svg';
  static const String preschool = 'preschool.svg';
  static const String prescription = 'prescription.svg';
  static const String press = 'press.svg';
  static const String preview_close = 'preview_close.svg';
  static const String preview_close_one = 'preview_close_one.svg';
  static const String preview_open = 'preview_open.svg';
  static const String printer = 'printer.svg';
  static const String printer_one = 'printer_one.svg';
  static const String printer_two = 'printer_two.svg';
  static const String prison = 'prison.svg';
  static const String process_line = 'process_line.svg';
  static const String projector = 'projector.svg';
  static const String projector_one = 'projector_one.svg';
  static const String projector_three = 'projector_three.svg';
  static const String projector_two = 'projector_two.svg';
  static const String proportional_scaling = 'proportional_scaling.svg';
  static const String protect = 'protect.svg';
  static const String protection = 'protection.svg';
  static const String public_toilet = 'public_toilet.svg';
  static const String pull_door = 'pull_door.svg';
  static const String pull_requests = 'pull_requests.svg';
  static const String pumpkin = 'pumpkin.svg';
  static const String pure_natural = 'pure_natural.svg';
  static const String push_door = 'push_door.svg';
  static const String puzzle = 'puzzle.svg';
  static const String pyramid = 'pyramid.svg';
  static const String pyramid_one = 'pyramid_one.svg';
  static const String qingniao_clue = 'qingniao_clue.svg';
  static const String qiyehao = 'qiyehao.svg';
  static const String quadrangular_pyramid = 'quadrangular_pyramid.svg';
  static const String quadrilateral = 'quadrilateral.svg';
  static const String quote = 'quote.svg';
  static const String radar = 'radar.svg';
  static const String radar_chart = 'radar_chart.svg';
  static const String radar_two = 'radar_two.svg';
  static const String radiation = 'radiation.svg';
  static const String radio = 'radio.svg';
  static const String radio_nanny = 'radio_nanny.svg';
  static const String radio_one = 'radio_one.svg';
  static const String radio_two = 'radio_two.svg';
  static const String radish = 'radish.svg';
  static const String radish_one = 'radish_one.svg';
  static const String railway = 'railway.svg';
  static const String ranking = 'ranking.svg';
  static const String ranking_list = 'ranking_list.svg';
  static const String rattle = 'rattle.svg';
  static const String rattle_one = 'rattle_one.svg';
  static const String razor = 'razor.svg';
  static const String receive = 'receive.svg';
  static const String receiver = 'receiver.svg';
  static const String recent_views_sort = 'recent_views_sort.svg';
  static const String record = 'record.svg';
  static const String record_disc = 'record_disc.svg';
  static const String record_player = 'record_player.svg';
  static const String rectangle = 'rectangle.svg';
  static const String rectangle_one = 'rectangle_one.svg';
  static const String rectangle_small = 'rectangle_small.svg';
  static const String rectangle_tear = 'rectangle_tear.svg';
  static const String rectangle_x = 'rectangle_x.svg';
  static const String rectangular_circular_connection = 'rectangular_circular_connection.svg';
  static const String rectangular_circular_separation = 'rectangular_circular_separation.svg';
  static const String rectangular_vertebra = 'rectangular_vertebra.svg';
  static const String recycle_bin = 'recycle_bin.svg';
  static const String recycling = 'recycling.svg';
  static const String recycling_pool = 'recycling_pool.svg';
  static const String red_cross = 'red_cross.svg';
  static const String red_envelope = 'red_envelope.svg';
  static const String red_envelopes = 'red_envelopes.svg';
  static const String redo = 'redo.svg';
  static const String reduce = 'reduce.svg';
  static const String reduce_decimal_places = 'reduce_decimal_places.svg';
  static const String reduce_one = 'reduce_one.svg';
  static const String reduce_two = 'reduce_two.svg';
  static const String reduce_user = 'reduce_user.svg';
  static const String reel = 'reel.svg';
  static const String refraction = 'refraction.svg';
  static const String refresh = 'refresh.svg';
  static const String refresh_one = 'refresh_one.svg';
  static const String refrigerator = 'refrigerator.svg';
  static const String reject = 'reject.svg';
  static const String relational_graph = 'relational_graph.svg';
  static const String relieved_face = 'relieved_face.svg';
  static const String reload = 'reload.svg';
  static const String remind = 'remind.svg';
  static const String remind_disable = 'remind_disable.svg';
  static const String remote_control = 'remote_control.svg';
  static const String remote_control_one = 'remote_control_one.svg';
  static const String renal = 'renal.svg';
  static const String renault = 'renault.svg';
  static const String repair = 'repair.svg';
  static const String replay_five = 'replay_five.svg';
  static const String replay_music = 'replay_music.svg';
  static const String report = 'report.svg';
  static const String repositioning = 'repositioning.svg';
  static const String resistor = 'resistor.svg';
  static const String respect = 'respect.svg';
  static const String resting = 'resting.svg';
  static const String retro_bag = 'retro_bag.svg';
  static const String i_return = 'i_return.svg';
  static const String reverse_lens = 'reverse_lens.svg';
  static const String reverse_lens_one = 'reverse_lens_one.svg';
  static const String reverse_operation_in = 'reverse_operation_in.svg';
  static const String reverse_operation_out = 'reverse_operation_out.svg';
  static const String reverse_rotation = 'reverse_rotation.svg';
  static const String rice = 'rice.svg';
  static const String riding = 'riding.svg';
  static const String riding_one = 'riding_one.svg';
  static const String right = 'right.svg';
  static const String right_angle = 'right_angle.svg';
  static const String right_bar = 'right_bar.svg';
  static const String right_c = 'right_c.svg';
  static const String right_expand = 'right_expand.svg';
  static const String right_one = 'right_one.svg';
  static const String right_run = 'right_run.svg';
  static const String right_small = 'right_small.svg';
  static const String right_small_down = 'right_small_down.svg';
  static const String right_small_up = 'right_small_up.svg';
  static const String right_square = 'right_square.svg';
  static const String right_two = 'right_two.svg';
  static const String right_user = 'right_user.svg';
  static const String ring = 'ring.svg';
  static const String ring_one = 'ring_one.svg';
  static const String rings = 'rings.svg';
  static const String ripple = 'ripple.svg';
  static const String road = 'road.svg';
  static const String road_cone = 'road_cone.svg';
  static const String road_sign = 'road_sign.svg';
  static const String road_sign_both = 'road_sign_both.svg';
  static const String robot = 'robot.svg';
  static const String robot_one = 'robot_one.svg';
  static const String robot_two = 'robot_two.svg';
  static const String rock = 'rock.svg';
  static const String rock_gesture = 'rock_gesture.svg';
  static const String rocket = 'rocket.svg';
  static const String rocket_one = 'rocket_one.svg';
  static const String rocking_horse = 'rocking_horse.svg';
  static const String rollerskates = 'rollerskates.svg';
  static const String romper = 'romper.svg';
  static const String rope_skipping = 'rope_skipping.svg';
  static const String rope_skipping_one = 'rope_skipping_one.svg';
  static const String rotate = 'rotate.svg';
  static const String rotate_one = 'rotate_one.svg';
  static const String rotating_add = 'rotating_add.svg';
  static const String rotating_forward = 'rotating_forward.svg';
  static const String rotation = 'rotation.svg';
  static const String rotation_horizontal = 'rotation_horizontal.svg';
  static const String rotation_one = 'rotation_one.svg';
  static const String rotation_vertical = 'rotation_vertical.svg';
  static const String round = 'round.svg';
  static const String round_caliper = 'round_caliper.svg';
  static const String round_distortion = 'round_distortion.svg';
  static const String round_mask = 'round_mask.svg';
  static const String round_socket = 'round_socket.svg';
  static const String round_trip = 'round_trip.svg';
  static const String router = 'router.svg';
  static const String router_one = 'router_one.svg';
  static const String row_height = 'row_height.svg';
  static const String rowing = 'rowing.svg';
  static const String rs_male = 'rs_male.svg';
  static const String rss = 'rss.svg';
  static const String rugby = 'rugby.svg';
  static const String rugby_one = 'rugby_one.svg';
  static const String ruler = 'ruler.svg';
  static const String ruler_one = 'ruler_one.svg';
  static const String run_left = 'run_left.svg';
  static const String s_turn_down = 's_turn_down.svg';
  static const String s_turn_left = 's_turn_left.svg';
  static const String s_turn_right = 's_turn_right.svg';
  static const String s_turn_up = 's_turn_up.svg';
  static const String sailboat = 'sailboat.svg';
  static const String sailing = 'sailing.svg';
  static const String sales_report = 'sales_report.svg';
  static const String sandals = 'sandals.svg';
  static const String sandstorm = 'sandstorm.svg';
  static const String sandwich = 'sandwich.svg';
  static const String sandwich_one = 'sandwich_one.svg';
  static const String sapling = 'sapling.svg';
  static const String save = 'save.svg';
  static const String save_one = 'save_one.svg';
  static const String scale = 'scale.svg';
  static const String scallion = 'scallion.svg';
  static const String scan = 'scan.svg';
  static const String scan_code = 'scan_code.svg';
  static const String scan_setting = 'scan_setting.svg';
  static const String scanning = 'scanning.svg';
  static const String scanning_two = 'scanning_two.svg';
  static const String scatter_alignment = 'scatter_alignment.svg';
  static const String schedule = 'schedule.svg';
  static const String school = 'school.svg';
  static const String scissors = 'scissors.svg';
  static const String scoreboard = 'scoreboard.svg';
  static const String screen_rotation = 'screen_rotation.svg';
  static const String screenshot = 'screenshot.svg';
  static const String screenshot_one = 'screenshot_one.svg';
  static const String screenshot_two = 'screenshot_two.svg';
  static const String sd = 'sd.svg';
  static const String sd_card = 'sd_card.svg';
  static const String seal = 'seal.svg';
  static const String search = 'search.svg';
  static const String security = 'security.svg';
  static const String security_stall = 'security_stall.svg';
  static const String selected = 'selected.svg';
  static const String selected_focus = 'selected_focus.svg';
  static const String selfie = 'selfie.svg';
  static const String send = 'send.svg';
  static const String send_backward = 'send_backward.svg';
  static const String send_email = 'send_email.svg';
  static const String send_one = 'send_one.svg';
  static const String send_to_back = 'send_to_back.svg';
  static const String sent_to_back = 'sent_to_back.svg';
  static const String seo = 'seo.svg';
  static const String seo_folder = 'seo_folder.svg';
  static const String server = 'server.svg';
  static const String set_off = 'set_off.svg';
  static const String setting = 'setting.svg';
  static const String setting_config = 'setting_config.svg';
  static const String setting_one = 'setting_one.svg';
  static const String setting_three = 'setting_three.svg';
  static const String setting_two = 'setting_two.svg';
  static const String seven_key = 'seven_key.svg';
  static const String shade = 'shade.svg';
  static const String shake = 'shake.svg';
  static const String share = 'share.svg';
  static const String share_one = 'share_one.svg';
  static const String share_sys = 'share_sys.svg';
  static const String share_three = 'share_three.svg';
  static const String share_two = 'share_two.svg';
  static const String shaver = 'shaver.svg';
  static const String shaver_one = 'shaver_one.svg';
  static const String shaving = 'shaving.svg';
  static const String shield = 'shield.svg';
  static const String shield_add = 'shield_add.svg';
  static const String ship = 'ship.svg';
  static const String shop = 'shop.svg';
  static const String shopping = 'shopping.svg';
  static const String shopping_bag = 'shopping_bag.svg';
  static const String shopping_cart = 'shopping_cart.svg';
  static const String shopping_cart_add = 'shopping_cart_add.svg';
  static const String shopping_cart_del = 'shopping_cart_del.svg';
  static const String shopping_cart_one = 'shopping_cart_one.svg';
  static const String shopping_mall = 'shopping_mall.svg';
  static const String short_skirt = 'short_skirt.svg';
  static const String shorts = 'shorts.svg';
  static const String shovel = 'shovel.svg';
  static const String shovel_one = 'shovel_one.svg';
  static const String shower_head = 'shower_head.svg';
  static const String shrimp = 'shrimp.svg';
  static const String shuffle = 'shuffle.svg';
  static const String shuffle_one = 'shuffle_one.svg';
  static const String shutter_priority = 'shutter_priority.svg';
  static const String signal = 'signal.svg';
  static const String signal_one = 'signal_one.svg';
  static const String signal_strength = 'signal_strength.svg';
  static const String signal_tower = 'signal_tower.svg';
  static const String signal_tower_one = 'signal_tower_one.svg';
  static const String sim = 'sim.svg';
  static const String sim_card = 'sim_card.svg';
  static const String single_bed = 'single_bed.svg';
  static const String sinusoid = 'sinusoid.svg';
  static const String sippy_cup = 'sippy_cup.svg';
  static const String six = 'six.svg';
  static const String six_circular_connection = 'six_circular_connection.svg';
  static const String six_key = 'six_key.svg';
  static const String six_points = 'six_points.svg';
  static const String skate = 'skate.svg';
  static const String skates = 'skates.svg';
  static const String skating = 'skating.svg';
  static const String sketch = 'sketch.svg';
  static const String skiing_nordic = 'skiing_nordic.svg';
  static const String skull = 'skull.svg';
  static const String slave = 'slave.svg';
  static const String sleaves = 'sleaves.svg';
  static const String sleep = 'sleep.svg';
  static const String sleep_one = 'sleep_one.svg';
  static const String slide = 'slide.svg';
  static const String slide_two = 'slide_two.svg';
  static const String sliding_horizontal = 'sliding_horizontal.svg';
  static const String sliding_vertical = 'sliding_vertical.svg';
  static const String slightly_frowning_face_whit_open_mouth = 'slightly_frowning_face_whit_open_mouth.svg';
  static const String slightly_smiling_face = 'slightly_smiling_face.svg';
  static const String slippers = 'slippers.svg';
  static const String slippers_one = 'slippers_one.svg';
  static const String sly_face_whit_smile = 'sly_face_whit_smile.svg';
  static const String smart_optimization = 'smart_optimization.svg';
  static const String smiling_face = 'smiling_face.svg';
  static const String smiling_face_with_squinting_eyes = 'smiling_face_with_squinting_eyes.svg';
  static const String snacks = 'snacks.svg';
  static const String snow = 'snow.svg';
  static const String snowflake = 'snowflake.svg';
  static const String soap_bubble = 'soap_bubble.svg';
  static const String soccer = 'soccer.svg';
  static const String soccer_one = 'soccer_one.svg';
  static const String socks = 'socks.svg';
  static const String sofa = 'sofa.svg';
  static const String sofa_two = 'sofa_two.svg';
  static const String softball = 'softball.svg';
  static const String solar_energy = 'solar_energy.svg';
  static const String solar_energy_one = 'solar_energy_one.svg';
  static const String solid_state_disk = 'solid_state_disk.svg';
  static const String sorcerer_hat = 'sorcerer_hat.svg';
  static const String sort = 'sort.svg';
  static const String sort_amount_down = 'sort_amount_down.svg';
  static const String sort_amount_up = 'sort_amount_up.svg';
  static const String sort_four = 'sort_four.svg';
  static const String sort_one = 'sort_one.svg';
  static const String sort_three = 'sort_three.svg';
  static const String sort_two = 'sort_two.svg';
  static const String sound = 'sound.svg';
  static const String sound_one = 'sound_one.svg';
  static const String sound_wave = 'sound_wave.svg';
  static const String soybean_milk_maker = 'soybean_milk_maker.svg';
  static const String spa_candle = 'spa_candle.svg';
  static const String space_colony = 'space_colony.svg';
  static const String speaker = 'speaker.svg';
  static const String speaker_one = 'speaker_one.svg';
  static const String speed = 'speed.svg';
  static const String speed_one = 'speed_one.svg';
  static const String sperm = 'sperm.svg';
  static const String sphere = 'sphere.svg';
  static const String spider_man = 'spider_man.svg';
  static const String spikedshoes = 'spikedshoes.svg';
  static const String spinning_top = 'spinning_top.svg';
  static const String split = 'split.svg';
  static const String split_branch = 'split_branch.svg';
  static const String split_cells = 'split_cells.svg';
  static const String split_turn_down_left = 'split_turn_down_left.svg';
  static const String split_turn_down_right = 'split_turn_down_right.svg';
  static const String spoon = 'spoon.svg';
  static const String sport = 'sport.svg';
  static const String square = 'square.svg';
  static const String square_small = 'square_small.svg';
  static const String ssd = 'ssd.svg';
  static const String stack_light = 'stack_light.svg';
  static const String stamp = 'stamp.svg';
  static const String stapler = 'stapler.svg';
  static const String star = 'star.svg';
  static const String star_one = 'star_one.svg';
  static const String start_time_sort = 'start_time_sort.svg';
  static const String steering_wheel = 'steering_wheel.svg';
  static const String steoller = 'steoller.svg';
  static const String stereo_nesting = 'stereo_nesting.svg';
  static const String stereo_one = 'stereo_one.svg';
  static const String stereo_perspective = 'stereo_perspective.svg';
  static const String stethoscope = 'stethoscope.svg';
  static const String stickers = 'stickers.svg';
  static const String stock_market = 'stock_market.svg';
  static const String stopwatch = 'stopwatch.svg';
  static const String stopwatch_start = 'stopwatch_start.svg';
  static const String storage_card_one = 'storage_card_one.svg';
  static const String storage_card_two = 'storage_card_two.svg';
  static const String straight_razor = 'straight_razor.svg';
  static const String straw_hat = 'straw_hat.svg';
  static const String stretching = 'stretching.svg';
  static const String strikethrough = 'strikethrough.svg';
  static const String strongbox = 'strongbox.svg';
  static const String subtract_selection = 'subtract_selection.svg';
  static const String subtract_selection_one = 'subtract_selection_one.svg';
  static const String subway = 'subway.svg';
  static const String success = 'success.svg';
  static const String sum = 'sum.svg';
  static const String sun = 'sun.svg';
  static const String sun_hat = 'sun_hat.svg';
  static const String sun_one = 'sun_one.svg';
  static const String sunbath = 'sunbath.svg';
  static const String sunny = 'sunny.svg';
  static const String sunrise = 'sunrise.svg';
  static const String sunshade = 'sunshade.svg';
  static const String surprised_face_with_open_big_mouth = 'surprised_face_with_open_big_mouth.svg';
  static const String surprised_face_with_open_mouth = 'surprised_face_with_open_mouth.svg';
  static const String surveillance_cameras = 'surveillance_cameras.svg';
  static const String surveillance_cameras_one = 'surveillance_cameras_one.svg';
  static const String surveillance_cameras_two = 'surveillance_cameras_two.svg';
  static const String swallow = 'swallow.svg';
  static const String sweater = 'sweater.svg';
  static const String swimming_pool = 'swimming_pool.svg';
  static const String swimming_ring = 'swimming_ring.svg';
  static const String swimsuit = 'swimsuit.svg';
  static const String swing = 'swing.svg';
  static const String swipe = 'swipe.svg';
  static const String i_switch = 'i_switch.svg';
  static const String switch_button = 'switch_button.svg';
  static const String switch_contrast = 'switch_contrast.svg';
  static const String switch_nintendo = 'switch_nintendo.svg';
  static const String switch_one = 'switch_one.svg';
  static const String switch_themes = 'switch_themes.svg';
  static const String switch_track = 'switch_track.svg';
  static const String switching_done = 'switching_done.svg';
  static const String symbol = 'symbol.svg';
  static const String symbol_double_x = 'symbol_double_x.svg';
  static const String symmetry = 'symmetry.svg';
  static const String i_sync = 'i_sync.svg';
  static const String system = 'system.svg';
  static const String t_shirt = 't_shirt.svg';
  static const String table = 'table.svg';
  static const String table_file = 'table_file.svg';
  static const String table_lamp = 'table_lamp.svg';
  static const String table_report = 'table_report.svg';
  static const String tabletennis = 'tabletennis.svg';
  static const String tag = 'tag.svg';
  static const String tag_one = 'tag_one.svg';
  static const String tailoring = 'tailoring.svg';
  static const String tailoring_two = 'tailoring_two.svg';
  static const String taj_mahal = 'taj_mahal.svg';
  static const String take_off = 'take_off.svg';
  static const String taobao = 'taobao.svg';
  static const String tape = 'tape.svg';
  static const String target = 'target.svg';
  static const String target_one = 'target_one.svg';
  static const String target_two = 'target_two.svg';
  static const String taxi = 'taxi.svg';
  static const String tea = 'tea.svg';
  static const String tea_drink = 'tea_drink.svg';
  static const String teapot = 'teapot.svg';
  static const String teeth = 'teeth.svg';
  static const String telegram = 'telegram.svg';
  static const String telescope = 'telescope.svg';
  static const String tencent_qq = 'tencent_qq.svg';
  static const String tennis = 'tennis.svg';
  static const String tent = 'tent.svg';
  static const String tent_banner = 'tent_banner.svg';
  static const String terminal = 'terminal.svg';
  static const String termination_file = 'termination_file.svg';
  static const String test_tube = 'test_tube.svg';
  static const String text = 'text.svg';
  static const String text_bold = 'text_bold.svg';
  static const String text_italic = 'text_italic.svg';
  static const String text_message = 'text_message.svg';
  static const String text_recognition = 'text_recognition.svg';
  static const String text_rotation_down = 'text_rotation_down.svg';
  static const String text_rotation_left = 'text_rotation_left.svg';
  static const String text_rotation_none = 'text_rotation_none.svg';
  static const String text_rotation_up = 'text_rotation_up.svg';
  static const String text_style = 'text_style.svg';
  static const String text_style_one = 'text_style_one.svg';
  static const String text_underline = 'text_underline.svg';
  static const String text_wrap_overflow = 'text_wrap_overflow.svg';
  static const String text_wrap_truncation = 'text_wrap_truncation.svg';
  static const String textarea = 'textarea.svg';
  static const String texture = 'texture.svg';
  static const String texture_two = 'texture_two.svg';
  static const String the_single_shoulder_bag = 'the_single_shoulder_bag.svg';
  static const String theater = 'theater.svg';
  static const String theme_ = 'theme.svg';
  static const String thermometer = 'thermometer.svg';
  static const String thermos_cup = 'thermos_cup.svg';
  static const String thin = 'thin.svg';
  static const String thinking_problem = 'thinking_problem.svg';
  static const String three = 'three.svg';
  static const String three_d_glasses = 'three_d_glasses.svg';
  static const String three_hexagons = 'three_hexagons.svg';
  static const String three_key = 'three_key.svg';
  static const String three_slashes = 'three_slashes.svg';
  static const String three_three = 'three_three.svg';
  static const String three_triangles = 'three_triangles.svg';
  static const String thumbs_down = 'thumbs_down.svg';
  static const String thumbs_up = 'thumbs_up.svg';
  static const String thunderbolt = 'thunderbolt.svg';
  static const String thunderstorm = 'thunderstorm.svg';
  static const String thunderstorm_one = 'thunderstorm_one.svg';
  static const String ticket = 'ticket.svg';
  static const String ticket_one = 'ticket_one.svg';
  static const String tickets_checked = 'tickets_checked.svg';
  static const String tickets_one = 'tickets_one.svg';
  static const String tickets_two = 'tickets_two.svg';
  static const String tiktok = 'tiktok.svg';
  static const String time = 'time.svg';
  static const String timed_mail = 'timed_mail.svg';
  static const String timeline = 'timeline.svg';
  static const String timer = 'timer.svg';
  static const String tips = 'tips.svg';
  static const String tips_one = 'tips_one.svg';
  static const String tire_swing = 'tire_swing.svg';
  static const String title_level = 'title_level.svg';
  static const String to_bottom = 'to_bottom.svg';
  static const String to_bottom_one = 'to_bottom_one.svg';
  static const String to_left = 'to_left.svg';
  static const String to_right = 'to_right.svg';
  static const String to_top = 'to_top.svg';
  static const String to_top_one = 'to_top_one.svg';
  static const String toilet = 'toilet.svg';
  static const String tomato = 'tomato.svg';
  static const String tool = 'tool.svg';
  static const String top_bar = 'top_bar.svg';
  static const String topbuzz = 'topbuzz.svg';
  static const String topic = 'topic.svg';
  static const String topic_discussion = 'topic_discussion.svg';
  static const String torch = 'torch.svg';
  static const String tour_bus = 'tour_bus.svg';
  static const String towel = 'towel.svg';
  static const String tower = 'tower.svg';
  static const String tower_of_babel = 'tower_of_babel.svg';
  static const String tower_of_pisa = 'tower_of_pisa.svg';
  static const String toxins = 'toxins.svg';
  static const String trace = 'trace.svg';
  static const String trademark = 'trademark.svg';
  static const String traditional_chinese_medicine = 'traditional_chinese_medicine.svg';
  static const String transaction = 'transaction.svg';
  static const String transaction_order = 'transaction_order.svg';
  static const String transfer = 'transfer.svg';
  static const String transfer_data = 'transfer_data.svg';
  static const String transform = 'transform.svg';
  static const String translate = 'translate.svg';
  static const String translation = 'translation.svg';
  static const String transport = 'transport.svg';
  static const String transporter = 'transporter.svg';
  static const String trapezoid = 'trapezoid.svg';
  static const String tray = 'tray.svg';
  static const String treadmill = 'treadmill.svg';
  static const String treadmill_one = 'treadmill_one.svg';
  static const String treasure_chest = 'treasure_chest.svg';
  static const String tree = 'tree.svg';
  static const String tree_diagram = 'tree_diagram.svg';
  static const String tree_list = 'tree_list.svg';
  static const String trend = 'trend.svg';
  static const String trend_two = 'trend_two.svg';
  static const String trending_down = 'trending_down.svg';
  static const String trending_up = 'trending_up.svg';
  static const String triangle = 'triangle.svg';
  static const String triangle_round_rectangle = 'triangle_round_rectangle.svg';
  static const String triangle_ruler = 'triangle_ruler.svg';
  static const String triangular_pyramid = 'triangular_pyramid.svg';
  static const String trophy = 'trophy.svg';
  static const String trousers_bell_bottoms = 'trousers_bell_bottoms.svg';
  static const String truck = 'truck.svg';
  static const String trumpet = 'trumpet.svg';
  static const String trunk = 'trunk.svg';
  static const String tuchong = 'tuchong.svg';
  static const String tumblr = 'tumblr.svg';
  static const String turkey = 'turkey.svg';
  static const String turn_around = 'turn_around.svg';
  static const String turn_off_bluetooth = 'turn_off_bluetooth.svg';
  static const String turn_on = 'turn_on.svg';
  static const String tv = 'tv.svg';
  static const String tv_one = 'tv_one.svg';
  static const String twitter = 'twitter.svg';
  static const String two = 'two.svg';
  static const String two_dimensional_code = 'two_dimensional_code.svg';
  static const String two_dimensional_code_one = 'two_dimensional_code_one.svg';
  static const String two_dimensional_code_two = 'two_dimensional_code_two.svg';
  static const String two_ellipses = 'two_ellipses.svg';
  static const String two_fingers = 'two_fingers.svg';
  static const String two_hands = 'two_hands.svg';
  static const String two_key = 'two_key.svg';
  static const String two_semicircles = 'two_semicircles.svg';
  static const String two_triangles = 'two_triangles.svg';
  static const String two_triangles_two = 'two_triangles_two.svg';
  static const String two_two = 'two_two.svg';
  static const String type_drive = 'type_drive.svg';
  static const String u_disk = 'u_disk.svg';
  static const String u_turn_down = 'u_turn_down.svg';
  static const String u_turn_left = 'u_turn_left.svg';
  static const String u_turn_right = 'u_turn_right.svg';
  static const String u_turn_up = 'u_turn_up.svg';
  static const String ulikecam = 'ulikecam.svg';
  static const String umbrella = 'umbrella.svg';
  static const String umbrella_one = 'umbrella_one.svg';
  static const String umbrella_two = 'umbrella_two.svg';
  static const String undo = 'undo.svg';
  static const String ungroup = 'ungroup.svg';
  static const String unicast = 'unicast.svg';
  static const String union_selection = 'union_selection.svg';
  static const String universal = 'universal.svg';
  static const String unlike = 'unlike.svg';
  static const String unlink = 'unlink.svg';
  static const String unlock = 'unlock.svg';
  static const String unordered_list = 'unordered_list.svg';
  static const String up = 'up.svg';
  static const String up_and_down = 'up_and_down.svg';
  static const String up_c = 'up_c.svg';
  static const String up_one = 'up_one.svg';
  static const String up_small = 'up_small.svg';
  static const String up_square = 'up_square.svg';
  static const String up_two = 'up_two.svg';
  static const String update_rotation = 'update_rotation.svg';
  static const String upload = 'upload.svg';
  static const String upload_logs = 'upload_logs.svg';
  static const String upload_one = 'upload_one.svg';
  static const String upload_three = 'upload_three.svg';
  static const String upload_two = 'upload_two.svg';
  static const String upside_down_face = 'upside_down_face.svg';
  static const String usb = 'usb.svg';
  static const String usb_memory_stick = 'usb_memory_stick.svg';
  static const String usb_micro_one = 'usb_micro_one.svg';
  static const String usb_micro_two = 'usb_micro_two.svg';
  static const String usb_one = 'usb_one.svg';
  static const String usb_type_c = 'usb_type_c.svg';
  static const String user = 'user.svg';
  static const String user_business = 'user_business.svg';
  static const String user_positioning = 'user_positioning.svg';
  static const String user_to_user_transmission = 'user_to_user_transmission.svg';
  static const String uterus = 'uterus.svg';
  static const String vacuum_cleaner = 'vacuum_cleaner.svg';
  static const String vegetable_basket = 'vegetable_basket.svg';
  static const String vegetables = 'vegetables.svg';
  static const String vertical_spacing_between_items = 'vertical_spacing_between_items.svg';
  static const String vertical_tidy_up = 'vertical_tidy_up.svg';
  static const String vertical_timeline = 'vertical_timeline.svg';
  static const String vertically_centered = 'vertically_centered.svg';
  static const String vest = 'vest.svg';
  static const String vial = 'vial.svg';
  static const String vicia_faba = 'vicia_faba.svg';
  static const String video = 'video.svg';
  static const String video_file = 'video_file.svg';
  static const String video_one = 'video_one.svg';
  static const String video_two = 'video_two.svg';
  static const String videocamera = 'videocamera.svg';
  static const String videocamera_one = 'videocamera_one.svg';
  static const String viencharts = 'viencharts.svg';
  static const String view_grid_card = 'view_grid_card.svg';
  static const String view_grid_detail = 'view_grid_detail.svg';
  static const String view_grid_list = 'view_grid_list.svg';
  static const String view_list = 'view_list.svg';
  static const String viewfinder = 'viewfinder.svg';
  static const String vigo = 'vigo.svg';
  static const String vip = 'vip.svg';
  static const String virtual_reality_glasses = 'virtual_reality_glasses.svg';
  static const String voice = 'voice.svg';
  static const String voice_input = 'voice_input.svg';
  static const String voice_message = 'voice_message.svg';
  static const String voice_off = 'voice_off.svg';
  static const String voice_one = 'voice_one.svg';
  static const String voicemail = 'voicemail.svg';
  static const String volkswagen = 'volkswagen.svg';
  static const String volleyball = 'volleyball.svg';
  static const String volume_down = 'volume_down.svg';
  static const String volume_mute = 'volume_mute.svg';
  static const String volume_notice = 'volume_notice.svg';
  static const String volume_small = 'volume_small.svg';
  static const String volume_up = 'volume_up.svg';
  static const String vr_glasses = 'vr_glasses.svg';
  static const String wallet = 'wallet.svg';
  static const String wallet_one = 'wallet_one.svg';
  static const String wallet_two = 'wallet_two.svg';
  static const String warehousing = 'warehousing.svg';
  static const String washing_machine = 'washing_machine.svg';
  static const String washing_machine_one = 'washing_machine_one.svg';
  static const String watch = 'watch.svg';
  static const String watch_one = 'watch_one.svg';
  static const String water = 'water.svg';
  static const String water_level = 'water_level.svg';
  static const String water_no = 'water_no.svg';
  static const String water_rate = 'water_rate.svg';
  static const String water_rate_two = 'water_rate_two.svg';
  static const String waterfalls_h = 'waterfalls_h.svg';
  static const String waterfalls_v = 'waterfalls_v.svg';
  static const String watermelon = 'watermelon.svg';
  static const String watermelon_one = 'watermelon_one.svg';
  static const String waterpolo = 'waterpolo.svg';
  static const String waterpolo_one = 'waterpolo_one.svg';
  static const String waves = 'waves.svg';
  static const String waves_left = 'waves_left.svg';
  static const String waves_right = 'waves_right.svg';
  static const String weary_face = 'weary_face.svg';
  static const String webcam = 'webcam.svg';
  static const String wechat = 'wechat.svg';
  static const String weibo = 'weibo.svg';
  static const String weight = 'weight.svg';
  static const String weightlifting = 'weightlifting.svg';
  static const String weixin_cards_offers = 'weixin_cards_offers.svg';
  static const String weixin_favorites = 'weixin_favorites.svg';
  static const String weixin_games = 'weixin_games.svg';
  static const String weixin_market = 'weixin_market.svg';
  static const String weixin_mini_app = 'weixin_mini_app.svg';
  static const String weixin_people_nearby = 'weixin_people_nearby.svg';
  static const String weixin_scan = 'weixin_scan.svg';
  static const String weixin_search = 'weixin_search.svg';
  static const String weixin_shake = 'weixin_shake.svg';
  static const String weixin_top_stories = 'weixin_top_stories.svg';
  static const String wheelchair = 'wheelchair.svg';
  static const String whirlwind = 'whirlwind.svg';
  static const String whistling = 'whistling.svg';
  static const String whole_site_accelerator = 'whole_site_accelerator.svg';
  static const String wifi = 'wifi.svg';
  static const String wind = 'wind.svg';
  static const String wind_turbine = 'wind_turbine.svg';
  static const String windmill = 'windmill.svg';
  static const String windmill_one = 'windmill_one.svg';
  static const String windmill_two = 'windmill_two.svg';
  static const String windows = 'windows.svg';
  static const String wingsuit_flying = 'wingsuit_flying.svg';
  static const String winking_face = 'winking_face.svg';
  static const String winking_face_with_open_eyes = 'winking_face_with_open_eyes.svg';
  static const String woman = 'woman.svg';
  static const String women_coat = 'women_coat.svg';
  static const String woolen_hat = 'woolen_hat.svg';
  static const String word = 'word.svg';
  static const String workbench = 'workbench.svg';
  static const String worker = 'worker.svg';
  static const String world = 'world.svg';
  static const String worried_face = 'worried_face.svg';
  static const String write = 'write.svg';
  static const String writing_fluently = 'writing_fluently.svg';
  static const String wrong_user = 'wrong_user.svg';
  static const String xiaodu = 'xiaodu.svg';
  static const String xiaodu_home = 'xiaodu_home.svg';
  static const String xigua = 'xigua.svg';
  static const String xingfuli = 'xingfuli.svg';
  static const String xingtu = 'xingtu.svg';
  static const String yep = 'yep.svg';
  static const String youtobe = 'youtobe.svg';
  static const String youtube = 'youtube.svg';
  static const String zero_key = 'zero_key.svg';
  static const String zijinyunying = 'zijinyunying.svg';
  static const String zip = 'zip.svg';
  static const String zoom = 'zoom.svg';
  static const String zoom_in = 'zoom_in.svg';
  static const String zoom_internal = 'zoom_internal.svg';
  static const String zoom_out = 'zoom_out.svg';
}
