import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

import 'icon_forest.dart';

/// Koukicons icons (692 icons)
///
/// - build svg for koukicons icon libraries
/// - constants link to svg icon resources
class Koukicons extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  const Koukicons(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return IconForest.svgAsset(
      'koukicons',
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  static const String about = 'about.svg';
  static const String acceptDatabase = 'acceptDatabase.svg';
  static const String add = 'add.svg';
  static const String add2 = 'add2.svg';
  static const String add3 = 'add3.svg';
  static const String addApp = 'addApp.svg';
  static const String addColumn = 'addColumn.svg';
  static const String addDatabase = 'addDatabase.svg';
  static const String addImage = 'addImage.svg';
  static const String addRow = 'addRow.svg';
  static const String addWin = 'addWin.svg';
  static const String addressBook = 'addressBook.svg';
  static const String advance = 'advance.svg';
  static const String advertising = 'advertising.svg';
  static const String airdrop = 'airdrop.svg';
  static const String airplay = 'airplay.svg';
  static const String alarm1 = 'alarm1.svg';
  static const String alarm2 = 'alarm2.svg';
  static const String alarmClock = 'alarmClock.svg';
  static const String alarmoff = 'alarmoff.svg';
  static const String album = 'album.svg';
  static const String albumCd = 'albumCd.svg';
  static const String albums = 'albums.svg';
  static const String albums2 = 'albums2.svg';
  static const String albumsView = 'albumsView.svg';
  static const String alphabeticalSortingAz = 'alphabeticalSortingAz.svg';
  static const String alphabeticalSortingZa = 'alphabeticalSortingZa.svg';
  static const String answers = 'answers.svg';
  static const String approval = 'approval.svg';
  static const String approve = 'approve.svg';
  static const String archive = 'archive.svg';
  static const String archive2 = 'archive2.svg';
  static const String archive3 = 'archive3.svg';
  static const String areaChart = 'areaChart.svg';
  static const String assistant = 'assistant.svg';
  static const String attach = 'attach.svg';
  static const String audioFile = 'audioFile.svg';
  static const String automatic = 'automatic.svg';
  static const String automotive = 'automotive.svg';
  static const String back = 'back.svg';
  static const String back2 = 'back2.svg';
  static const String badDecision = 'badDecision.svg';
  static const String barChart = 'barChart.svg';
  static const String bearish = 'bearish.svg';
  static const String binoculars = 'binoculars.svg';
  static const String biohazard = 'biohazard.svg';
  static const String biomass = 'biomass.svg';
  static const String biotech = 'biotech.svg';
  static const String blueprint = 'blueprint.svg';
  static const String bluetooth = 'bluetooth.svg';
  static const String bluetooth2 = 'bluetooth2.svg';
  static const String bookmark = 'bookmark.svg';
  static const String bookmark2 = 'bookmark2.svg';
  static const String bookmarkC = 'bookmarkC.svg';
  static const String box = 'box.svg';
  static const String boxArchive = 'boxArchive.svg';
  static const String boxArchive2 = 'boxArchive2.svg';
  static const String briefcase = 'briefcase.svg';
  static const String brokenLink = 'brokenLink.svg';
  static const String brokenLink2 = 'brokenLink2.svg';
  static const String bullish = 'bullish.svg';
  static const String business = 'business.svg';
  static const String businessContact = 'businessContact.svg';
  static const String businessman = 'businessman.svg';
  static const String businesswoman = 'businesswoman.svg';
  static const String buttingIn = 'buttingIn.svg';
  static const String cableRelease = 'cableRelease.svg';
  static const String calc = 'calc.svg';
  static const String calc2 = 'calc2.svg';
  static const String calculator = 'calculator.svg';
  static const String calend = 'calend.svg';
  static const String calendar = 'calendar.svg';
  static const String calendar1 = 'calendar1.svg';
  static const String calendar2 = 'calendar2.svg';
  static const String calendar3 = 'calendar3.svg';
  static const String calendar4 = 'calendar4.svg';
  static const String calendar5 = 'calendar5.svg';
  static const String callTransfer = 'callTransfer.svg';
  static const String callback = 'callback.svg';
  static const String camcorder = 'camcorder.svg';
  static const String camcorderPro = 'camcorderPro.svg';
  static const String camera = 'camera.svg';
  static const String camera2 = 'camera2.svg';
  static const String cameraAddon = 'cameraAddon.svg';
  static const String cameraIdentification = 'cameraIdentification.svg';
  static const String camx = 'camx.svg';
  static const String cancel = 'cancel.svg';
  static const String candleSticks = 'candleSticks.svg';
  static const String capacitor = 'capacitor.svg';
  static const String caseX = 'caseX.svg';
  static const String cd = 'cd.svg';
  static const String cd2 = 'cd2.svg';
  static const String cellPhone = 'cellPhone.svg';
  static const String chargeBattery = 'chargeBattery.svg';
  static const String chargingBattery = 'chargingBattery.svg';
  static const String checklist = 'checklist.svg';
  static const String checkmark = 'checkmark.svg';
  static const String circuit = 'circuit.svg';
  static const String clapperboard = 'clapperboard.svg';
  static const String clearFilters = 'clearFilters.svg';
  static const String clock = 'clock.svg';
  static const String clock2 = 'clock2.svg';
  static const String clocktime = 'clocktime.svg';
  static const String closeUpMode = 'closeUpMode.svg';
  static const String cloth = 'cloth.svg';
  static const String cloud = 'cloud.svg';
  static const String cloudDown = 'cloudDown.svg';
  static const String cloudSearch = 'cloudSearch.svg';
  static const String cloudSync = 'cloudSync.svg';
  static const String cloudTransfert = 'cloudTransfert.svg';
  static const String cloudUpload = 'cloudUpload.svg';
  static const String cloudWarning = 'cloudWarning.svg';
  static const String collaboration = 'collaboration.svg';
  static const String collapse = 'collapse.svg';
  static const String collect = 'collect.svg';
  static const String comboChart = 'comboChart.svg';
  static const String command = 'command.svg';
  static const String comments = 'comments.svg';
  static const String compactCamera = 'compactCamera.svg';
  static const String compass = 'compass.svg';
  static const String compose = 'compose.svg';
  static const String conferenceCall = 'conferenceCall.svg';
  static const String connectedNetwork = 'connectedNetwork.svg';
  static const String contacts = 'contacts.svg';
  static const String controls1 = 'controls1.svg';
  static const String controls10 = 'controls10.svg';
  static const String controls2 = 'controls2.svg';
  static const String controls3 = 'controls3.svg';
  static const String controls4 = 'controls4.svg';
  static const String controls5 = 'controls5.svg';
  static const String controls6 = 'controls6.svg';
  static const String controls7 = 'controls7.svg';
  static const String controls8 = 'controls8.svg';
  static const String controls9 = 'controls9.svg';
  static const String copyleft = 'copyleft.svg';
  static const String copyright = 'copyright.svg';
  static const String crystalOscillator = 'crystalOscillator.svg';
  static const String currencyExchange = 'currencyExchange.svg';
  static const String cursor = 'cursor.svg';
  static const String customerSupport = 'customerSupport.svg';
  static const String dam = 'dam.svg';
  static const String dataBackup = 'dataBackup.svg';
  static const String dataConfiguration = 'dataConfiguration.svg';
  static const String dataEncryption = 'dataEncryption.svg';
  static const String dataProtection = 'dataProtection.svg';
  static const String dataRecovery = 'dataRecovery.svg';
  static const String dataSheet = 'dataSheet.svg';
  static const String database = 'database.svg';
  static const String database2 = 'database2.svg';
  static const String database3 = 'database3.svg';
  static const String databaseNetwork = 'databaseNetwork.svg';
  static const String databaseX = 'databaseX.svg';
  static const String debt = 'debt.svg';
  static const String decision = 'decision.svg';
  static const String deleteColumn = 'deleteColumn.svg';
  static const String deleteDatabase = 'deleteDatabase.svg';
  static const String deleteRow = 'deleteRow.svg';
  static const String department = 'department.svg';
  static const String deployment = 'deployment.svg';
  static const String dialPad = 'dialPad.svg';
  static const String diamond = 'diamond.svg';
  static const String diploamaX = 'diploamaX.svg';
  static const String diploma = 'diploma.svg';
  static const String diploma1 = 'diploma1.svg';
  static const String disapprove = 'disapprove.svg';
  static const String disclaimer = 'disclaimer.svg';
  static const String disconnectedNetwork = 'disconnectedNetwork.svg';
  static const String dislike = 'dislike.svg';
  static const String disliked = 'disliked.svg';
  static const String display = 'display.svg';
  static const String divide = 'divide.svg';
  static const String divide2 = 'divide2.svg';
  static const String divide3 = 'divide3.svg';
  static const String doNotInhale = 'doNotInhale.svg';
  static const String doNotInsert = 'doNotInsert.svg';
  static const String doNotMix = 'doNotMix.svg';
  static const String doc = 'doc.svg';
  static const String docFolder = 'docFolder.svg';
  static const String docFolder2 = 'docFolder2.svg';
  static const String docFolder3 = 'docFolder3.svg';
  static const String docFolder4 = 'docFolder4.svg';
  static const String document = 'document.svg';
  static const String donate = 'donate.svg';
  static const String doughnutChart = 'doughnutChart.svg';
  static const String down = 'down.svg';
  static const String downLeft = 'downLeft.svg';
  static const String downRight = 'downRight.svg';
  static const String download = 'download.svg';
  static const String downloadFolder = 'downloadFolder.svg';
  static const String downloadX = 'downloadX.svg';
  static const String drainingBattery = 'drainingBattery.svg';
  static const String drainingBattery2 = 'drainingBattery2.svg';
  static const String driverLicence = 'driverLicence.svg';
  static const String edit = 'edit.svg';
  static const String editDoc = 'editDoc.svg';
  static const String editImage = 'editImage.svg';
  static const String eject = 'eject.svg';
  static const String eject2 = 'eject2.svg';
  static const String electricalSensor = 'electricalSensor.svg';
  static const String electricalThreshold = 'electricalThreshold.svg';
  static const String electricity = 'electricity.svg';
  static const String electroDevices = 'electroDevices.svg';
  static const String electronics = 'electronics.svg';
  static const String employeeBadge = 'employeeBadge.svg';
  static const String employeeBadge2 = 'employeeBadge2.svg';
  static const String employeeBadge3 = 'employeeBadge3.svg';
  static const String employeeBadge4 = 'employeeBadge4.svg';
  static const String emptyBattery = 'emptyBattery.svg';
  static const String emptyFilter = 'emptyFilter.svg';
  static const String emptyTrash = 'emptyTrash.svg';
  static const String endCall = 'endCall.svg';
  static const String engineering = 'engineering.svg';
  static const String enter = 'enter.svg';
  static const String enteringHeavenAlive = 'enteringHeavenAlive.svg';
  static const String equal = 'equal.svg';
  static const String equal2 = 'equal2.svg';
  static const String equal3 = 'equal3.svg';
  static const String error = 'error.svg';
  static const String eventDate = 'eventDate.svg';
  static const String eventDate2 = 'eventDate2.svg';
  static const String exitArrow = 'exitArrow.svg';
  static const String exitDoor = 'exitDoor.svg';
  static const String exitDoor2 = 'exitDoor2.svg';
  static const String exitWin = 'exitWin.svg';
  static const String expand = 'expand.svg';
  static const String expired = 'expired.svg';
  static const String export = 'export.svg';
  static const String external = 'external.svg';
  static const String factory = 'factory.svg';
  static const String factoryBreakdown = 'factoryBreakdown.svg';
  static const String faq = 'faq.svg';
  static const String fastBack = 'fastBack.svg';
  static const String fastBack2 = 'fastBack2.svg';
  static const String fastForward = 'fastForward.svg';
  static const String fastForward2 = 'fastForward2.svg';
  static const String favourite = 'favourite.svg';
  static const String favourite2 = 'favourite2.svg';
  static const String fax = 'fax.svg';
  static const String feedIn = 'feedIn.svg';
  static const String feedback = 'feedback.svg';
  static const String file = 'file.svg';
  static const String files = 'files.svg';
  static const String files2 = 'files2.svg';
  static const String filingCabinet = 'filingCabinet.svg';
  static const String filledFilter = 'filledFilter.svg';
  static const String film = 'film.svg';
  static const String filmReel = 'filmReel.svg';
  static const String finePrint = 'finePrint.svg';
  static const String fingerprint = 'fingerprint.svg';
  static const String flag1 = 'flag1.svg';
  static const String flag2 = 'flag2.svg';
  static const String flag3 = 'flag3.svg';
  static const String flag4 = 'flag4.svg';
  static const String flag5 = 'flag5.svg';
  static const String flashAuto = 'flashAuto.svg';
  static const String flashOff = 'flashOff.svg';
  static const String flashOn = 'flashOn.svg';
  static const String flipboard = 'flipboard.svg';
  static const String flipboard2 = 'flipboard2.svg';
  static const String flowChart = 'flowChart.svg';
  static const String focus = 'focus.svg';
  static const String folder = 'folder.svg';
  static const String folder2 = 'folder2.svg';
  static const String folder3 = 'folder3.svg';
  static const String folder4 = 'folder4.svg';
  static const String folder5 = 'folder5.svg';
  static const String folder6 = 'folder6.svg';
  static const String folder7 = 'folder7.svg';
  static const String folderX = 'folderX.svg';
  static const String forbidden = 'forbidden.svg';
  static const String forward = 'forward.svg';
  static const String forward2 = 'forward2.svg';
  static const String frame = 'frame.svg';
  static const String framePic = 'framePic.svg';
  static const String fullBattery = 'fullBattery.svg';
  static const String fullBattery2 = 'fullBattery2.svg';
  static const String fullBattery3 = 'fullBattery3.svg';
  static const String fullTrash = 'fullTrash.svg';
  static const String funnel = 'funnel.svg';
  static const String gallery = 'gallery.svg';
  static const String galleryX = 'galleryX.svg';
  static const String genealogy = 'genealogy.svg';
  static const String genericSortingAsc = 'genericSortingAsc.svg';
  static const String genericSortingDesc = 'genericSortingDesc.svg';
  static const String gift = 'gift.svg';
  static const String glasses = 'glasses.svg';
  static const String globe = 'globe.svg';
  static const String goodDecision = 'goodDecision.svg';
  static const String graduationCap = 'graduationCap.svg';
  static const String grid = 'grid.svg';
  static const String halfBattery = 'halfBattery.svg';
  static const String halfBattery2 = 'halfBattery2.svg';
  static const String hambMenu = 'hambMenu.svg';
  static const String hambMenu2 = 'hambMenu2.svg';
  static const String headset = 'headset.svg';
  static const String heatMap = 'heatMap.svg';
  static const String help = 'help.svg';
  static const String help2 = 'help2.svg';
  static const String hide = 'hide.svg';
  static const String highBattery = 'highBattery.svg';
  static const String highPriority = 'highPriority.svg';
  static const String highVol = 'highVol.svg';
  static const String highVol2 = 'highVol2.svg';
  static const String home = 'home.svg';
  static const String home1 = 'home1.svg';
  static const String home2 = 'home2.svg';
  static const String home3 = 'home3.svg';
  static const String home4 = 'home4.svg';
  static const String icons8Cup = 'icons8Cup.svg';
  static const String id = 'id.svg';
  static const String idea = 'idea.svg';
  static const String ideaX = 'ideaX.svg';
  static const String imageFile = 'imageFile.svg';
  static const String import = 'import.svg';
  static const String importantArchive = 'importantArchive.svg';
  static const String inTransit = 'inTransit.svg';
  static const String infinity = 'infinity.svg';
  static const String info = 'info.svg';
  static const String inspection = 'inspection.svg';
  static const String integratedWebcam = 'integratedWebcam.svg';
  static const String internal = 'internal.svg';
  static const String internet = 'internet.svg';
  static const String invite = 'invite.svg';
  static const String ipad = 'ipad.svg';
  static const String iphone = 'iphone.svg';
  static const String key1 = 'key1.svg';
  static const String key2 = 'key2.svg';
  static const String kindle = 'kindle.svg';
  static const String knob = 'knob.svg';
  static const String knob2 = 'knob2.svg';
  static const String lamp = 'lamp.svg';
  static const String lan = 'lan.svg';
  static const String landscape = 'landscape.svg';
  static const String layers = 'layers.svg';
  static const String layers2 = 'layers2.svg';
  static const String leakingBattery = 'leakingBattery.svg';
  static const String leave = 'leave.svg';
  static const String left = 'left.svg';
  static const String leftDown = 'leftDown.svg';
  static const String leftDown2 = 'leftDown2.svg';
  static const String leftUp = 'leftUp.svg';
  static const String leftUp2 = 'leftUp2.svg';
  static const String library = 'library.svg';
  static const String lightAtTheEndOfTunnel = 'lightAtTheEndOfTunnel.svg';
  static const String like = 'like.svg';
  static const String like2 = 'like2.svg';
  static const String likePlaceholder = 'likePlaceholder.svg';
  static const String likeX = 'likeX.svg';
  static const String lineChart = 'lineChart.svg';
  static const String link = 'link.svg';
  static const String linkGreen = 'linkGreen.svg';
  static const String list = 'list.svg';
  static const String liveNews = 'liveNews.svg';
  static const String location = 'location.svg';
  static const String location2 = 'location2.svg';
  static const String location3 = 'location3.svg';
  static const String locationArea = 'locationArea.svg';
  static const String locationPin = 'locationPin.svg';
  static const String lock = 'lock.svg';
  static const String lock2 = 'lock2.svg';
  static const String lock3 = 'lock3.svg';
  static const String lock4 = 'lock4.svg';
  static const String lockFolder = 'lockFolder.svg';
  static const String lockLandscape = 'lockLandscape.svg';
  static const String lockOri = 'lockOri.svg';
  static const String lockPortrait = 'lockPortrait.svg';
  static const String lockX = 'lockX.svg';
  static const String locked = 'locked.svg';
  static const String lowBattery = 'lowBattery.svg';
  static const String lowBattery2 = 'lowBattery2.svg';
  static const String lowBattery3 = 'lowBattery3.svg';
  static const String lowPriority = 'lowPriority.svg';
  static const String lowVol = 'lowVol.svg';
  static const String lowVol2 = 'lowVol2.svg';
  static const String magic = 'magic.svg';
  static const String magnet1 = 'magnet1.svg';
  static const String magnet2 = 'magnet2.svg';
  static const String magnet3 = 'magnet3.svg';
  static const String makeDecision = 'makeDecision.svg';
  static const String manager = 'manager.svg';
  static const String map = 'map.svg';
  static const String map2 = 'map2.svg';
  static const String mapLocation = 'mapLocation.svg';
  static const String medVol = 'medVol.svg';
  static const String medVol2 = 'medVol2.svg';
  static const String mediumPriority = 'mediumPriority.svg';
  static const String menu = 'menu.svg';
  static const String menu2 = 'menu2.svg';
  static const String menuX = 'menuX.svg';
  static const String middleBattery = 'middleBattery.svg';
  static const String mindMap = 'mindMap.svg';
  static const String minus = 'minus.svg';
  static const String missedCall = 'missedCall.svg';
  static const String mms = 'mms.svg';
  static const String moneyTransfer = 'moneyTransfer.svg';
  static const String more = 'more.svg';
  static const String more2 = 'more2.svg';
  static const String more3 = 'more3.svg';
  static const String movie = 'movie.svg';
  static const String movie2 = 'movie2.svg';
  static const String movieCam = 'movieCam.svg';
  static const String multipleCameras = 'multipleCameras.svg';
  static const String multipleDevices = 'multipleDevices.svg';
  static const String multipleInputs = 'multipleInputs.svg';
  static const String multipleSmartphones = 'multipleSmartphones.svg';
  static const String multiply = 'multiply.svg';
  static const String multiply3 = 'multiply3.svg';
  static const String music = 'music.svg';
  static const String musicX = 'musicX.svg';
  static const String musical = 'musical.svg';
  static const String mute = 'mute.svg';
  static const String mute2 = 'mute2.svg';
  static const String mute3 = 'mute3.svg';
  static const String navigation = 'navigation.svg';
  static const String navigator = 'navigator.svg';
  static const String negativeDynamic = 'negativeDynamic.svg';
  static const String network = 'network.svg';
  static const String network2 = 'network2.svg';
  static const String neutralDecision = 'neutralDecision.svg';
  static const String neutralTrading = 'neutralTrading.svg';
  static const String news = 'news.svg';
  static const String newspaper = 'newspaper.svg';
  static const String next = 'next.svg';
  static const String nightLandscape = 'nightLandscape.svg';
  static const String nightPortrait = 'nightPortrait.svg';
  static const String noIdea = 'noIdea.svg';
  static const String noVideo = 'noVideo.svg';
  static const String nook = 'nook.svg';
  static const String note = 'note.svg';
  static const String notebook = 'notebook.svg';
  static const String notebook1 = 'notebook1.svg';
  static const String notebook2 = 'notebook2.svg';
  static const String notebook3 = 'notebook3.svg';
  static const String notif = 'notif.svg';
  static const String numericalSorting12 = 'numericalSorting12.svg';
  static const String numericalSorting21 = 'numericalSorting21.svg';
  static const String off = 'off.svg';
  static const String offTrig = 'offTrig.svg';
  static const String offTrig2 = 'offTrig2.svg';
  static const String ok = 'ok.svg';
  static const String oldTimeCamera = 'oldTimeCamera.svg';
  static const String on = 'on.svg';
  static const String onOff = 'onOff.svg';
  static const String onOffSwitch = 'onOffSwitch.svg';
  static const String onTrig = 'onTrig.svg';
  static const String onTrig2 = 'onTrig2.svg';
  static const String onlineSupport = 'onlineSupport.svg';
  static const String openFolder = 'openFolder.svg';
  static const String openFolder2 = 'openFolder2.svg';
  static const String openedFolder = 'openedFolder.svg';
  static const String orgUnit = 'orgUnit.svg';
  static const String organization = 'organization.svg';
  static const String overtime = 'overtime.svg';
  static const String package_ = 'package.svg';
  static const String paid = 'paid.svg';
  static const String panorama = 'panorama.svg';
  static const String parallelTasks = 'parallelTasks.svg';
  static const String pause = 'pause.svg';
  static const String pause2 = 'pause2.svg';
  static const String percent = 'percent.svg';
  static const String percent2 = 'percent2.svg';
  static const String perspective = 'perspective.svg';
  static const String phone = 'phone.svg';
  static const String phoneAndroid = 'phoneAndroid.svg';
  static const String phoneApps = 'phoneApps.svg';
  static const String phoneChat = 'phoneChat.svg';
  static const String phoneDown = 'phoneDown.svg';
  static const String phoneMessage = 'phoneMessage.svg';
  static const String phoneProfile = 'phoneProfile.svg';
  static const String phoneUp = 'phoneUp.svg';
  static const String phoneVibrate = 'phoneVibrate.svg';
  static const String photoReel = 'photoReel.svg';
  static const String pic = 'pic.svg';
  static const String pic2 = 'pic2.svg';
  static const String picture = 'picture.svg';
  static const String pieChart = 'pieChart.svg';
  static const String pin = 'pin.svg';
  static const String planner = 'planner.svg';
  static const String play = 'play.svg';
  static const String play2 = 'play2.svg';
  static const String plus = 'plus.svg';
  static const String podiumWithAudience = 'podiumWithAudience.svg';
  static const String podiumWithSpeaker = 'podiumWithSpeaker.svg';
  static const String podiumWithoutSpeaker = 'podiumWithoutSpeaker.svg';
  static const String portraitMode = 'portraitMode.svg';
  static const String positiveDynamic = 'positiveDynamic.svg';
  static const String previous = 'previous.svg';
  static const String priceTag = 'priceTag.svg';
  static const String print = 'print.svg';
  static const String printer = 'printer.svg';
  static const String privacy = 'privacy.svg';
  static const String privacyX = 'privacyX.svg';
  static const String process = 'process.svg';
  static const String profile = 'profile.svg';
  static const String profile2 = 'profile2.svg';
  static const String profile3 = 'profile3.svg';
  static const String profile4 = 'profile4.svg';
  static const String profilex = 'profilex.svg';
  static const String profiley = 'profiley.svg';
  static const String promote = 'promote.svg';
  static const String promote2 = 'promote2.svg';
  static const String puzzle = 'puzzle.svg';
  static const String questions = 'questions.svg';
  static const String radar = 'radar.svg';
  static const String radarPlot = 'radarPlot.svg';
  static const String rating = 'rating.svg';
  static const String ratings = 'ratings.svg';
  static const String readX = 'readX.svg';
  static const String reading = 'reading.svg';
  static const String readingEbook = 'readingEbook.svg';
  static const String receive = 'receive.svg';
  static const String record = 'record.svg';
  static const String redo = 'redo.svg';
  static const String refresh = 'refresh.svg';
  static const String registeredTrademark = 'registeredTrademark.svg';
  static const String removeImage = 'removeImage.svg';
  static const String repeat = 'repeat.svg';
  static const String repeat2 = 'repeat2.svg';
  static const String report = 'report.svg';
  static const String restart = 'restart.svg';
  static const String resumee = 'resumee.svg';
  static const String reuse = 'reuse.svg';
  static const String right = 'right.svg';
  static const String rightDown = 'rightDown.svg';
  static const String rightDown2 = 'rightDown2.svg';
  static const String rightUp = 'rightUp.svg';
  static const String rightUp2 = 'rightUp2.svg';
  static const String ringing = 'ringing.svg';
  static const String ringing2 = 'ringing2.svg';
  static const String roadmap = 'roadmap.svg';
  static const String rotateCamera = 'rotateCamera.svg';
  static const String rotateLand = 'rotateLand.svg';
  static const String rotatePort = 'rotatePort.svg';
  static const String rotateToLandscape = 'rotateToLandscape.svg';
  static const String rotateToPortrait = 'rotateToPortrait.svg';
  static const String ruler = 'ruler.svg';
  static const String rules = 'rules.svg';
  static const String safe = 'safe.svg';
  static const String safety = 'safety.svg';
  static const String salesPerformance = 'salesPerformance.svg';
  static const String save = 'save.svg';
  static const String scatterPlot = 'scatterPlot.svg';
  static const String search = 'search.svg';
  static const String search1 = 'search1.svg';
  static const String search2 = 'search2.svg';
  static const String searchFile = 'searchFile.svg';
  static const String searchPhone = 'searchPhone.svg';
  static const String searchX = 'searchX.svg';
  static const String selectTab = 'selectTab.svg';
  static const String selectWin = 'selectWin.svg';
  static const String selectWin2 = 'selectWin2.svg';
  static const String selfServiceKiosk = 'selfServiceKiosk.svg';
  static const String selfie = 'selfie.svg';
  static const String send = 'send.svg';
  static const String send2 = 'send2.svg';
  static const String send3 = 'send3.svg';
  static const String serialTasks = 'serialTasks.svg';
  static const String serviceMark = 'serviceMark.svg';
  static const String services = 'services.svg';
  static const String settings = 'settings.svg';
  static const String settings1 = 'settings1.svg';
  static const String settings10 = 'settings10.svg';
  static const String settings2 = 'settings2.svg';
  static const String settings3 = 'settings3.svg';
  static const String settings4 = 'settings4.svg';
  static const String settings5 = 'settings5.svg';
  static const String settings6 = 'settings6.svg';
  static const String settings7 = 'settings7.svg';
  static const String settings8 = 'settings8.svg';
  static const String settings9 = 'settings9.svg';
  static const String share = 'share.svg';
  static const String share1 = 'share1.svg';
  static const String share2 = 'share2.svg';
  static const String share3 = 'share3.svg';
  static const String shipped = 'shipped.svg';
  static const String shop = 'shop.svg';
  static const String shuffle = 'shuffle.svg';
  static const String shuffle2 = 'shuffle2.svg';
  static const String shutdown = 'shutdown.svg';
  static const String sign = 'sign.svg';
  static const String signature = 'signature.svg';
  static const String signpost = 'signpost.svg';
  static const String silent = 'silent.svg';
  static const String silent2 = 'silent2.svg';
  static const String simCard = 'simCard.svg';
  static const String simCardChip = 'simCardChip.svg';
  static const String siri = 'siri.svg';
  static const String slrBackSide = 'slrBackSide.svg';
  static const String smartphoneTablet = 'smartphoneTablet.svg';
  static const String sms = 'sms.svg';
  static const String soundRecordingCopyright = 'soundRecordingCopyright.svg';
  static const String speaker = 'speaker.svg';
  static const String speed = 'speed.svg';
  static const String sportsMode = 'sportsMode.svg';
  static const String spotlight = 'spotlight.svg';
  static const String stackOfPhotos = 'stackOfPhotos.svg';
  static const String star = 'star.svg';
  static const String start = 'start.svg';
  static const String statistics = 'statistics.svg';
  static const String stop = 'stop.svg';
  static const String stop2 = 'stop2.svg';
  static const String stopwatch = 'stopwatch.svg';
  static const String stopwatch2 = 'stopwatch2.svg';
  static const String stopwatch3 = 'stopwatch3.svg';
  static const String streetLocation = 'streetLocation.svg';
  static const String streetName = 'streetName.svg';
  static const String streetOrien = 'streetOrien.svg';
  static const String substract = 'substract.svg';
  static const String substract2 = 'substract2.svg';
  static const String success = 'success.svg';
  static const String success2 = 'success2.svg';
  static const String success3 = 'success3.svg';
  static const String support = 'support.svg';
  static const String survey = 'survey.svg';
  static const String susbstract2 = 'susbstract2.svg';
  static const String switchCamera = 'switchCamera.svg';
  static const String switchOff = 'switchOff.svg';
  static const String synchronize = 'synchronize.svg';
  static const String tabletAndroid = 'tabletAndroid.svg';
  static const String tabs = 'tabs.svg';
  static const String takeNote = 'takeNote.svg';
  static const String takeNote2 = 'takeNote2.svg';
  static const String target = 'target.svg';
  static const String techPower = 'techPower.svg';
  static const String template = 'template.svg';
  static const String thumbDown = 'thumbDown.svg';
  static const String thumbUp = 'thumbUp.svg';
  static const String time = 'time.svg';
  static const String timeFlies = 'timeFlies.svg';
  static const String timeline = 'timeline.svg';
  static const String timetracking = 'timetracking.svg';
  static const String timetracking2 = 'timetracking2.svg';
  static const String timetracking3 = 'timetracking3.svg';
  static const String todoList = 'todoList.svg';
  static const String touchscreenSmartphone = 'touchscreenSmartphone.svg';
  static const String track = 'track.svg';
  static const String tracked = 'tracked.svg';
  static const String trademark = 'trademark.svg';
  static const String trash = 'trash.svg';
  static const String trash2 = 'trash2.svg';
  static const String trash3 = 'trash3.svg';
  static const String trash4 = 'trash4.svg';
  static const String treeStructure = 'treeStructure.svg';
  static const String twoSmartphones = 'twoSmartphones.svg';
  static const String undo = 'undo.svg';
  static const String unlink = 'unlink.svg';
  static const String unlock = 'unlock.svg';
  static const String unlock2 = 'unlock2.svg';
  static const String unlock3 = 'unlock3.svg';
  static const String unlock4 = 'unlock4.svg';
  static const String unlockFolder = 'unlockFolder.svg';
  static const String unlockOri = 'unlockOri.svg';
  static const String unlocked = 'unlocked.svg';
  static const String unlocked2 = 'unlocked2.svg';
  static const String up = 'up.svg';
  static const String upLeft = 'upLeft.svg';
  static const String upRight = 'upRight.svg';
  static const String upload = 'upload.svg';
  static const String uploadFolder = 'uploadFolder.svg';
  static const String uploadX = 'uploadX.svg';
  static const String userF = 'userF.svg';
  static const String userM = 'userM.svg';
  static const String users = 'users.svg';
  static const String users2 = 'users2.svg';
  static const String vid2 = 'vid2.svg';
  static const String vid3 = 'vid3.svg';
  static const String video = 'video.svg';
  static const String videoCall = 'videoCall.svg';
  static const String videoFile = 'videoFile.svg';
  static const String videoProjector = 'videoProjector.svg';
  static const String view = 'view.svg';
  static const String view2 = 'view2.svg';
  static const String viewDetails = 'viewDetails.svg';
  static const String views = 'views.svg';
  static const String vip = 'vip.svg';
  static const String voice = 'voice.svg';
  static const String voicePresentation = 'voicePresentation.svg';
  static const String voicemail = 'voicemail.svg';
  static const String volume = 'volume.svg';
  static const String volumeAdd = 'volumeAdd.svg';
  static const String warning = 'warning.svg';
  static const String webcam = 'webcam.svg';
  static const String wifi = 'wifi.svg';
  static const String wifiSignal = 'wifiSignal.svg';
  static const String win = 'win.svg';
  static const String win2 = 'win2.svg';
  static const String workflow = 'workflow.svg';
  static const String world = 'world.svg';
  static const String world2 = 'world2.svg';
  static const String write = 'write.svg';
  static const String zoomIn = 'zoomIn.svg';
  static const String zoomOut = 'zoomOut.svg';
}
