import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

import 'icon_forest.dart';

/// majesticons icons (760 icons)
///
/// - build svg for majesticons icon libraries
/// - constants link to svg icon resources
class Majesticons extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  const Majesticons(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return IconForest.svgAsset(
      'majesticons',
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  static const String add_column_line = 'add_column_line.svg';
  static const String add_column = 'add_column.svg';
  static const String add_row_line = 'add_row_line.svg';
  static const String add_row = 'add_row.svg';
  static const String airplane_flight_2_line = 'airplane_flight_2_line.svg';
  static const String airplane_flight_2 = 'airplane_flight_2.svg';
  static const String airplane_line = 'airplane_line.svg';
  static const String airplane = 'airplane.svg';
  static const String alert_circle_line = 'alert_circle_line.svg';
  static const String alert_circle = 'alert_circle.svg';
  static const String align_bottom_line = 'align_bottom_line.svg';
  static const String align_bottom = 'align_bottom.svg';
  static const String align_horizontal_center_line = 'align_horizontal_center_line.svg';
  static const String align_horizontal_center = 'align_horizontal_center.svg';
  static const String align_left_line = 'align_left_line.svg';
  static const String align_left = 'align_left.svg';
  static const String align_right_line = 'align_right_line.svg';
  static const String align_right = 'align_right.svg';
  static const String align_top_line = 'align_top_line.svg';
  static const String align_top = 'align_top.svg';
  static const String align_vertical_center_line = 'align_vertical_center_line.svg';
  static const String align_vertical_center = 'align_vertical_center.svg';
  static const String analytics_delete_line = 'analytics_delete_line.svg';
  static const String analytics_delete = 'analytics_delete.svg';
  static const String analytics_line = 'analytics_line.svg';
  static const String analytics_plus_line = 'analytics_plus_line.svg';
  static const String analytics_plus = 'analytics_plus.svg';
  static const String analytics_restricted_line = 'analytics_restricted_line.svg';
  static const String analytics_restricted = 'analytics_restricted.svg';
  static const String analytics = 'analytics.svg';
  static const String arrow_down_circle_line = 'arrow_down_circle_line.svg';
  static const String arrow_down_circle = 'arrow_down_circle.svg';
  static const String arrow_down_line = 'arrow_down_line.svg';
  static const String arrow_down = 'arrow_down.svg';
  static const String arrow_left_circle_line = 'arrow_left_circle_line.svg';
  static const String arrow_left_circle = 'arrow_left_circle.svg';
  static const String arrow_left_line = 'arrow_left_line.svg';
  static const String arrow_left = 'arrow_left.svg';
  static const String arrow_right_circle_line = 'arrow_right_circle_line.svg';
  static const String arrow_right_circle = 'arrow_right_circle.svg';
  static const String arrow_right_line = 'arrow_right_line.svg';
  static const String arrow_right = 'arrow_right.svg';
  static const String arrow_up_circle_line = 'arrow_up_circle_line.svg';
  static const String arrow_up_circle = 'arrow_up_circle.svg';
  static const String arrow_up_line = 'arrow_up_line.svg';
  static const String arrow_up = 'arrow_up.svg';
  static const String arrows_collapse_full_line = 'arrows_collapse_full_line.svg';
  static const String arrows_collapse_full = 'arrows_collapse_full.svg';
  static const String arrows_expand_full_line = 'arrows_expand_full_line.svg';
  static const String arrows_expand_full = 'arrows_expand_full.svg';
  static const String article_line = 'article_line.svg';
  static const String article_search_line = 'article_search_line.svg';
  static const String article_search = 'article_search.svg';
  static const String article = 'article.svg';
  static const String atom_2_line = 'atom_2_line.svg';
  static const String atom_2 = 'atom_2.svg';
  static const String attachment_line = 'attachment_line.svg';
  static const String attachment = 'attachment.svg';
  static const String award_line = 'award_line.svg';
  static const String award = 'award.svg';
  static const String back_circle_line = 'back_circle_line.svg';
  static const String back_circle = 'back_circle.svg';
  static const String backward_circle_line = 'backward_circle_line.svg';
  static const String backward_circle = 'backward_circle.svg';
  static const String backward_start_circle_line = 'backward_start_circle_line.svg';
  static const String backward_start_circle = 'backward_start_circle.svg';
  static const String band_aids_line = 'band_aids_line.svg';
  static const String band_aids = 'band_aids.svg';
  static const String barcode_2_line = 'barcode_2_line.svg';
  static const String barcode_2 = 'barcode_2.svg';
  static const String basket_2_line = 'basket_2_line.svg';
  static const String basket_2 = 'basket_2.svg';
  static const String bath_shower_line = 'bath_shower_line.svg';
  static const String bath_shower = 'bath_shower.svg';
  static const String battery_full_line = 'battery_full_line.svg';
  static const String battery_full = 'battery_full.svg';
  static const String battery_half_line = 'battery_half_line.svg';
  static const String battery_half = 'battery_half.svg';
  static const String battery_line = 'battery_line.svg';
  static const String battery_low_line = 'battery_low_line.svg';
  static const String battery_low = 'battery_low.svg';
  static const String battery = 'battery.svg';
  static const String beach_line = 'beach_line.svg';
  static const String beach = 'beach.svg';
  static const String bell_line = 'bell_line.svg';
  static const String bell = 'bell.svg';
  static const String bitcoin_circle_line = 'bitcoin_circle_line.svg';
  static const String bitcoin_circle = 'bitcoin_circle.svg';
  static const String bluetooth_line = 'bluetooth_line.svg';
  static const String bluetooth = 'bluetooth.svg';
  static const String bold_line = 'bold_line.svg';
  static const String bold = 'bold.svg';
  static const String book_line = 'book_line.svg';
  static const String book_minus_line = 'book_minus_line.svg';
  static const String book_minus = 'book_minus.svg';
  static const String book_open_line = 'book_open_line.svg';
  static const String book_open = 'book_open.svg';
  static const String book_plus_line = 'book_plus_line.svg';
  static const String book_plus = 'book_plus.svg';
  static const String book = 'book.svg';
  static const String bookmark_line = 'bookmark_line.svg';
  static const String bookmark_minus_line = 'bookmark_minus_line.svg';
  static const String bookmark_minus = 'bookmark_minus.svg';
  static const String bookmark_plus_line = 'bookmark_plus_line.svg';
  static const String bookmark_plus = 'bookmark_plus.svg';
  static const String bookmark = 'bookmark.svg';
  static const String box_line = 'box_line.svg';
  static const String box = 'box.svg';
  static const String briefcase_line = 'briefcase_line.svg';
  static const String briefcase = 'briefcase.svg';
  static const String browser_cookie_line = 'browser_cookie_line.svg';
  static const String browser_cookie = 'browser_cookie.svg';
  static const String browser_line = 'browser_line.svg';
  static const String browser = 'browser.svg';
  static const String bug_2_line = 'bug_2_line.svg';
  static const String bug_2 = 'bug_2.svg';
  static const String burger_line = 'burger_line.svg';
  static const String burger = 'burger.svg';
  static const String bus_line = 'bus_line.svg';
  static const String bus = 'bus.svg';
  static const String cake_line = 'cake_line.svg';
  static const String cake = 'cake.svg';
  static const String calculator_line = 'calculator_line.svg';
  static const String calculator = 'calculator.svg';
  static const String calendar_line = 'calendar_line.svg';
  static const String calendar_plus_line = 'calendar_plus_line.svg';
  static const String calendar_plus = 'calendar_plus.svg';
  static const String calendar = 'calendar.svg';
  static const String camera_line = 'camera_line.svg';
  static const String camera_off_line = 'camera_off_line.svg';
  static const String camera_off = 'camera_off.svg';
  static const String camera = 'camera.svg';
  static const String car_line = 'car_line.svg';
  static const String car = 'car.svg';
  static const String cent_circle_line = 'cent_circle_line.svg';
  static const String cent_circle = 'cent_circle.svg';
  static const String chat_2_line = 'chat_2_line.svg';
  static const String chat_2_text_line = 'chat_2_text_line.svg';
  static const String chat_2_text = 'chat_2_text.svg';
  static const String chat_2 = 'chat_2.svg';
  static const String chat_line = 'chat_line.svg';
  static const String chat_signal_line = 'chat_signal_line.svg';
  static const String chat_signal = 'chat_signal.svg';
  static const String chat_status_line = 'chat_status_line.svg';
  static const String chat_status = 'chat_status.svg';
  static const String chat_text_line = 'chat_text_line.svg';
  static const String chat_text = 'chat_text.svg';
  static const String chat = 'chat.svg';
  static const String chats_2_line = 'chats_2_line.svg';
  static const String chats_2 = 'chats_2.svg';
  static const String chats_line = 'chats_line.svg';
  static const String chats = 'chats.svg';
  static const String checkbox_list_detail_line = 'checkbox_list_detail_line.svg';
  static const String checkbox_list_detail = 'checkbox_list_detail.svg';
  static const String checkbox_list_line = 'checkbox_list_line.svg';
  static const String checkbox_list = 'checkbox_list.svg';
  static const String cheese_line = 'cheese_line.svg';
  static const String cheese = 'cheese.svg';
  static const String chevron_down_circle_line = 'chevron_down_circle_line.svg';
  static const String chevron_down_circle = 'chevron_down_circle.svg';
  static const String chevron_down_line = 'chevron_down_line.svg';
  static const String chevron_down = 'chevron_down.svg';
  static const String chevron_left_circle_line = 'chevron_left_circle_line.svg';
  static const String chevron_left_circle = 'chevron_left_circle.svg';
  static const String chevron_left_line = 'chevron_left_line.svg';
  static const String chevron_left = 'chevron_left.svg';
  static const String chevron_right_circle_line = 'chevron_right_circle_line.svg';
  static const String chevron_right_circle = 'chevron_right_circle.svg';
  static const String chevron_right_line = 'chevron_right_line.svg';
  static const String chevron_right = 'chevron_right.svg';
  static const String chevron_up_circle_line = 'chevron_up_circle_line.svg';
  static const String chevron_up_circle = 'chevron_up_circle.svg';
  static const String chevron_up_line = 'chevron_up_line.svg';
  static const String chevron_up = 'chevron_up.svg';
  static const String chromecast_line = 'chromecast_line.svg';
  static const String chromecast = 'chromecast.svg';
  static const String church_line = 'church_line.svg';
  static const String church = 'church.svg';
  static const String clipboard_check_line = 'clipboard_check_line.svg';
  static const String clipboard_check = 'clipboard_check.svg';
  static const String clipboard_line = 'clipboard_line.svg';
  static const String clipboard_minus_line = 'clipboard_minus_line.svg';
  static const String clipboard_minus = 'clipboard_minus.svg';
  static const String clipboard_plus_line = 'clipboard_plus_line.svg';
  static const String clipboard_plus = 'clipboard_plus.svg';
  static const String clipboard = 'clipboard.svg';
  static const String clock_line = 'clock_line.svg';
  static const String clock_plus_line = 'clock_plus_line.svg';
  static const String clock_plus = 'clock_plus.svg';
  static const String clock = 'clock.svg';
  static const String close_line = 'close_line.svg';
  static const String close = 'close.svg';
  static const String cloud_line = 'cloud_line.svg';
  static const String cloud = 'cloud.svg';
  static const String code_block_line = 'code_block_line.svg';
  static const String code_block = 'code_block.svg';
  static const String code_line = 'code_line.svg';
  static const String code = 'code.svg';
  static const String coins_line = 'coins_line.svg';
  static const String coins = 'coins.svg';
  static const String comet_line = 'comet_line.svg';
  static const String comet = 'comet.svg';
  static const String comment_2_line = 'comment_2_line.svg';
  static const String comment_2_text_line = 'comment_2_text_line.svg';
  static const String comment_2_text = 'comment_2_text.svg';
  static const String comment_2 = 'comment_2.svg';
  static const String comment_line = 'comment_line.svg';
  static const String comment_text_line = 'comment_text_line.svg';
  static const String comment_text = 'comment_text.svg';
  static const String comment = 'comment.svg';
  static const String comments_2_line = 'comments_2_line.svg';
  static const String comments_2 = 'comments_2.svg';
  static const String comments_line = 'comments_line.svg';
  static const String comments = 'comments.svg';
  static const String community_line = 'community_line.svg';
  static const String community = 'community.svg';
  static const String compass_2_line = 'compass_2_line.svg';
  static const String compass_2 = 'compass_2.svg';
  static const String cookie_line = 'cookie_line.svg';
  static const String cookie = 'cookie.svg';
  static const String covid_exclamation_line = 'covid_exclamation_line.svg';
  static const String covid_exclamation = 'covid_exclamation.svg';
  static const String covid_line = 'covid_line.svg';
  static const String covid_off_line = 'covid_off_line.svg';
  static const String covid_off = 'covid_off.svg';
  static const String covid = 'covid.svg';
  static const String cpu_line = 'cpu_line.svg';
  static const String cpu = 'cpu.svg';
  static const String creditcard_hand_line = 'creditcard_hand_line.svg';
  static const String creditcard_hand = 'creditcard_hand.svg';
  static const String creditcard_line = 'creditcard_line.svg';
  static const String creditcard_plus_line = 'creditcard_plus_line.svg';
  static const String creditcard_plus = 'creditcard_plus.svg';
  static const String creditcard = 'creditcard.svg';
  static const String crown_line = 'crown_line.svg';
  static const String crown = 'crown.svg';
  static const String cup_line = 'cup_line.svg';
  static const String cup = 'cup.svg';
  static const String curly_braces_line = 'curly_braces_line.svg';
  static const String curly_braces = 'curly_braces.svg';
  static const String data_line = 'data_line.svg';
  static const String data_minus_line = 'data_minus_line.svg';
  static const String data_minus = 'data_minus.svg';
  static const String data_plus_line = 'data_plus_line.svg';
  static const String data_plus = 'data_plus.svg';
  static const String data = 'data.svg';
  static const String delete_bin_line = 'delete_bin_line.svg';
  static const String delete_bin = 'delete_bin.svg';
  static const String distribute_horizontal_line = 'distribute_horizontal_line.svg';
  static const String distribute_horizontal = 'distribute_horizontal.svg';
  static const String distribute_vertical_line = 'distribute_vertical_line.svg';
  static const String distribute_vertical = 'distribute_vertical.svg';
  static const String divide_line = 'divide_line.svg';
  static const String divide = 'divide.svg';
  static const String document_award_line = 'document_award_line.svg';
  static const String document_award = 'document_award.svg';
  static const String document_line = 'document_line.svg';
  static const String document = 'document.svg';
  static const String dollar_circle_line = 'dollar_circle_line.svg';
  static const String dollar_circle = 'dollar_circle.svg';
  static const String door_enter_line = 'door_enter_line.svg';
  static const String door_enter = 'door_enter.svg';
  static const String door_exit_line = 'door_exit_line.svg';
  static const String door_exit = 'door_exit.svg';
  static const String earth_sphere_line = 'earth_sphere_line.svg';
  static const String earth_sphere = 'earth_sphere.svg';
  static const String edit_pen_2_line = 'edit_pen_2_line.svg';
  static const String edit_pen_2 = 'edit_pen_2.svg';
  static const String edit_pen_4_line = 'edit_pen_4_line.svg';
  static const String edit_pen_4 = 'edit_pen_4.svg';
  static const String eject_line = 'eject_line.svg';
  static const String eject = 'eject.svg';
  static const String eraser_line = 'eraser_line.svg';
  static const String eraser = 'eraser.svg';
  static const String etherium_circle_line = 'etherium_circle_line.svg';
  static const String etherium_circle = 'etherium_circle.svg';
  static const String euro_circle_line = 'euro_circle_line.svg';
  static const String euro_circle = 'euro_circle.svg';
  static const String eye_line = 'eye_line.svg';
  static const String eye_off_line = 'eye_off_line.svg';
  static const String eye_off = 'eye_off.svg';
  static const String eye = 'eye.svg';
  static const String ferris_wheel_line = 'ferris_wheel_line.svg';
  static const String ferris_wheel = 'ferris_wheel.svg';
  static const String file_line = 'file_line.svg';
  static const String file_minus_line = 'file_minus_line.svg';
  static const String file_minus = 'file_minus.svg';
  static const String file_plus_line = 'file_plus_line.svg';
  static const String file_plus = 'file_plus.svg';
  static const String file = 'file.svg';
  static const String filter_line = 'filter_line.svg';
  static const String filter = 'filter.svg';
  static const String fish_line = 'fish_line.svg';
  static const String fish = 'fish.svg';
  static const String flag_line = 'flag_line.svg';
  static const String flag = 'flag.svg';
  static const String flask_line = 'flask_line.svg';
  static const String flask = 'flask.svg';
  static const String flower_2_line = 'flower_2_line.svg';
  static const String flower_2 = 'flower_2.svg';
  static const String folder_check_line = 'folder_check_line.svg';
  static const String folder_check = 'folder_check.svg';
  static const String folder_line = 'folder_line.svg';
  static const String folder_minus_line = 'folder_minus_line.svg';
  static const String folder_minus = 'folder_minus.svg';
  static const String folder_plus_line = 'folder_plus_line.svg';
  static const String folder_plus = 'folder_plus.svg';
  static const String folder = 'folder.svg';
  static const String font_size_line = 'font_size_line.svg';
  static const String font_size = 'font_size.svg';
  static const String forward_circle_line = 'forward_circle_line.svg';
  static const String forward_circle = 'forward_circle.svg';
  static const String forward_end_circle_line = 'forward_end_circle_line.svg';
  static const String forward_end_circle = 'forward_end_circle.svg';
  static const String git_branch_line = 'git_branch_line.svg';
  static const String git_branch = 'git_branch.svg';
  static const String git_commit_line = 'git_commit_line.svg';
  static const String git_commit = 'git_commit.svg';
  static const String git_compare_line = 'git_compare_line.svg';
  static const String git_compare = 'git_compare.svg';
  static const String git_fork_line = 'git_fork_line.svg';
  static const String git_fork = 'git_fork.svg';
  static const String git_merge_line = 'git_merge_line.svg';
  static const String git_merge = 'git_merge.svg';
  static const String git_pull_line = 'git_pull_line.svg';
  static const String git_pull = 'git_pull.svg';
  static const String glas_water_line = 'glas_water_line.svg';
  static const String glas_water = 'glas_water.svg';
  static const String globe_earth_2_line = 'globe_earth_2_line.svg';
  static const String globe_earth_2 = 'globe_earth_2.svg';
  static const String globe_earth_line = 'globe_earth_line.svg';
  static const String globe_earth = 'globe_earth.svg';
  static const String globe_grid_line = 'globe_grid_line.svg';
  static const String globe_grid = 'globe_grid.svg';
  static const String hand_line = 'hand_line.svg';
  static const String hand_pointer_2_line = 'hand_pointer_2_line.svg';
  static const String hand_pointer_2 = 'hand_pointer_2.svg';
  static const String hand_pointer_event_line = 'hand_pointer_event_line.svg';
  static const String hand_pointer_event = 'hand_pointer_event.svg';
  static const String hand_pointer_line = 'hand_pointer_line.svg';
  static const String hand_pointer = 'hand_pointer.svg';
  static const String hand = 'hand.svg';
  static const String hard_drive_line = 'hard_drive_line.svg';
  static const String hard_drive = 'hard_drive.svg';
  static const String headset_line = 'headset_line.svg';
  static const String headset = 'headset.svg';
  static const String heart_line = 'heart_line.svg';
  static const String heart = 'heart.svg';
  static const String home_analytics_line = 'home_analytics_line.svg';
  static const String home_analytics = 'home_analytics.svg';
  static const String home_line = 'home_line.svg';
  static const String home_simple_line = 'home_simple_line.svg';
  static const String home_simple = 'home_simple.svg';
  static const String home = 'home.svg';
  static const String image_circle_line = 'image_circle_line.svg';
  static const String image_circle_off_line = 'image_circle_off_line.svg';
  static const String image_circle_off = 'image_circle_off.svg';
  static const String image_circle_plus_line = 'image_circle_plus_line.svg';
  static const String image_circle_plus = 'image_circle_plus.svg';
  static const String image_circle_story_line = 'image_circle_story_line.svg';
  static const String image_circle_story = 'image_circle_story.svg';
  static const String image_circle = 'image_circle.svg';
  static const String image_frame_line = 'image_frame_line.svg';
  static const String image_frame = 'image_frame.svg';
  static const String image_in_picture_line = 'image_in_picture_line.svg';
  static const String image_in_picture = 'image_in_picture.svg';
  static const String image_line = 'image_line.svg';
  static const String image_multiple_line = 'image_multiple_line.svg';
  static const String image_multiple = 'image_multiple.svg';
  static const String image_off_line = 'image_off_line.svg';
  static const String image_off = 'image_off.svg';
  static const String image_photography_line = 'image_photography_line.svg';
  static const String image_photography = 'image_photography.svg';
  static const String image_plus_line = 'image_plus_line.svg';
  static const String image_plus = 'image_plus.svg';
  static const String image = 'image.svg';
  static const String incognito_line = 'incognito_line.svg';
  static const String incognito = 'incognito.svg';
  static const String info_circle_line = 'info_circle_line.svg';
  static const String info_circle = 'info_circle.svg';
  static const String iphone_old_apps_line = 'iphone_old_apps_line.svg';
  static const String iphone_old_apps = 'iphone_old_apps.svg';
  static const String iphone_x_apps_line = 'iphone_x_apps_line.svg';
  static const String iphone_x_apps = 'iphone_x_apps.svg';
  static const String italic_line = 'italic_line.svg';
  static const String italic = 'italic.svg';
  static const String key_line = 'key_line.svg';
  static const String key_ = 'key.svg';
  static const String keyboard_line = 'keyboard_line.svg';
  static const String keyboard = 'keyboard.svg';
  static const String laptop_line = 'laptop_line.svg';
  static const String laptop = 'laptop.svg';
  static const String leaf_3_angled_line = 'leaf_3_angled_line.svg';
  static const String leaf_3_angled = 'leaf_3_angled.svg';
  static const String library_line = 'library_line.svg';
  static const String library = 'library.svg';
  static const String lidquid_drop_waves_2_line = 'lidquid_drop_waves_2_line.svg';
  static const String lidquid_drop_waves_2 = 'lidquid_drop_waves_2.svg';
  static const String lifebuoy_line = 'lifebuoy_line.svg';
  static const String lifebuoy = 'lifebuoy.svg';
  static const String lightbulb_shine_line = 'lightbulb_shine_line.svg';
  static const String lightbulb_shine = 'lightbulb_shine.svg';
  static const String lightning_bolt_line = 'lightning_bolt_line.svg';
  static const String lightning_bolt = 'lightning_bolt.svg';
  static const String line_height_line = 'line_height_line.svg';
  static const String line_height = 'line_height.svg';
  static const String link_circle_line = 'link_circle_line.svg';
  static const String link_circle = 'link_circle.svg';
  static const String link_line = 'link_line.svg';
  static const String link = 'link.svg';
  static const String lira_circle_line = 'lira_circle_line.svg';
  static const String lira_circle = 'lira_circle.svg';
  static const String list_box_line = 'list_box_line.svg';
  static const String list_box = 'list_box.svg';
  static const String lock_line = 'lock_line.svg';
  static const String lock_off_line = 'lock_off_line.svg';
  static const String lock_off = 'lock_off.svg';
  static const String lock = 'lock.svg';
  static const String login_half_circle_line = 'login_half_circle_line.svg';
  static const String login_half_circle = 'login_half_circle.svg';
  static const String login_line = 'login_line.svg';
  static const String login = 'login.svg';
  static const String logout_half_circle_line = 'logout_half_circle_line.svg';
  static const String logout_half_circle = 'logout_half_circle.svg';
  static const String logout_line = 'logout_line.svg';
  static const String logout = 'logout.svg';
  static const String mail_line = 'mail_line.svg';
  static const String mail = 'mail.svg';
  static const String map_marker_area_line = 'map_marker_area_line.svg';
  static const String map_marker_area = 'map_marker_area.svg';
  static const String map_marker_line = 'map_marker_line.svg';
  static const String map_marker_path_line = 'map_marker_path_line.svg';
  static const String map_marker_path = 'map_marker_path.svg';
  static const String map_marker_plus_line = 'map_marker_plus_line.svg';
  static const String map_marker_plus = 'map_marker_plus.svg';
  static const String map_marker = 'map_marker.svg';
  static const String map_simple_destination_line = 'map_simple_destination_line.svg';
  static const String map_simple_destination = 'map_simple_destination.svg';
  static const String map_simple_line = 'map_simple_line.svg';
  static const String map_simple_marker_line = 'map_simple_marker_line.svg';
  static const String map_simple_marker = 'map_simple_marker.svg';
  static const String map_simple_off_line = 'map_simple_off_line.svg';
  static const String map_simple_off = 'map_simple_off.svg';
  static const String map_simple = 'map_simple.svg';
  static const String maximize_line = 'maximize_line.svg';
  static const String maximize = 'maximize.svg';
  static const String megaphone_line = 'megaphone_line.svg';
  static const String megaphone = 'megaphone.svg';
  static const String menu_expand_left_line = 'menu_expand_left_line.svg';
  static const String menu_expand_left = 'menu_expand_left.svg';
  static const String menu_expand_right_line = 'menu_expand_right_line.svg';
  static const String menu_expand_right = 'menu_expand_right.svg';
  static const String menu_line = 'menu_line.svg';
  static const String menu = 'menu.svg';
  static const String microphone_line = 'microphone_line.svg';
  static const String microphone = 'microphone.svg';
  static const String minimize_line = 'minimize_line.svg';
  static const String minimize = 'minimize.svg';
  static const String minus_five_circle_line = 'minus_five_circle_line.svg';
  static const String minus_five_circle = 'minus_five_circle.svg';
  static const String minus_line = 'minus_line.svg';
  static const String minus_ten_circle_line = 'minus_ten_circle_line.svg';
  static const String minus_ten_circle = 'minus_ten_circle.svg';
  static const String minus = 'minus.svg';
  static const String money_hand_line = 'money_hand_line.svg';
  static const String money_hand = 'money_hand.svg';
  static const String money_line = 'money_line.svg';
  static const String money_minus_line = 'money_minus_line.svg';
  static const String money_minus = 'money_minus.svg';
  static const String money_plus_line = 'money_plus_line.svg';
  static const String money_plus = 'money_plus.svg';
  static const String money = 'money.svg';
  static const String monitor_line = 'monitor_line.svg';
  static const String monitor = 'monitor.svg';
  static const String moon_line = 'moon_line.svg';
  static const String moon = 'moon.svg';
  static const String more_menu_line = 'more_menu_line.svg';
  static const String more_menu_vertical_line = 'more_menu_vertical_line.svg';
  static const String more_menu_vertical = 'more_menu_vertical.svg';
  static const String more_menu = 'more_menu.svg';
  static const String mouse_line = 'mouse_line.svg';
  static const String mouse = 'mouse.svg';
  static const String multiply_line = 'multiply_line.svg';
  static const String multiply = 'multiply.svg';
  static const String music_line = 'music_line.svg';
  static const String music_note_line = 'music_note_line.svg';
  static const String music_note = 'music_note.svg';
  static const String music = 'music.svg';
  static const String next_circle_line = 'next_circle_line.svg';
  static const String next_circle = 'next_circle.svg';
  static const String note_text_line = 'note_text_line.svg';
  static const String note_text_minus_line = 'note_text_minus_line.svg';
  static const String note_text_minus = 'note_text_minus.svg';
  static const String note_text_plus_line = 'note_text_plus_line.svg';
  static const String note_text_plus = 'note_text_plus.svg';
  static const String note_text = 'note_text.svg';
  static const String noteblock_line = 'noteblock_line.svg';
  static const String noteblock_text_line = 'noteblock_text_line.svg';
  static const String noteblock_text = 'noteblock_text.svg';
  static const String noteblock = 'noteblock.svg';
  static const String open_line = 'open_line.svg';
  static const String open = 'open.svg';
  static const String paper_fold_line = 'paper_fold_line.svg';
  static const String paper_fold_text_line = 'paper_fold_text_line.svg';
  static const String paper_fold_text = 'paper_fold_text.svg';
  static const String paper_fold = 'paper_fold.svg';
  static const String paper_roll_2_line = 'paper_roll_2_line.svg';
  static const String paper_roll_2 = 'paper_roll_2.svg';
  static const String paragraph_line = 'paragraph_line.svg';
  static const String paragraph = 'paragraph.svg';
  static const String pause_circle_line = 'pause_circle_line.svg';
  static const String pause_circle = 'pause_circle.svg';
  static const String percent_line = 'percent_line.svg';
  static const String percent = 'percent.svg';
  static const String phone_dial_line = 'phone_dial_line.svg';
  static const String phone_dial = 'phone_dial.svg';
  static const String phone_hangup_line = 'phone_hangup_line.svg';
  static const String phone_hangup = 'phone_hangup.svg';
  static const String phone_incoming_line = 'phone_incoming_line.svg';
  static const String phone_incoming = 'phone_incoming.svg';
  static const String phone_line = 'phone_line.svg';
  static const String phone_outgoing_line = 'phone_outgoing_line.svg';
  static const String phone_outgoing = 'phone_outgoing.svg';
  static const String phone_retro_line = 'phone_retro_line.svg';
  static const String phone_retro = 'phone_retro.svg';
  static const String phone_ring_line = 'phone_ring_line.svg';
  static const String phone_ring = 'phone_ring.svg';
  static const String phone = 'phone.svg';
  static const String pill_line = 'pill_line.svg';
  static const String pill = 'pill.svg';
  static const String pin_line = 'pin_line.svg';
  static const String pin = 'pin.svg';
  static const String pinwheel_line = 'pinwheel_line.svg';
  static const String pinwheel = 'pinwheel.svg';
  static const String planet_line = 'planet_line.svg';
  static const String planet_ring_2_line = 'planet_ring_2_line.svg';
  static const String planet_ring_2 = 'planet_ring_2.svg';
  static const String planet_rocket_line = 'planet_rocket_line.svg';
  static const String planet_rocket = 'planet_rocket.svg';
  static const String planet = 'planet.svg';
  static const String play_circle_line = 'play_circle_line.svg';
  static const String play_circle = 'play_circle.svg';
  static const String playlist_line = 'playlist_line.svg';
  static const String playlist = 'playlist.svg';
  static const String plus_five_circle_line = 'plus_five_circle_line.svg';
  static const String plus_five_circle = 'plus_five_circle.svg';
  static const String plus_line = 'plus_line.svg';
  static const String plus_minus_2_line = 'plus_minus_2_line.svg';
  static const String plus_minus_2 = 'plus_minus_2.svg';
  static const String plus_minus_line = 'plus_minus_line.svg';
  static const String plus_minus = 'plus_minus.svg';
  static const String plus_ten_circle_line = 'plus_ten_circle_line.svg';
  static const String plus_ten_circle = 'plus_ten_circle.svg';
  static const String plus = 'plus.svg';
  static const String pound_circle_line = 'pound_circle_line.svg';
  static const String pound_circle = 'pound_circle.svg';
  static const String presentation_chart_line = 'presentation_chart_line.svg';
  static const String presentation_chart = 'presentation_chart.svg';
  static const String presentation_line = 'presentation_line.svg';
  static const String presentation_play_line = 'presentation_play_line.svg';
  static const String presentation_play = 'presentation_play.svg';
  static const String presentation = 'presentation.svg';
  static const String printer_line = 'printer_line.svg';
  static const String printer = 'printer.svg';
  static const String pulse_line = 'pulse_line.svg';
  static const String pulse = 'pulse.svg';
  static const String puzzle_line = 'puzzle_line.svg';
  static const String puzzle = 'puzzle.svg';
  static const String qr_code_line = 'qr_code_line.svg';
  static const String qr_code = 'qr_code.svg';
  static const String question_circle_line = 'question_circle_line.svg';
  static const String question_circle = 'question_circle.svg';
  static const String radio_list_line = 'radio_list_line.svg';
  static const String radio_list = 'radio_list.svg';
  static const String receipt_text_line = 'receipt_text_line.svg';
  static const String receipt_text = 'receipt_text.svg';
  static const String redo_line = 'redo_line.svg';
  static const String redo = 'redo.svg';
  static const String reload_circle_line = 'reload_circle_line.svg';
  static const String reload_circle = 'reload_circle.svg';
  static const String reload_line = 'reload_line.svg';
  static const String reload = 'reload.svg';
  static const String remove_column_line = 'remove_column_line.svg';
  static const String remove_column = 'remove_column.svg';
  static const String remove_format_line = 'remove_format_line.svg';
  static const String remove_format = 'remove_format.svg';
  static const String remove_row_line = 'remove_row_line.svg';
  static const String remove_row = 'remove_row.svg';
  static const String repeat_circle_line = 'repeat_circle_line.svg';
  static const String repeat_circle = 'repeat_circle.svg';
  static const String restricted_line = 'restricted_line.svg';
  static const String restricted = 'restricted.svg';
  static const String robot_line = 'robot_line.svg';
  static const String robot = 'robot.svg';
  static const String rocket_3_start_line = 'rocket_3_start_line.svg';
  static const String rocket_3_start = 'rocket_3_start.svg';
  static const String rubel_circle_line = 'rubel_circle_line.svg';
  static const String rubel_circle = 'rubel_circle.svg';
  static const String ruler_2_line = 'ruler_2_line.svg';
  static const String ruler_2 = 'ruler_2.svg';
  static const String rupee_circle_line = 'rupee_circle_line.svg';
  static const String rupee_circle = 'rupee_circle.svg';
  static const String save_line = 'save_line.svg';
  static const String save = 'save.svg';
  static const String scale_light_line = 'scale_light_line.svg';
  static const String scale_light = 'scale_light.svg';
  static const String scan_fingerprint_line = 'scan_fingerprint_line.svg';
  static const String scan_fingerprint = 'scan_fingerprint.svg';
  static const String scan_user_line = 'scan_user_line.svg';
  static const String scan_user = 'scan_user.svg';
  static const String scanner_line = 'scanner_line.svg';
  static const String scanner = 'scanner.svg';
  static const String scooter_line = 'scooter_line.svg';
  static const String scooter = 'scooter.svg';
  static const String script_prescription_line = 'script_prescription_line.svg';
  static const String script_prescription = 'script_prescription.svg';
  static const String scroll_line = 'scroll_line.svg';
  static const String scroll_text_line = 'scroll_text_line.svg';
  static const String scroll_text = 'scroll_text.svg';
  static const String scroll = 'scroll.svg';
  static const String search_line = 'search_line.svg';
  static const String search_minus_line = 'search_minus_line.svg';
  static const String search_minus = 'search_minus.svg';
  static const String search_plus_line = 'search_plus_line.svg';
  static const String search_plus = 'search_plus.svg';
  static const String search = 'search.svg';
  static const String send_line = 'send_line.svg';
  static const String send = 'send.svg';
  static const String server_line = 'server_line.svg';
  static const String server = 'server.svg';
  static const String settings_cog_check_line = 'settings_cog_check_line.svg';
  static const String settings_cog_check = 'settings_cog_check.svg';
  static const String settings_cog_line = 'settings_cog_line.svg';
  static const String settings_cog_plus_line = 'settings_cog_plus_line.svg';
  static const String settings_cog_plus = 'settings_cog_plus.svg';
  static const String settings_cog = 'settings_cog.svg';
  static const String share_circle_line = 'share_circle_line.svg';
  static const String share_circle = 'share_circle.svg';
  static const String share_line = 'share_line.svg';
  static const String share = 'share.svg';
  static const String shield_line = 'shield_line.svg';
  static const String shield_off_line = 'shield_off_line.svg';
  static const String shield_off = 'shield_off.svg';
  static const String shield_plus_line = 'shield_plus_line.svg';
  static const String shield_plus = 'shield_plus.svg';
  static const String shield = 'shield.svg';
  static const String ship_line = 'ship_line.svg';
  static const String ship = 'ship.svg';
  static const String shooting_star_line = 'shooting_star_line.svg';
  static const String shooting_star = 'shooting_star.svg';
  static const String shopping_cart_line = 'shopping_cart_line.svg';
  static const String shopping_cart = 'shopping_cart.svg';
  static const String sim_card_line = 'sim_card_line.svg';
  static const String sim_card = 'sim_card.svg';
  static const String sitemap_line = 'sitemap_line.svg';
  static const String sitemap = 'sitemap.svg';
  static const String skull_line = 'skull_line.svg';
  static const String skull = 'skull.svg';
  static const String smartphone_apps_line = 'smartphone_apps_line.svg';
  static const String smartphone_apps = 'smartphone_apps.svg';
  static const String speaker_line = 'speaker_line.svg';
  static const String speaker = 'speaker.svg';
  static const String stop_circle_line = 'stop_circle_line.svg';
  static const String stop_circle = 'stop_circle.svg';
  static const String strike_through_line = 'strike_through_line.svg';
  static const String strike_through = 'strike_through.svg';
  static const String suitcase_2_line = 'suitcase_2_line.svg';
  static const String suitcase_2 = 'suitcase_2.svg';
  static const String suitcase_3_line = 'suitcase_3_line.svg';
  static const String suitcase_3 = 'suitcase_3.svg';
  static const String suitcase_line = 'suitcase_line.svg';
  static const String suitcase = 'suitcase.svg';
  static const String t_shirt_line = 't_shirt_line.svg';
  static const String t_shirt = 't_shirt.svg';
  static const String table_heart_line = 'table_heart_line.svg';
  static const String table_heart = 'table_heart.svg';
  static const String table_line = 'table_line.svg';
  static const String table_plus_line = 'table_plus_line.svg';
  static const String table_plus = 'table_plus.svg';
  static const String table = 'table.svg';
  static const String tag_line = 'tag_line.svg';
  static const String tag_off_line = 'tag_off_line.svg';
  static const String tag_off = 'tag_off.svg';
  static const String tag = 'tag.svg';
  static const String telescope_line = 'telescope_line.svg';
  static const String telescope = 'telescope.svg';
  static const String test_tube_filled_line = 'test_tube_filled_line.svg';
  static const String test_tube_filled = 'test_tube_filled.svg';
  static const String text_align_center_line = 'text_align_center_line.svg';
  static const String text_align_center = 'text_align_center.svg';
  static const String text_align_justify_line = 'text_align_justify_line.svg';
  static const String text_align_justify = 'text_align_justify.svg';
  static const String text_align_left_line = 'text_align_left_line.svg';
  static const String text_align_left = 'text_align_left.svg';
  static const String text_align_right_line = 'text_align_right_line.svg';
  static const String text_align_right = 'text_align_right.svg';
  static const String text_line = 'text_line.svg';
  static const String text_wrap_line = 'text_wrap_line.svg';
  static const String text_wrap = 'text_wrap.svg';
  static const String text = 'text.svg';
  static const String textbox_line = 'textbox_line.svg';
  static const String textbox_minus_line = 'textbox_minus_line.svg';
  static const String textbox_minus = 'textbox_minus.svg';
  static const String textbox_plus_line = 'textbox_plus_line.svg';
  static const String textbox_plus = 'textbox_plus.svg';
  static const String textbox = 'textbox.svg';
  static const String ticket_check_line = 'ticket_check_line.svg';
  static const String ticket_check = 'ticket_check.svg';
  static const String ticket_line = 'ticket_line.svg';
  static const String ticket_text_line = 'ticket_text_line.svg';
  static const String ticket_text = 'ticket_text.svg';
  static const String ticket = 'ticket.svg';
  static const String tickets_line = 'tickets_line.svg';
  static const String tickets = 'tickets.svg';
  static const String timer_line = 'timer_line.svg';
  static const String timer = 'timer.svg';
  static const String tooltip_line = 'tooltip_line.svg';
  static const String tooltip_text_line = 'tooltip_text_line.svg';
  static const String tooltip_text = 'tooltip_text.svg';
  static const String tooltip = 'tooltip.svg';
  static const String tooltips_2_line = 'tooltips_2_line.svg';
  static const String tooltips_2 = 'tooltips_2.svg';
  static const String tooltips_line = 'tooltips_line.svg';
  static const String tooltips = 'tooltips.svg';
  static const String tv_old_line = 'tv_old_line.svg';
  static const String tv_old = 'tv_old.svg';
  static const String umbrella_line = 'umbrella_line.svg';
  static const String umbrella = 'umbrella.svg';
  static const String underline_2_line = 'underline_2_line.svg';
  static const String underline_2 = 'underline_2.svg';
  static const String underline_line = 'underline_line.svg';
  static const String underline = 'underline.svg';
  static const String undo_line = 'undo_line.svg';
  static const String undo = 'undo.svg';
  static const String unlock_open_line = 'unlock_open_line.svg';
  static const String unlock_open = 'unlock_open.svg';
  static const String usb_line = 'usb_line.svg';
  static const String usb = 'usb.svg';
  static const String user_box_line = 'user_box_line.svg';
  static const String user_box = 'user_box.svg';
  static const String user_line = 'user_line.svg';
  static const String user = 'user.svg';
  static const String users_line = 'users_line.svg';
  static const String users = 'users.svg';
  static const String ux_circle_line = 'ux_circle_line.svg';
  static const String ux_circle = 'ux_circle.svg';
  static const String video_line = 'video_line.svg';
  static const String video_minus_line = 'video_minus_line.svg';
  static const String video_minus = 'video_minus.svg';
  static const String video_plus_line = 'video_plus_line.svg';
  static const String video_plus = 'video_plus.svg';
  static const String video = 'video.svg';
  static const String view_columns_line = 'view_columns_line.svg';
  static const String view_columns = 'view_columns.svg';
  static const String view_rows_line = 'view_rows_line.svg';
  static const String view_rows = 'view_rows.svg';
  static const String watch_line = 'watch_line.svg';
  static const String watch = 'watch.svg';
  static const String yen_circle_line = 'yen_circle_line.svg';
  static const String yen_circle = 'yen_circle.svg';
}
