import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

import 'icon_forest.dart';

/// Arcticons icons (4237 icons)
///
/// - build svg for arcticons icon libraries
/// App crypto icons (30 icons)
///
/// - build svg for app_crypto_icons icon libraries
/// - constants link to svg icon resources
class Arcticons extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  const Arcticons(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return IconForest.svgAsset(
      'arcticons',
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  static const String a_0h_h1 = 'a_0h_h1.svg';
  static const String a1111 = 'a1111.svg';
  static const String a1822tan = 'a1822tan.svg';
  static const String a1945airforce = 'a1945airforce.svg';
  static const String a1by1 = 'a1by1.svg';
  static const String a1dm = 'a1dm.svg';
  static const String a1money = 'a1money.svg';
  static const String a1password = 'a1password.svg';
  static const String a1se = 'a1se.svg';
  static const String a1xbit = 'a1xbit.svg';
  static const String a2 = 'a2.svg';
  static const String a2048 = 'a2048.svg';
  static const String a2050 = 'a2050.svg';
  static const String a30_day_fitness_challenge = 'a30_day_fitness_challenge.svg';
  static const String a3c_all_in_one_toolbox = 'a3c_all_in_one_toolbox.svg';
  static const String a3ctaskmanager = 'a3ctaskmanager.svg';
  static const String a3d_calculator = 'a3d_calculator.svg';
  static const String a5etools = 'a5etools.svg';
  static const String a7m_workout = 'a7m_workout.svg';
  static const String a7mind = 'a7mind.svg';
  static const String a7zipper = 'a7zipper.svg';
  static const String a8ballpool = 'a8ballpool.svg';
  static const String a8vim = 'a8vim.svg';
  static const String a9292 = 'a9292.svg';
  static const String a99 = 'a99.svg';
  static const String a9gag = 'a9gag.svg';
  static const String aaaaa = 'aaaaa.svg';
  static const String aard = 'aard.svg';
  static const String aarogya_setu = 'aarogya_setu.svg';
  static const String abanca = 'abanca.svg';
  static const String abnamro = 'abnamro.svg';
  static const String acadboost = 'acadboost.svg';
  static const String acalendar_plus = 'acalendar_plus.svg';
  static const String acastusphoton = 'acastusphoton.svg';
  static const String acc = 'acc.svg';
  static const String acca = 'acca.svg';
  static const String access_dots = 'access_dots.svg';
  static const String accordion = 'accordion.svg';
  static const String accubattery = 'accubattery.svg';
  static const String accuweather = 'accuweather.svg';
  static const String acdisplay = 'acdisplay.svg';
  static const String achikaps = 'achikaps.svg';
  static const String acm = 'acm.svg';
  static const String acode = 'acode.svg';
  static const String acrylicicons = 'acrylicicons.svg';
  static const String actiondash = 'actiondash.svg';
  static const String actionlauncher = 'actionlauncher.svg';
  static const String activebuilding = 'activebuilding.svg';
  static const String activitylauncher = 'activitylauncher.svg';
  static const String activitywatch = 'activitywatch.svg';
  static const String adaptivebrightnesstile = 'adaptivebrightnesstile.svg';
  static const String adaway = 'adaway.svg';
  static const String adblock_for_samsung_internet = 'adblock_for_samsung_internet.svg';
  static const String adblock_plus_fur_samsung_internet = 'adblock_plus_fur_samsung_internet.svg';
  static const String adblockbrowser = 'adblockbrowser.svg';
  static const String adbmanager = 'adbmanager.svg';
  static const String adguard = 'adguard.svg';
  static const String adguardvpn = 'adguardvpn.svg';
  static const String adidas_training = 'adidas_training.svg';
  static const String adiutor = 'adiutor.svg';
  static const String adm = 'adm.svg';
  static const String admission_assistant = 'admission_assistant.svg';
  static const String adnihilation = 'adnihilation.svg';
  static const String adobeacrobat = 'adobeacrobat.svg';
  static const String adobecomp = 'adobecomp.svg';
  static const String adobecreativecloud = 'adobecreativecloud.svg';
  static const String adobelightroom = 'adobelightroom.svg';
  static const String adobephotoshop = 'adobephotoshop.svg';
  static const String adobephotoshopfix = 'adobephotoshopfix.svg';
  static const String adobephotoshopmix = 'adobephotoshopmix.svg';
  static const String adoberush = 'adoberush.svg';
  static const String adobescan = 'adobescan.svg';
  static const String adobexd = 'adobexd.svg';
  static const String advanced_task_manager = 'advanced_task_manager.svg';
  static const String aegis = 'aegis.svg';
  static const String afk_arena = 'afk_arena.svg';
  static const String aftership = 'aftership.svg';
  static const String afwall = 'afwall.svg';
  static const String afweatherwidget = 'afweatherwidget.svg';
  static const String agenda = 'agenda.svg';
  static const String ags_player = 'ags_player.svg';
  static const String ahs_parking = 'ahs_parking.svg';
  static const String aicamera = 'aicamera.svg';
  static const String aida64 = 'aida64.svg';
  static const String aide = 'aide.svg';
  static const String aidungeon = 'aidungeon.svg';
  static const String aimp = 'aimp.svg';
  static const String aimsicd = 'aimsicd.svg';
  static const String air_nz = 'air_nz.svg';
  static const String air_travel = 'air_travel.svg';
  static const String air_vpn = 'air_vpn.svg';
  static const String airbnb = 'airbnb.svg';
  static const String airguard = 'airguard.svg';
  static const String airtel = 'airtel.svg';
  static const String airvisual = 'airvisual.svg';
  static const String al_chan = 'al_chan.svg';
  static const String al_jazeera = 'al_jazeera.svg';
  static const String alarmclockxtreme = 'alarmclockxtreme.svg';
  static const String alarmio = 'alarmio.svg';
  static const String alarmklock = 'alarmklock.svg';
  static const String alarms = 'alarms.svg';
  static const String alarmy = 'alarmy.svg';
  static const String albaraka = 'albaraka.svg';
  static const String albatross = 'albatross.svg';
  static const String albert_heijn = 'albert_heijn.svg';
  static const String alchemy_stars = 'alchemy_stars.svg';
  static const String aldi_nord = 'aldi_nord.svg';
  static const String alditalk = 'alditalk.svg';
  static const String alephbeta = 'alephbeta.svg';
  static const String alert_bridge = 'alert_bridge.svg';
  static const String alfia = 'alfia.svg';
  static const String alfred_camera = 'alfred_camera.svg';
  static const String alienshooter = 'alienshooter.svg';
  static const String aliexpress = 'aliexpress.svg';
  static const String alipay = 'alipay.svg';
  static const String alitelecom = 'alitelecom.svg';
  static const String aliucordinstaller = 'aliucordinstaller.svg';
  static const String all4hue = 'all4hue.svg';
  static const String allcast = 'allcast.svg';
  static const String allegro_lokalnie = 'allegro_lokalnie.svg';
  static const String allegro = 'allegro.svg';
  static const String alliant = 'alliant.svg';
  static const String alligator = 'alligator.svg';
  static const String almost_a_hero = 'almost_a_hero.svg';
  static const String alogcat = 'alogcat.svg';
  static const String altcoinprices = 'altcoinprices.svg';
  static const String alto = 'alto.svg';
  static const String alttp_tracker = 'alttp_tracker.svg';
  static const String amaze = 'amaze.svg';
  static const String amazon_alexa = 'amazon_alexa.svg';
  static const String amazon_appstore = 'amazon_appstore.svg';
  static const String amazon_music = 'amazon_music.svg';
  static const String amazon_photos = 'amazon_photos.svg';
  static const String amazon_prime_video = 'amazon_prime_video.svg';
  static const String amazon_shopper_panel = 'amazon_shopper_panel.svg';
  static const String amazon_shopping = 'amazon_shopping.svg';
  static const String ambiance_alt = 'ambiance_alt.svg';
  static const String ambience = 'ambience.svg';
  static const String amdroid = 'amdroid.svg';
  static const String ameli = 'ameli.svg';
  static const String amexca = 'amexca.svg';
  static const String amoledbackgrounds = 'amoledbackgrounds.svg';
  static const String amongus = 'amongus.svg';
  static const String ampere = 'ampere.svg';
  static const String ampli = 'ampli.svg';
  static const String an2linux = 'an2linux.svg';
  static const String anchr = 'anchr.svg';
  static const String andorstrail = 'andorstrail.svg';
  static const String andotp = 'andotp.svg';
  static const String androbd = 'androbd.svg';
  static const String android_samba_client = 'android_samba_client.svg';
  static const String android_tv = 'android_tv.svg';
  static const String android = 'android.svg';
  static const String androidauto = 'androidauto.svg';
  static const String androidrun = 'androidrun.svg';
  static const String androidterm = 'androidterm.svg';
  static const String androidvnc = 'androidvnc.svg';
  static const String androits_gps_test = 'androits_gps_test.svg';
  static const String andronix = 'andronix.svg';
  static const String androtainer = 'androtainer.svg';
  static const String andstatus = 'andstatus.svg';
  static const String anexplorer = 'anexplorer.svg';
  static const String angband = 'angband.svg';
  static const String anidroid = 'anidroid.svg';
  static const String aniki = 'aniki.svg';
  static const String animeultima = 'animeultima.svg';
  static const String animexstream = 'animexstream.svg';
  static const String animezone = 'animezone.svg';
  static const String aniyomi = 'aniyomi.svg';
  static const String anker = 'anker.svg';
  static const String ankidroid = 'ankidroid.svg';
  static const String anlinux = 'anlinux.svg';
  static const String annaboard = 'annaboard.svg';
  static const String anonaddy = 'anonaddy.svg';
  static const String anonymous_messenger = 'anonymous_messenger.svg';
  static const String anonymousmessenger_alt = 'anonymousmessenger_alt.svg';
  static const String another_notes = 'another_notes.svg';
  static const String another_widget = 'another_widget.svg';
  static const String anotherterm = 'anotherterm.svg';
  static const String ant_legion = 'ant_legion.svg';
  static const String antennapod = 'antennapod.svg';
  static const String antidote = 'antidote.svg';
  static const String antimatter_dimensions = 'antimatter_dimensions.svg';
  static const String antimine = 'antimine.svg';
  static const String antiyoy = 'antiyoy.svg';
  static const String antox = 'antox.svg';
  static const String anutotd = 'anutotd.svg';
  static const String anydesk = 'anydesk.svg';
  static const String anydo = 'anydo.svg';
  static const String anymex = 'anymex.svg';
  static const String anythingtopip = 'anythingtopip.svg';
  static const String anyun_continuing_education = 'anyun_continuing_education.svg';
  static const String anywhere = 'anywhere.svg';
  static const String ap_news = 'ap_news.svg';
  static const String apex = 'apex.svg';
  static const String apk_analyzer = 'apk_analyzer.svg';
  static const String apk_explorer_and_editor = 'apk_explorer_and_editor.svg';
  static const String apk_extractor = 'apk_extractor.svg';
  static const String apkeditor = 'apkeditor.svg';
  static const String apkgrabber = 'apkgrabber.svg';
  static const String apkkit = 'apkkit.svg';
  static const String apkmirror_installer = 'apkmirror_installer.svg';
  static const String apkmirror = 'apkmirror.svg';
  static const String apkpure = 'apkpure.svg';
  static const String apkpurer = 'apkpurer.svg';
  static const String apktrack = 'apktrack.svg';
  static const String apkupdater = 'apkupdater.svg';
  static const String aplayer = 'aplayer.svg';
  static const String apoteket = 'apoteket.svg';
  static const String appbrainaddetector = 'appbrainaddetector.svg';
  static const String appcloner = 'appcloner.svg';
  static const String appleflinger = 'appleflinger.svg';
  static const String applemusic = 'applemusic.svg';
  static const String applicationsinfo = 'applicationsinfo.svg';
  static const String applore = 'applore.svg';
  static const String appmanager = 'appmanager.svg';
  static const String appops = 'appops.svg';
  static const String appopsx = 'appopsx.svg';
  static const String apps2org = 'apps2org.svg';
  static const String apps2sd = 'apps2sd.svg';
  static const String appstract = 'appstract.svg';
  static const String apptester = 'apptester.svg';
  static const String aptoide = 'aptoide.svg';
  static const String aqua_mail = 'aqua_mail.svg';
  static const String arbetsfor = 'arbetsfor.svg';
  static const String arbys = 'arbys.svg';
  static const String arcaea = 'arcaea.svg';
  static const String archero = 'archero.svg';
  static const String archwikiviewer = 'archwikiviewer.svg';
  static const String arcticons = 'arcticons.svg';
  static const String arcticonsdark = 'arcticonsdark.svg';
  static const String arcticonslight = 'arcticonslight.svg';
  static const String ardmediathek = 'ardmediathek.svg';
  static const String arduinodroid = 'arduinodroid.svg';
  static const String areffect = 'areffect.svg';
  static const String arena = 'arena.svg';
  static const String arevelation = 'arevelation.svg';
  static const String argenta = 'argenta.svg';
  static const String aria2app = 'aria2app.svg';
  static const String ariane = 'ariane.svg';
  static const String ariane2 = 'ariane2.svg';
  static const String arity = 'arity.svg';
  static const String arknights = 'arknights.svg';
  static const String arlo = 'arlo.svg';
  static const String armory_and_machine = 'armory_and_machine.svg';
  static const String arte = 'arte.svg';
  static const String arzone = 'arzone.svg';
  static const String asana = 'asana.svg';
  static const String asciicam = 'asciicam.svg';
  static const String asn_bankieren = 'asn_bankieren.svg';
  static const String asn_betalen = 'asn_betalen.svg';
  static const String asr_licence = 'asr_licence.svg';
  static const String asr = 'asr.svg';
  static const String assembly_line = 'assembly_line.svg';
  static const String asteroidossync = 'asteroidossync.svg';
  static const String at_and_t_photo_storage = 'at_and_t_photo_storage.svg';
  static const String atalk_alt = 'atalk_alt.svg';
  static const String atalk = 'atalk.svg';
  static const String athmvil = 'athmvil.svg';
  static const String atmospherelogger = 'atmospherelogger.svg';
  static const String atom = 'atom.svg';
  static const String atomic = 'atomic.svg';
  static const String attacktheblock = 'attacktheblock.svg';
  static const String attestationdedeplacement = 'attestationdedeplacement.svg';
  static const String audible = 'audible.svg';
  static const String audinaut = 'audinaut.svg';
  static const String audio_video_factory = 'audio_video_factory.svg';
  static const String audioanchor = 'audioanchor.svg';
  static const String audiobookshelf = 'audiobookshelf.svg';
  static const String audiofx = 'audiofx.svg';
  static const String audiolab = 'audiolab.svg';
  static const String audiometer = 'audiometer.svg';
  static const String audiotechnicaconnect = 'audiotechnicaconnect.svg';
  static const String audiovideomanager = 'audiovideomanager.svg';
  static const String auditor = 'auditor.svg';
  static const String auphonicedit = 'auphonicedit.svg';
  static const String aurdroid = 'aurdroid.svg';
  static const String aurora = 'aurora.svg';
  static const String auroradroid = 'auroradroid.svg';
  static const String auroraservices = 'auroraservices.svg';
  static const String aurorastore = 'aurorastore.svg';
  static const String ausweisapp = 'ausweisapp.svg';
  static const String authenticate = 'authenticate.svg';
  static const String authenticator = 'authenticator.svg';
  static const String authpass = 'authpass.svg';
  static const String authy = 'authy.svg';
  static const String auto_auto_rotate = 'auto_auto_rotate.svg';
  static const String auto_away = 'auto_away.svg';
  static const String autodark = 'autodark.svg';
  static const String automatag = 'automatag.svg';
  static const String automate = 'automate.svg';
  static const String automation = 'automation.svg';
  static const String autonavi = 'autonavi.svg';
  static const String autoshare = 'autoshare.svg';
  static const String autotagger = 'autotagger.svg';
  static const String auxio = 'auxio.svg';
  static const String avans = 'avans.svg';
  static const String avanza = 'avanza.svg';
  static const String avenza = 'avenza.svg';
  static const String aves = 'aves.svg';
  static const String aviasales = 'aviasales.svg';
  static const String aviraphantomvpn = 'aviraphantomvpn.svg';
  static const String avnc = 'avnc.svg';
  static const String awork = 'awork.svg';
  static const String axetfilemanager = 'axetfilemanager.svg';
  static const String axieinfinity = 'axieinfinity.svg';
  static const String axismobile = 'axismobile.svg';
  static const String axs = 'axs.svg';
  static const String azur_lane = 'azur_lane.svg';
  static const String babbel = 'babbel.svg';
  static const String babelio = 'babelio.svg';
  static const String babydots = 'babydots.svg';
  static const String babyphone = 'babyphone.svg';
  static const String backdrops = 'backdrops.svg';
  static const String backgroundrestrictor = 'backgroundrestrictor.svg';
  static const String backup = 'backup.svg';
  static const String baconreader = 'baconreader.svg';
  static const String badoo = 'badoo.svg';
  static const String badpiggies_hd = 'badpiggies_hd.svg';
  static const String badreads = 'badreads.svg';
  static const String bahamut = 'bahamut.svg';
  static const String bahnbonus = 'bahnbonus.svg';
  static const String baidu_map = 'baidu_map.svg';
  static const String baidu_netdisk = 'baidu_netdisk.svg';
  static const String ballpark = 'ballpark.svg';
  static const String ballz_shooter = 'ballz_shooter.svg';
  static const String bamowi = 'bamowi.svg';
  static const String bananakong = 'bananakong.svg';
  static const String bandcamp = 'bandcamp.svg';
  static const String bandlab = 'bandlab.svg';
  static const String bandsintown = 'bandsintown.svg';
  static const String bankid = 'bankid.svg';
  static const String bankin = 'bankin.svg';
  static const String bankmillennium = 'bankmillennium.svg';
  static const String banque = 'banque.svg';
  static const String barclays = 'barclays.svg';
  static const String barcode = 'barcode.svg';
  static const String baresip = 'baresip.svg';
  static const String barinsta = 'barinsta.svg';
  static const String barq = 'barq.svg';
  static const String bartbontecolors = 'bartbontecolors.svg';
  static const String based_cooking = 'based_cooking.svg';
  static const String battery_guru = 'battery_guru.svg';
  static const String battery_log = 'battery_log.svg';
  static const String battery = 'battery.svg';
  static const String batterycalibration = 'batterycalibration.svg';
  static const String batterychargelimit = 'batterychargelimit.svg';
  static const String batterytool = 'batterytool.svg';
  static const String battleforwesnoth = 'battleforwesnoth.svg';
  static const String battleheart = 'battleheart.svg';
  static const String battlelands = 'battlelands.svg';
  static const String battlenet = 'battlenet.svg';
  static const String bb = 'bb.svg';
  static const String bbcnews = 'bbcnews.svg';
  static const String beanconqueror = 'beanconqueror.svg';
  static const String beat_game = 'beat_game.svg';
  static const String beatfind = 'beatfind.svg';
  static const String beats = 'beats.svg';
  static const String becu = 'becu.svg';
  static const String beebrilliant = 'beebrilliant.svg';
  static const String beecount = 'beecount.svg';
  static const String beelinguapp = 'beelinguapp.svg';
  static const String beetv = 'beetv.svg';
  static const String behance = 'behance.svg';
  static const String bejeweled_3 = 'bejeweled_3.svg';
  static const String bejeweled_blitz = 'bejeweled_blitz.svg';
  static const String bejeweled_stars = 'bejeweled_stars.svg';
  static const String ben = 'ben.svg';
  static const String beowulfweather = 'beowulfweather.svg';
  static const String berichtenbox = 'berichtenbox.svg';
  static const String best_connect = 'best_connect.svg';
  static const String bestbuy = 'bestbuy.svg';
  static const String bestiary = 'bestiary.svg';
  static const String bestprice = 'bestprice.svg';
  static const String bestsign_app = 'bestsign_app.svg';
  static const String beterdichtbij = 'beterdichtbij.svg';
  static const String betterbatterystats = 'betterbatterystats.svg';
  static const String bettercounter = 'bettercounter.svg';
  static const String betterschedule = 'betterschedule.svg';
  static const String betteruntis = 'betteruntis.svg';
  static const String beyondmenu = 'beyondmenu.svg';
  static const String bggcatalog = 'bggcatalog.svg';
  static const String bhim_sbi_pay = 'bhim_sbi_pay.svg';
  static const String bhim = 'bhim.svg';
  static const String bible = 'bible.svg';
  static const String biblia = 'biblia.svg';
  static const String biblio = 'biblio.svg';
  static const String biblioteket = 'biblioteket.svg';
  static const String bigbasket = 'bigbasket.svg';
  static const String bikelocation = 'bikelocation.svg';
  static const String bikesharinghub = 'bikesharinghub.svg';
  static const String bilibili = 'bilibili.svg';
  static const String bilkaplus = 'bilkaplus.svg';
  static const String bilkascango = 'bilkascango.svg';
  static const String bilkatogo = 'bilkatogo.svg';
  static const String billthefarmercrossword = 'billthefarmercrossword.svg';
  static const String binance = 'binance.svg';
  static const String binaryeye_alt = 'binaryeye_alt.svg';
  static const String binaryeye = 'binaryeye.svg';
  static const String binauralbeats = 'binauralbeats.svg';
  static const String birday = 'birday.svg';
  static const String birdnet_alt = 'birdnet_alt.svg';
  static const String birdnet = 'birdnet.svg';
  static const String birthdayadapter = 'birthdayadapter.svg';
  static const String bison = 'bison.svg';
  static const String bisq = 'bisq.svg';
  static const String bitcoin = 'bitcoin.svg';
  static const String bitdefender = 'bitdefender.svg';
  static const String bitmask = 'bitmask.svg';
  static const String bitmoji = 'bitmoji.svg';
  static const String bitpanda = 'bitpanda.svg';
  static const String bitpay = 'bitpay.svg';
  static const String bitrue = 'bitrue.svg';
  static const String bitstamp = 'bitstamp.svg';
  static const String bitwarden = 'bitwarden.svg';
  static const String biwo = 'biwo.svg';
  static const String bixby_vision = 'bixby_vision.svg';
  static const String bixby = 'bixby.svg';
  static const String blabber = 'blabber.svg';
  static const String blabla_alt = 'blabla_alt.svg';
  static const String blabla = 'blabla.svg';
  static const String blackberrydevicesearch = 'blackberrydevicesearch.svg';
  static const String blackberrylauncher = 'blackberrylauncher.svg';
  static const String blackberrymessenger = 'blackberrymessenger.svg';
  static const String blackberrysupportcenter = 'blackberrysupportcenter.svg';
  static const String blackboard = 'blackboard.svg';
  static const String blackhole = 'blackhole.svg';
  static const String blacklistblocker = 'blacklistblocker.svg';
  static const String blackpearl_kangeqiu = 'blackpearl_kangeqiu.svg';
  static const String blackplayer = 'blackplayer.svg';
  static const String blade_player = 'blade_player.svg';
  static const String ble_scanner = 'ble_scanner.svg';
  static const String bleentoro = 'bleentoro.svg';
  static const String blemonitor = 'blemonitor.svg';
  static const String blitz = 'blitz.svg';
  static const String blitzerde = 'blitzerde.svg';
  static const String blitzortung_lightning_monitor = 'blitzortung_lightning_monitor.svg';
  static const String blizzardauthenticator = 'blizzardauthenticator.svg';
  static const String blockchain = 'blockchain.svg';
  static const String blocker = 'blocker.svg';
  static const String blocket = 'blocket.svg';
  static const String blockinger = 'blockinger.svg';
  static const String blogger = 'blogger.svg';
  static const String blokada_alt = 'blokada_alt.svg';
  static const String blokada = 'blokada.svg';
  static const String bloonstd6 = 'bloonstd6.svg';
  static const String bluebot = 'bluebot.svg';
  static const String bluecoins = 'bluecoins.svg';
  static const String bluedriver = 'bluedriver.svg';
  static const String blueletterbible = 'blueletterbible.svg';
  static const String bluelineconsole = 'bluelineconsole.svg';
  static const String bluemail = 'bluemail.svg';
  static const String blueminimal = 'blueminimal.svg';
  static const String bluetooth = 'bluetooth.svg';
  static const String bluetoothterminal = 'bluetoothterminal.svg';
  static const String blur = 'blur.svg';
  static const String blw = 'blw.svg';
  static const String bmap = 'bmap.svg';
  static const String bob_world = 'bob_world.svg';
  static const String boc = 'boc.svg';
  static const String bodhi_timer = 'bodhi_timer.svg';
  static const String bofa = 'bofa.svg';
  static const String boinc = 'boinc.svg';
  static const String bol = 'bol.svg';
  static const String bolt = 'bolt.svg';
  static const String bolton = 'bolton.svg';
  static const String book = 'book.svg';
  static const String bookcatalogue = 'bookcatalogue.svg';
  static const String booking = 'booking.svg';
  static const String bookshelf = 'bookshelf.svg';
  static const String bookwyrm = 'bookwyrm.svg';
  static const String boost = 'boost.svg';
  static const String bouncer = 'bouncer.svg';
  static const String boursorama_banque = 'boursorama_banque.svg';
  static const String box_2 = 'box_2.svg';
  static const String box = 'box.svg';
  static const String boxtogopro = 'boxtogopro.svg';
  static const String bpi_mobile = 'bpi_mobile.svg';
  static const String brackeyside = 'brackeyside.svg';
  static const String brainf = 'brainf.svg';
  static const String brainly = 'brainly.svg';
  static const String brakarbillett = 'brakarbillett.svg';
  static const String brave_beta = 'brave_beta.svg';
  static const String brave_nightly = 'brave_nightly.svg';
  static const String brave = 'brave.svg';
  static const String brawlstars = 'brawlstars.svg';
  static const String breathly = 'breathly.svg';
  static const String brevent = 'brevent.svg';
  static const String breviary = 'breviary.svg';
  static const String briar = 'briar.svg';
  static const String bricksbreakerballscrush = 'bricksbreakerballscrush.svg';
  static const String brilliant = 'brilliant.svg';
  static const String bring = 'bring.svg';
  static const String bromite = 'bromite.svg';
  static const String brouter = 'brouter.svg';
  static const String browser = 'browser.svg';
  static const String brubank = 'brubank.svg';
  static const String bspb = 'bspb.svg';
  static const String bubble_alt = 'bubble_alt.svg';
  static const String bubble = 'bubble.svg';
  static const String bubbleupnp = 'bubbleupnp.svg';
  static const String buddhaquotes = 'buddhaquotes.svg';
  static const String budgetmylife = 'budgetmylife.svg';
  static const String budgetwatch = 'budgetwatch.svg';
  static const String bugjaeger = 'bugjaeger.svg';
  static const String buienalarm = 'buienalarm.svg';
  static const String buienradar = 'buienradar.svg';
  static const String bumble = 'bumble.svg';
  static const String bundlednotes = 'bundlednotes.svg';
  static const String bunpo = 'bunpo.svg';
  static const String bunq = 'bunq.svg';
  static const String buoy = 'buoy.svg';
  static const String burgerking = 'burgerking.svg';
  static const String burgerservice = 'burgerservice.svg';
  static const String bus_tram = 'bus_tram.svg';
  static const String bus = 'bus.svg';
  static const String busto = 'busto.svg';
  static const String busybox = 'busybox.svg';
  static const String busyboxinstaller = 'busyboxinstaller.svg';
  static const String buttercup = 'buttercup.svg';
  static const String buzkill = 'buzkill.svg';
  static const String bvgfahrinfo = 'bvgfahrinfo.svg';
  static const String bvnc = 'bvnc.svg';
  static const String bxactions = 'bxactions.svg';
  static const String bybit = 'bybit.svg';
  static const String bykea = 'bykea.svg';
  static const String c6bank = 'c6bank.svg';
  static const String cabify = 'cabify.svg';
  static const String cabinet = 'cabinet.svg';
  static const String cainiao_wireless = 'cainiao_wireless.svg';
  static const String cajaarena = 'cajaarena.svg';
  static const String cake = 'cake.svg';
  static const String cakewallet = 'cakewallet.svg';
  static const String calces = 'calces.svg';
  static const String calcolatrice_cas = 'calcolatrice_cas.svg';
  static const String calctastic = 'calctastic.svg';
  static const String calculator = 'calculator.svg';
  static const String calculatorplusplus = 'calculatorplusplus.svg';
  static const String calculatorpluspluswindowed = 'calculatorpluspluswindowed.svg';
  static const String calef = 'calef.svg';
  static const String calendar_1 = 'calendar_1.svg';
  static const String calendar_10 = 'calendar_10.svg';
  static const String calendar_11 = 'calendar_11.svg';
  static const String calendar_12 = 'calendar_12.svg';
  static const String calendar_13 = 'calendar_13.svg';
  static const String calendar_14 = 'calendar_14.svg';
  static const String calendar_15 = 'calendar_15.svg';
  static const String calendar_16 = 'calendar_16.svg';
  static const String calendar_17 = 'calendar_17.svg';
  static const String calendar_18 = 'calendar_18.svg';
  static const String calendar_19 = 'calendar_19.svg';
  static const String calendar_2 = 'calendar_2.svg';
  static const String calendar_20 = 'calendar_20.svg';
  static const String calendar_21 = 'calendar_21.svg';
  static const String calendar_22 = 'calendar_22.svg';
  static const String calendar_23 = 'calendar_23.svg';
  static const String calendar_24 = 'calendar_24.svg';
  static const String calendar_25 = 'calendar_25.svg';
  static const String calendar_26 = 'calendar_26.svg';
  static const String calendar_27 = 'calendar_27.svg';
  static const String calendar_28 = 'calendar_28.svg';
  static const String calendar_29 = 'calendar_29.svg';
  static const String calendar_3 = 'calendar_3.svg';
  static const String calendar_30 = 'calendar_30.svg';
  static const String calendar_31 = 'calendar_31.svg';
  static const String calendar_4 = 'calendar_4.svg';
  static const String calendar_5 = 'calendar_5.svg';
  static const String calendar_6 = 'calendar_6.svg';
  static const String calendar_7 = 'calendar_7.svg';
  static const String calendar_8 = 'calendar_8.svg';
  static const String calendar_9 = 'calendar_9.svg';
  static const String calendar_proton_1 = 'calendar_proton_1.svg';
  static const String calendar_proton_10 = 'calendar_proton_10.svg';
  static const String calendar_proton_11 = 'calendar_proton_11.svg';
  static const String calendar_proton_12 = 'calendar_proton_12.svg';
  static const String calendar_proton_13 = 'calendar_proton_13.svg';
  static const String calendar_proton_14 = 'calendar_proton_14.svg';
  static const String calendar_proton_15 = 'calendar_proton_15.svg';
  static const String calendar_proton_16 = 'calendar_proton_16.svg';
  static const String calendar_proton_17 = 'calendar_proton_17.svg';
  static const String calendar_proton_18 = 'calendar_proton_18.svg';
  static const String calendar_proton_19 = 'calendar_proton_19.svg';
  static const String calendar_proton_2 = 'calendar_proton_2.svg';
  static const String calendar_proton_20 = 'calendar_proton_20.svg';
  static const String calendar_proton_21 = 'calendar_proton_21.svg';
  static const String calendar_proton_22 = 'calendar_proton_22.svg';
  static const String calendar_proton_23 = 'calendar_proton_23.svg';
  static const String calendar_proton_24 = 'calendar_proton_24.svg';
  static const String calendar_proton_25 = 'calendar_proton_25.svg';
  static const String calendar_proton_26 = 'calendar_proton_26.svg';
  static const String calendar_proton_27 = 'calendar_proton_27.svg';
  static const String calendar_proton_28 = 'calendar_proton_28.svg';
  static const String calendar_proton_29 = 'calendar_proton_29.svg';
  static const String calendar_proton_3 = 'calendar_proton_3.svg';
  static const String calendar_proton_30 = 'calendar_proton_30.svg';
  static const String calendar_proton_31 = 'calendar_proton_31.svg';
  static const String calendar_proton_4 = 'calendar_proton_4.svg';
  static const String calendar_proton_5 = 'calendar_proton_5.svg';
  static const String calendar_proton_6 = 'calendar_proton_6.svg';
  static const String calendar_proton_7 = 'calendar_proton_7.svg';
  static const String calendar_proton_8 = 'calendar_proton_8.svg';
  static const String calendar_proton_9 = 'calendar_proton_9.svg';
  static const String calendara = 'calendara.svg';
  static const String calendarcolor = 'calendarcolor.svg';
  static const String calendarimportexport = 'calendarimportexport.svg';
  static const String calendula = 'calendula.svg';
  static const String calibrecompanion = 'calibrecompanion.svg';
  static const String call_of_duty = 'call_of_duty.svg';
  static const String call_protect = 'call_protect.svg';
  static const String callabike = 'callabike.svg';
  static const String callrecorder = 'callrecorder.svg';
  static const String callsblacklist = 'callsblacklist.svg';
  static const String calm = 'calm.svg';
  static const String calyxvpn = 'calyxvpn.svg';
  static const String camera = 'camera.svg';
  static const String cameraconnect = 'cameraconnect.svg';
  static const String cameraremote = 'cameraremote.svg';
  static const String cameraroll = 'cameraroll.svg';
  static const String camscanner = 'camscanner.svg';
  static const String canadabusiness = 'canadabusiness.svg';
  static const String canadaradar = 'canadaradar.svg';
  static const String canadaweather = 'canadaweather.svg';
  static const String canarabank = 'canarabank.svg';
  static const String canary = 'canary.svg';
  static const String candy_crush_saga = 'candy_crush_saga.svg';
  static const String canva = 'canva.svg';
  static const String canvasstudent = 'canvasstudent.svg';
  static const String capcut = 'capcut.svg';
  static const String capitalone = 'capitalone.svg';
  static const String card_emulator_pro = 'card_emulator_pro.svg';
  static const String cardboardmuseum = 'cardboardmuseum.svg';
  static const String cardinal_quest_2 = 'cardinal_quest_2.svg';
  static const String cardmindreader = 'cardmindreader.svg';
  static const String careem = 'careem.svg';
  static const String carnet = 'carnet.svg';
  static const String carreport = 'carreport.svg';
  static const String carscanner = 'carscanner.svg';
  static const String carsmile = 'carsmile.svg';
  static const String caseys = 'caseys.svg';
  static const String casper = 'casper.svg';
  static const String castlevania = 'castlevania.svg';
  static const String castro = 'castro.svg';
  static const String cat_avatar_generator = 'cat_avatar_generator.svg';
  static const String cataclysm_dda = 'cataclysm_dda.svg';
  static const String catandicegame = 'catandicegame.svg';
  static const String catima = 'catima.svg';
  static const String catogram = 'catogram.svg';
  static const String catsa = 'catsa.svg';
  static const String caynaxsportstracker = 'caynaxsportstracker.svg';
  static const String ccgt = 'ccgt.svg';
  static const String cdiscount = 'cdiscount.svg';
  static const String celighting = 'celighting.svg';
  static const String cell = 'cell.svg';
  static const String cepher = 'cepher.svg';
  static const String cflumen = 'cflumen.svg';
  static const String cgeo = 'cgeo.svg';
  static const String changedetection = 'changedetection.svg';
  static const String chanu = 'chanu.svg';
  static const String character_pad = 'character_pad.svg';
  static const String charmap = 'charmap.svg';
  static const String chase = 'chase.svg';
  static const String chatcraft = 'chatcraft.svg';
  static const String checkers = 'checkers.svg';
  static const String checkudvej = 'checkudvej.svg';
  static const String chefkoch = 'chefkoch.svg';
  static const String cheogram = 'cheogram.svg';
  static const String chess = 'chess.svg';
  static const String chessclock = 'chessclock.svg';
  static const String chessmix = 'chessmix.svg';
  static const String chieffollow = 'chieffollow.svg';
  static const String china_construction_bank = 'china_construction_bank.svg';
  static const String china_life_insurance = 'china_life_insurance.svg';
  static const String china_railway = 'china_railway.svg';
  static const String china_unicom = 'china_unicom.svg';
  static const String china_university_mooc = 'china_university_mooc.svg';
  static const String chip = 'chip.svg';
  static const String chogue = 'chogue.svg';
  static const String chordanalyser = 'chordanalyser.svg';
  static const String chromiumautoupdater = 'chromiumautoupdater.svg';
  static const String chronicle_audiobook_player = 'chronicle_audiobook_player.svg';
  static const String chrono_trigger = 'chrono_trigger.svg';
  static const String chronus = 'chronus.svg';
  static const String chubbyclick = 'chubbyclick.svg';
  static const String churchdesk = 'churchdesk.svg';
  static const String cifsdocumentsprovider = 'cifsdocumentsprovider.svg';
  static const String cimb_bank_ph = 'cimb_bank_ph.svg';
  static const String cineaste = 'cineaste.svg';
  static const String cinelog = 'cinelog.svg';
  static const String cinema_pro = 'cinema_pro.svg';
  static const String cinemark_theatres = 'cinemark_theatres.svg';
  static const String cinetrak = 'cinetrak.svg';
  static const String cineville = 'cineville.svg';
  static const String cinexplore = 'cinexplore.svg';
  static const String cinta = 'cinta.svg';
  static const String circle_letter_x = 'circle_letter_x.svg';
  static const String circle = 'circle.svg';
  static const String citi_mobile = 'citi_mobile.svg';
  static const String citizenportal = 'citizenportal.svg';
  static const String citra = 'citra.svg';
  static const String cittamobi = 'cittamobi.svg';
  static const String city_transit = 'city_transit.svg';
  static const String citymapper = 'citymapper.svg';
  static const String citymaps2go = 'citymaps2go.svg';
  static const String cityzen = 'cityzen.svg';
  static const String claro = 'claro.svg';
  static const String clash_mini = 'clash_mini.svg';
  static const String clash_of_clans = 'clash_of_clans.svg';
  static const String clash = 'clash.svg';
  static const String clashroyale = 'clashroyale.svg';
  static const String classical_music_tagger = 'classical_music_tagger.svg';
  static const String classroom = 'classroom.svg';
  static const String classysharkexodus = 'classysharkexodus.svg';
  static const String cleantimer = 'cleantimer.svg';
  static const String clearscan = 'clearscan.svg';
  static const String cleverbook_for_minecraft = 'cleverbook_for_minecraft.svg';
  static const String click_to_chat = 'click_to_chat.svg';
  static const String clientis_secure = 'clientis_secure.svg';
  static const String clima = 'clima.svg';
  static const String clinometer = 'clinometer.svg';
  static const String clipboardcleaner = 'clipboardcleaner.svg';
  static const String clock = 'clock.svg';
  static const String clocksync = 'clocksync.svg';
  static const String clonephone = 'clonephone.svg';
  static const String cloudstream = 'cloudstream.svg';
  static const String cloudtv_remote = 'cloudtv_remote.svg';
  static const String clover = 'clover.svg';
  static const String clubhouse = 'clubhouse.svg';
  static const String coconut = 'coconut.svg';
  static const String codeassist = 'codeassist.svg';
  static const String codecheck = 'codecheck.svg';
  static const String coffee = 'coffee.svg';
  static const String cofi = 'cofi.svg';
  static const String coin_flip = 'coin_flip.svg';
  static const String coinbase = 'coinbase.svg';
  static const String coindcx = 'coindcx.svg';
  static const String coingecko = 'coingecko.svg';
  static const String coini = 'coini.svg';
  static const String coinomi = 'coinomi.svg';
  static const String coinstats = 'coinstats.svg';
  static const String coinswitch = 'coinswitch.svg';
  static const String collaboraoffice = 'collaboraoffice.svg';
  static const String collage = 'collage.svg';
  static const String colordict = 'colordict.svg';
  static const String coloringbook = 'coloringbook.svg';
  static const String colornamer = 'colornamer.svg';
  static const String colornote = 'colornote.svg';
  static const String colorpicker = 'colorpicker.svg';
  static const String combide = 'combide.svg';
  static const String comdirect = 'comdirect.svg';
  static const String comicscreen = 'comicscreen.svg';
  static const String commons = 'commons.svg';
  static const String commonvoice = 'commonvoice.svg';
  static const String community = 'community.svg';
  static const String compaan_portaal = 'compaan_portaal.svg';
  static const String compass = 'compass.svg';
  static const String concentricclock = 'concentricclock.svg';
  static const String concepts = 'concepts.svg';
  static const String congstar = 'congstar.svg';
  static const String connectips = 'connectips.svg';
  static const String connectme = 'connectme.svg';
  static const String consorsbank_secureplus = 'consorsbank_secureplus.svg';
  static const String consumidor = 'consumidor.svg';
  static const String contactdiary = 'contactdiary.svg';
  static const String contacts_alt = 'contacts_alt.svg';
  static const String contacts = 'contacts.svg';
  static const String contenttransfer = 'contenttransfer.svg';
  static const String controlloid = 'controlloid.svg';
  static const String conversations = 'conversations.svg';
  static const String converternow = 'converternow.svg';
  static const String cookidoo = 'cookidoo.svg';
  static const String cool_reader = 'cool_reader.svg';
  static const String coolapk = 'coolapk.svg';
  static const String corona_scanner = 'corona_scanner.svg';
  static const String coronacheck = 'coronacheck.svg';
  static const String coronalert = 'coronalert.svg';
  static const String coronamelder = 'coronamelder.svg';
  static const String coronapas = 'coronapas.svg';
  static const String coronatracing = 'coronatracing.svg';
  static const String coronavirus = 'coronavirus.svg';
  static const String coronawarn = 'coronawarn.svg';
  static const String correspondent = 'correspondent.svg';
  static const String couchsurfing = 'couchsurfing.svg';
  static const String covidalert = 'covidalert.svg';
  static const String covidalertny = 'covidalertny.svg';
  static const String covidcert = 'covidcert.svg';
  static const String covidcheck = 'covidcheck.svg';
  static const String covidscancst = 'covidscancst.svg';
  static const String covpass = 'covpass.svg';
  static const String covpasscheck = 'covpasscheck.svg';
  static const String cows_revenge = 'cows_revenge.svg';
  static const String cowsay = 'cowsay.svg';
  static const String coxhealthnow = 'coxhealthnow.svg';
  static const String cozydrive = 'cozydrive.svg';
  static const String cpuinfo = 'cpuinfo.svg';
  static const String cpustats = 'cpustats.svg';
  static const String cpuz = 'cpuz.svg';
  static const String craigslist = 'craigslist.svg';
  static const String crashontherun = 'crashontherun.svg';
  static const String crayon = 'crayon.svg';
  static const String cred = 'cred.svg';
  static const String credit_karma = 'credit_karma.svg';
  static const String creditagricole = 'creditagricole.svg';
  static const String creditas = 'creditas.svg';
  static const String creditcoop = 'creditcoop.svg';
  static const String creditone = 'creditone.svg';
  static const String critical_maps = 'critical_maps.svg';
  static const String croc = 'croc.svg';
  static const String cronograma = 'cronograma.svg';
  static const String cronometer = 'cronometer.svg';
  static const String crontosignswiss = 'crontosignswiss.svg';
  static const String cross_platfrom_disk_test = 'cross_platfrom_disk_test.svg';
  static const String crossword = 'crossword.svg';
  static const String crosswords = 'crosswords.svg';
  static const String crossy_road = 'crossy_road.svg';
  static const String crowdcity = 'crowdcity.svg';
  static const String crrowd = 'crrowd.svg';
  static const String crunchyroll = 'crunchyroll.svg';
  static const String crypto_prices = 'crypto_prices.svg';
  static const String cryptocam = 'cryptocam.svg';
  static const String cryptomator = 'cryptomator.svg';
  static const String cryten = 'cryten.svg';
  static const String csoundforandroid = 'csoundforandroid.svg';
  static const String ctemplar = 'ctemplar.svg';
  static const String ctrl_c_programming_idle_game = 'ctrl_c_programming_idle_game.svg';
  static const String cube_escape = 'cube_escape.svg';
  static const String cuppa = 'cuppa.svg';
  static const String curiositystream = 'curiositystream.svg';
  static const String curiouscat = 'curiouscat.svg';
  static const String currencies = 'currencies.svg';
  static const String currency = 'currency.svg';
  static const String curve = 'curve.svg';
  static const String cut_the_rope = 'cut_the_rope.svg';
  static const String cutthecord = 'cutthecord.svg';
  static const String cx_file_explorer = 'cx_file_explorer.svg';
  static const String cxxdroid = 'cxxdroid.svg';
  static const String cyberghost = 'cyberghost.svg';
  static const String cythara = 'cythara.svg';
  static const String d_point = 'd_point.svg';
  static const String dagger = 'dagger.svg';
  static const String dailyart = 'dailyart.svg';
  static const String dailydozen = 'dailydozen.svg';
  static const String dailypic = 'dailypic.svg';
  static const String dailytube = 'dailytube.svg';
  static const String dankchat = 'dankchat.svg';
  static const String dankort = 'dankort.svg';
  static const String dante = 'dante.svg';
  static const String daraz = 'daraz.svg';
  static const String dark = 'dark.svg';
  static const String darkcroc_theme = 'darkcroc_theme.svg';
  static const String darkmodelivewallpaper = 'darkmodelivewallpaper.svg';
  static const String darksky = 'darksky.svg';
  static const String darq = 'darq.svg';
  static const String dartchecker = 'dartchecker.svg';
  static const String daserste = 'daserste.svg';
  static const String dasher = 'dasher.svg';
  static const String dashlane = 'dashlane.svg';
  static const String datadex = 'datadex.svg';
  static const String datawing = 'datawing.svg';
  static const String davdroid = 'davdroid.svg';
  static const String dawn = 'dawn.svg';
  static const String daylio = 'daylio.svg';
  static const String dazn = 'dazn.svg';
  static const String db_legends = 'db_legends.svg';
  static const String dba = 'dba.svg';
  static const String dbnavigator_alt = 'dbnavigator_alt.svg';
  static const String dbnavigator_beta = 'dbnavigator_beta.svg';
  static const String dbnavigator = 'dbnavigator.svg';
  static const String dcss = 'dcss.svg';
  static const String ddbplayer = 'ddbplayer.svg';
  static const String deadcells = 'deadcells.svg';
  static const String debatekeeper = 'debatekeeper.svg';
  static const String debiandroid = 'debiandroid.svg';
  static const String debitum = 'debitum.svg';
  static const String debloater = 'debloater.svg';
  static const String debtcalc = 'debtcalc.svg';
  static const String decisions = 'decisions.svg';
  static const String deck = 'deck.svg';
  static const String deckboard_pro = 'deckboard_pro.svg';
  static const String deco = 'deco.svg';
  static const String decsyncc = 'decsyncc.svg';
  static const String deedum = 'deedum.svg';
  static const String deepl = 'deepl.svg';
  static const String deepstash = 'deepstash.svg';
  static const String deezer_audiobooks = 'deezer_audiobooks.svg';
  static const String deezer = 'deezer.svg';
  static const String defaultdarktheme = 'defaultdarktheme.svg';
  static const String defendo = 'defendo.svg';
  static const String defit = 'defit.svg';
  static const String degiro = 'degiro.svg';
  static const String degoo = 'degoo.svg';
  static const String delist = 'delist.svg';
  static const String deliveroo = 'deliveroo.svg';
  static const String dellconnect = 'dellconnect.svg';
  static const String delta = 'delta.svg';
  static const String deltachat = 'deltachat.svg';
  static const String deltafx = 'deltafx.svg';
  static const String deluge = 'deluge.svg';
  static const String demineur = 'demineur.svg';
  static const String democracy = 'democracy.svg';
  static const String denik_n = 'denik_n.svg';
  static const String der_spiegel = 'der_spiegel.svg';
  static const String descomplica_faculdade_digital = 'descomplica_faculdade_digital.svg';
  static const String desjardins = 'desjardins.svg';
  static const String deskclock = 'deskclock.svg';
  static const String desmos_scientific = 'desmos_scientific.svg';
  static const String desmos = 'desmos.svg';
  static const String detexify = 'detexify.svg';
  static const String detoxdroid = 'detoxdroid.svg';
  static const String devcheck = 'devcheck.svg';
  static const String developerwidget = 'developerwidget.svg';
  static const String deviantart = 'deviantart.svg';
  static const String device_care = 'device_care.svg';
  static const String device_connect = 'device_connect.svg';
  static const String device_info_pro = 'device_info_pro.svg';
  static const String device_unlock = 'device_unlock.svg';
  static const String deviceinfo = 'deviceinfo.svg';
  static const String deviceinfohw = 'deviceinfohw.svg';
  static const String devrant = 'devrant.svg';
  static const String dfv = 'dfv.svg';
  static const String dharma = 'dharma.svg';
  static const String diabetesm = 'diabetesm.svg';
  static const String diaguard = 'diaguard.svg';
  static const String diary = 'diary.svg';
  static const String diaspora = 'diaspora.svg';
  static const String dice = 'dice.svg';
  static const String dicer = 'dicer.svg';
  static const String diceware = 'diceware.svg';
  static const String dicio = 'dicio.svg';
  static const String dictcc = 'dictcc.svg';
  static const String dictionary_cs_fr = 'dictionary_cs_fr.svg';
  static const String dictionary = 'dictionary.svg';
  static const String dictionaryformids = 'dictionaryformids.svg';
  static const String didi_greater_china = 'didi_greater_china.svg';
  static const String didi = 'didi.svg';
  static const String digid = 'digid.svg';
  static const String digilocker = 'digilocker.svg';
  static const String digilux = 'digilux.svg';
  static const String digital_wellbeing = 'digital_wellbeing.svg';
  static const String digital_work_wallet = 'digital_work_wallet.svg';
  static const String digital_yuan = 'digital_yuan.svg';
  static const String digitalsignage = 'digitalsignage.svg';
  static const String digitalwellbeing = 'digitalwellbeing.svg';
  static const String diia = 'diia.svg';
  static const String dimmer_2 = 'dimmer_2.svg';
  static const String dimmer = 'dimmer.svg';
  static const String dingtalk = 'dingtalk.svg';
  static const String dinomail = 'dinomail.svg';
  static const String diode = 'diode.svg';
  static const String diohub = 'diohub.svg';
  static const String dir = 'dir.svg';
  static const String disabler = 'disabler.svg';
  static const String discogs = 'discogs.svg';
  static const String discord_alt = 'discord_alt.svg';
  static const String discord = 'discord.svg';
  static const String discover = 'discover.svg';
  static const String discovery_ = 'discovery_.svg';
  static const String discreetlauncher = 'discreetlauncher.svg';
  static const String diskusage = 'diskusage.svg';
  static const String disney = 'disney.svg';
  static const String disroot = 'disroot.svg';
  static const String dissembler = 'dissembler.svg';
  static const String ditmm = 'ditmm.svg';
  static const String ditzo_zorg = 'ditzo_zorg.svg';
  static const String djezzy = 'djezzy.svg';
  static const String dji_pilot = 'dji_pilot.svg';
  static const String dkadico = 'dkadico.svg';
  static const String dkbbanking = 'dkbbanking.svg';
  static const String dkbtantogo = 'dkbtantogo.svg';
  static const String dlf_nachrichten = 'dlf_nachrichten.svg';
  static const String dm_unipd = 'dm_unipd.svg';
  static const String dmi = 'dmi.svg';
  static const String dndrulebook = 'dndrulebook.svg';
  static const String dns_changer = 'dns_changer.svg';
  static const String dns66 = 'dns66.svg';
  static const String dnsfilter = 'dnsfilter.svg';
  static const String dnshero = 'dnshero.svg';
  static const String dnsman = 'dnsman.svg';
  static const String docsensepro = 'docsensepro.svg';
  static const String doctolib = 'doctolib.svg';
  static const String document_viewer = 'document_viewer.svg';
  static const String documents = 'documents.svg';
  static const String docus = 'docus.svg';
  static const String docutain = 'docutain.svg';
  static const String dodopizza = 'dodopizza.svg';
  static const String dol = 'dol.svg';
  static const String dolby = 'dolby.svg';
  static const String dolbyon = 'dolbyon.svg';
  static const String dolphinemulator = 'dolphinemulator.svg';
  static const String dominos = 'dominos.svg';
  static const String doodle = 'doodle.svg';
  static const String doodle2 = 'doodle2.svg';
  static const String doom = 'doom.svg';
  static const String doordash = 'doordash.svg';
  static const String doswimmer = 'doswimmer.svg';
  static const String dotpict = 'dotpict.svg';
  static const String dots_and_co = 'dots_and_co.svg';
  static const String dots = 'dots.svg';
  static const String douban = 'douban.svg';
  static const String doubletwistpro = 'doubletwistpro.svg';
  static const String doubtnut = 'doubtnut.svg';
  static const String downloadnavi = 'downloadnavi.svg';
  static const String downloads = 'downloads.svg';
  static const String downwell = 'downwell.svg';
  static const String dowser = 'dowser.svg';
  static const String drastic = 'drastic.svg';
  static const String drawer = 'drawer.svg';
  static const String dreamlab = 'dreamlab.svg';
  static const String drinks = 'drinks.svg';
  static const String drip = 'drip.svg';
  static const String drive_safe_save = 'drive_safe_save.svg';
  static const String drive = 'drive.svg';
  static const String drivedroid = 'drivedroid.svg';
  static const String drm_info = 'drm_info.svg';
  static const String droid48sx = 'droid48sx.svg';
  static const String droidcam_obs = 'droidcam_obs.svg';
  static const String droidcam = 'droidcam.svg';
  static const String droidedit = 'droidedit.svg';
  static const String droidfish = 'droidfish.svg';
  static const String droidfs = 'droidfs.svg';
  static const String droidify_alt = 'droidify_alt.svg';
  static const String droidify = 'droidify.svg';
  static const String droidshows = 'droidshows.svg';
  static const String droidvim = 'droidvim.svg';
  static const String droidvncngadminpanel = 'droidvncngadminpanel.svg';
  static const String droidzebra = 'droidzebra.svg';
  static const String dronecast = 'dronecast.svg';
  static const String dropbox = 'dropbox.svg';
  static const String droplets = 'droplets.svg';
  static const String drops = 'drops.svg';
  static const String drumon = 'drumon.svg';
  static const String ds_cam = 'ds_cam.svg';
  static const String dsb = 'dsb.svg';
  static const String dsd6 = 'dsd6.svg';
  static const String dsdrive = 'dsdrive.svg';
  static const String dslrdashboard = 'dslrdashboard.svg';
  static const String dsphoto = 'dsphoto.svg';
  static const String dsub = 'dsub.svg';
  static const String duca = 'duca.svg';
  static const String duckduckgo = 'duckduckgo.svg';
  static const String duo = 'duo.svg';
  static const String duolingo_alt = 'duolingo_alt.svg';
  static const String duolingo = 'duolingo.svg';
  static const String duomobile = 'duomobile.svg';
  static const String duorem = 'duorem.svg';
  static const String dustsettle = 'dustsettle.svg';
  static const String dvd = 'dvd.svg';
  static const String e_rezept = 'e_rezept.svg';
  static const String e1547 = 'e1547.svg';
  static const String eapps = 'eapps.svg';
  static const String earmouse = 'earmouse.svg';
  static const String earthmoon = 'earthmoon.svg';
  static const String easer = 'easer.svg';
  static const String easy_jet = 'easy_jet.svg';
  static const String easy_watermark = 'easy_watermark.svg';
  static const String easyconnect = 'easyconnect.svg';
  static const String easydiary = 'easydiary.svg';
  static const String easyjoin = 'easyjoin.svg';
  static const String easynoise = 'easynoise.svg';
  static const String easypaisa = 'easypaisa.svg';
  static const String easypark = 'easypark.svg';
  static const String easyrpg_player = 'easyrpg_player.svg';
  static const String easyxkcd = 'easyxkcd.svg';
  static const String ebarimt = 'ebarimt.svg';
  static const String ebay = 'ebay.svg';
  static const String ebbanking = 'ebbanking.svg';
  static const String ebobirthday = 'ebobirthday.svg';
  static const String eboks = 'eboks.svg';
  static const String ebookdroid = 'ebookdroid.svg';
  static const String echo = 'echo.svg';
  static const String ecosia = 'ecosia.svg';
  static const String edge = 'edge.svg';
  static const String editor = 'editor.svg';
  static const String edpzero = 'edpzero.svg';
  static const String edslite = 'edslite.svg';
  static const String edt_univ = 'edt_univ.svg';
  static const String eduroamcat = 'eduroamcat.svg';
  static const String eduvpn = 'eduvpn.svg';
  static const String eero = 'eero.svg';
  static const String efteling = 'efteling.svg';
  static const String egg_inc = 'egg_inc.svg';
  static const String eka2l1 = 'eka2l1.svg';
  static const String ekonto = 'ekonto.svg';
  static const String elder_launcher = 'elder_launcher.svg';
  static const String electron = 'electron.svg';
  static const String electrum = 'electrum.svg';
  static const String elektrichki = 'elektrichki.svg';
  static const String element = 'element.svg';
  static const String elementary = 'elementary.svg';
  static const String eleven = 'eleven.svg';
  static const String elisa = 'elisa.svg';
  static const String ella = 'ella.svg';
  static const String emby = 'emby.svg';
  static const String emerald = 'emerald.svg';
  static const String emit = 'emit.svg';
  static const String emkan = 'emkan.svg';
  static const String english = 'english.svg';
  static const String enigmbox = 'enigmbox.svg';
  static const String enoceantool = 'enoceantool.svg';
  static const String enpass = 'enpass.svg';
  static const String enrecipes = 'enrecipes.svg';
  static const String enroute = 'enroute.svg';
  static const String entel = 'entel.svg';
  static const String epassportreader = 'epassportreader.svg';
  static const String episodes_two = 'episodes_two.svg';
  static const String episodes = 'episodes.svg';
  static const String equalizer = 'equalizer.svg';
  static const String equate = 'equate.svg';
  static const String ereolen = 'ereolen.svg';
  static const String eruditedictionary = 'eruditedictionary.svg';
  static const String eruditetranslator = 'eruditetranslator.svg';
  static const String es = 'es.svg';
  static const String escapepod = 'escapepod.svg';
  static const String eset_payment_protection = 'eset_payment_protection.svg';
  static const String eset_security = 'eset_security.svg';
  static const String esewa = 'esewa.svg';
  static const String esis = 'esis.svg';
  static const String espaol = 'espaol.svg';
  static const String et_legacy = 'et_legacy.svg';
  static const String etchdroid = 'etchdroid.svg';
  static const String etesync = 'etesync.svg';
  static const String etesyncnotes = 'etesyncnotes.svg';
  static const String etherpad = 'etherpad.svg';
  static const String etrade = 'etrade.svg';
  static const String etsy = 'etsy.svg';
  static const String eufyhome = 'eufyhome.svg';
  static const String eufylife = 'eufylife.svg';
  static const String eventyayattendee = 'eventyayattendee.svg';
  static const String everdo = 'everdo.svg';
  static const String evernote = 'evernote.svg';
  static const String evie = 'evie.svg';
  static const String evmap = 'evmap.svg';
  static const String ewesticker = 'ewesticker.svg';
  static const String ex_kernel_manager = 'ex_kernel_manager.svg';
  static const String exercisetimer = 'exercisetimer.svg';
  static const String exiferaser = 'exiferaser.svg';
  static const String exifthumbnailadder = 'exifthumbnailadder.svg';
  static const String exodus = 'exodus.svg';
  static const String exodusprivacy = 'exodusprivacy.svg';
  static const String expedia = 'expedia.svg';
  static const String exponential_idle = 'exponential_idle.svg';
  static const String exportcontacts = 'exportcontacts.svg';
  static const String expressvpn = 'expressvpn.svg';
  static const String fabularium = 'fabularium.svg';
  static const String faceapp = 'faceapp.svg';
  static const String facebook_lite = 'facebook_lite.svg';
  static const String facebook_messenger_lite = 'facebook_messenger_lite.svg';
  static const String facebook_messenger = 'facebook_messenger.svg';
  static const String facebook = 'facebook.svg';
  static const String fairemail = 'fairemail.svg';
  static const String fakestandby = 'fakestandby.svg';
  static const String faketraveller = 'faketraveller.svg';
  static const String falling_lightblocks = 'falling_lightblocks.svg';
  static const String familygem = 'familygem.svg';
  static const String familylink = 'familylink.svg';
  static const String fancade = 'fancade.svg';
  static const String fanfiction_net = 'fanfiction_net.svg';
  static const String fast_brightness_control_widget = 'fast_brightness_control_widget.svg';
  static const String fast_n_fitness = 'fast_n_fitness.svg';
  static const String fast_shopping = 'fast_shopping.svg';
  static const String fast = 'fast.svg';
  static const String fastdic = 'fastdic.svg';
  static const String fasthub = 'fasthub.svg';
  static const String fastient = 'fastient.svg';
  static const String fastlikeafox = 'fastlikeafox.svg';
  static const String fastmail = 'fastmail.svg';
  static const String fastreset = 'fastreset.svg';
  static const String fawry = 'fawry.svg';
  static const String fbreader = 'fbreader.svg';
  static const String fdeai = 'fdeai.svg';
  static const String fdroid_alt = 'fdroid_alt.svg';
  static const String fdroid_nearby = 'fdroid_nearby.svg';
  static const String fdroid = 'fdroid.svg';
  static const String fdroidbuildstatus = 'fdroidbuildstatus.svg';
  static const String fdroidclassic = 'fdroidclassic.svg';
  static const String fdroidforum = 'fdroidforum.svg';
  static const String fdroidkdi = 'fdroidkdi.svg';
  static const String fe_clock = 'fe_clock.svg';
  static const String fedex = 'fedex.svg';
  static const String fedilab = 'fedilab.svg';
  static const String feedback = 'feedback.svg';
  static const String feeder = 'feeder.svg';
  static const String feedlyclassic = 'feedlyclassic.svg';
  static const String feedme = 'feedme.svg';
  static const String feedwatcher = 'feedwatcher.svg';
  static const String feeel = 'feeel.svg';
  static const String feeld = 'feeld.svg';
  static const String feinstaubwidget = 'feinstaubwidget.svg';
  static const String feit_electric = 'feit_electric.svg';
  static const String fendertune = 'fendertune.svg';
  static const String fengyun_format_factory = 'fengyun_format_factory.svg';
  static const String fennec = 'fennec.svg';
  static const String fetch_rewards = 'fetch_rewards.svg';
  static const String fetlife = 'fetlife.svg';
  static const String ffmpegmediaencoder = 'ffmpegmediaencoder.svg';
  static const String ffupdater = 'ffupdater.svg';
  static const String ffvi = 'ffvi.svg';
  static const String fidelity = 'fidelity.svg';
  static const String fidibo = 'fidibo.svg';
  static const String field_guide_ingress = 'field_guide_ingress.svg';
  static const String fiftheditioncharactersheet = 'fiftheditioncharactersheet.svg';
  static const String fiitjee_recorded_lectures = 'fiitjee_recorded_lectures.svg';
  static const String fildo = 'fildo.svg';
  static const String file_commander = 'file_commander.svg';
  static const String file = 'file.svg';
  static const String fileee = 'fileee.svg';
  static const String filen = 'filen.svg';
  static const String files = 'files.svg';
  static const String final_surge = 'final_surge.svg';
  static const String finale = 'finale.svg';
  static const String finamp = 'finamp.svg';
  static const String financeguru = 'financeguru.svg';
  static const String finanzassistent = 'finanzassistent.svg';
  static const String finch = 'finch.svg';
  static const String finddevice = 'finddevice.svg';
  static const String finder = 'finder.svg';
  static const String findmydevice = 'findmydevice.svg';
  static const String findroid = 'findroid.svg';
  static const String fing = 'fing.svg';
  static const String fireflyiiimobile = 'fireflyiiimobile.svg';
  static const String firefox_beta = 'firefox_beta.svg';
  static const String firefox_focus = 'firefox_focus.svg';
  static const String firefox_lite = 'firefox_lite.svg';
  static const String firefox_master = 'firefox_master.svg';
  static const String firefox_nightly = 'firefox_nightly.svg';
  static const String firefox = 'firefox.svg';
  static const String firefoxlockwise = 'firefoxlockwise.svg';
  static const String firefoxnotes = 'firefoxnotes.svg';
  static const String firefoxsend = 'firefoxsend.svg';
  static const String firestrikeretro = 'firestrikeretro.svg';
  static const String firetv = 'firetv.svg';
  static const String firewall = 'firewall.svg';
  static const String firstbus = 'firstbus.svg';
  static const String firstmobile = 'firstmobile.svg';
  static const String fitbit = 'fitbit.svg';
  static const String fitify = 'fitify.svg';
  static const String fitotrack = 'fitotrack.svg';
  static const String fiverr = 'fiverr.svg';
  static const String fixedsmart = 'fixedsmart.svg';
  static const String fkm = 'fkm.svg';
  static const String flamingdurtles = 'flamingdurtles.svg';
  static const String flamingo = 'flamingo.svg';
  static const String flappycrush = 'flappycrush.svg';
  static const String flash_deck = 'flash_deck.svg';
  static const String flashscore = 'flashscore.svg';
  static const String flashy = 'flashy.svg';
  static const String flatastic = 'flatastic.svg';
  static const String flextrafik = 'flextrafik.svg';
  static const String flic = 'flic.svg';
  static const String flickr = 'flickr.svg';
  static const String flightradar24 = 'flightradar24.svg';
  static const String flightstats = 'flightstats.svg';
  static const String flink = 'flink.svg';
  static const String flinkster = 'flinkster.svg';
  static const String flip = 'flip.svg';
  static const String flipboard = 'flipboard.svg';
  static const String flipkart_alt = 'flipkart_alt.svg';
  static const String flipkart = 'flipkart.svg';
  static const String flixbus = 'flixbus.svg';
  static const String floatplane = 'floatplane.svg';
  static const String floccus = 'floccus.svg';
  static const String flora = 'flora.svg';
  static const String florisboard = 'florisboard.svg';
  static const String flote = 'flote.svg';
  static const String flowbird = 'flowbird.svg';
  static const String flowfree = 'flowfree.svg';
  static const String flowfreebridges = 'flowfreebridges.svg';
  static const String flowfreehexes = 'flowfreehexes.svg';
  static const String flowfreewarps = 'flowfreewarps.svg';
  static const String flud = 'flud.svg';
  static const String fluentreader = 'fluentreader.svg';
  static const String fluffychat = 'fluffychat.svg';
  static const String fluid_ng = 'fluid_ng.svg';
  static const String flutterhole = 'flutterhole.svg';
  static const String flux = 'flux.svg';
  static const String flym_decsync = 'flym_decsync.svg';
  static const String flym = 'flym.svg';
  static const String fmiweather = 'fmiweather.svg';
  static const String fokus = 'fokus.svg';
  static const String folder_ = 'folder_.svg';
  static const String folder_dollar = 'folder_dollar.svg';
  static const String folder_euro = 'folder_euro.svg';
  static const String folder_favourites = 'folder_favourites.svg';
  static const String folder_games = 'folder_games.svg';
  static const String folder_google = 'folder_google.svg';
  static const String folder_heart = 'folder_heart.svg';
  static const String folder_home = 'folder_home.svg';
  static const String folder_mail = 'folder_mail.svg';
  static const String folder_media = 'folder_media.svg';
  static const String folder_music = 'folder_music.svg';
  static const String folder_phone = 'folder_phone.svg';
  static const String folder_settings = 'folder_settings.svg';
  static const String folder_sync = 'folder_sync.svg';
  static const String folder_utilities = 'folder_utilities.svg';
  static const String folder_weather = 'folder_weather.svg';
  static const String follow = 'follow.svg';
  static const String fon = 'fon.svg';
  static const String fondos_interactivos = 'fondos_interactivos.svg';
  static const String foobar2000 = 'foobar2000.svg';
  static const String foodpanda = 'foodpanda.svg';
  static const String foodtracker = 'foodtracker.svg';
  static const String fooview = 'fooview.svg';
  static const String forecaster = 'forecaster.svg';
  static const String forecastie = 'forecastie.svg';
  static const String foreground = 'foreground.svg';
  static const String forest = 'forest.svg';
  static const String forgetmenot = 'forgetmenot.svg';
  static const String forkclient = 'forkclient.svg';
  static const String forkhub = 'forkhub.svg';
  static const String forkyz = 'forkyz.svg';
  static const String formulia = 'formulia.svg';
  static const String fortuneo = 'fortuneo.svg';
  static const String fortunes = 'fortunes.svg';
  static const String foss_moodle = 'foss_moodle.svg';
  static const String foss_warn = 'foss_warn.svg';
  static const String fossbrowser = 'fossbrowser.svg';
  static const String fossilhybrid = 'fossilhybrid.svg';
  static const String fotmob = 'fotmob.svg';
  static const String foursquare = 'foursquare.svg';
  static const String foxs_mmm = 'foxs_mmm.svg';
  static const String foxydroid = 'foxydroid.svg';
  static const String frameo = 'frameo.svg';
  static const String francais = 'francais.svg';
  static const String franceinfo = 'franceinfo.svg';
  static const String francetv = 'francetv.svg';
  static const String francomanca = 'francomanca.svg';
  static const String free_quran_education = 'free_quran_education.svg';
  static const String free2pass = 'free2pass.svg';
  static const String freeblocks = 'freeblocks.svg';
  static const String freebox = 'freebox.svg';
  static const String freebox2 = 'freebox2.svg';
  static const String freedcam = 'freedcam.svg';
  static const String freedcamviewer = 'freedcamviewer.svg';
  static const String freedombox = 'freedombox.svg';
  static const String freelancer_upwork = 'freelancer_upwork.svg';
  static const String freemobilenetstat = 'freemobilenetstat.svg';
  static const String freenet_mobile = 'freenet_mobile.svg';
  static const String freeotp = 'freeotp.svg';
  static const String freeotpplus = 'freeotpplus.svg';
  static const String freeprints = 'freeprints.svg';
  static const String freetrade = 'freetrade.svg';
  static const String freetrailer = 'freetrailer.svg';
  static const String freezer = 'freezer.svg';
  static const String freezeyou = 'freezeyou.svg';
  static const String freifunk_auto_connect = 'freifunk_auto_connect.svg';
  static const String freifunk_karte = 'freifunk_karte.svg';
  static const String freshrss = 'freshrss.svg';
  static const String friday_night_funkin = 'friday_night_funkin.svg';
  static const String friendiqa = 'friendiqa.svg';
  static const String friendly_iq = 'friendly_iq.svg';
  static const String fritter = 'fritter.svg';
  static const String fritz_app_wlan = 'fritz_app_wlan.svg';
  static const String frost = 'frost.svg';
  static const String frostfacebook = 'frostfacebook.svg';
  static const String frozenbubble = 'frozenbubble.svg';
  static const String fruit_ninja = 'fruit_ninja.svg';
  static const String fruux = 'fruux.svg';
  static const String ftxpro = 'ftxpro.svg';
  static const String fuelflash = 'fuelflash.svg';
  static const String fuelio = 'fuelio.svg';
  static const String fujifilmconnect = 'fujifilmconnect.svg';
  static const String functiongenerator = 'functiongenerator.svg';
  static const String funktrainer = 'funktrainer.svg';
  static const String funkwhale = 'funkwhale.svg';
  static const String fx = 'fx.svg';
  static const String fxtextedit = 'fxtextedit.svg';
  static const String gadgetbridge = 'gadgetbridge.svg';
  static const String gag = 'gag.svg';
  static const String galaxyinvaders = 'galaxyinvaders.svg';
  static const String galaxystore = 'galaxystore.svg';
  static const String galaxywearable = 'galaxywearable.svg';
  static const String galeria = 'galeria.svg';
  static const String gallery = 'gallery.svg';
  static const String galnet_dictionary = 'galnet_dictionary.svg';
  static const String game_of_life = 'game_of_life.svg';
  static const String game_plugins = 'game_plugins.svg';
  static const String gamelauncher = 'gamelauncher.svg';
  static const String games_tracker = 'games_tracker.svg';
  static const String games = 'games.svg';
  static const String gametree = 'gametree.svg';
  static const String gameturbo = 'gameturbo.svg';
  static const String garena = 'garena.svg';
  static const String garmin_connect_iq = 'garmin_connect_iq.svg';
  static const String garmin_connect = 'garmin_connect.svg';
  static const String garmin_dive = 'garmin_dive.svg';
  static const String garmin_drive = 'garmin_drive.svg';
  static const String garmin_explore = 'garmin_explore.svg';
  static const String garmin_golf = 'garmin_golf.svg';
  static const String garmin_jr = 'garmin_jr.svg';
  static const String garmin_virb = 'garmin_virb.svg';
  static const String garminconnect = 'garminconnect.svg';
  static const String gasflow = 'gasflow.svg';
  static const String gaspar = 'gaspar.svg';
  static const String gcash = 'gcash.svg';
  static const String gcompris = 'gcompris.svg';
  static const String gcore = 'gcore.svg';
  static const String gdroid = 'gdroid.svg';
  static const String gear_vpn = 'gear_vpn.svg';
  static const String gearbest = 'gearbest.svg';
  static const String geekbench = 'geekbench.svg';
  static const String geekttrss = 'geekttrss.svg';
  static const String geeni = 'geeni.svg';
  static const String geizhals = 'geizhals.svg';
  static const String gelli = 'gelli.svg';
  static const String genius_home = 'genius_home.svg';
  static const String genius = 'genius.svg';
  static const String genshin_impact = 'genshin_impact.svg';
  static const String geocaching = 'geocaching.svg';
  static const String geogebra = 'geogebra.svg';
  static const String geologicaltimescale = 'geologicaltimescale.svg';
  static const String geometricweather = 'geometricweather.svg';
  static const String geometry_dash = 'geometry_dash.svg';
  static const String geometrydash = 'geometrydash.svg';
  static const String geonotes = 'geonotes.svg';
  static const String geovelo = 'geovelo.svg';
  static const String germanos = 'germanos.svg';
  static const String gesture = 'gesture.svg';
  static const String getapps = 'getapps.svg';
  static const String getflow = 'getflow.svg';
  static const String gettr = 'gettr.svg';
  static const String ghost = 'ghost.svg';
  static const String ghostcommander = 'ghostcommander.svg';
  static const String giffgaff = 'giffgaff.svg';
  static const String giflivewallpaper = 'giflivewallpaper.svg';
  static const String gifmaker = 'gifmaker.svg';
  static const String git = 'git.svg';
  static const String gitfox = 'gitfox.svg';
  static const String githo = 'githo.svg';
  static const String github = 'github.svg';
  static const String gitlab = 'gitlab.svg';
  static const String gitnex = 'gitnex.svg';
  static const String gitter = 'gitter.svg';
  static const String gittouch = 'gittouch.svg';
  static const String glasswire = 'glasswire.svg';
  static const String glider = 'glider.svg';
  static const String glitch_lab = 'glitch_lab.svg';
  static const String glmark2 = 'glmark2.svg';
  static const String globalcitizen = 'globalcitizen.svg';
  static const String gls = 'gls.svg';
  static const String glsbank = 'glsbank.svg';
  static const String glxy = 'glxy.svg';
  static const String gmapswv = 'gmapswv.svg';
  static const String gmxmail = 'gmxmail.svg';
  static const String gnucash = 'gnucash.svg';
  static const String goblim = 'goblim.svg';
  static const String godsdjsradio = 'godsdjsradio.svg';
  static const String godtsmil = 'godtsmil.svg';
  static const String godville = 'godville.svg';
  static const String goldenone = 'goldenone.svg';
  static const String golomt_bank = 'golomt_bank.svg';
  static const String gomo_ph = 'gomo_ph.svg';
  static const String goodrx = 'goodrx.svg';
  static const String goodtime = 'goodtime.svg';
  static const String goodweather = 'goodweather.svg';
  static const String google_app = 'google_app.svg';
  static const String google_assistant = 'google_assistant.svg';
  static const String google_authenticator = 'google_authenticator.svg';
  static const String google_camera = 'google_camera.svg';
  static const String google_chat = 'google_chat.svg';
  static const String google_chrome_beta = 'google_chrome_beta.svg';
  static const String google_chrome_canary = 'google_chrome_canary.svg';
  static const String google_chrome_dev = 'google_chrome_dev.svg';
  static const String google_chrome = 'google_chrome.svg';
  static const String google_docs = 'google_docs.svg';
  static const String google_drive = 'google_drive.svg';
  static const String google_earth = 'google_earth.svg';
  static const String google_fi = 'google_fi.svg';
  static const String google_hangouts = 'google_hangouts.svg';
  static const String google_home = 'google_home.svg';
  static const String google_keep = 'google_keep.svg';
  static const String google_keyboard = 'google_keyboard.svg';
  static const String google_mail = 'google_mail.svg';
  static const String google_maps = 'google_maps.svg';
  static const String google_meet = 'google_meet.svg';
  static const String google_movies = 'google_movies.svg';
  static const String google_music = 'google_music.svg';
  static const String google_my_business = 'google_my_business.svg';
  static const String google_newsstand = 'google_newsstand.svg';
  static const String google_newsweather = 'google_newsweather.svg';
  static const String google_one = 'google_one.svg';
  static const String google_pay = 'google_pay.svg';
  static const String google_photos = 'google_photos.svg';
  static const String google_pinyin_input = 'google_pinyin_input.svg';
  static const String google_play_console = 'google_play_console.svg';
  static const String google_play = 'google_play.svg';
  static const String google_playstore = 'google_playstore.svg';
  static const String google_podcasts = 'google_podcasts.svg';
  static const String google_settings = 'google_settings.svg';
  static const String google_sheets = 'google_sheets.svg';
  static const String google_slides = 'google_slides.svg';
  static const String google_tasks = 'google_tasks.svg';
  static const String google_translate = 'google_translate.svg';
  static const String google_tv = 'google_tv.svg';
  static const String google_voice_alt = 'google_voice_alt.svg';
  static const String google_voice = 'google_voice.svg';
  static const String google_weather = 'google_weather.svg';
  static const String google = 'google.svg';
  static const String googleplaystore_alt = 'googleplaystore_alt.svg';
  static const String gotify = 'gotify.svg';
  static const String govmo = 'govmo.svg';
  static const String gpscockpit = 'gpscockpit.svg';
  static const String gpslogger = 'gpslogger.svg';
  static const String gpslogger2 = 'gpslogger2.svg';
  static const String gpsstatus = 'gpsstatus.svg';
  static const String gpstest = 'gpstest.svg';
  static const String gpsvc = 'gpsvc.svg';
  static const String gpw = 'gpw.svg';
  static const String grab = 'grab.svg';
  static const String gramly = 'gramly.svg';
  static const String grammarly = 'grammarly.svg';
  static const String grasshopper = 'grasshopper.svg';
  static const String gravadordevoz = 'gravadordevoz.svg';
  static const String greaderpro = 'greaderpro.svg';
  static const String green = 'green.svg';
  static const String greenbits = 'greenbits.svg';
  static const String greenify = 'greenify.svg';
  static const String greenlight = 'greenlight.svg';
  static const String greenp = 'greenp.svg';
  static const String greenpass = 'greenpass.svg';
  static const String greenroom = 'greenroom.svg';
  static const String greentooth = 'greentooth.svg';
  static const String grindr = 'grindr.svg';
  static const String grocy = 'grocy.svg';
  static const String grofers = 'grofers.svg';
  static const String grokio = 'grokio.svg';
  static const String groupme = 'groupme.svg';
  static const String growtracker = 'growtracker.svg';
  static const String groww = 'groww.svg';
  static const String gsc_everywhere = 'gsc_everywhere.svg';
  static const String gsmarena = 'gsmarena.svg';
  static const String gstrings = 'gstrings.svg';
  static const String guardian = 'guardian.svg';
  static const String guerrillamail = 'guerrillamail.svg';
  static const String guide_for_rainbow_six_siege = 'guide_for_rainbow_six_siege.svg';
  static const String guilded = 'guilded.svg';
  static const String guilty_force = 'guilty_force.svg';
  static const String guitartuna = 'guitartuna.svg';
  static const String gurgle = 'gurgle.svg';
  static const String gyanfresh = 'gyanfresh.svg';
  static const String gymroutines = 'gymroutines.svg';
  static const String habitica = 'habitica.svg';
  static const String hackerskb = 'hackerskb.svg';
  static const String hadesstar = 'hadesstar.svg';
  static const String halifax = 'halifax.svg';
  static const String hamgps = 'hamgps.svg';
  static const String hamradiotools = 'hamradiotools.svg';
  static const String handynewsreader = 'handynewsreader.svg';
  static const String hangzhou_metro = 'hangzhou_metro.svg';
  static const String hanju_tv = 'hanju_tv.svg';
  static const String hanping_lite = 'hanping_lite.svg';
  static const String happening = 'happening.svg';
  static const String harmonic = 'harmonic.svg';
  static const String harmony = 'harmony.svg';
  static const String hasheasily = 'hasheasily.svg';
  static const String hauk = 'hauk.svg';
  static const String haven = 'haven.svg';
  static const String hayago = 'hayago.svg';
  static const String hbo_max = 'hbo_max.svg';
  static const String hdfc_bank = 'hdfc_bank.svg';
  static const String headi = 'headi.svg';
  static const String healthcoach = 'healthcoach.svg';
  static const String healthelife = 'healthelife.svg';
  static const String healthmate = 'healthmate.svg';
  static const String heartbeat = 'heartbeat.svg';
  static const String hearth = 'hearth.svg';
  static const String hearthstone = 'hearthstone.svg';
  static const String heavensabove = 'heavensabove.svg';
  static const String heavymetal = 'heavymetal.svg';
  static const String hedgecam_2 = 'hedgecam_2.svg';
  static const String hello_bank = 'hello_bank.svg';
  static const String hello_travel = 'hello_travel.svg';
  static const String hellotalk = 'hellotalk.svg';
  static const String hendroid = 'hendroid.svg';
  static const String her = 'her.svg';
  static const String here_wego = 'here_wego.svg';
  static const String here = 'here.svg';
  static const String hermes = 'hermes.svg';
  static const String hermit = 'hermit.svg';
  static const String hexiano = 'hexiano.svg';
  static const String hexpress = 'hexpress.svg';
  static const String hexviewer = 'hexviewer.svg';
  static const String heymelody = 'heymelody.svg';
  static const String hidden_settings = 'hidden_settings.svg';
  static const String hide_my_applist = 'hide_my_applist.svg';
  static const String hidedroid = 'hidedroid.svg';
  static const String hidemevpn = 'hidemevpn.svg';
  static const String hieduscientificcalculator = 'hieduscientificcalculator.svg';
  static const String hiit = 'hiit.svg';
  static const String hikar = 'hikar.svg';
  static const String hikconnect = 'hikconnect.svg';
  static const String hiki = 'hiki.svg';
  static const String hiraganaquest = 'hiraganaquest.svg';
  static const String hl = 'hl.svg';
  static const String hmanager = 'hmanager.svg';
  static const String hngry = 'hngry.svg';
  static const String ho = 'ho.svg';
  static const String holfuy = 'holfuy.svg';
  static const String home_connect = 'home_connect.svg';
  static const String home_smart = 'home_smart.svg';
  static const String homeassistant = 'homeassistant.svg';
  static const String homee = 'homee.svg';
  static const String homewav = 'homewav.svg';
  static const String honeygain = 'honeygain.svg';
  static const String hoopla = 'hoopla.svg';
  static const String hoot_mobile = 'hoot_mobile.svg';
  static const String host = 'host.svg';
  static const String hotdeath = 'hotdeath.svg';
  static const String hourlyreminder = 'hourlyreminder.svg';
  static const String howlr = 'howlr.svg';
  static const String hpprinteraio = 'hpprinteraio.svg';
  static const String hsbcuk = 'hsbcuk.svg';
  static const String hsl = 'hsl.svg';
  static const String httpshortcuts = 'httpshortcuts.svg';
  static const String huawaihealth = 'huawaihealth.svg';
  static const String huawei_appmarket = 'huawei_appmarket.svg';
  static const String huawei_ar_measure = 'huawei_ar_measure.svg';
  static const String huawei_assistant = 'huawei_assistant.svg';
  static const String huawei_browser = 'huawei_browser.svg';
  static const String huawei_calculator = 'huawei_calculator.svg';
  static const String huawei_calendar = 'huawei_calendar.svg';
  static const String huawei_compass = 'huawei_compass.svg';
  static const String huawei_contacts = 'huawei_contacts.svg';
  static const String huawei_deskclock = 'huawei_deskclock.svg';
  static const String huawei_email = 'huawei_email.svg';
  static const String huawei_findmyphone = 'huawei_findmyphone.svg';
  static const String huawei_freebuds = 'huawei_freebuds.svg';
  static const String huawei_gameassistant = 'huawei_gameassistant.svg';
  static const String huawei_gamebox = 'huawei_gamebox.svg';
  static const String huawei_hidisk = 'huawei_hidisk.svg';
  static const String huawei_hiskytone = 'huawei_hiskytone.svg';
  static const String huawei_lives = 'huawei_lives.svg';
  static const String huawei_meetime = 'huawei_meetime.svg';
  static const String huawei_mirror = 'huawei_mirror.svg';
  static const String huawei_movie = 'huawei_movie.svg';
  static const String huawei_multiscreenshot = 'huawei_multiscreenshot.svg';
  static const String huawei_music = 'huawei_music.svg';
  static const String huawei_mycenter = 'huawei_mycenter.svg';
  static const String huawei_notepad = 'huawei_notepad.svg';
  static const String huawei_phone_clone = 'huawei_phone_clone.svg';
  static const String huawei_phoneservice = 'huawei_phoneservice.svg';
  static const String huawei_photos = 'huawei_photos.svg';
  static const String huawei_reader = 'huawei_reader.svg';
  static const String huawei_remotecontroller = 'huawei_remotecontroller.svg';
  static const String huawei_smartphone = 'huawei_smartphone.svg';
  static const String huawei_soundrecorder = 'huawei_soundrecorder.svg';
  static const String huawei_system_update = 'huawei_system_update.svg';
  static const String huawei_tips = 'huawei_tips.svg';
  static const String huawei_wallet = 'huawei_wallet.svg';
  static const String huaweihilink = 'huaweihilink.svg';
  static const String huaweisystemmanager = 'huaweisystemmanager.svg';
  static const String hub = 'hub.svg';
  static const String hue_bt = 'hue_bt.svg';
  static const String hue = 'hue.svg';
  static const String hue2 = 'hue2.svg';
  static const String hulu = 'hulu.svg';
  static const String hundred_words = 'hundred_words.svg';
  static const String huntington = 'huntington.svg';
  static const String hushed = 'hushed.svg';
  static const String husky = 'husky.svg';
  static const String hvv = 'hvv.svg';
  static const String hydro_quebec = 'hydro_quebec.svg';
  static const String hyperfocal_pro = 'hyperfocal_pro.svg';
  static const String hyperion = 'hyperion.svg';
  static const String hyperlocal_weather = 'hyperlocal_weather.svg';
  static const String hypocam = 'hypocam.svg';
  static const String i_am_sober = 'i_am_sober.svg';
  static const String i_cant_wake_up = 'i_cant_wake_up.svg';
  static const String i2p = 'i2p.svg';
  static const String i2pd = 'i2pd.svg';
  static const String ibispaint_x = 'ibispaint_x.svg';
  static const String icbc = 'icbc.svg';
  static const String icebox = 'icebox.svg';
  static const String icecat = 'icecat.svg';
  static const String iceraven = 'iceraven.svg';
  static const String ichaival = 'ichaival.svg';
  static const String icon_pack_studio = 'icon_pack_studio.svg';
  static const String icon_pusher = 'icon_pusher.svg';
  static const String iconic = 'iconic.svg';
  static const String iconrequest = 'iconrequest.svg';
  static const String icq = 'icq.svg';
  static const String icsdroid = 'icsdroid.svg';
  static const String id_wallet = 'id_wallet.svg';
  static const String identiconizer = 'identiconizer.svg';
  static const String idfmobilits = 'idfmobilits.svg';
  static const String idm_browser = 'idm_browser.svg';
  static const String ifood = 'ifood.svg';
  static const String ifruit = 'ifruit.svg';
  static const String ifunny = 'ifunny.svg';
  static const String igloo = 'igloo.svg';
  static const String iheartradio = 'iheartradio.svg';
  static const String iitcmobile = 'iitcmobile.svg';
  static const String ikea = 'ikea.svg';
  static const String iko = 'iko.svg';
  static const String imagepipe = 'imagepipe.svg';
  static const String imagingedgemobile = 'imagingedgemobile.svg';
  static const String imdb = 'imdb.svg';
  static const String imepay = 'imepay.svg';
  static const String imgflip = 'imgflip.svg';
  static const String imgur = 'imgur.svg';
  static const String imgurviewer = 'imgurviewer.svg';
  static const String immoscout24 = 'immoscout24.svg';
  static const String improvementroll = 'improvementroll.svg';
  static const String imss = 'imss.svg';
  static const String inaturalist = 'inaturalist.svg';
  static const String inbento = 'inbento.svg';
  static const String inbrowser = 'inbrowser.svg';
  static const String incognitowallet = 'incognitowallet.svg';
  static const String indigo = 'indigo.svg';
  static const String indoormap = 'indoormap.svg';
  static const String indriver = 'indriver.svg';
  static const String infakt = 'infakt.svg';
  static const String infinilist = 'infinilist.svg';
  static const String infinitejapanese = 'infinitejapanese.svg';
  static const String infinity_alt = 'infinity_alt.svg';
  static const String infinity = 'infinity.svg';
  static const String infraredremote = 'infraredremote.svg';
  static const String ing = 'ing.svg';
  static const String ingress = 'ingress.svg';
  static const String inkredible = 'inkredible.svg';
  static const String inmage = 'inmage.svg';
  static const String inoreader = 'inoreader.svg';
  static const String inpost_mobile = 'inpost_mobile.svg';
  static const String inshorts = 'inshorts.svg';
  static const String inshot = 'inshot.svg';
  static const String instacart = 'instacart.svg';
  static const String instagrabber = 'instagrabber.svg';
  static const String instagram = 'instagram.svg';
  static const String instalate = 'instalate.svg';
  static const String insular = 'insular.svg';
  static const String intellect = 'intellect.svg';
  static const String intentintercept = 'intentintercept.svg';
  static const String intercepter_ng = 'intercepter_ng.svg';
  static const String internet_speed_meter_lite = 'internet_speed_meter_lite.svg';
  static const String interval_timer = 'interval_timer.svg';
  static const String intra = 'intra.svg';
  static const String intti = 'intti.svg';
  static const String inventory = 'inventory.svg';
  static const String invest = 'invest.svg';
  static const String investing = 'investing.svg';
  static const String inviziblepro = 'inviziblepro.svg';
  static const String io = 'io.svg';
  static const String ip_tools = 'ip_tools.svg';
  static const String ip_webcam = 'ip_webcam.svg';
  static const String ipfslite = 'ipfslite.svg';
  static const String iplus = 'iplus.svg';
  static const String ipmiview = 'ipmiview.svg';
  static const String ipray = 'ipray.svg';
  static const String iprint_and_scan_alt = 'iprint_and_scan_alt.svg';
  static const String iprint_and_scan = 'iprint_and_scan.svg';
  static const String iptv_smarters = 'iptv_smarters.svg';
  static const String ipvanish = 'ipvanish.svg';
  static const String irctc_rail_connect = 'irctc_rail_connect.svg';
  static const String iriunwebcam = 'iriunwebcam.svg';
  static const String irma = 'irma.svg';
  static const String ironwill = 'ironwill.svg';
  static const String irplus = 'irplus.svg';
  static const String irregularexpressions = 'irregularexpressions.svg';
  static const String irremote = 'irremote.svg';
  static const String island = 'island.svg';
  static const String isotopebrowser = 'isotopebrowser.svg';
  static const String italki = 'italki.svg';
  static const String itiita = 'itiita.svg';
  static const String itsme = 'itsme.svg';
  static const String ivi = 'ivi.svg';
  static const String ivms = 'ivms.svg';
  static const String ivonaenglish = 'ivonaenglish.svg';
  static const String ivonafrench = 'ivonafrench.svg';
  static const String ivonatexttospeech = 'ivonatexttospeech.svg';
  static const String ivpn = 'ivpn.svg';
  static const String ivy_wallet = 'ivy_wallet.svg';
  static const String iwara = 'iwara.svg';
  static const String ixigo_trains = 'ixigo_trains.svg';
  static const String izly = 'izly.svg';
  static const String izzyondroid = 'izzyondroid.svg';
  static const String j2meloader = 'j2meloader.svg';
  static const String jada = 'jada.svg';
  static const String jakdojade = 'jakdojade.svg';
  static const String jamendo = 'jamendo.svg';
  static const String jamesdsp = 'jamesdsp.svg';
  static const String japanese_vaccination_certificate = 'japanese_vaccination_certificate.svg';
  static const String jasensei = 'jasensei.svg';
  static const String jazzcash = 'jazzcash.svg';
  static const String jazzworld = 'jazzworld.svg';
  static const String jblheadphones = 'jblheadphones.svg';
  static const String jcrosswords = 'jcrosswords.svg';
  static const String jeevansathi = 'jeevansathi.svg';
  static const String jelbi = 'jelbi.svg';
  static const String jelly = 'jelly.svg';
  static const String jellydrift = 'jellydrift.svg';
  static const String jellyfin = 'jellyfin.svg';
  static const String jerboa_for_lemmy = 'jerboa_for_lemmy.svg';
  static const String jetpack_joyride = 'jetpack_joyride.svg';
  static const String jiocinema = 'jiocinema.svg';
  static const String jiojoin = 'jiojoin.svg';
  static const String jiosaavn = 'jiosaavn.svg';
  static const String jiotv = 'jiotv.svg';
  static const String jira = 'jira.svg';
  static const String jitsimeet = 'jitsimeet.svg';
  static const String joey = 'joey.svg';
  static const String join = 'join.svg';
  static const String joiplay = 'joiplay.svg';
  static const String joplin = 'joplin.svg';
  static const String jotatexteditor = 'jotatexteditor.svg';
  static const String jottacloud = 'jottacloud.svg';
  static const String joyn = 'joyn.svg';
  static const String jsho = 'jsho.svg';
  static const String jsupdater = 'jsupdater.svg';
  static const String juegos = 'juegos.svg';
  static const String juicessh = 'juicessh.svg';
  static const String jumbo_privacy = 'jumbo_privacy.svg';
  static const String jump_rope_training_pro = 'jump_rope_training_pro.svg';
  static const String just_dance_now = 'just_dance_now.svg';
  static const String just24hours = 'just24hours.svg';
  static const String justanotherworkouttimer = 'justanotherworkouttimer.svg';
  static const String justchess = 'justchess.svg';
  static const String jyskebank = 'jyskebank.svg';
  static const String k_and_ns = 'k_and_ns.svg';
  static const String k9mail = 'k9mail.svg';
  static const String kaidan = 'kaidan.svg';
  static const String kakaotalk = 'kakaotalk.svg';
  static const String kaku = 'kaku.svg';
  static const String kakugo = 'kakugo.svg';
  static const String kaleidoscope = 'kaleidoscope.svg';
  static const String kalgebra = 'kalgebra.svg';
  static const String kamusku = 'kamusku.svg';
  static const String kanadrill = 'kanadrill.svg';
  static const String kanapkaman = 'kanapkaman.svg';
  static const String kancionl = 'kancionl.svg';
  static const String kanji_study = 'kanji_study.svg';
  static const String kanjidraw = 'kanjidraw.svg';
  static const String kanjitree = 'kanjitree.svg';
  static const String kaqui = 'kaqui.svg';
  static const String karafun = 'karafun.svg';
  static const String karta_krakowska = 'karta_krakowska.svg';
  static const String karten = 'karten.svg';
  static const String kasa = 'kasa.svg';
  static const String kaspikz = 'kaspikz.svg';
  static const String kasts = 'kasts.svg';
  static const String katwarn = 'katwarn.svg';
  static const String kaufland = 'kaufland.svg';
  static const String kdeconnect = 'kdeconnect.svg';
  static const String kdrive = 'kdrive.svg';
  static const String keep = 'keep.svg';
  static const String keepass2android = 'keepass2android.svg';
  static const String keepass2androidoffline = 'keepass2androidoffline.svg';
  static const String keepassdroid = 'keepassdroid.svg';
  static const String keepassdx = 'keepassdx.svg';
  static const String keepon = 'keepon.svg';
  static const String keepscreen = 'keepscreen.svg';
  static const String kena_mobile = 'kena_mobile.svg';
  static const String keto_mojo = 'keto_mojo.svg';
  static const String key_ = 'key.svg';
  static const String keybase = 'keybase.svg';
  static const String keyboard = 'keyboard.svg';
  static const String keyboard69 = 'keyboard69.svg';
  static const String keyboardswitcher = 'keyboardswitcher.svg';
  static const String keychain = 'keychain.svg';
  static const String keyman = 'keyman.svg';
  static const String keymapper = 'keymapper.svg';
  static const String keyoxide = 'keyoxide.svg';
  static const String keypass = 'keypass.svg';
  static const String keysmith = 'keysmith.svg';
  static const String kfhonline = 'kfhonline.svg';
  static const String khalti = 'khalti.svg';
  static const String khl = 'khl.svg';
  static const String kickstarter = 'kickstarter.svg';
  static const String kid3 = 'kid3.svg';
  static const String kijk = 'kijk.svg';
  static const String kik = 'kik.svg';
  static const String kinderundgift = 'kinderundgift.svg';
  static const String kindle = 'kindle.svg';
  static const String kinemaster = 'kinemaster.svg';
  static const String kinoko = 'kinoko.svg';
  static const String kinopoisk = 'kinopoisk.svg';
  static const String kinoteatr = 'kinoteatr.svg';
  static const String kiss = 'kiss.svg';
  static const String kitchen_stories = 'kitchen_stories.svg';
  static const String kite = 'kite.svg';
  static const String kivra = 'kivra.svg';
  static const String kiwibrowser = 'kiwibrowser.svg';
  static const String kiwix = 'kiwix.svg';
  static const String klarna = 'klarna.svg';
  static const String klock = 'klock.svg';
  static const String kmeet = 'kmeet.svg';
  static const String knockonports = 'knockonports.svg';
  static const String knots_3d = 'knots_3d.svg';
  static const String kobo_books = 'kobo_books.svg';
  static const String kodi = 'kodi.svg';
  static const String kodiremote = 'kodiremote.svg';
  static const String kofi = 'kofi.svg';
  static const String koleo = 'koleo.svg';
  static const String koler = 'koler.svg';
  static const String komoot = 'komoot.svg';
  static const String kontrast = 'kontrast.svg';
  static const String koofr = 'koofr.svg';
  static const String kopieid = 'kopieid.svg';
  static const String kore = 'kore.svg';
  static const String koreader = 'koreader.svg';
  static const String kotatsu = 'kotatsu.svg';
  static const String kotori = 'kotori.svg';
  static const String koyuspace = 'koyuspace.svg';
  static const String kp = 'kp.svg';
  static const String kraken = 'kraken.svg';
  static const String krekort = 'krekort.svg';
  static const String krkortnu = 'krkortnu.svg';
  static const String ksync = 'ksync.svg';
  static const String ktweak = 'ktweak.svg';
  static const String kubenav = 'kubenav.svg';
  static const String kucoin = 'kucoin.svg';
  static const String kuda = 'kuda.svg';
  static const String kuroba = 'kuroba.svg';
  static const String kusc = 'kusc.svg';
  static const String kvaesitso = 'kvaesitso.svg';
  static const String kvsitso = 'kvsitso.svg';
  static const String kwgt = 'kwgt.svg';
  static const String kwikefis = 'kwikefis.svg';
  static const String kyivdigital = 'kyivdigital.svg';
  static const String l_speed = 'l_speed.svg';
  static const String la_mia_banca = 'la_mia_banca.svg';
  static const String labanquepostale = 'labanquepostale.svg';
  static const String laboralkutxa = 'laboralkutxa.svg';
  static const String labyrinthos = 'labyrinthos.svg';
  static const String lagrange = 'lagrange.svg';
  static const String lamusica = 'lamusica.svg';
  static const String landroid = 'landroid.svg';
  static const String langeasylexis = 'langeasylexis.svg';
  static const String lanxchange = 'lanxchange.svg';
  static const String lark_player = 'lark_player.svg';
  static const String lastfm = 'lastfm.svg';
  static const String lastfmscrobbler = 'lastfmscrobbler.svg';
  static const String lastpass = 'lastpass.svg';
  static const String lastpassauthenticator = 'lastpassauthenticator.svg';
  static const String latern = 'latern.svg';
  static const String lawnchair = 'lawnchair.svg';
  static const String lawnchairsettings = 'lawnchairsettings.svg';
  static const String lawnicons = 'lawnicons.svg';
  static const String lbry = 'lbry.svg';
  static const String le_met = 'le_met.svg';
  static const String leaflet = 'leaflet.svg';
  static const String leafpic = 'leafpic.svg';
  static const String league = 'league.svg';
  static const String lean_remote = 'lean_remote.svg';
  static const String learn_css = 'learn_css.svg';
  static const String learn_html = 'learn_html.svg';
  static const String learn_javascript = 'learn_javascript.svg';
  static const String leboncoin_alt = 'leboncoin_alt.svg';
  static const String leboncoin = 'leboncoin.svg';
  static const String lecteur_google_videos = 'lecteur_google_videos.svg';
  static const String ledger_live = 'ledger_live.svg';
  static const String ledmote = 'ledmote.svg';
  static const String leetcode = 'leetcode.svg';
  static const String left_right_stereo_test = 'left_right_stereo_test.svg';
  static const String legado = 'legado.svg';
  static const String lekcionr = 'lekcionr.svg';
  static const String lemmur = 'lemmur.svg';
  static const String lemuroid = 'lemuroid.svg';
  static const String lenovo_life = 'lenovo_life.svg';
  static const String lens = 'lens.svg';
  static const String leo = 'leo.svg';
  static const String leon_urlcleaner = 'leon_urlcleaner.svg';
  static const String lespas = 'lespas.svg';
  static const String lesserpad = 'lesserpad.svg';
  static const String letter_lowercase_a = 'letter_lowercase_a.svg';
  static const String letter_lowercase_b = 'letter_lowercase_b.svg';
  static const String letter_lowercase_c = 'letter_lowercase_c.svg';
  static const String letter_lowercase_d = 'letter_lowercase_d.svg';
  static const String letter_lowercase_e = 'letter_lowercase_e.svg';
  static const String letter_lowercase_f = 'letter_lowercase_f.svg';
  static const String letter_lowercase_g = 'letter_lowercase_g.svg';
  static const String letter_lowercase_h = 'letter_lowercase_h.svg';
  static const String letter_lowercase_i = 'letter_lowercase_i.svg';
  static const String letter_lowercase_j = 'letter_lowercase_j.svg';
  static const String letter_lowercase_k = 'letter_lowercase_k.svg';
  static const String letter_lowercase_l = 'letter_lowercase_l.svg';
  static const String letter_lowercase_m = 'letter_lowercase_m.svg';
  static const String letter_lowercase_n = 'letter_lowercase_n.svg';
  static const String letter_lowercase_o = 'letter_lowercase_o.svg';
  static const String letter_lowercase_p = 'letter_lowercase_p.svg';
  static const String letter_lowercase_q = 'letter_lowercase_q.svg';
  static const String letter_lowercase_r = 'letter_lowercase_r.svg';
  static const String letter_lowercase_s = 'letter_lowercase_s.svg';
  static const String letter_lowercase_t = 'letter_lowercase_t.svg';
  static const String letter_lowercase_u = 'letter_lowercase_u.svg';
  static const String letter_lowercase_v = 'letter_lowercase_v.svg';
  static const String letter_lowercase_w = 'letter_lowercase_w.svg';
  static const String letter_lowercase_x = 'letter_lowercase_x.svg';
  static const String letter_lowercase_y = 'letter_lowercase_y.svg';
  static const String letter_lowercase_z = 'letter_lowercase_z.svg';
  static const String letter_uppercase_a = 'letter_uppercase_a.svg';
  static const String letter_uppercase_b = 'letter_uppercase_b.svg';
  static const String letter_uppercase_c = 'letter_uppercase_c.svg';
  static const String letter_uppercase_d = 'letter_uppercase_d.svg';
  static const String letter_uppercase_e = 'letter_uppercase_e.svg';
  static const String letter_uppercase_f = 'letter_uppercase_f.svg';
  static const String letter_uppercase_g = 'letter_uppercase_g.svg';
  static const String letter_uppercase_h = 'letter_uppercase_h.svg';
  static const String letter_uppercase_i = 'letter_uppercase_i.svg';
  static const String letter_uppercase_j = 'letter_uppercase_j.svg';
  static const String letter_uppercase_k = 'letter_uppercase_k.svg';
  static const String letter_uppercase_l = 'letter_uppercase_l.svg';
  static const String letter_uppercase_m = 'letter_uppercase_m.svg';
  static const String letter_uppercase_n = 'letter_uppercase_n.svg';
  static const String letter_uppercase_o = 'letter_uppercase_o.svg';
  static const String letter_uppercase_p = 'letter_uppercase_p.svg';
  static const String letter_uppercase_q = 'letter_uppercase_q.svg';
  static const String letter_uppercase_r = 'letter_uppercase_r.svg';
  static const String letter_uppercase_s = 'letter_uppercase_s.svg';
  static const String letter_uppercase_t = 'letter_uppercase_t.svg';
  static const String letter_uppercase_u = 'letter_uppercase_u.svg';
  static const String letter_uppercase_v = 'letter_uppercase_v.svg';
  static const String letter_uppercase_w = 'letter_uppercase_w.svg';
  static const String letter_uppercase_x = 'letter_uppercase_x.svg';
  static const String letter_uppercase_y = 'letter_uppercase_y.svg';
  static const String letter_uppercase_z = 'letter_uppercase_z.svg';
  static const String letterboxd = 'letterboxd.svg';
  static const String leumiwallet = 'leumiwallet.svg';
  static const String lewdfi = 'lewdfi.svg';
  static const String lex = 'lex.svg';
  static const String lexica = 'lexica.svg';
  static const String lexmark_print = 'lexmark_print.svg';
  static const String libary = 'libary.svg';
  static const String libby = 'libby.svg';
  static const String liberapay = 'liberapay.svg';
  static const String liberovocab = 'liberovocab.svg';
  static const String libgen = 'libgen.svg';
  static const String library_mobile = 'library_mobile.svg';
  static const String libratone = 'libratone.svg';
  static const String libre_3 = 'libre_3.svg';
  static const String libreav = 'libreav.svg';
  static const String librechovid = 'librechovid.svg';
  static const String libreflix = 'libreflix.svg';
  static const String librehealth = 'librehealth.svg';
  static const String librelink = 'librelink.svg';
  static const String libremchat = 'libremchat.svg';
  static const String libremmail = 'libremmail.svg';
  static const String libremsocial = 'libremsocial.svg';
  static const String libremtunnel = 'libremtunnel.svg';
  static const String libreofficeviewer = 'libreofficeviewer.svg';
  static const String librerapro = 'librerapro.svg';
  static const String librespeed = 'librespeed.svg';
  static const String libretorrent = 'libretorrent.svg';
  static const String libretrack = 'libretrack.svg';
  static const String libretranslater = 'libretranslater.svg';
  static const String libretube = 'libretube.svg';
  static const String librivox = 'librivox.svg';
  static const String librofm = 'librofm.svg';
  static const String license = 'license.svg';
  static const String lichess = 'lichess.svg';
  static const String lidl_connect = 'lidl_connect.svg';
  static const String lidl_plus = 'lidl_plus.svg';
  static const String lidl = 'lidl.svg';
  static const String lidraughts = 'lidraughts.svg';
  static const String liedgutverzeichnis = 'liedgutverzeichnis.svg';
  static const String life_fits_into_home = 'life_fits_into_home.svg';
  static const String life = 'life.svg';
  static const String lifelinker = 'lifelinker.svg';
  static const String liferpg = 'liferpg.svg';
  static const String lifetotal = 'lifetotal.svg';
  static const String liftago = 'liftago.svg';
  static const String lightblue = 'lightblue.svg';
  static const String lightbulb = 'lightbulb.svg';
  static const String lightmeter = 'lightmeter.svg';
  static const String lightning = 'lightning.svg';
  static const String lightplan = 'lightplan.svg';
  static const String lighttraceartist = 'lighttraceartist.svg';
  static const String limbo_x86 = 'limbo_x86.svg';
  static const String lime = 'lime.svg';
  static const String line_music = 'line_music.svg';
  static const String line = 'line.svg';
  static const String lineage_updater = 'lineage_updater.svg';
  static const String lineagerec = 'lineagerec.svg';
  static const String linebit = 'linebit.svg';
  static const String linebitlight = 'linebitlight.svg';
  static const String linex = 'linex.svg';
  static const String linguee = 'linguee.svg';
  static const String lingvist = 'lingvist.svg';
  static const String link_now = 'link_now.svg';
  static const String link2sd = 'link2sd.svg';
  static const String linkedin = 'linkedin.svg';
  static const String linkeye = 'linkeye.svg';
  static const String linphone = 'linphone.svg';
  static const String linshare = 'linshare.svg';
  static const String linux_deploy = 'linux_deploy.svg';
  static const String listen = 'listen.svg';
  static const String listmyapps = 'listmyapps.svg';
  static const String lithium = 'lithium.svg';
  static const String littlealchemy = 'littlealchemy.svg';
  static const String live_transcribe = 'live_transcribe.svg';
  static const String liveboot = 'liveboot.svg';
  static const String livedv = 'livedv.svg';
  static const String livemagicscreen = 'livemagicscreen.svg';
  static const String livetl = 'livetl.svg';
  static const String livres_de_proches = 'livres_de_proches.svg';
  static const String llcroplossless = 'llcroplossless.svg';
  static const String lloydsbank = 'lloydsbank.svg';
  static const String lms = 'lms.svg';
  static const String lnsfrskringar = 'lnsfrskringar.svg';
  static const String locationprivacy = 'locationprivacy.svg';
  static const String lock_my_phone = 'lock_my_phone.svg';
  static const String lock = 'lock.svg';
  static const String locker_2 = 'locker_2.svg';
  static const String locker = 'locker.svg';
  static const String locus_map_pro = 'locus_map_pro.svg';
  static const String logcatreader = 'logcatreader.svg';
  static const String logseq = 'logseq.svg';
  static const String lona = 'lona.svg';
  static const String london = 'london.svg';
  static const String longshot = 'longshot.svg';
  static const String look4sat = 'look4sat.svg';
  static const String lookofdisapproval = 'lookofdisapproval.svg';
  static const String loop = 'loop.svg';
  static const String loopboard = 'loopboard.svg';
  static const String lounge = 'lounge.svg';
  static const String lovegame = 'lovegame.svg';
  static const String lovense_remote = 'lovense_remote.svg';
  static const String lovoo = 'lovoo.svg';
  static const String loyaltycardkeychain = 'loyaltycardkeychain.svg';
  static const String lrc_editor = 'lrc_editor.svg';
  static const String lsposed = 'lsposed.svg';
  static const String ltecleaner = 'ltecleaner.svg';
  static const String luca = 'luca.svg';
  static const String lucia = 'lucia.svg';
  static const String luckin_coffee = 'luckin_coffee.svg';
  static const String lufthansa = 'lufthansa.svg';
  static const String luisterbieb = 'luisterbieb.svg';
  static const String lumicall = 'lumicall.svg';
  static const String lydia = 'lydia.svg';
  static const String lyfpay = 'lyfpay.svg';
  static const String lyft = 'lyft.svg';
  static const String lyne = 'lyne.svg';
  static const String macrodroid = 'macrodroid.svg';
  static const String magic = 'magic.svg';
  static const String magicearth = 'magicearth.svg';
  static const String magisk = 'magisk.svg';
  static const String magister = 'magister.svg';
  static const String magnetometer = 'magnetometer.svg';
  static const String magnustrainer = 'magnustrainer.svg';
  static const String mahjonggbuilder = 'mahjonggbuilder.svg';
  static const String mail = 'mail.svg';
  static const String maingau = 'maingau.svg';
  static const String makemytrip = 'makemytrip.svg';
  static const String malclient = 'malclient.svg';
  static const String malivebox = 'malivebox.svg';
  static const String malp = 'malp.svg';
  static const String malwarebytes = 'malwarebytes.svg';
  static const String manga_plus = 'manga_plus.svg';
  static const String maniac = 'maniac.svg';
  static const String manman = 'manman.svg';
  static const String manyverse = 'manyverse.svg';
  static const String map = 'map.svg';
  static const String mapassist = 'mapassist.svg';
  static const String mapillary = 'mapillary.svg';
  static const String maps = 'maps.svg';
  static const String mapsgeobookmarks = 'mapsgeobookmarks.svg';
  static const String mapsgo = 'mapsgo.svg';
  static const String mapsme = 'mapsme.svg';
  static const String mapy = 'mapy.svg';
  static const String marindeck = 'marindeck.svg';
  static const String marindiver = 'marindiver.svg';
  static const String mark = 'mark.svg';
  static const String markdown = 'markdown.svg';
  static const String markers = 'markers.svg';
  static const String markor = 'markor.svg';
  static const String marktde = 'marktde.svg';
  static const String marktplaats = 'marktplaats.svg';
  static const String marvelapp = 'marvelapp.svg';
  static const String mastercomworkbook = 'mastercomworkbook.svg';
  static const String masterpassword = 'masterpassword.svg';
  static const String mastodon = 'mastodon.svg';
  static const String material_flashlight = 'material_flashlight.svg';
  static const String materialislands = 'materialislands.svg';
  static const String materialistic = 'materialistic.svg';
  static const String materialnotes = 'materialnotes.svg';
  static const String materialos = 'materialos.svg';
  static const String materialplayer = 'materialplayer.svg';
  static const String math_wiki = 'math_wiki.svg';
  static const String math = 'math.svg';
  static const String mather = 'mather.svg';
  static const String mathtricks = 'mathtricks.svg';
  static const String mathway = 'mathway.svg';
  static const String matlog = 'matlog.svg';
  static const String mattermost = 'mattermost.svg';
  static const String mbank_cz = 'mbank_cz.svg';
  static const String mbank = 'mbank.svg';
  static const String mbestyle = 'mbestyle.svg';
  static const String mcdonalds_plus = 'mcdonalds_plus.svg';
  static const String mcdonalds = 'mcdonalds.svg';
  static const String mditct = 'mditct.svg';
  static const String media_rescan = 'media_rescan.svg';
  static const String mediafire = 'mediafire.svg';
  static const String mediamonkey = 'mediamonkey.svg';
  static const String mediapart = 'mediapart.svg';
  static const String mediaplayer = 'mediaplayer.svg';
  static const String mediatekcamera = 'mediatekcamera.svg';
  static const String medicinkortet = 'medicinkortet.svg';
  static const String medilog = 'medilog.svg';
  static const String meditation_timer_and_log = 'meditation_timer_and_log.svg';
  static const String meditationassistant = 'meditationassistant.svg';
  static const String medito = 'medito.svg';
  static const String medium_alt = 'medium_alt.svg';
  static const String medium = 'medium.svg';
  static const String meesho = 'meesho.svg';
  static const String meeting_guide = 'meeting_guide.svg';
  static const String meetup = 'meetup.svg';
  static const String meezanbank = 'meezanbank.svg';
  static const String megafon = 'megafon.svg';
  static const String meinblau = 'meinblau.svg';
  static const String meinesv = 'meinesv.svg';
  static const String meinheidelberg = 'meinheidelberg.svg';
  static const String meipian_photo_album_maker = 'meipian_photo_album_maker.svg';
  static const String mekorama = 'mekorama.svg';
  static const String melonds = 'melonds.svg';
  static const String melvoridle = 'melvoridle.svg';
  static const String meme_generator = 'meme_generator.svg';
  static const String memechat = 'memechat.svg';
  static const String memento_database = 'memento_database.svg';
  static const String memetastic = 'memetastic.svg';
  static const String memo_game = 'memo_game.svg';
  static const String memrise = 'memrise.svg';
  static const String mercado_pago = 'mercado_pago.svg';
  static const String mercedes_me = 'mercedes_me.svg';
  static const String mercuryssh = 'mercuryssh.svg';
  static const String merrickmobile = 'merrickmobile.svg';
  static const String mescompteslcl = 'mescompteslcl.svg';
  static const String meshenger = 'meshenger.svg';
  static const String messagease_keyboard = 'messagease_keyboard.svg';
  static const String messages = 'messages.svg';
  static const String messaging = 'messaging.svg';
  static const String met_office = 'met_office.svg';
  static const String metadataremover = 'metadataremover.svg';
  static const String metamask = 'metamask.svg';
  static const String meteo = 'meteo.svg';
  static const String meteociel = 'meteociel.svg';
  static const String meteoswiss = 'meteoswiss.svg';
  static const String metrictime = 'metrictime.svg';
  static const String metro = 'metro.svg';
  static const String metro2 = 'metro2.svg';
  static const String metrobank = 'metrobank.svg';
  static const String metrodroid = 'metrodroid.svg';
  static const String metronome = 'metronome.svg';
  static const String metroplayer = 'metroplayer.svg';
  static const String meualelo = 'meualelo.svg';
  static const String mewe = 'mewe.svg';
  static const String mgen = 'mgen.svg';
  static const String mhle = 'mhle.svg';
  static const String mi_home = 'mi_home.svg';
  static const String mi_movistar = 'mi_movistar.svg';
  static const String mi_o2 = 'mi_o2.svg';
  static const String mi_pay = 'mi_pay.svg';
  static const String miband = 'miband.svg';
  static const String microchip = 'microchip.svg';
  static const String microcoil_calculator = 'microcoil_calculator.svg';
  static const String microgsettings = 'microgsettings.svg';
  static const String microsoft_edge_beta = 'microsoft_edge_beta.svg';
  static const String microsoft_edge_canary = 'microsoft_edge_canary.svg';
  static const String microsoft_edge_dev = 'microsoft_edge_dev.svg';
  static const String microsoft_translator = 'microsoft_translator.svg';
  static const String microsoftauthenticator_alt = 'microsoftauthenticator_alt.svg';
  static const String microsoftauthenticator = 'microsoftauthenticator.svg';
  static const String microsoftbing = 'microsoftbing.svg';
  static const String microsoftedge = 'microsoftedge.svg';
  static const String microsoftexcel = 'microsoftexcel.svg';
  static const String microsoftlauncher = 'microsoftlauncher.svg';
  static const String microsoftlens = 'microsoftlens.svg';
  static const String microsoftoffice = 'microsoftoffice.svg';
  static const String microsoftonedrive = 'microsoftonedrive.svg';
  static const String microsoftonenote = 'microsoftonenote.svg';
  static const String microsoftoutlook = 'microsoftoutlook.svg';
  static const String microsoftpowerpoint = 'microsoftpowerpoint.svg';
  static const String microsoftsolitaire = 'microsoftsolitaire.svg';
  static const String microsoftteams = 'microsoftteams.svg';
  static const String microsofttodo = 'microsofttodo.svg';
  static const String microsoftword = 'microsoftword.svg';
  static const String midikeyboard = 'midikeyboard.svg';
  static const String mifareclassictool = 'mifareclassictool.svg';
  static const String mifit = 'mifit.svg';
  static const String migrate_flasher = 'migrate_flasher.svg';
  static const String migrate_helper = 'migrate_helper.svg';
  static const String migrategpe = 'migrategpe.svg';
  static const String mijngegevens = 'mijngegevens.svg';
  static const String mijnuva = 'mijnuva.svg';
  static const String mikrotik = 'mikrotik.svg';
  static const String mileage = 'mileage.svg';
  static const String miles_and_more = 'miles_and_more.svg';
  static const String milkteamisskey = 'milkteamisskey.svg';
  static const String milkytracker = 'milkytracker.svg';
  static const String mimo = 'mimo.svg';
  static const String mindfulnotifier = 'mindfulnotifier.svg';
  static const String minds = 'minds.svg';
  static const String mindtwisted_kanjistudy = 'mindtwisted_kanjistudy.svg';
  static const String mindustry = 'mindustry.svg';
  static const String minecraft = 'minecraft.svg';
  static const String minekort = 'minekort.svg';
  static const String minesweeper = 'minesweeper.svg';
  static const String minetest = 'minetest.svg';
  static const String minhaoi = 'minhaoi.svg';
  static const String minidoro = 'minidoro.svg';
  static const String miniflutt = 'miniflutt.svg';
  static const String minimal = 'minimal.svg';
  static const String minimetro = 'minimetro.svg';
  static const String minireview = 'minireview.svg';
  static const String minlge = 'minlge.svg';
  static const String minminguard = 'minminguard.svg';
  static const String minsundhed = 'minsundhed.svg';
  static const String mint = 'mint.svg';
  static const String mirakel = 'mirakel.svg';
  static const String miremote = 'miremote.svg';
  static const String mirry = 'mirry.svg';
  static const String mis_materias = 'mis_materias.svg';
  static const String misskey = 'misskey.svg';
  static const String mitaicompanion = 'mitaicompanion.svg';
  static const String mitch = 'mitch.svg';
  static const String mitidapp = 'mitidapp.svg';
  static const String mivideo = 'mivideo.svg';
  static const String mixcloud = 'mixcloud.svg';
  static const String mixplorer = 'mixplorer.svg';
  static const String mjweather = 'mjweather.svg';
  static const String mlmanager = 'mlmanager.svg';
  static const String mnml = 'mnml.svg';
  static const String mobilbank = 'mobilbank.svg';
  static const String mobile_legends_bang_bang_alt_2 = 'mobile_legends_bang_bang_alt_2.svg';
  static const String mobile_legends_bang_bang_alt = 'mobile_legends_bang_bang_alt.svg';
  static const String mobile_legends_bang_bang = 'mobile_legends_bang_bang.svg';
  static const String mobile_print = 'mobile_print.svg';
  static const String mobilempk = 'mobilempk.svg';
  static const String mobilepass = 'mobilepass.svg';
  static const String mobilepay = 'mobilepay.svg';
  static const String mobility = 'mobility.svg';
  static const String mobilizon = 'mobilizon.svg';
  static const String mobilklinik = 'mobilklinik.svg';
  static const String mobmuplat = 'mobmuplat.svg';
  static const String mobywatel = 'mobywatel.svg';
  static const String modalis = 'modalis.svg';
  static const String model3d = 'model3d.svg';
  static const String modpizza = 'modpizza.svg';
  static const String moelist = 'moelist.svg';
  static const String mohafiz = 'mohafiz.svg';
  static const String moin_card = 'moin_card.svg';
  static const String mojepliki = 'mojepliki.svg';
  static const String mole = 'mole.svg';
  static const String molly = 'molly.svg';
  static const String molotov = 'molotov.svg';
  static const String momox = 'momox.svg';
  static const String monefy = 'monefy.svg';
  static const String monero = 'monero.svg';
  static const String monerujo = 'monerujo.svg';
  static const String monespace = 'monespace.svg';
  static const String money_manager = 'money_manager.svg';
  static const String moneybuster = 'moneybuster.svg';
  static const String moneytracker = 'moneytracker.svg';
  static const String moneywallet = 'moneywallet.svg';
  static const String monito = 'monito.svg';
  static const String mono = 'mono.svg';
  static const String monochromatic = 'monochromatic.svg';
  static const String monocles_browser = 'monocles_browser.svg';
  static const String monocles_chat = 'monocles_chat.svg';
  static const String monoclesmail_alt = 'monoclesmail_alt.svg';
  static const String monoclesmail = 'monoclesmail.svg';
  static const String monpetitgazon = 'monpetitgazon.svg';
  static const String monument_valley_2 = 'monument_valley_2.svg';
  static const String monument_valley = 'monument_valley.svg';
  static const String monzo = 'monzo.svg';
  static const String moodle = 'moodle.svg';
  static const String mooltifill = 'mooltifill.svg';
  static const String moonlight = 'moonlight.svg';
  static const String moonreaderpro = 'moonreaderpro.svg';
  static const String moovit = 'moovit.svg';
  static const String moredays = 'moredays.svg';
  static const String morse = 'morse.svg';
  static const String morsetrainer = 'morsetrainer.svg';
  static const String motioneye = 'motioneye.svg';
  static const String moto = 'moto.svg';
  static const String motoaudio = 'motoaudio.svg';
  static const String motomarket = 'motomarket.svg';
  static const String motonotifications = 'motonotifications.svg';
  static const String mouser_eiu_magazine = 'mouser_eiu_magazine.svg';
  static const String moviebase = 'moviebase.svg';
  static const String moviedb = 'moviedb.svg';
  static const String mowsnowpros = 'mowsnowpros.svg';
  static const String mozc = 'mozc.svg';
  static const String mozilla_vpn = 'mozilla_vpn.svg';
  static const String mparivahan = 'mparivahan.svg';
  static const String mpdroid = 'mpdroid.svg';
  static const String mpp = 'mpp.svg';
  static const String mtgfam = 'mtgfam.svg';
  static const String mtofrance = 'mtofrance.svg';
  static const String mubi = 'mubi.svg';
  static const String muchbetter = 'muchbetter.svg';
  static const String mull = 'mull.svg';
  static const String mullvadvpn = 'mullvadvpn.svg';
  static const String mullwegde = 'mullwegde.svg';
  static const String multiling_o_keyboard = 'multiling_o_keyboard.svg';
  static const String multivnc = 'multivnc.svg';
  static const String mupdf = 'mupdf.svg';
  static const String musescore = 'musescore.svg';
  static const String music_editor = 'music_editor.svg';
  static const String music_you = 'music_you.svg';
  static const String music = 'music.svg';
  static const String musicbrainz = 'musicbrainz.svg';
  static const String musicolet = 'musicolet.svg';
  static const String musicpiped = 'musicpiped.svg';
  static const String musicplayergo = 'musicplayergo.svg';
  static const String musik_kontrolle = 'musik_kontrolle.svg';
  static const String muslim_pro = 'muslim_pro.svg';
  static const String mutify = 'mutify.svg';
  static const String muzei = 'muzei.svg';
  static const String mvv_app = 'mvv_app.svg';
  static const String mx = 'mx.svg';
  static const String my_boy = 'my_boy.svg';
  static const String my_device = 'my_device.svg';
  static const String my_dishtv = 'my_dishtv.svg';
  static const String my_fairphone_alt = 'my_fairphone_alt.svg';
  static const String my_fairphone = 'my_fairphone.svg';
  static const String my_magenta = 'my_magenta.svg';
  static const String my_notes = 'my_notes.svg';
  static const String my_oldboy = 'my_oldboy.svg';
  static const String my_oppo = 'my_oppo.svg';
  static const String my_qsc_mobile_3 = 'my_qsc_mobile_3.svg';
  static const String my_skoda = 'my_skoda.svg';
  static const String my_tele2 = 'my_tele2.svg';
  static const String my_virgin_media = 'my_virgin_media.svg';
  static const String my_vodafone = 'my_vodafone.svg';
  static const String myandroidtools = 'myandroidtools.svg';
  static const String myanimelist = 'myanimelist.svg';
  static const String myapplist = 'myapplist.svg';
  static const String myat_and_t = 'myat_and_t.svg';
  static const String mycalendar = 'mycalendar.svg';
  static const String mycelium = 'mycelium.svg';
  static const String mychart = 'mychart.svg';
  static const String mycricket = 'mycricket.svg';
  static const String mydealz = 'mydealz.svg';
  static const String myexpenses = 'myexpenses.svg';
  static const String myfeedlexiconrabbits = 'myfeedlexiconrabbits.svg';
  static const String myfitnesspal = 'myfitnesspal.svg';
  static const String myfritz = 'myfritz.svg';
  static const String mygp = 'mygp.svg';
  static const String myhaema = 'myhaema.svg';
  static const String myid = 'myid.svg';
  static const String myjio = 'myjio.svg';
  static const String myleaf = 'myleaf.svg';
  static const String mymail = 'mymail.svg';
  static const String mynayatel = 'mynayatel.svg';
  static const String mynoise = 'mynoise.svg';
  static const String myntra = 'myntra.svg';
  static const String myparking = 'myparking.svg';
  static const String mypat = 'mypat.svg';
  static const String myphonak = 'myphonak.svg';
  static const String myphoneexplorerclient = 'myphoneexplorerclient.svg';
  static const String myproximus = 'myproximus.svg';
  static const String myradar = 'myradar.svg';
  static const String mysielteid = 'mysielteid.svg';
  static const String mysosh = 'mysosh.svg';
  static const String mysplash = 'mysplash.svg';
  static const String myswordforandroid = 'myswordforandroid.svg';
  static const String mytargets = 'mytargets.svg';
  static const String mytelenor = 'mytelenor.svg';
  static const String myude = 'myude.svg';
  static const String myufone = 'myufone.svg';
  static const String myvrn = 'myvrn.svg';
  static const String myzong = 'myzong.svg';
  static const String n26 = 'n26.svg';
  static const String nagad = 'nagad.svg';
  static const String namecheap = 'namecheap.svg';
  static const String nani = 'nani.svg';
  static const String nanji = 'nanji.svg';
  static const String napster = 'napster.svg';
  static const String naptime = 'naptime.svg';
  static const String naranja_x = 'naranja_x.svg';
  static const String naroth = 'naroth.svg';
  static const String nasa_imagery_fetcher = 'nasa_imagery_fetcher.svg';
  static const String nationwide = 'nationwide.svg';
  static const String native_a = 'native_a.svg';
  static const String native_alpha = 'native_alpha.svg';
  static const String naturalhour = 'naturalhour.svg';
  static const String navegadoreinkbro = 'navegadoreinkbro.svg';
  static const String nayapay = 'nayapay.svg';
  static const String nayateljoy = 'nayateljoy.svg';
  static const String nayatv = 'nayatv.svg';
  static const String nayto = 'nayto.svg';
  static const String nc_passwords = 'nc_passwords.svg';
  static const String ncalc = 'ncalc.svg';
  static const String ncert_book = 'ncert_book.svg';
  static const String nclient = 'nclient.svg';
  static const String ndax = 'ndax.svg';
  static const String neato = 'neato.svg';
  static const String nebulo = 'nebulo.svg';
  static const String nect = 'nect.svg';
  static const String nekkoto = 'nekkoto.svg';
  static const String neko = 'neko.svg';
  static const String nekogotchi_alt = 'nekogotchi_alt.svg';
  static const String nekogotchi_alt2 = 'nekogotchi_alt2.svg';
  static const String nekogotchi = 'nekogotchi.svg';
  static const String nekogramx = 'nekogramx.svg';
  static const String nekome = 'nekome.svg';
  static const String nem_id = 'nem_id.svg';
  static const String nemid = 'nemid.svg';
  static const String neo_backup = 'neo_backup.svg';
  static const String neo_launcher = 'neo_launcher.svg';
  static const String neo_store = 'neo_store.svg';
  static const String neochat = 'neochat.svg';
  static const String neolife = 'neolife.svg';
  static const String neoterm = 'neoterm.svg';
  static const String nestbank = 'nestbank.svg';
  static const String netbenefits = 'netbenefits.svg';
  static const String netease_mail = 'netease_mail.svg';
  static const String netease_open_class = 'netease_open_class.svg';
  static const String neteasecloudmusic = 'neteasecloudmusic.svg';
  static const String netflix = 'netflix.svg';
  static const String netguard = 'netguard.svg';
  static const String nethack = 'nethack.svg';
  static const String nethunter = 'nethunter.svg';
  static const String netiq_advanced_authentication = 'netiq_advanced_authentication.svg';
  static const String netmonitor = 'netmonitor.svg';
  static const String netto = 'netto.svg';
  static const String network_speed = 'network_speed.svg';
  static const String networkmapper = 'networkmapper.svg';
  static const String networksurvey = 'networksurvey.svg';
  static const String netx = 'netx.svg';
  static const String neumorphic_calculator = 'neumorphic_calculator.svg';
  static const String neuralnetworksimulator = 'neuralnetworksimulator.svg';
  static const String neutrinotes = 'neutrinotes.svg';
  static const String newb_mobile_banking = 'newb_mobile_banking.svg';
  static const String newpipe = 'newpipe.svg';
  static const String news = 'news.svg';
  static const String newsblur = 'newsblur.svg';
  static const String newsout = 'newsout.svg';
  static const String newsprovider = 'newsprovider.svg';
  static const String newsreader = 'newsreader.svg';
  static const String nexo_wallet = 'nexo_wallet.svg';
  static const String nextbike = 'nextbike.svg';
  static const String nextcloud_services = 'nextcloud_services.svg';
  static const String nextcloud = 'nextcloud.svg';
  static const String nextcloudbookmarks = 'nextcloudbookmarks.svg';
  static const String nextcloudcookbook = 'nextcloudcookbook.svg';
  static const String nextclouddev = 'nextclouddev.svg';
  static const String nextcloudnotes = 'nextcloudnotes.svg';
  static const String nextcloudsms = 'nextcloudsms.svg';
  static const String nextcloudtalk = 'nextcloudtalk.svg';
  static const String nextdns = 'nextdns.svg';
  static const String nextpass = 'nextpass.svg';
  static const String nexttracks = 'nexttracks.svg';
  static const String nexus = 'nexus.svg';
  static const String nfcreader = 'nfcreader.svg';
  static const String nfctasks = 'nfctasks.svg';
  static const String nfctools = 'nfctools.svg';
  static const String nhbooks = 'nhbooks.svg';
  static const String nhsapp = 'nhsapp.svg';
  static const String niagara_launcher = 'niagara_launcher.svg';
  static const String nicefeed = 'nicefeed.svg';
  static const String nicehash = 'nicehash.svg';
  static const String nightscreen = 'nightscreen.svg';
  static const String nihonoari = 'nihonoari.svg';
  static const String nike = 'nike.svg';
  static const String nina = 'nina.svg';
  static const String nine = 'nine.svg';
  static const String ning = 'ning.svg';
  static const String nofbeventscraper = 'nofbeventscraper.svg';
  static const String noice = 'noice.svg';
  static const String nonocross = 'nonocross.svg';
  static const String noorulhuda = 'noorulhuda.svg';
  static const String nordnet = 'nordnet.svg';
  static const String nordvpn = 'nordvpn.svg';
  static const String norisbank = 'norisbank.svg';
  static const String normal = 'normal.svg';
  static const String nortonclean = 'nortonclean.svg';
  static const String nos_teletekst = 'nos_teletekst.svg';
  static const String nos = 'nos.svg';
  static const String nosurfreddit = 'nosurfreddit.svg';
  static const String notable = 'notable.svg';
  static const String notally = 'notally.svg';
  static const String note_it = 'note_it.svg';
  static const String note = 'note.svg';
  static const String notebloc = 'notebloc.svg';
  static const String notecryptpro = 'notecryptpro.svg';
  static const String noteless = 'noteless.svg';
  static const String notepad = 'notepad.svg';
  static const String notes = 'notes.svg';
  static const String notification_dictionary = 'notification_dictionary.svg';
  static const String notificationcron = 'notificationcron.svg';
  static const String notificationlog = 'notificationlog.svg';
  static const String notificationnotes = 'notificationnotes.svg';
  static const String notifiche_meteo = 'notifiche_meteo.svg';
  static const String notifyformiband = 'notifyformiband.svg';
  static const String notion = 'notion.svg';
  static const String nova_america = 'nova_america.svg';
  static const String nova_video_player = 'nova_video_player.svg';
  static const String nova = 'nova.svg';
  static const String novaprime = 'novaprime.svg';
  static const String novavideo = 'novavideo.svg';
  static const String npo_radio_1 = 'npo_radio_1.svg';
  static const String npo_radio_2 = 'npo_radio_2.svg';
  static const String npo_radio_3 = 'npo_radio_3.svg';
  static const String npo_radio_4 = 'npo_radio_4.svg';
  static const String npo_radio_5 = 'npo_radio_5.svg';
  static const String npo = 'npo.svg';
  static const String nps = 'nps.svg';
  static const String nrboks = 'nrboks.svg';
  static const String nrc = 'nrc.svg';
  static const String nrf_connect = 'nrf_connect.svg';
  static const String nrk = 'nrk.svg';
  static const String ns = 'ns.svg';
  static const String ntes = 'ntes.svg';
  static const String ntfy = 'ntfy.svg';
  static const String ntv = 'ntv.svg';
  static const String nu_carnival = 'nu_carnival.svg';
  static const String nubank = 'nubank.svg';
  static const String nucleusamdc = 'nucleusamdc.svg';
  static const String number_0 = 'number_0.svg';
  static const String number_1 = 'number_1.svg';
  static const String number_2 = 'number_2.svg';
  static const String number_3 = 'number_3.svg';
  static const String number_4 = 'number_4.svg';
  static const String number_5 = 'number_5.svg';
  static const String number_6 = 'number_6.svg';
  static const String number_7 = 'number_7.svg';
  static const String number_8 = 'number_8.svg';
  static const String number_9 = 'number_9.svg';
  static const String numerica = 'numerica.svg';
  static const String nunti = 'nunti.svg';
  static const String nvidia = 'nvidia.svg';
  static const String nwsnow = 'nwsnow.svg';
  static const String nytimes = 'nytimes.svg';
  static const String nyx = 'nyx.svg';
  static const String nzb360 = 'nzb360.svg';
  static const String oandbackup = 'oandbackup.svg';
  static const String oandbackupx = 'oandbackupx.svg';
  static const String obb_scotty = 'obb_scotty.svg';
  static const String obb = 'obb.svg';
  static const String obedience = 'obedience.svg';
  static const String obscuracam = 'obscuracam.svg';
  static const String obsidian = 'obsidian.svg';
  static const String oci_mobile = 'oci_mobile.svg';
  static const String ocr = 'ocr.svg';
  static const String octodroid = 'octodroid.svg';
  static const String octopus = 'octopus.svg';
  static const String octoremote = 'octoremote.svg';
  static const String oculus = 'oculus.svg';
  static const String odysee = 'odysee.svg';
  static const String odyssey = 'odyssey.svg';
  static const String oeffidirections = 'oeffidirections.svg';
  static const String oeffiplans = 'oeffiplans.svg';
  static const String offerup = 'offerup.svg';
  static const String office_reader = 'office_reader.svg';
  static const String officesuite = 'officesuite.svg';
  static const String offlinecalendar = 'offlinecalendar.svg';
  static const String offlinepuzzlesolver = 'offlinepuzzlesolver.svg';
  static const String oh_hi = 'oh_hi.svg';
  static const String oh_no = 'oh_no.svg';
  static const String ohmsnow = 'ohmsnow.svg';
  static const String oipalette = 'oipalette.svg';
  static const String oishare = 'oishare.svg';
  static const String oitrack = 'oitrack.svg';
  static const String ojo = 'ojo.svg';
  static const String ok_payment = 'ok_payment.svg';
  static const String okcupid = 'okcupid.svg';
  static const String okolightmeter = 'okolightmeter.svg';
  static const String okta_verify = 'okta_verify.svg';
  static const String ola = 'ola.svg';
  static const String olx = 'olx.svg';
  static const String olxro = 'olxro.svg';
  static const String olympics = 'olympics.svg';
  static const String om = 'om.svg';
  static const String omegalauncher = 'omegalauncher.svg';
  static const String omninotes = 'omninotes.svg';
  static const String omw = 'omw.svg';
  static const String onay = 'onay.svg';
  static const String once = 'once.svg';
  static const String one_hand_operation = 'one_hand_operation.svg';
  static const String one = 'one.svg';
  static const String onecalendar = 'onecalendar.svg';
  static const String onelist = 'onelist.svg';
  static const String oneplus_weather = 'oneplus_weather.svg';
  static const String onleihe = 'onleihe.svg';
  static const String onlyoffice_documents = 'onlyoffice_documents.svg';
  static const String ooniprobe = 'ooniprobe.svg';
  static const String op_mobile = 'op_mobile.svg';
  static const String open_flood = 'open_flood.svg';
  static const String open_gapps = 'open_gapps.svg';
  static const String open = 'open.svg';
  static const String openapk = 'openapk.svg';
  static const String openarena = 'openarena.svg';
  static const String openbank = 'openbank.svg';
  static const String openboard = 'openboard.svg';
  static const String opencamera = 'opencamera.svg';
  static const String openchaoschess = 'openchaoschess.svg';
  static const String openconnect = 'openconnect.svg';
  static const String opencontacts = 'opencontacts.svg';
  static const String opencvmanager = 'opencvmanager.svg';
  static const String opendocument_reader = 'opendocument_reader.svg';
  static const String openflashlight = 'openflashlight.svg';
  static const String openfoodfacts = 'openfoodfacts.svg';
  static const String openhab = 'openhab.svg';
  static const String openhub = 'openhub.svg';
  static const String openinwhatsapp = 'openinwhatsapp.svg';
  static const String openlauncher = 'openlauncher.svg';
  static const String openlinkwith = 'openlinkwith.svg';
  static const String openlp = 'openlp.svg';
  static const String openmaps = 'openmaps.svg';
  static const String openmensa = 'openmensa.svg';
  static const String openmoneybox = 'openmoneybox.svg';
  static const String openmw = 'openmw.svg';
  static const String opennotescanner = 'opennotescanner.svg';
  static const String openrectv = 'openrectv.svg';
  static const String openscale = 'openscale.svg';
  static const String openscan = 'openscan.svg';
  static const String opensignal = 'opensignal.svg';
  static const String opensstpclient = 'opensstpclient.svg';
  static const String opensudoku = 'opensudoku.svg';
  static const String opensync = 'opensync.svg';
  static const String opentasks = 'opentasks.svg';
  static const String opentimer = 'opentimer.svg';
  static const String opentodolist = 'opentodolist.svg';
  static const String opentopomap = 'opentopomap.svg';
  static const String opentracks = 'opentracks.svg';
  static const String openvegemap = 'openvegemap.svg';
  static const String openvpn = 'openvpn.svg';
  static const String openvpnconnect = 'openvpnconnect.svg';
  static const String openweather_alt = 'openweather_alt.svg';
  static const String openweather = 'openweather.svg';
  static const String openworkout = 'openworkout.svg';
  static const String opera_gx = 'opera_gx.svg';
  static const String opera = 'opera.svg';
  static const String opgg = 'opgg.svg';
  static const String oplayer = 'oplayer.svg';
  static const String opsu_ = 'opsu_.svg';
  static const String orange_flex = 'orange_flex.svg';
  static const String orangevvm = 'orangevvm.svg';
  static const String orbia = 'orbia.svg';
  static const String orbit_reader = 'orbit_reader.svg';
  static const String orbitaai = 'orbitaai.svg';
  static const String orbot = 'orbot.svg';
  static const String orfox = 'orfox.svg';
  static const String organicmaps = 'organicmaps.svg';
  static const String organtrail = 'organtrail.svg';
  static const String orgro = 'orgro.svg';
  static const String orgzly = 'orgzly.svg';
  static const String orientation_control = 'orientation_control.svg';
  static const String orionviewer = 'orionviewer.svg';
  static const String orloj = 'orloj.svg';
  static const String orna = 'orna.svg';
  static const String ornito = 'ornito.svg';
  static const String oroaming = 'oroaming.svg';
  static const String orweb = 'orweb.svg';
  static const String os_maps = 'os_maps.svg';
  static const String osaifu_keitai = 'osaifu_keitai.svg';
  static const String oscilloscope = 'oscilloscope.svg';
  static const String osesfrandroid = 'osesfrandroid.svg';
  static const String osm_go = 'osm_go.svg';
  static const String osmand = 'osmand.svg';
  static const String osmandtelegram = 'osmandtelegram.svg';
  static const String osmdashboardforopentracks = 'osmdashboardforopentracks.svg';
  static const String osmin = 'osmin.svg';
  static const String osmonitor = 'osmonitor.svg';
  static const String osmtracker = 'osmtracker.svg';
  static const String ostgotatrafiken = 'ostgotatrafiken.svg';
  static const String osu = 'osu.svg';
  static const String osudroid = 'osudroid.svg';
  static const String oto_music = 'oto_music.svg';
  static const String otomoto = 'otomoto.svg';
  static const String otraku = 'otraku.svg';
  static const String otter = 'otter.svg';
  static const String ouigo = 'ouigo.svg';
  static const String ouisncf = 'ouisncf.svg';
  static const String oujo = 'oujo.svg';
  static const String oura = 'oura.svg';
  static const String ourhome = 'ourhome.svg';
  static const String outdooractive = 'outdooractive.svg';
  static const String outdoortoolbox = 'outdoortoolbox.svg';
  static const String overchan = 'overchan.svg';
  static const String overdrive = 'overdrive.svg';
  static const String overdrop = 'overdrop.svg';
  static const String overridedns = 'overridedns.svg';
  static const String oversec = 'oversec.svg';
  static const String ovine_icons = 'ovine_icons.svg';
  static const String owlgram = 'owlgram.svg';
  static const String owly = 'owly.svg';
  static const String owncloud = 'owncloud.svg';
  static const String owntracks = 'owntracks.svg';
  static const String oxen_wallet = 'oxen_wallet.svg';
  static const String oxford_dictionary = 'oxford_dictionary.svg';
  static const String oxygenupdater = 'oxygenupdater.svg';
  static const String ozobotevo = 'ozobotevo.svg';
  static const String p2chelp = 'p2chelp.svg';
  static const String pac_man256 = 'pac_man256.svg';
  static const String packagemanager = 'packagemanager.svg';
  static const String packlist = 'packlist.svg';
  static const String pacman = 'pacman.svg';
  static const String padland = 'padland.svg';
  static const String pady = 'pady.svg';
  static const String pairz = 'pairz.svg';
  static const String palette = 'palette.svg';
  static const String palmcalc = 'palmcalc.svg';
  static const String panasonicapp = 'panasonicapp.svg';
  static const String pandora = 'pandora.svg';
  static const String panflix = 'panflix.svg';
  static const String paperlaunch = 'paperlaunch.svg';
  static const String paperless = 'paperless.svg';
  static const String papertag = 'papertag.svg';
  static const String papirus = 'papirus.svg';
  static const String paprika3 = 'paprika3.svg';
  static const String paramount_plus = 'paramount_plus.svg';
  static const String parcel_tracker = 'parcel_tracker.svg';
  static const String parcello = 'parcello.svg';
  static const String pareudepararme = 'pareudepararme.svg';
  static const String parimatchru = 'parimatchru.svg';
  static const String paristransporttraffic = 'paristransporttraffic.svg';
  static const String park4night = 'park4night.svg';
  static const String parkeren = 'parkeren.svg';
  static const String partygames = 'partygames.svg';
  static const String paseo = 'paseo.svg';
  static const String passandroid = 'passandroid.svg';
  static const String passbolt = 'passbolt.svg';
  static const String passman = 'passman.svg';
  static const String password = 'password.svg';
  static const String passwordgenerator = 'passwordgenerator.svg';
  static const String passwordkeeper = 'passwordkeeper.svg';
  static const String passwordstore = 'passwordstore.svg';
  static const String pastebin = 'pastebin.svg';
  static const String patient_portal = 'patient_portal.svg';
  static const String patreon = 'patreon.svg';
  static const String payback = 'payback.svg';
  static const String paydirekt = 'paydirekt.svg';
  static const String paypal = 'paypal.svg';
  static const String paysafecard = 'paysafecard.svg';
  static const String paytm = 'paytm.svg';
  static const String pb = 'pb.svg';
  static const String pc_creator = 'pc_creator.svg';
  static const String pc_express = 'pc_express.svg';
  static const String pc_financial = 'pc_financial.svg';
  static const String pcapdroid = 'pcapdroid.svg';
  static const String pcivendevdatabase = 'pcivendevdatabase.svg';
  static const String pcloud = 'pcloud.svg';
  static const String pcstartshutdown = 'pcstartshutdown.svg';
  static const String pdf_viewer = 'pdf_viewer.svg';
  static const String pdfconverter = 'pdfconverter.svg';
  static const String pdfviewerplus = 'pdfviewerplus.svg';
  static const String peace_of_mind = 'peace_of_mind.svg';
  static const String peacock = 'peacock.svg';
  static const String peakfinder = 'peakfinder.svg';
  static const String pebble = 'pebble.svg';
  static const String pebbledialer = 'pebbledialer.svg';
  static const String pedometer = 'pedometer.svg';
  static const String peercoin = 'peercoin.svg';
  static const String peertube = 'peertube.svg';
  static const String pegasus = 'pegasus.svg';
  static const String pep = 'pep.svg';
  static const String peppercarrotreader = 'peppercarrotreader.svg';
  static const String periodical = 'periodical.svg';
  static const String permissionchecker = 'permissionchecker.svg';
  static const String permissionmanagerx = 'permissionmanagerx.svg';
  static const String permissionsmanager = 'permissionsmanager.svg';
  static const String persian_calendar = 'persian_calendar.svg';
  static const String petitbambou = 'petitbambou.svg';
  static const String pewpew_2 = 'pewpew_2.svg';
  static const String pewpew = 'pewpew.svg';
  static const String phase6 = 'phase6.svg';
  static const String phigros = 'phigros.svg';
  static const String phimpme = 'phimpme.svg';
  static const String phone_manager = 'phone_manager.svg';
  static const String phone = 'phone.svg';
  static const String phoneaccountabusedetector = 'phoneaccountabusedetector.svg';
  static const String phonepe = 'phonepe.svg';
  static const String phonesaver = 'phonesaver.svg';
  static const String phonetrack = 'phonetrack.svg';
  static const String phonograph = 'phonograph.svg';
  static const String photo_pro = 'photo_pro.svg';
  static const String photochiotte = 'photochiotte.svg';
  static const String photoczip = 'photoczip.svg';
  static const String photoeditor = 'photoeditor.svg';
  static const String photok = 'photok.svg';
  static const String photomath = 'photomath.svg';
  static const String photoprism = 'photoprism.svg';
  static const String photoscan = 'photoscan.svg';
  static const String photospherefree = 'photospherefree.svg';
  static const String phototan = 'phototan.svg';
  static const String phviewer = 'phviewer.svg';
  static const String phyphox = 'phyphox.svg';
  static const String physics_wallah = 'physics_wallah.svg';
  static const String pi = 'pi.svg';
  static const String pianoli = 'pianoli.svg';
  static const String piavpn = 'piavpn.svg';
  static const String picardbarcodescanner = 'picardbarcodescanner.svg';
  static const String picnic = 'picnic.svg';
  static const String picooc = 'picooc.svg';
  static const String picpay = 'picpay.svg';
  static const String picsart = 'picsart.svg';
  static const String pie_launcher = 'pie_launcher.svg';
  static const String pikmin_app = 'pikmin_app.svg';
  static const String pikminbloom = 'pikminbloom.svg';
  static const String pilfershush_jammer = 'pilfershush_jammer.svg';
  static const String pimplepopper = 'pimplepopper.svg';
  static const String pimsleur = 'pimsleur.svg';
  static const String pin = 'pin.svg';
  static const String pinafore = 'pinafore.svg';
  static const String pinterest = 'pinterest.svg';
  static const String pismowitewer = 'pismowitewer.svg';
  static const String pixbit = 'pixbit.svg';
  static const String pixel_filter = 'pixel_filter.svg';
  static const String pixel_tips = 'pixel_tips.svg';
  static const String pixelartist = 'pixelartist.svg';
  static const String pixelator = 'pixelator.svg';
  static const String pixeldroid_alt = 'pixeldroid_alt.svg';
  static const String pixeldroid = 'pixeldroid.svg';
  static const String pixeldungeon = 'pixeldungeon.svg';
  static const String pixellab = 'pixellab.svg';
  static const String pixelwheels = 'pixelwheels.svg';
  static const String pixez = 'pixez.svg';
  static const String pixiv = 'pixiv.svg';
  static const String pixlr = 'pixlr.svg';
  static const String pizzahut = 'pizzahut.svg';
  static const String plagueinc = 'plagueinc.svg';
  static const String planesandroid = 'planesandroid.svg';
  static const String planisphere = 'planisphere.svg';
  static const String plantnet = 'plantnet.svg';
  static const String plants_vs_zombies = 'plants_vs_zombies.svg';
  static const String play_together = 'play_together.svg';
  static const String playsuisse = 'playsuisse.svg';
  static const String pleco = 'pleco.svg';
  static const String pleestracker = 'pleestracker.svg';
  static const String plex = 'plex.svg';
  static const String plexamp = 'plexamp.svg';
  static const String plthub = 'plthub.svg';
  static const String plugsurfing = 'plugsurfing.svg';
  static const String plumble = 'plumble.svg';
  static const String plume = 'plume.svg';
  static const String pluralsight = 'pluralsight.svg';
  static const String plurk = 'plurk.svg';
  static const String pluto_tv = 'pluto_tv.svg';
  static const String plutus = 'plutus.svg';
  static const String pocket_fm = 'pocket_fm.svg';
  static const String pocket = 'pocket.svg';
  static const String pocketcasts = 'pocketcasts.svg';
  static const String pocketpaint = 'pocketpaint.svg';
  static const String pocolauncher = 'pocolauncher.svg';
  static const String podcast_republic = 'podcast_republic.svg';
  static const String podcastaddict = 'podcastaddict.svg';
  static const String podlisten = 'podlisten.svg';
  static const String podverse = 'podverse.svg';
  static const String pojavlauncher = 'pojavlauncher.svg';
  static const String pokemon_unite = 'pokemon_unite.svg';
  static const String pokemongo = 'pokemongo.svg';
  static const String pokerstars = 'pokerstars.svg';
  static const String pokitmeter = 'pokitmeter.svg';
  static const String polaris_office = 'polaris_office.svg';
  static const String polytopia = 'polytopia.svg';
  static const String pong = 'pong.svg';
  static const String pontoon = 'pontoon.svg';
  static const String pop_time = 'pop_time.svg';
  static const String popcorntime = 'popcorntime.svg';
  static const String portauthority = 'portauthority.svg';
  static const String portdroid = 'portdroid.svg';
  static const String portknocker = 'portknocker.svg';
  static const String portscanner = 'portscanner.svg';
  static const String posidonlauncher = 'posidonlauncher.svg';
  static const String post = 'post.svg';
  static const String postdhl = 'postdhl.svg';
  static const String postepay = 'postepay.svg';
  static const String postid = 'postid.svg';
  static const String postnl = 'postnl.svg';
  static const String postnord = 'postnord.svg';
  static const String poweramp_equalizer = 'poweramp_equalizer.svg';
  static const String poweramp = 'poweramp.svg';
  static const String powerapp = 'powerapp.svg';
  static const String powerschool = 'powerschool.svg';
  static const String powertunnel = 'powertunnel.svg';
  static const String ppsspp = 'ppsspp.svg';
  static const String pr0gramm = 'pr0gramm.svg';
  static const String practicehub = 'practicehub.svg';
  static const String praxis = 'praxis.svg';
  static const String precio_luz_alt = 'precio_luz_alt.svg';
  static const String precio_luz = 'precio_luz.svg';
  static const String precisevolume = 'precisevolume.svg';
  static const String presearch = 'presearch.svg';
  static const String presencepublisher = 'presencepublisher.svg';
  static const String press = 'press.svg';
  static const String pretixprint = 'pretixprint.svg';
  static const String preview = 'preview.svg';
  static const String prevo = 'prevo.svg';
  static const String prey = 'prey.svg';
  static const String priceconverter = 'priceconverter.svg';
  static const String priceperunit = 'priceperunit.svg';
  static const String primitiveftpd = 'primitiveftpd.svg';
  static const String printbot = 'printbot.svg';
  static const String privacy_dashboard = 'privacy_dashboard.svg';
  static const String privacyblur = 'privacyblur.svg';
  static const String privacybrowser = 'privacybrowser.svg';
  static const String privacyindicators = 'privacyindicators.svg';
  static const String privat24 = 'privat24.svg';
  static const String private_share = 'private_share.svg';
  static const String privatelocation = 'privatelocation.svg';
  static const String privatelock = 'privatelock.svg';
  static const String productivity = 'productivity.svg';
  static const String proexpense = 'proexpense.svg';
  static const String programming_hero = 'programming_hero.svg';
  static const String programming_hub = 'programming_hub.svg';
  static const String projectm = 'projectm.svg';
  static const String pronote = 'pronote.svg';
  static const String proshot = 'proshot.svg';
  static const String protonmail = 'protonmail.svg';
  static const String protonvideocompressor = 'protonvideocompressor.svg';
  static const String protonvpn = 'protonvpn.svg';
  static const String proxdroid = 'proxdroid.svg';
  static const String ps_app = 'ps_app.svg';
  static const String psiphon = 'psiphon.svg';
  static const String pslab = 'pslab.svg';
  static const String psremoteplay = 'psremoteplay.svg';
  static const String ptcltouch = 'ptcltouch.svg';
  static const String pubg_mobile = 'pubg_mobile.svg';
  static const String pubtran = 'pubtran.svg';
  static const String pulse = 'pulse.svg';
  static const String pulseaudiortpreceiver = 'pulseaudiortpreceiver.svg';
  static const String pulsemusic = 'pulsemusic.svg';
  static const String pulsesms = 'pulsesms.svg';
  static const String purchased_apps = 'purchased_apps.svg';
  static const String pushbullet = 'pushbullet.svg';
  static const String pushie = 'pushie.svg';
  static const String pushieblocks = 'pushieblocks.svg';
  static const String pushover = 'pushover.svg';
  static const String puzzles = 'puzzles.svg';
  static const String pydroid3 = 'pydroid3.svg';
  static const String pysolfc = 'pysolfc.svg';
  static const String pzizz = 'pzizz.svg';
  static const String qfile = 'qfile.svg';
  static const String qksms = 'qksms.svg';
  static const String qmanager = 'qmanager.svg';
  static const String qq_2 = 'qq_2.svg';
  static const String qq_music = 'qq_music.svg';
  static const String qq = 'qq.svg';
  static const String qr = 'qr.svg';
  static const String qrforkeepass = 'qrforkeepass.svg';
  static const String qtranslate = 'qtranslate.svg';
  static const String quakedroid = 'quakedroid.svg';
  static const String quasseldroid = 'quasseldroid.svg';
  static const String quebec511 = 'quebec511.svg';
  static const String questionnaire_star = 'questionnaire_star.svg';
  static const String quick_bible = 'quick_bible.svg';
  static const String quick_calculation = 'quick_calculation.svg';
  static const String quick_cursor = 'quick_cursor.svg';
  static const String quick_dice_roller = 'quick_dice_roller.svg';
  static const String quickdic = 'quickdic.svg';
  static const String quickedit = 'quickedit.svg';
  static const String quicklyquit = 'quicklyquit.svg';
  static const String quicknote = 'quicknote.svg';
  static const String quicknovel = 'quicknovel.svg';
  static const String quicksupport = 'quicksupport.svg';
  static const String quickswitch = 'quickswitch.svg';
  static const String quicksy = 'quicksy.svg';
  static const String quicktiles = 'quicktiles.svg';
  static const String quickweather = 'quickweather.svg';
  static const String quillnote = 'quillnote.svg';
  static const String quinb = 'quinb.svg';
  static const String quire = 'quire.svg';
  static const String quit_tracker = 'quit_tracker.svg';
  static const String quizlet = 'quizlet.svg';
  static const String qunar = 'qunar.svg';
  static const String quoteunquote = 'quoteunquote.svg';
  static const String quran_alt = 'quran_alt.svg';
  static const String quran = 'quran.svg';
  static const String qwant_alt = 'qwant_alt.svg';
  static const String qwant = 'qwant.svg';
  static const String raag = 'raag.svg';
  static const String rabbitescape = 'rabbitescape.svg';
  static const String racoon = 'racoon.svg';
  static const String radarscope = 'radarscope.svg';
  static const String radio = 'radio.svg';
  static const String radiodroid = 'radiodroid.svg';
  static const String radiofm = 'radiofm.svg';
  static const String radiofm4 = 'radiofm4.svg';
  static const String radiofrance = 'radiofrance.svg';
  static const String radiogram = 'radiogram.svg';
  static const String radioparadise = 'radioparadise.svg';
  static const String railwaystationphotos = 'railwaystationphotos.svg';
  static const String raindrop = 'raindrop.svg';
  static const String raise_to_answer = 'raise_to_answer.svg';
  static const String rakuten_link = 'rakuten_link.svg';
  static const String randomfilemaker = 'randomfilemaker.svg';
  static const String randomix = 'randomix.svg';
  static const String rapido = 'rapido.svg';
  static const String rappi = 'rappi.svg';
  static const String rar = 'rar.svg';
  static const String raspi_check = 'raspi_check.svg';
  static const String ratio = 'ratio.svg';
  static const String raumfeld = 'raumfeld.svg';
  static const String rave = 'rave.svg';
  static const String raze_touch = 'raze_touch.svg';
  static const String rbcmobile = 'rbcmobile.svg';
  static const String rcx = 'rcx.svg';
  static const String rd_client = 'rd_client.svg';
  static const String rdclient = 'rdclient.svg';
  static const String reactiontraining = 'reactiontraining.svg';
  static const String readera = 'readera.svg';
  static const String readerforselfoss = 'readerforselfoss.svg';
  static const String readrops = 'readrops.svg';
  static const String real_racing = 'real_racing.svg';
  static const String reallybadchess = 'reallybadchess.svg';
  static const String realme_link = 'realme_link.svg';
  static const String receiptmanager = 'receiptmanager.svg';
  static const String recon = 'recon.svg';
  static const String recorder = 'recorder.svg';
  static const String recurrence = 'recurrence.svg';
  static const String recyclelocation = 'recyclelocation.svg';
  static const String redactor = 'redactor.svg';
  static const String reddit_is_fun = 'reddit_is_fun.svg';
  static const String reddit = 'reddit.svg';
  static const String redditoria = 'redditoria.svg';
  static const String redditsync = 'redditsync.svg';
  static const String redmoi = 'redmoi.svg';
  static const String redmoon = 'redmoon.svg';
  static const String redream = 'redream.svg';
  static const String regenradar = 'regenradar.svg';
  static const String regentijd = 'regentijd.svg';
  static const String regex = 'regex.svg';
  static const String regexcrossword = 'regexcrossword.svg';
  static const String reinstead = 'reinstead.svg';
  static const String rejsekortstatus = 'rejsekortstatus.svg';
  static const String rekado = 'rekado.svg';
  static const String relayreddit = 'relayreddit.svg';
  static const String rema1000 = 'rema1000.svg';
  static const String remarkable = 'remarkable.svg';
  static const String remind = 'remind.svg';
  static const String reminder = 'reminder.svg';
  static const String remixeddungeon = 'remixeddungeon.svg';
  static const String remote_mouse = 'remote_mouse.svg';
  static const String remotedesktop = 'remotedesktop.svg';
  static const String remotefiles = 'remotefiles.svg';
  static const String remotenumpad = 'remotenumpad.svg';
  static const String removed = 'removed.svg';
  static const String renpho = 'renpho.svg';
  static const String reolink = 'reolink.svg';
  static const String repeaterbook = 'repeaterbook.svg';
  static const String replika = 'replika.svg';
  static const String replit = 'replit.svg';
  static const String reroll = 'reroll.svg';
  static const String resplash = 'resplash.svg';
  static const String rethinkdns = 'rethinkdns.svg';
  static const String retrica = 'retrica.svg';
  static const String retroarch = 'retroarch.svg';
  static const String retrobreaker = 'retrobreaker.svg';
  static const String retrowars = 'retrowars.svg';
  static const String retrowave_radio = 'retrowave_radio.svg';
  static const String reverseimagesearch = 'reverseimagesearch.svg';
  static const String reversocontext = 'reversocontext.svg';
  static const String revolut = 'revolut.svg';
  static const String revolution = 'revolution.svg';
  static const String rewards = 'rewards.svg';
  static const String rewe = 'rewe.svg';
  static const String rfanalyzer = 'rfanalyzer.svg';
  static const String rfid_tools = 'rfid_tools.svg';
  static const String rhvoice = 'rhvoice.svg';
  static const String ride_mode = 'ride_mode.svg';
  static const String ring_2 = 'ring_2.svg';
  static const String ring = 'ring.svg';
  static const String ringdroid = 'ringdroid.svg';
  static const String riot = 'riot.svg';
  static const String ripio = 'ripio.svg';
  static const String ripple = 'ripple.svg';
  static const String riseupvpn = 'riseupvpn.svg';
  static const String rne = 'rne.svg';
  static const String roadeagle = 'roadeagle.svg';
  static const String robinhood = 'robinhood.svg';
  static const String roblox = 'roblox.svg';
  static const String roborock = 'roborock.svg';
  static const String rocketbook = 'rocketbook.svg';
  static const String rocketchat = 'rocketchat.svg';
  static const String rocksndiamonds = 'rocksndiamonds.svg';
  static const String roku = 'roku.svg';
  static const String romeo = 'romeo.svg';
  static const String romote = 'romote.svg';
  static const String ronin_wallet = 'ronin_wallet.svg';
  static const String rootexplorer = 'rootexplorer.svg';
  static const String rootlesspixellauncher = 'rootlesspixellauncher.svg';
  static const String rosetta_stone = 'rosetta_stone.svg';
  static const String rosettastone = 'rosettastone.svg';
  static const String rossman = 'rossman.svg';
  static const String router_keygen = 'router_keygen.svg';
  static const String royalsortballpuzzle = 'royalsortballpuzzle.svg';
  static const String rpicameraviewer = 'rpicameraviewer.svg';
  static const String rpncalc = 'rpncalc.svg';
  static const String rpur = 'rpur.svg';
  static const String rss = 'rss.svg';
  static const String rssreader = 'rssreader.svg';
  static const String rtlsdrdriver = 'rtlsdrdriver.svg';
  static const String rucardsmobile = 'rucardsmobile.svg';
  static const String ruleofthree = 'ruleofthree.svg';
  static const String runawaytoad = 'runawaytoad.svg';
  static const String runnerup = 'runnerup.svg';
  static const String rust = 'rust.svg';
  static const String rustdesk = 'rustdesk.svg';
  static const String ruthlesssettings = 'ruthlesssettings.svg';
  static const String ruuvistation = 'ruuvistation.svg';
  static const String rxdroid = 'rxdroid.svg';
  static const String s_mobiili = 's_mobiili.svg';
  static const String s_notz = 's_notz.svg';
  static const String s_trust = 's_trust.svg';
  static const String sadapay = 'sadapay.svg';
  static const String safenhancer = 'safenhancer.svg';
  static const String safety = 'safety.svg';
  static const String safevac = 'safevac.svg';
  static const String sagernet = 'sagernet.svg';
  static const String sai_alt = 'sai_alt.svg';
  static const String sai = 'sai.svg';
  static const String saikou = 'saikou.svg';
  static const String samourai = 'samourai.svg';
  static const String samsung_browser = 'samsung_browser.svg';
  static const String samsung_finder = 'samsung_finder.svg';
  static const String samsung_health_monitor = 'samsung_health_monitor.svg';
  static const String samsung_health = 'samsung_health.svg';
  static const String samsung_max = 'samsung_max.svg';
  static const String samsung_members = 'samsung_members.svg';
  static const String samsung_music = 'samsung_music.svg';
  static const String samsung_secure = 'samsung_secure.svg';
  static const String samsung_shop = 'samsung_shop.svg';
  static const String samsungpass = 'samsungpass.svg';
  static const String samsungpaymini = 'samsungpaymini.svg';
  static const String sankuaimeituan = 'sankuaimeituan.svg';
  static const String santander = 'santander.svg';
  static const String satellite = 'satellite.svg';
  static const String satstat = 'satstat.svg';
  static const String saucenao = 'saucenao.svg';
  static const String saucillatorforandroid = 'saucillatorforandroid.svg';
  static const String save_for_offline = 'save_for_offline.svg';
  static const String saveto = 'saveto.svg';
  static const String sbbmobile = 'sbbmobile.svg';
  static const String sberbank = 'sberbank.svg';
  static const String scam_shield = 'scam_shield.svg';
  static const String scanbot = 'scanbot.svg';
  static const String scanmediaplz = 'scanmediaplz.svg';
  static const String scanner = 'scanner.svg';
  static const String scarletnotesfd = 'scarletnotesfd.svg';
  static const String schildichat = 'schildichat.svg';
  static const String schwab = 'schwab.svg';
  static const String scoop_alt = 'scoop_alt.svg';
  static const String scoop = 'scoop.svg';
  static const String score_sheets = 'score_sheets.svg';
  static const String scrambledexif = 'scrambledexif.svg';
  static const String screencam = 'screencam.svg';
  static const String screencast = 'screencast.svg';
  static const String screener = 'screener.svg';
  static const String screenmaster = 'screenmaster.svg';
  static const String screenrecorder = 'screenrecorder.svg';
  static const String screenshottile = 'screenshottile.svg';
  static const String screenstream = 'screenstream.svg';
  static const String screentime = 'screentime.svg';
  static const String screeps = 'screeps.svg';
  static const String screwfix = 'screwfix.svg';
  static const String scrobb = 'scrobb.svg';
  static const String sd_maid_pro = 'sd_maid_pro.svg';
  static const String sd_maid = 'sd_maid.svg';
  static const String sd_worx = 'sd_worx.svg';
  static const String sdk_monitor = 'sdk_monitor.svg';
  static const String sdscanner = 'sdscanner.svg';
  static const String seafile = 'seafile.svg';
  static const String seasoncalendar = 'seasoncalendar.svg';
  static const String secretcodes = 'secretcodes.svg';
  static const String sectograph = 'sectograph.svg';
  static const String secur = 'secur.svg';
  static const String secure_box = 'secure_box.svg';
  static const String securefolder = 'securefolder.svg';
  static const String securid = 'securid.svg';
  static const String security = 'security.svg';
  static const String secusosolitaire = 'secusosolitaire.svg';
  static const String seeder = 'seeder.svg';
  static const String seedship = 'seedship.svg';
  static const String seeker = 'seeker.svg';
  static const String seeneva = 'seeneva.svg';
  static const String sefaria = 'sefaria.svg';
  static const String seguime = 'seguime.svg';
  static const String selfprivacy = 'selfprivacy.svg';
  static const String sellonetsy = 'sellonetsy.svg';
  static const String semitone = 'semitone.svg';
  static const String sendreducedfree = 'sendreducedfree.svg';
  static const String sendtosqueezeboxsettings = 'sendtosqueezeboxsettings.svg';
  static const String sensorreadout = 'sensorreadout.svg';
  static const String sensorz = 'sensorz.svg';
  static const String sentienlauncher = 'sentienlauncher.svg';
  static const String serasa = 'serasa.svg';
  static const String serialusbterminal = 'serialusbterminal.svg';
  static const String seriesguide = 'seriesguide.svg';
  static const String serveit = 'serveit.svg';
  static const String service_nsw = 'service_nsw.svg';
  static const String serviigo = 'serviigo.svg';
  static const String sesame = 'sesame.svg';
  static const String session = 'session.svg';
  static const String setedit = 'setedit.svg';
  static const String setter = 'setter.svg';
  static const String settings = 'settings.svg';
  static const String sgame = 'sgame.svg';
  static const String shaadi = 'shaadi.svg';
  static const String shaarlier = 'shaarlier.svg';
  static const String shade = 'shade.svg';
  static const String shadereditor = 'shadereditor.svg';
  static const String shadow = 'shadow.svg';
  static const String shadowfight2 = 'shadowfight2.svg';
  static const String shadowsocks = 'shadowsocks.svg';
  static const String shadowweather = 'shadowweather.svg';
  static const String share_via_http = 'share_via_http.svg';
  static const String shareme = 'shareme.svg';
  static const String sharetoclipboard = 'sharetoclipboard.svg';
  static const String sharetopinboard = 'sharetopinboard.svg';
  static const String sharik = 'sharik.svg';
  static const String shark_clean = 'shark_clean.svg';
  static const String shatteredpixeldungeon = 'shatteredpixeldungeon.svg';
  static const String shazam = 'shazam.svg';
  static const String sheepy_horn = 'sheepy_horn.svg';
  static const String shell = 'shell.svg';
  static const String shelter = 'shelter.svg';
  static const String shield = 'shield.svg';
  static const String shieldt = 'shieldt.svg';
  static const String shiftcal = 'shiftcal.svg';
  static const String shiftmanager_pro = 'shiftmanager_pro.svg';
  static const String shiro = 'shiro.svg';
  static const String shizuku = 'shizuku.svg';
  static const String shokz = 'shokz.svg';
  static const String shopee = 'shopee.svg';
  static const String shoppinglist = 'shoppinglist.svg';
  static const String shortcut_maker = 'shortcut_maker.svg';
  static const String shosetsu = 'shosetsu.svg';
  static const String should_i_answer = 'should_i_answer.svg';
  static const String shoutem = 'shoutem.svg';
  static const String shpock = 'shpock.svg';
  static const String shrug = 'shrug.svg';
  static const String shuttle = 'shuttle.svg';
  static const String sicmu_player = 'sicmu_player.svg';
  static const String sidcheck = 'sidcheck.svg';
  static const String siddharthabanksmart = 'siddharthabanksmart.svg';
  static const String sigmalink = 'sigmalink.svg';
  static const String signal = 'signal.svg';
  static const String signalgenerator = 'signalgenerator.svg';
  static const String signature = 'signature.svg';
  static const String signaturespoofingchecker = 'signaturespoofingchecker.svg';
  static const String siilo = 'siilo.svg';
  static const String silence_2 = 'silence_2.svg';
  static const String silence = 'silence.svg';
  static const String sim = 'sim.svg';
  static const String simexplorer = 'simexplorer.svg';
  static const String simpill = 'simpill.svg';
  static const String simple_keyboard = 'simple_keyboard.svg';
  static const String simple_sharing = 'simple_sharing.svg';
  static const String simple_system_monitor = 'simple_system_monitor.svg';
  static const String simple = 'simple.svg';
  static const String simpleaccounting = 'simpleaccounting.svg';
  static const String simpleapplauncher = 'simpleapplauncher.svg';
  static const String simplecalendar = 'simplecalendar.svg';
  static const String simplecamera = 'simplecamera.svg';
  static const String simpledraw = 'simpledraw.svg';
  static const String simplefilemanager = 'simplefilemanager.svg';
  static const String simpleflashlight = 'simpleflashlight.svg';
  static const String simplegallery = 'simplegallery.svg';
  static const String simplelogin = 'simplelogin.svg';
  static const String simplemind_lite = 'simplemind_lite.svg';
  static const String simplemusicplayer = 'simplemusicplayer.svg';
  static const String simplenote = 'simplenote.svg';
  static const String simplenotes = 'simplenotes.svg';
  static const String simplereboot = 'simplereboot.svg';
  static const String simplesearch = 'simplesearch.svg';
  static const String simpletask = 'simpletask.svg';
  static const String simpletextcrypt = 'simpletextcrypt.svg';
  static const String simpletexteditor = 'simpletexteditor.svg';
  static const String simplethankyou = 'simplethankyou.svg';
  static const String simpleweather = 'simpleweather.svg';
  static const String simplicon = 'simplicon.svg';
  static const String simplisafe = 'simplisafe.svg';
  static const String simplytranslate = 'simplytranslate.svg';
  static const String simplytranslatemobile = 'simplytranslatemobile.svg';
  static const String sipnetic = 'sipnetic.svg';
  static const String sj = 'sj.svg';
  static const String skeelo_audiobooks = 'skeelo_audiobooks.svg';
  static const String sketch = 'sketch.svg';
  static const String sketchbook = 'sketchbook.svg';
  static const String skilter = 'skilter.svg';
  static const String skipthedishes = 'skipthedishes.svg';
  static const String skit = 'skit.svg';
  static const String skolschema = 'skolschema.svg';
  static const String skoob_alt = 'skoob_alt.svg';
  static const String skoob = 'skoob.svg';
  static const String skrill = 'skrill.svg';
  static const String skroutz = 'skroutz.svg';
  static const String sky = 'sky.svg';
  static const String skycash = 'skycash.svg';
  static const String skydroid = 'skydroid.svg';
  static const String skylist = 'skylist.svg';
  static const String skymap = 'skymap.svg';
  static const String skype = 'skype.svg';
  static const String skysafari = 'skysafari.svg';
  static const String skytube = 'skytube.svg';
  static const String skyward = 'skyward.svg';
  static const String sl = 'sl.svg';
  static const String slack = 'slack.svg';
  static const String slay_the_spire = 'slay_the_spire.svg';
  static const String sleepa = 'sleepa.svg';
  static const String sleepcycle = 'sleepcycle.svg';
  static const String sleeptimer = 'sleeptimer.svg';
  static const String sleipnir = 'sleipnir.svg';
  static const String slicknewsletters = 'slicknewsletters.svg';
  static const String slide = 'slide.svg';
  static const String slidereddit = 'slidereddit.svg';
  static const String slimsocialfortwitter = 'slimsocialfortwitter.svg';
  static const String slowly = 'slowly.svg';
  static const String smart_audiobook_player = 'smart_audiobook_player.svg';
  static const String smart_home = 'smart_home.svg';
  static const String smart_life = 'smart_life.svg';
  static const String smart_transfer = 'smart_transfer.svg';
  static const String smart_vpn = 'smart_vpn.svg';
  static const String smartautoclicker = 'smartautoclicker.svg';
  static const String smartcontrol = 'smartcontrol.svg';
  static const String smartcookieweb = 'smartcookieweb.svg';
  static const String smarteggtimer = 'smarteggtimer.svg';
  static const String smartflasher = 'smartflasher.svg';
  static const String smartlauncher = 'smartlauncher.svg';
  static const String smartlogicsim = 'smartlogicsim.svg';
  static const String smartnews = 'smartnews.svg';
  static const String smartpack = 'smartpack.svg';
  static const String smartthings = 'smartthings.svg';
  static const String smb_sync = 'smb_sync.svg';
  static const String sms_backup_ = 'sms_backup_.svg';
  static const String sms_gate = 'sms_gate.svg';
  static const String sms_import_export = 'sms_import_export.svg';
  static const String smsbackuprestore = 'smsbackuprestore.svg';
  static const String smsq = 'smsq.svg';
  static const String smugmug = 'smugmug.svg';
  static const String snakebird = 'snakebird.svg';
  static const String snapcast = 'snapcast.svg';
  static const String snapchat = 'snapchat.svg';
  static const String snapdrop = 'snapdrop.svg';
  static const String snapmod = 'snapmod.svg';
  static const String snapseed = 'snapseed.svg';
  static const String sncb = 'sncb.svg';
  static const String sncf = 'sncf.svg';
  static const String snikket = 'snikket.svg';
  static const String snooperstopper = 'snooperstopper.svg';
  static const String snow = 'snow.svg';
  static const String sns_24 = 'sns_24.svg';
  static const String social = 'social.svg';
  static const String socitgnrale = 'socitgnrale.svg';
  static const String socratic = 'socratic.svg';
  static const String socrative = 'socrative.svg';
  static const String sodexo = 'sodexo.svg';
  static const String sofascore = 'sofascore.svg';
  static const String softlist = 'softlist.svg';
  static const String sokoban = 'sokoban.svg';
  static const String solarcompass = 'solarcompass.svg';
  static const String solarman = 'solarman.svg';
  static const String solidexplorer = 'solidexplorer.svg';
  static const String solitaire = 'solitaire.svg';
  static const String solitairecg = 'solitairecg.svg';
  static const String sololearn = 'sololearn.svg';
  static const String solunarperiods = 'solunarperiods.svg';
  static const String somafm = 'somafm.svg';
  static const String songtube = 'songtube.svg';
  static const String sonic_runners = 'sonic_runners.svg';
  static const String sonic = 'sonic.svg';
  static const String sonorox = 'sonorox.svg';
  static const String sonos = 'sonos.svg';
  static const String sosalarm = 'sosalarm.svg';
  static const String soulknight = 'soulknight.svg';
  static const String soundcloud = 'soundcloud.svg';
  static const String soundcore = 'soundcore.svg';
  static const String soundhound = 'soundhound.svg';
  static const String soundid = 'soundid.svg';
  static const String soundtoggle = 'soundtoggle.svg';
  static const String sovcombank = 'sovcombank.svg';
  static const String spacenow = 'spacenow.svg';
  static const String spacepeng = 'spacepeng.svg';
  static const String spaceteam = 'spaceteam.svg';
  static const String spacetrader = 'spacetrader.svg';
  static const String spanishdict = 'spanishdict.svg';
  static const String sparebankenost = 'sparebankenost.svg';
  static const String spark = 'spark.svg';
  static const String sparkasse = 'sparkasse.svg';
  static const String sparss_decsync = 'sparss_decsync.svg';
  static const String sparss = 'sparss.svg';
  static const String speakingpal = 'speakingpal.svg';
  static const String spectroid = 'spectroid.svg';
  static const String speed_math = 'speed_math.svg';
  static const String speedmeter = 'speedmeter.svg';
  static const String speedtest = 'speedtest.svg';
  static const String spell4wiki = 'spell4wiki.svg';
  static const String spellbook = 'spellbook.svg';
  static const String spike_email = 'spike_email.svg';
  static const String spitogatos = 'spitogatos.svg';
  static const String splid = 'splid.svg';
  static const String splitser = 'splitser.svg';
  static const String splitwise = 'splitwise.svg';
  static const String spooks = 'spooks.svg';
  static const String spotiflyer_alt = 'spotiflyer_alt.svg';
  static const String spotiflyer = 'spotiflyer.svg';
  static const String spotify = 'spotify.svg';
  static const String spotistats = 'spotistats.svg';
  static const String spotit = 'spotit.svg';
  static const String spren = 'spren.svg';
  static const String spritpreise = 'spritpreise.svg';
  static const String sproutedpixeldungeon = 'sproutedpixeldungeon.svg';
  static const String spynetcamera = 'spynetcamera.svg';
  static const String sq_mixpad = 'sq_mixpad.svg';
  static const String sq4you = 'sq4you.svg';
  static const String sqrllogin = 'sqrllogin.svg';
  static const String square = 'square.svg';
  static const String square2 = 'square2.svg';
  static const String squeezer = 'squeezer.svg';
  static const String squid = 'squid.svg';
  static const String squircle_ide = 'squircle_ide.svg';
  static const String stack_exchange = 'stack_exchange.svg';
  static const String stack = 'stack.svg';
  static const String stadia = 'stadia.svg';
  static const String stadtmobil = 'stadtmobil.svg';
  static const String stadtrad_hamburg = 'stadtrad_hamburg.svg';
  static const String standardnotes = 'standardnotes.svg';
  static const String star = 'star.svg';
  static const String stardew_valley = 'stardew_valley.svg';
  static const String starkeverben = 'starkeverben.svg';
  static const String starling = 'starling.svg';
  static const String startradersrpg = 'startradersrpg.svg';
  static const String state_farm = 'state_farm.svg';
  static const String status = 'status.svg';
  static const String status2 = 'status2.svg';
  static const String stay_hydrated = 'stay_hydrated.svg';
  static const String stayfree = 'stayfree.svg';
  static const String stealthreddit = 'stealthreddit.svg';
  static const String steam_chat = 'steam_chat.svg';
  static const String steam = 'steam.svg';
  static const String steamlink = 'steamlink.svg';
  static const String steamtracker = 'steamtracker.svg';
  static const String stellarium = 'stellarium.svg';
  static const String stellariumfree = 'stellariumfree.svg';
  static const String stepstone = 'stepstone.svg';
  static const String stickerconv = 'stickerconv.svg';
  static const String stickermaker = 'stickermaker.svg';
  static const String stingle = 'stingle.svg';
  static const String stocard = 'stocard.svg';
  static const String stockswidget = 'stockswidget.svg';
  static const String stoic = 'stoic.svg';
  static const String storkim = 'storkim.svg';
  static const String storytel = 'storytel.svg';
  static const String storzbickel = 'storzbickel.svg';
  static const String straslines = 'straslines.svg';
  static const String strava = 'strava.svg';
  static const String stream_pi_client = 'stream_pi_client.svg';
  static const String streamlabs = 'streamlabs.svg';
  static const String streetcomplete_alt = 'streetcomplete_alt.svg';
  static const String streetcomplete = 'streetcomplete.svg';
  static const String streetview = 'streetview.svg';
  static const String stremio = 'stremio.svg';
  static const String stride_health = 'stride_health.svg';
  static const String stronglifts = 'stronglifts.svg';
  static const String studierendenwerkheidelberg = 'studierendenwerkheidelberg.svg';
  static const String studo = 'studo.svg';
  static const String studyplus = 'studyplus.svg';
  static const String studysmarter = 'studysmarter.svg';
  static const String stuff = 'stuff.svg';
  static const String stumbler = 'stumbler.svg';
  static const String styxbrowser = 'styxbrowser.svg';
  static const String styxbrowser2 = 'styxbrowser2.svg';
  static const String su = 'su.svg';
  static const String subby = 'subby.svg';
  static const String substratum = 'substratum.svg';
  static const String subtracks = 'subtracks.svg';
  static const String subway = 'subway.svg';
  static const String subwaysurf = 'subwaysurf.svg';
  static const String subz = 'subz.svg';
  static const String sudoku = 'sudoku.svg';
  static const String sudokufree = 'sudokufree.svg';
  static const String sudokuopen = 'sudokuopen.svg';
  static const String sudokuoss = 'sudokuoss.svg';
  static const String sudoq = 'sudoq.svg';
  static const String sugarizer = 'sugarizer.svg';
  static const String suissemobile = 'suissemobile.svg';
  static const String sulamericasaude = 'sulamericasaude.svg';
  static const String summoners_war = 'summoners_war.svg';
  static const String sundhedskortet = 'sundhedskortet.svg';
  static const String suntimes = 'suntimes.svg';
  static const String suntimesalarms = 'suntimesalarms.svg';
  static const String suntimescalendars = 'suntimescalendars.svg';
  static const String super_backup = 'super_backup.svg';
  static const String superautopets = 'superautopets.svg';
  static const String superfreezz = 'superfreezz.svg';
  static const String superhexagon = 'superhexagon.svg';
  static const String supermemo = 'supermemo.svg';
  static const String supertux = 'supertux.svg';
  static const String supertuxkart = 'supertuxkart.svg';
  static const String surfshark = 'surfshark.svg';
  static const String survivalmanual_alt = 'survivalmanual_alt.svg';
  static const String survivalmanual = 'survivalmanual.svg';
  static const String suunto = 'suunto.svg';
  static const String sverigesradioplay = 'sverigesradioplay.svg';
  static const String svgpreview = 'svgpreview.svg';
  static const String svtplay = 'svtplay.svg';
  static const String swappa = 'swappa.svg';
  static const String sweatcoin = 'sweatcoin.svg';
  static const String swedbank = 'swedbank.svg';
  static const String sweech = 'sweech.svg';
  static const String swift_backup = 'swift_backup.svg';
  static const String swift_installer = 'swift_installer.svg';
  static const String swiftkey = 'swiftkey.svg';
  static const String swiggy = 'swiggy.svg';
  static const String swindon_bus = 'swindon_bus.svg';
  static const String swish = 'swish.svg';
  static const String swissbankers = 'swissbankers.svg';
  static const String swisstopo = 'swisstopo.svg';
  static const String symbolab = 'symbolab.svg';
  static const String symboldollar = 'symboldollar.svg';
  static const String symboleuro = 'symboleuro.svg';
  static const String syncme = 'syncme.svg';
  static const String syncopoli = 'syncopoli.svg';
  static const String syncthing = 'syncthing.svg';
  static const String syncthingcamera = 'syncthingcamera.svg';
  static const String synology_active_insight = 'synology_active_insight.svg';
  static const String synology_assistant = 'synology_assistant.svg';
  static const String synology_photos = 'synology_photos.svg';
  static const String syphon = 'syphon.svg';
  static const String syska_smart_home = 'syska_smart_home.svg';
  static const String system_ui_tuner = 'system_ui_tuner.svg';
  static const String systemappmover = 'systemappmover.svg';
  static const String systemusagedirect = 'systemusagedirect.svg';
  static const String t_mobile = 't_mobile.svg';
  static const String tabs = 'tabs.svg';
  static const String tachij2k = 'tachij2k.svg';
  static const String tachiyomi = 'tachiyomi.svg';
  static const String tachometer = 'tachometer.svg';
  static const String tacobell = 'tacobell.svg';
  static const String tagesschau = 'tagesschau.svg';
  static const String taginfo = 'taginfo.svg';
  static const String tagspaces = 'tagspaces.svg';
  static const String tagwriter = 'tagwriter.svg';
  static const String taigamobile = 'taigamobile.svg';
  static const String tailscale = 'tailscale.svg';
  static const String taimi = 'taimi.svg';
  static const String talalarmo = 'talalarmo.svg';
  static const String tallahassee_police_department = 'tallahassee_police_department.svg';
  static const String tan = 'tan.svg';
  static const String tandem = 'tandem.svg';
  static const String tanglemaster3d = 'tanglemaster3d.svg';
  static const String taobao = 'taobao.svg';
  static const String tap_and_go = 'tap_and_go.svg';
  static const String tap_tap = 'tap_tap.svg';
  static const String tape = 'tape.svg';
  static const String tapemeasure = 'tapemeasure.svg';
  static const String tapnturn = 'tapnturn.svg';
  static const String tapped_out = 'tapped_out.svg';
  static const String target = 'target.svg';
  static const String taskbar = 'taskbar.svg';
  static const String tasker = 'tasker.svg';
  static const String tasks = 'tasks.svg';
  static const String taskwarrior = 'taskwarrior.svg';
  static const String tawakkalna = 'tawakkalna.svg';
  static const String teamviewer = 'teamviewer.svg';
  static const String teamward = 'teamward.svg';
  static const String teapod = 'teapod.svg';
  static const String tec = 'tec.svg';
  static const String techmino = 'techmino.svg';
  static const String ted = 'ted.svg';
  static const String tedit = 'tedit.svg';
  static const String teilen_nach = 'teilen_nach.svg';
  static const String telegraher = 'telegraher.svg';
  static const String telegram_plus = 'telegram_plus.svg';
  static const String telegram = 'telegram.svg';
  static const String telegraph = 'telegraph.svg';
  static const String telepizza = 'telepizza.svg';
  static const String tellurium = 'tellurium.svg';
  static const String temple_run = 'temple_run.svg';
  static const String tempmonitor = 'tempmonitor.svg';
  static const String tempusromanum = 'tempusromanum.svg';
  static const String tenacity = 'tenacity.svg';
  static const String tenbitclockwidget = 'tenbitclockwidget.svg';
  static const String tenki_jp = 'tenki_jp.svg';
  static const String tenshi = 'tenshi.svg';
  static const String tentenklooni = 'tentenklooni.svg';
  static const String teoritentamen = 'teoritentamen.svg';
  static const String terminal = 'terminal.svg';
  static const String terminightor = 'terminightor.svg';
  static const String termius = 'termius.svg';
  static const String termux = 'termux.svg';
  static const String terraria = 'terraria.svg';
  static const String tescomobile = 'tescomobile.svg';
  static const String tether = 'tether.svg';
  static const String tetris = 'tetris.svg';
  static const String text_repeater = 'text_repeater.svg';
  static const String textfairy = 'textfairy.svg';
  static const String textra = 'textra.svg';
  static const String tfiletransfer = 'tfiletransfer.svg';
  static const String thalia = 'thalia.svg';
  static const String the_kana_quiz = 'the_kana_quiz.svg';
  static const String the_light = 'the_light.svg';
  static const String the_wolfs_stash = 'the_wolfs_stash.svg';
  static const String theants = 'theants.svg';
  static const String thebattlecats = 'thebattlecats.svg';
  static const String thehindu = 'thehindu.svg';
  static const String thelife = 'thelife.svg';
  static const String themes = 'themes.svg';
  static const String therapeer = 'therapeer.svg';
  static const String thermo = 'thermo.svg';
  static const String thermoworks = 'thermoworks.svg';
  static const String theswitch = 'theswitch.svg';
  static const String thinkfree = 'thinkfree.svg';
  static const String third_crisis = 'third_crisis.svg';
  static const String thor = 'thor.svg';
  static const String thorium = 'thorium.svg';
  static const String threedo = 'threedo.svg';
  static const String threema = 'threema.svg';
  static const String thud = 'thud.svg';
  static const String thuisbezorgd = 'thuisbezorgd.svg';
  static const String thunder_vpn = 'thunder_vpn.svg';
  static const String tibackup = 'tibackup.svg';
  static const String tickertape = 'tickertape.svg';
  static const String tickets = 'tickets.svg';
  static const String ticketswap = 'ticketswap.svg';
  static const String tickmate = 'tickmate.svg';
  static const String ticktick = 'ticktick.svg';
  static const String tidal = 'tidal.svg';
  static const String tiddloid = 'tiddloid.svg';
  static const String tides = 'tides.svg';
  static const String tier = 'tier.svg';
  static const String tigps = 'tigps.svg';
  static const String tikkie = 'tikkie.svg';
  static const String tiktok = 'tiktok.svg';
  static const String tim = 'tim.svg';
  static const String timber = 'timber.svg';
  static const String timbre = 'timbre.svg';
  static const String timeclock = 'timeclock.svg';
  static const String timejot = 'timejot.svg';
  static const String timelimit = 'timelimit.svg';
  static const String tinc_app = 'tinc_app.svg';
  static const String tinc = 'tinc.svg';
  static const String tinder = 'tinder.svg';
  static const String tinfoilforfacebook = 'tinfoilforfacebook.svg';
  static const String ting = 'ting.svg';
  static const String tinkoffbiz = 'tinkoffbiz.svg';
  static const String tiny_planet_fx_pro = 'tiny_planet_fx_pro.svg';
  static const String tinybit_alt = 'tinybit_alt.svg';
  static const String tinybit = 'tinybit.svg';
  static const String tinykeepass = 'tinykeepass.svg';
  static const String tinyscanner = 'tinyscanner.svg';
  static const String tinytinyrss = 'tinytinyrss.svg';
  static const String tinytraveltracker = 'tinytraveltracker.svg';
  static const String tisseo = 'tisseo.svg';
  static const String tk = 'tk.svg';
  static const String tlajoapp = 'tlajoapp.svg';
  static const String tldr = 'tldr.svg';
  static const String tmshappinest = 'tmshappinest.svg';
  static const String to_do = 'to_do.svg';
  static const String tobojapanese = 'tobojapanese.svg';
  static const String todoagenda = 'todoagenda.svg';
  static const String todolist = 'todolist.svg';
  static const String todont = 'todont.svg';
  static const String tokopedia = 'tokopedia.svg';
  static const String tokyootakumode = 'tokyootakumode.svg';
  static const String tolino = 'tolino.svg';
  static const String tomorrow = 'tomorrow.svg';
  static const String tonality = 'tonality.svg';
  static const String tonuino_nfc_tools = 'tonuino_nfc_tools.svg';
  static const String toogoodtogo = 'toogoodtogo.svg';
  static const String toon_blast = 'toon_blast.svg';
  static const String toplogger = 'toplogger.svg';
  static const String torbrowser_alpha = 'torbrowser_alpha.svg';
  static const String torbrowser = 'torbrowser.svg';
  static const String torch = 'torch.svg';
  static const String torchie = 'torchie.svg';
  static const String torguard = 'torguard.svg';
  static const String torque = 'torque.svg';
  static const String torrentsearchsettings = 'torrentsearchsettings.svg';
  static const String torservices = 'torservices.svg';
  static const String tosca = 'tosca.svg';
  static const String totalcommander = 'totalcommander.svg';
  static const String totallauncher = 'totallauncher.svg';
  static const String touhou_danmaku_kagura = 'touhou_danmaku_kagura.svg';
  static const String towercollector = 'towercollector.svg';
  static const String towerjumper = 'towerjumper.svg';
  static const String toya_go = 'toya_go.svg';
  static const String tpmifi = 'tpmifi.svg';
  static const String trabeepocket = 'trabeepocket.svg';
  static const String traccarclient = 'traccarclient.svg';
  static const String trackbook = 'trackbook.svg';
  static const String trackercontrol = 'trackercontrol.svg';
  static const String trackgraph = 'trackgraph.svg';
  static const String trackworktime = 'trackworktime.svg';
  static const String traderepublic = 'traderepublic.svg';
  static const String tradingview_alt = 'tradingview_alt.svg';
  static const String tradingview = 'tradingview.svg';
  static const String trailsense = 'trailsense.svg';
  static const String trainasone = 'trainasone.svg';
  static const String traingo = 'traingo.svg';
  static const String trainline = 'trainline.svg';
  static const String transcriber = 'transcriber.svg';
  static const String transdroid = 'transdroid.svg';
  static const String transfer = 'transfer.svg';
  static const String transistor = 'transistor.svg';
  static const String transit = 'transit.svg';
  static const String transitnow = 'transitnow.svg';
  static const String translate = 'translate.svg';
  static const String translator_cs_fr = 'translator_cs_fr.svg';
  static const String transmission = 'transmission.svg';
  static const String transport = 'transport.svg';
  static const String transportr = 'transportr.svg';
  static const String trcamera = 'trcamera.svg';
  static const String trebleshot = 'trebleshot.svg';
  static const String trello = 'trello.svg';
  static const String tremotesf = 'tremotesf.svg';
  static const String trenit = 'trenit.svg';
  static const String trenord = 'trenord.svg';
  static const String tresorit = 'tresorit.svg';
  static const String trexrunner = 'trexrunner.svg';
  static const String tri_rose = 'tri_rose.svg';
  static const String tricount = 'tricount.svg';
  static const String trifa = 'trifa.svg';
  static const String trigger = 'trigger.svg';
  static const String trilium_sender = 'trilium_sender.svg';
  static const String trime = 'trime.svg';
  static const String triodos_bank = 'triodos_bank.svg';
  static const String tripviatours = 'tripviatours.svg';
  static const String trivago = 'trivago.svg';
  static const String trufi = 'trufi.svg';
  static const String truist = 'truist.svg';
  static const String trussme = 'trussme.svg';
  static const String trustmanager = 'trustmanager.svg';
  static const String tsacdop = 'tsacdop.svg';
  static const String tsb = 'tsb.svg';
  static const String tsuki_odyssey = 'tsuki_odyssey.svg';
  static const String tsumugi = 'tsumugi.svg';
  static const String tubemate = 'tubemate.svg';
  static const String tui = 'tui.svg';
  static const String tumblr = 'tumblr.svg';
  static const String tunein_radio = 'tunein_radio.svg';
  static const String tuner_2 = 'tuner_2.svg';
  static const String tuner = 'tuner.svg';
  static const String tunerly = 'tunerly.svg';
  static const String turingmachine = 'turingmachine.svg';
  static const String turk_telekom = 'turk_telekom.svg';
  static const String turn_me_on = 'turn_me_on.svg';
  static const String turtl = 'turtl.svg';
  static const String tusky_alt = 'tusky_alt.svg';
  static const String tusky = 'tusky.svg';
  static const String tutanota = 'tutanota.svg';
  static const String tuxguitar = 'tuxguitar.svg';
  static const String tuxrider = 'tuxrider.svg';
  static const String tv_browser_updateplugin = 'tv_browser_updateplugin.svg';
  static const String tv_browser = 'tv_browser.svg';
  static const String tv = 'tv.svg';
  static const String tvkill = 'tvkill.svg';
  static const String tvtime = 'tvtime.svg';
  static const String twidere = 'twidere.svg';
  static const String twilight = 'twilight.svg';
  static const String twint = 'twint.svg';
  static const String twire = 'twire.svg';
  static const String twist = 'twist.svg';
  static const String twistytimer = 'twistytimer.svg';
  static const String twitch = 'twitch.svg';
  static const String twitlatte = 'twitlatte.svg';
  static const String twitter = 'twitter.svg';
  static const String twodots = 'twodots.svg';
  static const String twrp = 'twrp.svg';
  static const String tydom = 'tydom.svg';
  static const String typinghero = 'typinghero.svg';
  static const String uae4all2 = 'uae4all2.svg';
  static const String uae4arm = 'uae4arm.svg';
  static const String uae4droid = 'uae4droid.svg';
  static const String ub_smart_bus = 'ub_smart_bus.svg';
  static const String uber_driver = 'uber_driver.svg';
  static const String uber = 'uber.svg';
  static const String ubereats = 'ubereats.svg';
  static const String ubikitouch = 'ubikitouch.svg';
  static const String ubisoft_connect = 'ubisoft_connect.svg';
  static const String ubybbt = 'ubybbt.svg';
  static const String uchealth = 'uchealth.svg';
  static const String udeapp = 'udeapp.svg';
  static const String udemy = 'udemy.svg';
  static const String ukraine_alarm = 'ukraine_alarm.svg';
  static const String ukw_radio = 'ukw_radio.svg';
  static const String ulogger = 'ulogger.svg';
  static const String ultimate_software = 'ultimate_software.svg';
  static const String ultrasonic = 'ultrasonic.svg';
  static const String umath = 'umath.svg';
  static const String umbrella = 'umbrella.svg';
  static const String unab = 'unab.svg';
  static const String unacademy = 'unacademy.svg';
  static const String unchained = 'unchained.svg';
  static const String unciv = 'unciv.svg';
  static const String underhand = 'underhand.svg';
  static const String underlords = 'underlords.svg';
  static const String unicodepad = 'unicodepad.svg';
  static const String unieuro = 'unieuro.svg';
  static const String unifi_network = 'unifi_network.svg';
  static const String unifi_protect = 'unifi_protect.svg';
  static const String unified_remote = 'unified_remote.svg';
  static const String unifiednlp = 'unifiednlp.svg';
  static const String unimainz = 'unimainz.svg';
  static const String unipatcher = 'unipatcher.svg';
  static const String unitconverterultimate = 'unitconverterultimate.svg';
  static const String units = 'units.svg';
  static const String universal_tuner = 'universal_tuner.svg';
  static const String universalcopy = 'universalcopy.svg';
  static const String unlauncher = 'unlauncher.svg';
  static const String unpuzzler = 'unpuzzler.svg';
  static const String unscripted = 'unscripted.svg';
  static const String unseen_gallery = 'unseen_gallery.svg';
  static const String unstoppable = 'unstoppable.svg';
  static const String untappd = 'untappd.svg';
  static const String untis_mobile = 'untis_mobile.svg';
  static const String untrackme = 'untrackme.svg';
  static const String updeck = 'updeck.svg';
  static const String upgradeall = 'upgradeall.svg';
  static const String uplive = 'uplive.svg';
  static const String uploadgram = 'uploadgram.svg';
  static const String ups = 'ups.svg';
  static const String upscaler = 'upscaler.svg';
  static const String uptimerobot = 'uptimerobot.svg';
  static const String uptodate = 'uptodate.svg';
  static const String ur_quan_masters = 'ur_quan_masters.svg';
  static const String urban_dictionary = 'urban_dictionary.svg';
  static const String urbandroid = 'urbandroid.svg';
  static const String urbansports = 'urbansports.svg';
  static const String urecord = 'urecord.svg';
  static const String urforms = 'urforms.svg';
  static const String urinox = 'urinox.svg';
  static const String url_checker = 'url_checker.svg';
  static const String url_forwarder = 'url_forwarder.svg';
  static const String url_radio = 'url_radio.svg';
  static const String urlsanitizer = 'urlsanitizer.svg';
  static const String usaa = 'usaa.svg';
  static const String usagedirect = 'usagedirect.svg';
  static const String usbkeyboard = 'usbkeyboard.svg';
  static const String usbvendevdatabase = 'usbvendevdatabase.svg';
  static const String user_manual = 'user_manual.svg';
  static const String userland = 'userland.svg';
  static const String utd_rooms = 'utd_rooms.svg';
  static const String utorrent = 'utorrent.svg';
  static const String uuid0xfd6fscanner = 'uuid0xfd6fscanner.svg';
  static const String vacation_days = 'vacation_days.svg';
  static const String valetudocompanion = 'valetudocompanion.svg';
  static const String valkyrieprofile = 'valkyrieprofile.svg';
  static const String vancedmanager = 'vancedmanager.svg';
  static const String vancedmicrogsettings = 'vancedmicrogsettings.svg';
  static const String vanillamusic = 'vanillamusic.svg';
  static const String varobank = 'varobank.svg';
  static const String vattenfall = 'vattenfall.svg';
  static const String vcmi = 'vcmi.svg';
  static const String vector_camera = 'vector_camera.svg';
  static const String vector = 'vector.svg';
  static const String vectorassetcreator = 'vectorassetcreator.svg';
  static const String vectorifydahome = 'vectorifydahome.svg';
  static const String vectorpinball = 'vectorpinball.svg';
  static const String veganradar = 'veganradar.svg';
  static const String vendora = 'vendora.svg';
  static const String venlow = 'venlow.svg';
  static const String venmo = 'venmo.svg';
  static const String verge = 'verge.svg';
  static const String vernet = 'vernet.svg';
  static const String very = 'very.svg';
  static const String vespucci = 'vespucci.svg';
  static const String vflat = 'vflat.svg';
  static const String vi = 'vi.svg';
  static const String via = 'via.svg';
  static const String vianavigo = 'vianavigo.svg';
  static const String viaplay = 'viaplay.svg';
  static const String viber = 'viber.svg';
  static const String vibrationstest = 'vibrationstest.svg';
  static const String vibrons = 'vibrons.svg';
  static const String vicare = 'vicare.svg';
  static const String victronconnect_alt = 'victronconnect_alt.svg';
  static const String victronconnect = 'victronconnect.svg';
  static const String video = 'video.svg';
  static const String videoland = 'videoland.svg';
  static const String videotranscoder = 'videotranscoder.svg';
  static const String videotvsideview = 'videotvsideview.svg';
  static const String vidyoconnect = 'vidyoconnect.svg';
  static const String vigilante = 'vigilante.svg';
  static const String vimeo = 'vimeo.svg';
  static const String vinted = 'vinted.svg';
  static const String vinyl = 'vinyl.svg';
  static const String vip_access = 'vip_access.svg';
  static const String viper = 'viper.svg';
  static const String vipps = 'vipps.svg';
  static const String virginmoney = 'virginmoney.svg';
  static const String virtuosity = 'virtuosity.svg';
  static const String viruswar = 'viruswar.svg';
  static const String visecaone = 'visecaone.svg';
  static const String vivaldi_snapshot = 'vivaldi_snapshot.svg';
  static const String vivaldi = 'vivaldi.svg';
  static const String vivint = 'vivint.svg';
  static const String vivo_appstore = 'vivo_appstore.svg';
  static const String vivo_cloud = 'vivo_cloud.svg';
  static const String vivo_i_manager = 'vivo_i_manager.svg';
  static const String vivo_tips = 'vivo_tips.svg';
  static const String vivo_vivo = 'vivo_vivo.svg';
  static const String vivocom = 'vivocom.svg';
  static const String vk = 'vk.svg';
  static const String vklass = 'vklass.svg';
  static const String vlc = 'vlc.svg';
  static const String vln = 'vln.svg';
  static const String vmall = 'vmall.svg';
  static const String vncviewer = 'vncviewer.svg';
  static const String voice_access = 'voice_access.svg';
  static const String voice = 'voice.svg';
  static const String voicemail_alt = 'voicemail_alt.svg';
  static const String voicemail = 'voicemail.svg';
  static const String volkskrant = 'volkskrant.svg';
  static const String volumio = 'volumio.svg';
  static const String volunteer_exchange = 'volunteer_exchange.svg';
  static const String voteinfo = 'voteinfo.svg';
  static const String vouchervault = 'vouchervault.svg';
  static const String vpnh = 'vpnh.svg';
  static const String vpnhotspot = 'vpnhotspot.svg';
  static const String vr_offshore = 'vr_offshore.svg';
  static const String vradio = 'vradio.svg';
  static const String vrbankingclassic = 'vrbankingclassic.svg';
  static const String vrnetarif = 'vrnetarif.svg';
  static const String vrsecuregoplus = 'vrsecuregoplus.svg';
  static const String vrv = 'vrv.svg';
  static const String vsco = 'vsco.svg';
  static const String vsim = 'vsim.svg';
  static const String vsttrafik = 'vsttrafik.svg';
  static const String vuetube = 'vuetube.svg';
  static const String vytal = 'vytal.svg';
  static const String wachatviewer = 'wachatviewer.svg';
  static const String waistline = 'waistline.svg';
  static const String wakeonlan = 'wakeonlan.svg';
  static const String waking_up = 'waking_up.svg';
  static const String walkr = 'walkr.svg';
  static const String wallabagger = 'wallabagger.svg';
  static const String wallet = 'wallet.svg';
  static const String walletcount = 'walletcount.svg';
  static const String wallpaperchangerforreddit = 'wallpaperchangerforreddit.svg';
  static const String wallpaperengine = 'wallpaperengine.svg';
  static const String wallpapers = 'wallpapers.svg';
  static const String wallth = 'wallth.svg';
  static const String walmart = 'walmart.svg';
  static const String wand = 'wand.svg';
  static const String warden = 'warden.svg';
  static const String wardencam = 'wardencam.svg';
  static const String warnwetter = 'warnwetter.svg';
  static const String warpinator = 'warpinator.svg';
  static const String warszawskie_zlobki = 'warszawskie_zlobki.svg';
  static const String watchcheck = 'watchcheck.svg';
  static const String watchmaker = 'watchmaker.svg';
  static const String waterdrinkreminder = 'waterdrinkreminder.svg';
  static const String watertracker = 'watertracker.svg';
  static const String watomatic = 'watomatic.svg';
  static const String wattpad = 'wattpad.svg';
  static const String wavelet = 'wavelet.svg';
  static const String waves = 'waves.svg';
  static const String waveup = 'waveup.svg';
  static const String way = 'way.svg';
  static const String waze = 'waze.svg';
  static const String wazirx = 'wazirx.svg';
  static const String wdbible = 'wdbible.svg';
  static const String we_share = 'we_share.svg';
  static const String weareone = 'weareone.svg';
  static const String wearos = 'wearos.svg';
  static const String weather_forecast = 'weather_forecast.svg';
  static const String weather = 'weather.svg';
  static const String weathercan = 'weathercan.svg';
  static const String weawow = 'weawow.svg';
  static const String web_inspector_fork = 'web_inspector_fork.svg';
  static const String webapps = 'webapps.svg';
  static const String webmediashare = 'webmediashare.svg';
  static const String webopac = 'webopac.svg';
  static const String websitemonitor = 'websitemonitor.svg';
  static const String webtoon = 'webtoon.svg';
  static const String webtube = 'webtube.svg';
  static const String webvideocaster = 'webvideocaster.svg';
  static const String wechat = 'wechat.svg';
  static const String weechat = 'weechat.svg';
  static const String weex = 'weex.svg';
  static const String wells_fargo = 'wells_fargo.svg';
  static const String weread = 'weread.svg';
  static const String weshare = 'weshare.svg';
  static const String westjet = 'westjet.svg';
  static const String wetteronline = 'wetteronline.svg';
  static const String wger = 'wger.svg';
  static const String wggesucht = 'wggesucht.svg';
  static const String what3words = 'what3words.svg';
  static const String whats_up = 'whats_up.svg';
  static const String whatsapp = 'whatsapp.svg';
  static const String whatsappbusiness = 'whatsappbusiness.svg';
  static const String whatsappwebtogo = 'whatsappwebtogo.svg';
  static const String whatsdeleted = 'whatsdeleted.svg';
  static const String whatsnew = 'whatsnew.svg';
  static const String where_is_my_train = 'where_is_my_train.svg';
  static const String whereby = 'whereby.svg';
  static const String whereyougo = 'whereyougo.svg';
  static const String whicons = 'whicons.svg';
  static const String whirlpool = 'whirlpool.svg';
  static const String wi_fi_toolkit = 'wi_fi_toolkit.svg';
  static const String wiebetaaldwat = 'wiebetaaldwat.svg';
  static const String wifi_map = 'wifi_map.svg';
  static const String wifi_monitor_pro = 'wifi_monitor_pro.svg';
  static const String wifi_pro_ftp_server = 'wifi_pro_ftp_server.svg';
  static const String wifi = 'wifi.svg';
  static const String wifianalyzer = 'wifianalyzer.svg';
  static const String wifiautomatic = 'wifiautomatic.svg';
  static const String wifikeyshare = 'wifikeyshare.svg';
  static const String wifikeyview = 'wifikeyview.svg';
  static const String wifiprivacy = 'wifiprivacy.svg';
  static const String wifitransfer = 'wifitransfer.svg';
  static const String wigle_wifi = 'wigle_wifi.svg';
  static const String wikipedia = 'wikipedia.svg';
  static const String willhaben = 'willhaben.svg';
  static const String willyweather = 'willyweather.svg';
  static const String wilma = 'wilma.svg';
  static const String winbank = 'winbank.svg';
  static const String windscribevpn = 'windscribevpn.svg';
  static const String windy = 'windy.svg';
  static const String wire_flow = 'wire_flow.svg';
  static const String wire = 'wire.svg';
  static const String wireguard = 'wireguard.svg';
  static const String wise = 'wise.svg';
  static const String wiseradar = 'wiseradar.svg';
  static const String wisetimer = 'wisetimer.svg';
  static const String wish = 'wish.svg';
  static const String wiwinsafekeeping = 'wiwinsafekeeping.svg';
  static const String wlanscanner = 'wlanscanner.svg';
  static const String wled = 'wled.svg';
  static const String wo_mic = 'wo_mic.svg';
  static const String wolframalpha = 'wolframalpha.svg';
  static const String wonerujo = 'wonerujo.svg';
  static const String wordfeud = 'wordfeud.svg';
  static const String wordoftheday = 'wordoftheday.svg';
  static const String wordpress = 'wordpress.svg';
  static const String wordreference = 'wordreference.svg';
  static const String wordweb = 'wordweb.svg';
  static const String workouttime = 'workouttime.svg';
  static const String workplace = 'workplace.svg';
  static const String worktimer = 'worktimer.svg';
  static const String worldexplorers = 'worldexplorers.svg';
  static const String wormhole_william = 'wormhole_william.svg';
  static const String worterbuch = 'worterbuch.svg';
  static const String wot_compendium_unofficial = 'wot_compendium_unofficial.svg';
  static const String wovietv = 'wovietv.svg';
  static const String wpgen = 'wpgen.svg';
  static const String wpsoffice = 'wpsoffice.svg';
  static const String writeilypro = 'writeilypro.svg';
  static const String wrong_pin_shutdown = 'wrong_pin_shutdown.svg';
  static const String wrotto = 'wrotto.svg';
  static const String wsj = 'wsj.svg';
  static const String wtmp = 'wtmp.svg';
  static const String wulkanowy = 'wulkanowy.svg';
  static const String wunderground = 'wunderground.svg';
  static const String wunderlist = 'wunderlist.svg';
  static const String wx = 'wx.svg';
  static const String wynk_music = 'wynk_music.svg';
  static const String wyze = 'wyze.svg';
  static const String x_plore = 'x_plore.svg';
  static const String x_server = 'x_server.svg';
  static const String xabber = 'xabber.svg';
  static const String xbox = 'xbox.svg';
  static const String xbrowsersync = 'xbrowsersync.svg';
  static const String xclipper = 'xclipper.svg';
  static const String xdadevelopers = 'xdadevelopers.svg';
  static const String xdalabs = 'xdalabs.svg';
  static const String xeonjia = 'xeonjia.svg';
  static const String xiaomiwear = 'xiaomiwear.svg';
  static const String xiaoyuan_search = 'xiaoyuan_search.svg';
  static const String xingse = 'xingse.svg';
  static const String xkcd = 'xkcd.svg';
  static const String xkcdviewer = 'xkcdviewer.svg';
  static const String xmanager = 'xmanager.svg';
  static const String xododocs = 'xododocs.svg';
  static const String xperiaassist = 'xperiaassist.svg';
  static const String xposed_alt = 'xposed_alt.svg';
  static const String xposed = 'xposed.svg';
  static const String xprivacy = 'xprivacy.svg';
  static const String xscreensaver = 'xscreensaver.svg';
  static const String xstation = 'xstation.svg';
  static const String yaata = 'yaata.svg';
  static const String yaauto = 'yaauto.svg';
  static const String yadrive = 'yadrive.svg';
  static const String yaeda = 'yaeda.svg';
  static const String yahoo_mail = 'yahoo_mail.svg';
  static const String yalp = 'yalp.svg';
  static const String yamaps = 'yamaps.svg';
  static const String yamusic = 'yamusic.svg';
  static const String yanavi = 'yanavi.svg';
  static const String yandex_keyboard = 'yandex_keyboard.svg';
  static const String yasnac = 'yasnac.svg';
  static const String yatse = 'yatse.svg';
  static const String yaweather = 'yaweather.svg';
  static const String yelp = 'yelp.svg';
  static const String yetanothercallblocker = 'yetanothercallblocker.svg';
  static const String yetanothervideoplayer = 'yetanothervideoplayer.svg';
  static const String ynab = 'ynab.svg';
  static const String yoga = 'yoga.svg';
  static const String yoke = 'yoke.svg';
  static const String yono_lite_sbi = 'yono_lite_sbi.svg';
  static const String yono_sbi = 'yono_sbi.svg';
  static const String youcutvideoeditor = 'youcutvideoeditor.svg';
  static const String youdao_note = 'youdao_note.svg';
  static const String yourbatterydrainer = 'yourbatterydrainer.svg';
  static const String yourhour = 'yourhour.svg';
  static const String yourlocalweather = 'yourlocalweather.svg';
  static const String yourphone = 'yourphone.svg';
  static const String youtube_downloader = 'youtube_downloader.svg';
  static const String youtube_kids = 'youtube_kids.svg';
  static const String youtube_music = 'youtube_music.svg';
  static const String youtube_studio = 'youtube_studio.svg';
  static const String youtube_vanced = 'youtube_vanced.svg';
  static const String youtube = 'youtube.svg';
  static const String yr = 'yr.svg';
  static const String ytaxi = 'ytaxi.svg';
  static const String yubico_authenticator = 'yubico_authenticator.svg';
  static const String yuito = 'yuito.svg';
  static const String yuka = 'yuka.svg';
  static const String zahler = 'zahler.svg';
  static const String zalando = 'zalando.svg';
  static const String zalo = 'zalo.svg';
  static const String zalopay = 'zalopay.svg';
  static const String zap = 'zap.svg';
  static const String zapp = 'zapp.svg';
  static const String zapya_go = 'zapya_go.svg';
  static const String zarchiver = 'zarchiver.svg';
  static const String zdfheute = 'zdfheute.svg';
  static const String zdfmediathek = 'zdfmediathek.svg';
  static const String zdict = 'zdict.svg';
  static const String zedge = 'zedge.svg';
  static const String zee5 = 'zee5.svg';
  static const String zepp = 'zepp.svg';
  static const String zeronet = 'zeronet.svg';
  static const String zerotier_one = 'zerotier_one.svg';
  static const String zfont = 'zfont.svg';
  static const String zhed = 'zhed.svg';
  static const String zhejiang_liban = 'zhejiang_liban.svg';
  static const String zhihu = 'zhihu.svg';
  static const String zhihuishu_treenity = 'zhihuishu_treenity.svg';
  static const String zipme = 'zipme.svg';
  static const String zlib = 'zlib.svg';
  static const String zmninja = 'zmninja.svg';
  static const String znanylekarz = 'znanylekarz.svg';
  static const String zoho_projects = 'zoho_projects.svg';
  static const String zoho_workdrive = 'zoho_workdrive.svg';
  static const String zohomail = 'zohomail.svg';
  static const String zomato = 'zomato.svg';
  static const String zombieville = 'zombieville.svg';
  static const String zonky = 'zonky.svg';
  static const String zooforzotero = 'zooforzotero.svg';
  static const String zoom = 'zoom.svg';
  static const String zoysii = 'zoysii.svg';
  static const String zulip = 'zulip.svg';
  static const String zvvfahrplan = 'zvvfahrplan.svg';
  static const String zwart = 'zwart.svg';
  static const String zwift = 'zwift.svg';
  static const String zxtune = 'zxtune.svg';
}
